/* Generated by Cython 0.29.7 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_TRACE", 
                "1"
            ]
        ], 
        "depends": [], 
        "name": "ttygif.tty.viewer", 
        "sources": [
            "./ttygif/tty/viewer.pyx"
        ]
    }, 
    "module_name": "ttygif.tty.viewer"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_7"
#define CYTHON_HEX_VERSION 0x001D07F0
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
  #define PyObject_Unicode             PyObject_Str
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : (Py_INCREF(func), func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__ttygif__tty__viewer
#define __PYX_HAVE_API__ttygif__tty__viewer
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "pythread.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "ttygif/tty/viewer.pyx",
  "stringsource",
  "array.pxd",
  "type.pxd",
  "bool.pxd",
  "complex.pxd",
  "ttygif/tty/font.pxd",
};

/*--- Type declarations ---*/
#ifndef _ARRAYARRAY_H
struct arrayobject;
typedef struct arrayobject arrayobject;
#endif
struct __pyx_obj_6ttygif_3tty_4font_font_map;
struct __pyx_obj_6ttygif_3tty_6viewer_viewer;
struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence;
struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr;
struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr;

/* "font.pxd":5
 * 
 * 
 * cdef class font_map:             # <<<<<<<<<<<<<<
 * 
 *     cdef str        name
 */
struct __pyx_obj_6ttygif_3tty_4font_font_map {
  PyObject_HEAD
  PyObject *name;
  int chars_per_line;
  int lines;
  int width;
  int height;
  int font_width;
  int font_height;
  int spacing_x;
  int spacing_y;
  int offset_x;
  int offset_y;
  arrayobject *color_table;
  int transparent;
  arrayobject *graphic;
};


/* "ttygif/tty/viewer.pyx":17
 * 
 * 
 * cdef class viewer:             # <<<<<<<<<<<<<<
 *     cdef public object          last_timestamp
 *     cdef public int             viewport_px_width
 */
struct __pyx_obj_6ttygif_3tty_6viewer_viewer {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *__pyx_vtab;
  PyObject *last_timestamp;
  int viewport_px_width;
  int viewport_px_height;
  int viewport_char_height;
  int viewport_char_width;
  int viewport_char_stride;
  int background_color;
  int foreground_color;
  PyObject *window_style;
  PyObject *stream;
  int video_length;
  arrayobject *video;
  PyObject *color_table;
  arrayobject *buffer;
  int buffer_rows;
  PyObject *debug_mode;
  PyObject *sequence;
  PyObject *sequence_pos;
  int x;
  int y;
  int def_fg;
  int def_bg;
  int fg;
  int bg;
  PyObject *reverse_video;
  PyObject *bold;
  PyObject *extra_text;
};


/* "ttygif/tty/viewer.pyx":631
 * 
 * 
 *     cdef stream_2_sequence(self,text,timestamp,delay):             # <<<<<<<<<<<<<<
 * 
 *         # patterns for filtering out commands from the stream
 */
struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence {
  PyObject_HEAD
  PyObject *__pyx_v_paramstring;
};


/* "ttygif/tty/viewer.pyx":682
 *                 command=groups[10]
 *                 if command in 'Hf':
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))             # <<<<<<<<<<<<<<
 *                     while len(params) < 2:
 *                         params = params + (1,)
 */
struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *__pyx_outer_scope;
  PyObject *__pyx_v_p;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "ttygif/tty/viewer.pyx":690
 *                 else:
 * 
 *                     params = tuple(int(p) for p in paramstring.split(';') if len(p) != 0)             # <<<<<<<<<<<<<<
 *                     if len(params) == 0:
 *                         if command in 'JKm':
 */
struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *__pyx_outer_scope;
  PyObject *__pyx_v_p;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};



/* "ttygif/tty/viewer.pyx":17
 * 
 * 
 * cdef class viewer:             # <<<<<<<<<<<<<<
 *     cdef public object          last_timestamp
 *     cdef public int             viewport_px_width
 */

struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer {
  PyObject *(*ascii_safe)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *);
  PyObject *(*info)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *);
  PyObject *(*new_char_buffer)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *);
  PyObject *(*new_video_buffer)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *);
  PyObject *(*draw_character3)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, int, int, int, int, int, int);
  PyObject *(*get_buffer_height)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *);
  PyObject *(*debug)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *);
  PyObject *(*shift_buffer)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, arrayobject *);
  PyObject *(*write_buffer)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, int, int, int, arrayobject *);
  PyObject *(*sequence_to_buffer)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *);
  PyObject *(*stream_2_sequence)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *, PyObject *, PyObject *);
  PyObject *(*remap_character)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *);
  PyObject *(*save_screen)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *);
};
static struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *__pyx_vtabptr_6ttygif_3tty_6viewer_viewer;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* Profile.proto */
#ifndef CYTHON_PROFILE
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
  #define CYTHON_PROFILE 0
#else
  #define CYTHON_PROFILE 1
#endif
#endif
#ifndef CYTHON_TRACE_NOGIL
  #define CYTHON_TRACE_NOGIL 0
#else
  #if CYTHON_TRACE_NOGIL && !defined(CYTHON_TRACE)
    #define CYTHON_TRACE 1
  #endif
#endif
#ifndef CYTHON_TRACE
  #define CYTHON_TRACE 0
#endif
#if CYTHON_TRACE
  #undef CYTHON_PROFILE_REUSE_FRAME
#endif
#ifndef CYTHON_PROFILE_REUSE_FRAME
  #define CYTHON_PROFILE_REUSE_FRAME 0
#endif
#if CYTHON_PROFILE || CYTHON_TRACE
  #include "compile.h"
  #include "frameobject.h"
  #include "traceback.h"
  #if CYTHON_PROFILE_REUSE_FRAME
    #define CYTHON_FRAME_MODIFIER static
    #define CYTHON_FRAME_DEL(frame)
  #else
    #define CYTHON_FRAME_MODIFIER
    #define CYTHON_FRAME_DEL(frame) Py_CLEAR(frame)
  #endif
  #define __Pyx_TraceDeclarations\
  static PyCodeObject *__pyx_frame_code = NULL;\
  CYTHON_FRAME_MODIFIER PyFrameObject *__pyx_frame = NULL;\
  int __Pyx_use_tracing = 0;
  #define __Pyx_TraceFrameInit(codeobj)\
  if (codeobj) __pyx_frame_code = (PyCodeObject*) codeobj;
  #ifdef WITH_THREAD
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)\
  if (nogil) {\
      if (CYTHON_TRACE_NOGIL) {\
          PyThreadState *tstate;\
          PyGILState_STATE state = PyGILState_Ensure();\
          tstate = __Pyx_PyThreadState_Current;\
          if (unlikely(tstate->use_tracing) && !tstate->tracing &&\
                  (tstate->c_profilefunc || (CYTHON_TRACE && tstate->c_tracefunc))) {\
              __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          }\
          PyGILState_Release(state);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  } else {\
      PyThreadState* tstate = PyThreadState_GET();\
      if (unlikely(tstate->use_tracing) && !tstate->tracing &&\
              (tstate->c_profilefunc || (CYTHON_TRACE && tstate->c_tracefunc))) {\
          __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  }
  #else
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)\
  {   PyThreadState* tstate = PyThreadState_GET();\
      if (unlikely(tstate->use_tracing) && !tstate->tracing &&\
              (tstate->c_profilefunc || (CYTHON_TRACE && tstate->c_tracefunc))) {\
          __Pyx_use_tracing = __Pyx_TraceSetupAndCall(&__pyx_frame_code, &__pyx_frame, tstate, funcname, srcfile, firstlineno);\
          if (unlikely(__Pyx_use_tracing < 0)) goto_error;\
      }\
  }
  #endif
  #define __Pyx_TraceException()\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (tstate->use_tracing &&\
              (tstate->c_profilefunc || (CYTHON_TRACE && tstate->c_tracefunc))) {\
          tstate->tracing++;\
          tstate->use_tracing = 0;\
          PyObject *exc_info = __Pyx_GetExceptionTuple(tstate);\
          if (exc_info) {\
              if (CYTHON_TRACE && tstate->c_tracefunc)\
                  tstate->c_tracefunc(\
                      tstate->c_traceobj, __pyx_frame, PyTrace_EXCEPTION, exc_info);\
              tstate->c_profilefunc(\
                  tstate->c_profileobj, __pyx_frame, PyTrace_EXCEPTION, exc_info);\
              Py_DECREF(exc_info);\
          }\
          tstate->use_tracing = 1;\
          tstate->tracing--;\
      }\
  }
  static void __Pyx_call_return_trace_func(PyThreadState *tstate, PyFrameObject *frame, PyObject *result) {
      PyObject *type, *value, *traceback;
      __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
      tstate->tracing++;
      tstate->use_tracing = 0;
      if (CYTHON_TRACE && tstate->c_tracefunc)
          tstate->c_tracefunc(tstate->c_traceobj, frame, PyTrace_RETURN, result);
      if (tstate->c_profilefunc)
          tstate->c_profilefunc(tstate->c_profileobj, frame, PyTrace_RETURN, result);
      CYTHON_FRAME_DEL(frame);
      tstate->use_tracing = 1;
      tstate->tracing--;
      __Pyx_ErrRestoreInState(tstate, type, value, traceback);
  }
  #ifdef WITH_THREAD
  #define __Pyx_TraceReturn(result, nogil)\
  if (likely(!__Pyx_use_tracing)); else {\
      if (nogil) {\
          if (CYTHON_TRACE_NOGIL) {\
              PyThreadState *tstate;\
              PyGILState_STATE state = PyGILState_Ensure();\
              tstate = __Pyx_PyThreadState_Current;\
              if (tstate->use_tracing) {\
                  __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
              }\
              PyGILState_Release(state);\
          }\
      } else {\
          PyThreadState* tstate = __Pyx_PyThreadState_Current;\
          if (tstate->use_tracing) {\
              __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
          }\
      }\
  }
  #else
  #define __Pyx_TraceReturn(result, nogil)\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (tstate->use_tracing) {\
          __Pyx_call_return_trace_func(tstate, __pyx_frame, (PyObject*)result);\
      }\
  }
  #endif
  static PyCodeObject *__Pyx_createFrameCodeObject(const char *funcname, const char *srcfile, int firstlineno);
  static int __Pyx_TraceSetupAndCall(PyCodeObject** code, PyFrameObject** frame, PyThreadState* tstate, const char *funcname, const char *srcfile, int firstlineno);
#else
  #define __Pyx_TraceDeclarations
  #define __Pyx_TraceFrameInit(codeobj)
  #define __Pyx_TraceCall(funcname, srcfile, firstlineno, nogil, goto_error)   if ((1)); else goto_error;
  #define __Pyx_TraceException()
  #define __Pyx_TraceReturn(result, nogil)
#endif
#if CYTHON_TRACE
  static int __Pyx_call_line_trace_func(PyThreadState *tstate, PyFrameObject *frame, int lineno) {
      int ret;
      PyObject *type, *value, *traceback;
      __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
      __Pyx_PyFrame_SetLineNumber(frame, lineno);
      tstate->tracing++;
      tstate->use_tracing = 0;
      ret = tstate->c_tracefunc(tstate->c_traceobj, frame, PyTrace_LINE, NULL);
      tstate->use_tracing = 1;
      tstate->tracing--;
      if (likely(!ret)) {
          __Pyx_ErrRestoreInState(tstate, type, value, traceback);
      } else {
          Py_XDECREF(type);
          Py_XDECREF(value);
          Py_XDECREF(traceback);
      }
      return ret;
  }
  #ifdef WITH_THREAD
  #define __Pyx_TraceLine(lineno, nogil, goto_error)\
  if (likely(!__Pyx_use_tracing)); else {\
      if (nogil) {\
          if (CYTHON_TRACE_NOGIL) {\
              int ret = 0;\
              PyThreadState *tstate;\
              PyGILState_STATE state = PyGILState_Ensure();\
              tstate = __Pyx_PyThreadState_Current;\
              if (unlikely(tstate->use_tracing && tstate->c_tracefunc && __pyx_frame->f_trace)) {\
                  ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
              }\
              PyGILState_Release(state);\
              if (unlikely(ret)) goto_error;\
          }\
      } else {\
          PyThreadState* tstate = __Pyx_PyThreadState_Current;\
          if (unlikely(tstate->use_tracing && tstate->c_tracefunc && __pyx_frame->f_trace)) {\
              int ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
              if (unlikely(ret)) goto_error;\
          }\
      }\
  }
  #else
  #define __Pyx_TraceLine(lineno, nogil, goto_error)\
  if (likely(!__Pyx_use_tracing)); else {\
      PyThreadState* tstate = __Pyx_PyThreadState_Current;\
      if (unlikely(tstate->use_tracing && tstate->c_tracefunc && __pyx_frame->f_trace)) {\
          int ret = __Pyx_call_line_trace_func(tstate, __pyx_frame, lineno);\
          if (unlikely(ret)) goto_error;\
      }\
  }
  #endif
#else
  #define __Pyx_TraceLine(lineno, nogil, goto_error)   if ((1)); else goto_error;
#endif

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION < 3
    #define __Pyx_PyBytes_Join _PyString_Join
    #else
    #define __Pyx_PyBytes_Join _PyBytes_Join
    #endif
#else
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);
#endif

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* UnicodeAsUCS4.proto */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject*);

/* object_ord.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Ord(c)\
    (likely(PyUnicode_Check(c)) ? (long)__Pyx_PyUnicode_AsPy_UCS4(c) : __Pyx__PyObject_Ord(c))
#else
#define __Pyx_PyObject_Ord(c) __Pyx__PyObject_Ord(c)
#endif
static long __Pyx__PyObject_Ord(PyObject* c);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* None.proto */
static CYTHON_INLINE int __Pyx_div_int(int, int);

/* UnaryNegOverflows.proto */
#define UNARY_NEG_WOULD_OVERFLOW(x)\
        (((x) < 0) & ((unsigned long)(x) == 0-(unsigned long)(x)))

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* None.proto */
static CYTHON_INLINE int __Pyx_mod_int(int, int);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* pop_index.proto */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix);
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix);
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (likely(PyList_CheckExact(L) && __Pyx_fits_Py_ssize_t(ix, type, is_signed))) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    __Pyx_fits_Py_ssize_t(ix, type, is_signed) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#else
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)\
    __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
        __Pyx__PyObject_PopIndex(L, py_ix))
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* ArrayAPI.proto */
#ifndef _ARRAYARRAY_H
#define _ARRAYARRAY_H
typedef struct arraydescr {
    int typecode;
    int itemsize;
    PyObject * (*getitem)(struct arrayobject *, Py_ssize_t);
    int (*setitem)(struct arrayobject *, Py_ssize_t, PyObject *);
#if PY_MAJOR_VERSION >= 3
    char *formats;
#endif
} arraydescr;
struct arrayobject {
    PyObject_HEAD
    Py_ssize_t ob_size;
    union {
        char *ob_item;
        float *as_floats;
        double *as_doubles;
        int *as_ints;
        unsigned int *as_uints;
        unsigned char *as_uchars;
        signed char *as_schars;
        char *as_chars;
        unsigned long *as_ulongs;
        long *as_longs;
#if PY_MAJOR_VERSION >= 3
        unsigned long long *as_ulonglongs;
        long long *as_longlongs;
#endif
        short *as_shorts;
        unsigned short *as_ushorts;
        Py_UNICODE *as_pyunicodes;
        void *as_voidptr;
    } data;
    Py_ssize_t allocated;
    struct arraydescr *ob_descr;
    PyObject *weakreflist;
#if PY_MAJOR_VERSION >= 3
        int ob_exports;
#endif
};
#ifndef NO_NEWARRAY_INLINE
static CYTHON_INLINE PyObject * newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr) {
    arrayobject *op;
    size_t nbytes;
    if (size < 0) {
        PyErr_BadInternalCall();
        return NULL;
    }
    nbytes = size * descr->itemsize;
    if (nbytes / descr->itemsize != (size_t)size) {
        return PyErr_NoMemory();
    }
    op = (arrayobject *) type->tp_alloc(type, 0);
    if (op == NULL) {
        return NULL;
    }
    op->ob_descr = descr;
    op->allocated = size;
    op->weakreflist = NULL;
    op->ob_size = size;
    if (size <= 0) {
        op->data.ob_item = NULL;
    }
    else {
        op->data.ob_item = PyMem_NEW(char, nbytes);
        if (op->data.ob_item == NULL) {
            Py_DECREF(op);
            return PyErr_NoMemory();
        }
    }
    return (PyObject *) op;
}
#else
PyObject* newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr);
#endif
static CYTHON_INLINE int resize(arrayobject *self, Py_ssize_t n) {
    void *items = (void*) self->data.ob_item;
    PyMem_Resize(items, char, (size_t)(n * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    self->ob_size = n;
    self->allocated = n;
    return 0;
}
static CYTHON_INLINE int resize_smart(arrayobject *self, Py_ssize_t n) {
    void *items = (void*) self->data.ob_item;
    Py_ssize_t newsize;
    if (n < self->allocated && n*4 > self->allocated) {
        self->ob_size = n;
        return 0;
    }
    newsize = n + (n / 2) + 1;
    if (newsize <= n) {
        PyErr_NoMemory();
        return -1;
    }
    PyMem_Resize(items, char, (size_t)(newsize * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    self->ob_size = n;
    self->allocated = newsize;
    return 0;
}
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* Print.proto */
static int __Pyx_Print(PyObject*, PyObject *, int);
#if CYTHON_COMPILING_IN_PYPY || PY_MAJOR_VERSION >= 3
static PyObject* __pyx_print = 0;
static PyObject* __pyx_print_kwargs = 0;
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* PrintOne.proto */
static int __Pyx_PrintOne(PyObject* stream, PyObject *o);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_ascii_safe(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_info(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_new_char_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_new_video_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_draw_character3(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, int __pyx_v_character, int __pyx_v_x, int __pyx_v_y, CYTHON_UNUSED int __pyx_v_offset, int __pyx_v_foreground_color, int __pyx_v_background_color); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_get_buffer_height(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_debug(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_shift_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, arrayobject *__pyx_v_buffer); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_write_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, int __pyx_v_x, int __pyx_v_y, int __pyx_v_c, arrayobject *__pyx_v_buffer); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_sequence_to_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_stream_2_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_timestamp, PyObject *__pyx_v_delay); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_remap_character(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_character); /* proto*/
static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_save_screen(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto*/

/* Module declarations from 'cpython.version' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.exc' */

/* Module declarations from 'cpython.module' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'cpython.tuple' */

/* Module declarations from 'cpython.list' */

/* Module declarations from 'cpython.sequence' */

/* Module declarations from 'cpython.mapping' */

/* Module declarations from 'cpython.iterator' */

/* Module declarations from 'cpython.number' */

/* Module declarations from 'cpython.int' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.bool' */
static PyTypeObject *__pyx_ptype_7cpython_4bool_bool = 0;

/* Module declarations from 'cpython.long' */

/* Module declarations from 'cpython.float' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.complex' */
static PyTypeObject *__pyx_ptype_7cpython_7complex_complex = 0;

/* Module declarations from 'cpython.string' */

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.dict' */

/* Module declarations from 'cpython.instance' */

/* Module declarations from 'cpython.function' */

/* Module declarations from 'cpython.method' */

/* Module declarations from 'cpython.weakref' */

/* Module declarations from 'cpython.getargs' */

/* Module declarations from 'cpython.pythread' */

/* Module declarations from 'cpython.pystate' */

/* Module declarations from 'cpython.cobject' */

/* Module declarations from 'cpython.oldbuffer' */

/* Module declarations from 'cpython.set' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'cpython.pycapsule' */

/* Module declarations from 'cpython' */

/* Module declarations from 'array' */

/* Module declarations from 'cpython.array' */
static PyTypeObject *__pyx_ptype_7cpython_5array_array = 0;
static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_copy(arrayobject *); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *, char *, Py_ssize_t); /*proto*/

/* Module declarations from 'ttygif.tty.font' */
static PyTypeObject *__pyx_ptype_6ttygif_3tty_4font_font_map = 0;

/* Module declarations from 'ttygif.tty.fonts' */
static struct __pyx_obj_6ttygif_3tty_4font_font_map **__pyx_vp_6ttygif_3tty_5fonts_font = 0;
#define __pyx_v_6ttygif_3tty_5fonts_font (*__pyx_vp_6ttygif_3tty_5fonts_font)

/* Module declarations from 'ttygif.tty.viewer' */
static PyTypeObject *__pyx_ptype_6ttygif_3tty_6viewer_viewer = 0;
static PyTypeObject *__pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence = 0;
static PyTypeObject *__pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr = 0;
static PyTypeObject *__pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr = 0;
static PyObject *__pyx_f_6ttygif_3tty_6viewer___pyx_unpickle_viewer__set_state(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "ttygif.tty.viewer"
extern int __pyx_module_is_main_ttygif__tty__viewer;
int __pyx_module_is_main_ttygif__tty__viewer = 0;

/* Implementation of 'ttygif.tty.viewer' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_unichr;
static PyObject *__pyx_builtin_round;
static PyObject *__pyx_builtin_MemoryError;
static const char __pyx_k_[] = "";
static const char __pyx_k_A[] = "A";
static const char __pyx_k_B[] = "B";
static const char __pyx_k_C[] = "C";
static const char __pyx_k_D[] = "D";
static const char __pyx_k_E[] = "E";
static const char __pyx_k_F[] = "F";
static const char __pyx_k_G[] = "G";
static const char __pyx_k_H[] = "H";
static const char __pyx_k_J[] = "J";
static const char __pyx_k_K[] = "K";
static const char __pyx_k_P[] = "P";
static const char __pyx_k_X[] = "X";
static const char __pyx_k_b[] = "b";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_g[] = "g";
static const char __pyx_k_h[] = "h";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_o[] = "o";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_y[] = "y";
static const char __pyx_k_G0[] = "G0";
static const char __pyx_k_G1[] = "G1";
static const char __pyx_k_Hf[] = "Hf";
static const char __pyx_k__2[] = "*";
static const char __pyx_k__4[] = "\n";
static const char __pyx_k__5[] = "`";
static const char __pyx_k__6[] = ";";
#if PY_MAJOR_VERSION >= 3
static const char __pyx_k__7[] = "(?:\001?\\]|\302\235).*?(?:\001?\\\\|[\007\302\234])";
#endif
#if PY_MAJOR_VERSION < 3
static const char __pyx_k__8[] = "(?:\001?\\]|\235).*?(?:\001?\\\\|[\007\234])";
#endif
static const char __pyx_k__9[] = "(";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_CSI[] = "CSI";
static const char __pyx_k_JKm[] = "JKm";
static const char __pyx_k_OSC[] = "OSC";
static const char __pyx_k__10[] = ")|(";
static const char __pyx_k__11[] = ")";
static const char __pyx_k__13[] = "?";
static const char __pyx_k__16[] = "============";
static const char __pyx_k_b_G[] = "[\001b|\033]\\%([@G*])";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_ABCD[] = "ABCD";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_file[] = "file";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_span[] = "span";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_delay[] = "delay";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_round[] = "round";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_width[] = "width";
static const char __pyx_k_BOTTOM[] = "BOTTOM";
static const char __pyx_k_Buffer[] = "Buffer:";
static const char __pyx_k_SINGLE[] = "SINGLE";
static const char __pyx_k_Set_BG[] = "Set BG";
static const char __pyx_k_Set_FG[] = "Set FG";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_b_B0UK[] = "[\001b|\033]\\(([B0UK])";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_groups[] = "groups";
static const char __pyx_k_height[] = "height";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_params[] = "params";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_unichr[] = "unichr";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_viewer[] = "viewer";
static const char __pyx_k_Count_0[] = "Count:{0}";
static const char __pyx_k_command[] = "command";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_CHAR_SET[] = "CHAR_SET";
static const char __pyx_k_Cursor_X[] = "Cursor X";
static const char __pyx_k_Set_BOLD[] = "Set BOLD";
static const char __pyx_k_VIEWPORT[] = "VIEWPORT:";
static const char __pyx_k_b_B0UK_2[] = "[\001b|\033]\\)([B0UK])";
static const char __pyx_k_esc_type[] = "esc_type";
static const char __pyx_k_finditer[] = "finditer";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_set_mode[] = "set_mode";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_Cursor_Up[] = "Cursor Up";
static const char __pyx_k_RESET_All[] = "RESET All";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_timestamp[] = "timestamp";
static const char __pyx_k_Cursor_Pos[] = "Cursor Pos";
static const char __pyx_k_Erase_Line[] = "Erase Line";
static const char __pyx_k_b_cDEHMZ78[] = "[\001b|\033]([cDEHMZ78>=])";
static const char __pyx_k_b_d_a_zA_Z[] = "[\001b|\033]\\[((?:\\d|;|<|>|=|\\?)*)([a-zA-Z])\002?";
static const char __pyx_k_char_width[] = "char_width";
static const char __pyx_k_has_escape[] = "has_escape";
static const char __pyx_k_px_width_0[] = "  px width:           {0}";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_reset_mode[] = "reset_mode";
static const char __pyx_k_Cursor_Down[] = "Cursor Down";
static const char __pyx_k_Cursor_Left[] = "Cursor Left";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_char_height[] = "char_height";
static const char __pyx_k_color_table[] = "color_table";
static const char __pyx_k_px_height_0[] = "  px height:          {0}";
static const char __pyx_k_Cursor_Right[] = "Cursor Right";
static const char __pyx_k_Erase_Line_0[] = "Erase Line: {0}";
static const char __pyx_k_char_width_0[] = "  char width:         {0}";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_Erase_Display[] = "Erase Display";
static const char __pyx_k_Sequence_List[] = "Sequence List";
static const char __pyx_k_char_height_0[] = "  char height:        {0}";
static const char __pyx_k_char_stride_0[] = "  char stride:        {0}";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_Cursor_Pos_0_1[] = "Cursor Pos:{0},{1}";
static const char __pyx_k_Set_Default_BG[] = "Set Default BG";
static const char __pyx_k_Set_Default_FG[] = "Set Default FG";
static const char __pyx_k_clear_sequence[] = "clear_sequence";
static const char __pyx_k_rgb_to_palette[] = "rgb_to_palette";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_Cursor_Next_Line[] = "Cursor Next Line";
static const char __pyx_k_Reverse_Video_On[] = "Reverse Video On";
static const char __pyx_k_Reverse_Video_Off[] = "Reverse Video Off";
static const char __pyx_k_add_text_sequence[] = "add_text_sequence";
static const char __pyx_k_ttygif_tty_viewer[] = "ttygif.tty.viewer";
static const char __pyx_k_char_buffer_size_0[] = "  char buffer size:   {0}";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_Missing_character_0[] = "Missing character: {0}";
static const char __pyx_k_pyx_unpickle_viewer[] = "__pyx_unpickle_viewer";
static const char __pyx_k_video_buffer_size_0[] = "  video buffer size:  {0}";
static const char __pyx_k_Cursor_Previous_Line[] = "Cursor Previous Line";
static const char __pyx_k_add_command_sequence[] = "add_command_sequence";
static const char __pyx_k_buffer_char_height_0[] = "  buffer char height: {0}";
static const char __pyx_k_Set_High_INTENSITY_BG[] = "Set High INTENSITY BG";
static const char __pyx_k_Set_High_INTENSITY_FG[] = "Set High INTENSITY FG";
static const char __pyx_k_Cursor_X_0_x_1_2_y_2_2[] = "Cursor X:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Set_mode_0_x_1_2_y_2_2[] = "Set mode:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Cursor_Up_0_x_1_2_y_2_2[] = "Cursor Up:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Cursor_X_0_x_1_2_y_2_2_2[] = "Cursor (~) X:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Cursor_d_Y_0_x_1_2_y_2_2[] = "Cursor (d) Y{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Erase_Display_and_buffer[] = "Erase Display and buffer";
static const char __pyx_k_Charactrer_out_of_range_0[] = "Charactrer out of range -{0}";
static const char __pyx_k_Cursor_Down_0_x_1_2_y_2_2[] = "Cursor Down:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Cursor_Left_0_x_1_2_y_2_2[] = "Cursor Left:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Impliment_pos_x_2_Y_3_0_1[] = "Impliment: pos x:{2},Y:{3} - {0}-{1}";
static const char __pyx_k_Cursor_Right_0_x_1_2_y_2_2[] = "Cursor Right:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Erase_Display_cursor_to_end[] = "Erase Display cursor to end";
static const char __pyx_k_Text_0_Length_1_Timestamp_2[] = "Text: '{0}' Length:{1} Timestamp:{2}";
static const char __pyx_k_Erase_Display_top_til_cursor[] = "Erase Display top til cursor";
static const char __pyx_k_X_0_2_1_2_FG_2_2_BG_3_Text_4[] = "X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}";
static const char __pyx_k_Cursor_Next_Line_0_x_1_2_y_2_2[] = "Cursor Next Line:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_CMD_0_Name_3_Command_1_Params_2[] = "CMD:  '{0}', Name:'{3}', Command:{1}, Params:{2}  Timestamp:{4}";
static const char __pyx_k_viewer_stream_2_sequence_locals[] = "viewer.stream_2_sequence.<locals>.genexpr";
static const char __pyx_k_Cursor_Previous_Line_0_x_1_2_y_2[] = "Cursor Previous Line:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Delete_number_of_charchters_on_l[] = "Delete number of charchters on line:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Erase_number_of_charchters_on_li[] = "Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}";
static const char __pyx_k_Incompatible_checksums_s_vs_0x3c[] = "Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))";
static const char __pyx_k_Msg_0_X_1_Y_2_C_3_FG_4_BG_5_Buff[] = "Msg:{0} X:{1},Y:{2},C:{3},FG:{4},BG:{5},Buffer Len:{6}";
static PyObject *__pyx_kp_s_;
static PyObject *__pyx_n_s_A;
static PyObject *__pyx_n_s_ABCD;
static PyObject *__pyx_n_s_B;
static PyObject *__pyx_n_s_BOTTOM;
static PyObject *__pyx_kp_s_Buffer;
static PyObject *__pyx_n_s_C;
static PyObject *__pyx_n_s_CHAR_SET;
static PyObject *__pyx_kp_s_CMD_0_Name_3_Command_1_Params_2;
static PyObject *__pyx_n_s_CSI;
static PyObject *__pyx_kp_s_Charactrer_out_of_range_0;
static PyObject *__pyx_kp_s_Count_0;
static PyObject *__pyx_kp_s_Cursor_Down;
static PyObject *__pyx_kp_s_Cursor_Down_0_x_1_2_y_2_2;
static PyObject *__pyx_kp_s_Cursor_Left;
static PyObject *__pyx_kp_s_Cursor_Left_0_x_1_2_y_2_2;
static PyObject *__pyx_kp_s_Cursor_Next_Line;
static PyObject *__pyx_kp_s_Cursor_Next_Line_0_x_1_2_y_2_2;
static PyObject *__pyx_kp_s_Cursor_Pos;
static PyObject *__pyx_kp_s_Cursor_Pos_0_1;
static PyObject *__pyx_kp_s_Cursor_Previous_Line;
static PyObject *__pyx_kp_s_Cursor_Previous_Line_0_x_1_2_y_2;
static PyObject *__pyx_kp_s_Cursor_Right;
static PyObject *__pyx_kp_s_Cursor_Right_0_x_1_2_y_2_2;
static PyObject *__pyx_kp_s_Cursor_Up;
static PyObject *__pyx_kp_s_Cursor_Up_0_x_1_2_y_2_2;
static PyObject *__pyx_kp_s_Cursor_X;
static PyObject *__pyx_kp_s_Cursor_X_0_x_1_2_y_2_2;
static PyObject *__pyx_kp_s_Cursor_X_0_x_1_2_y_2_2_2;
static PyObject *__pyx_kp_s_Cursor_d_Y_0_x_1_2_y_2_2;
static PyObject *__pyx_n_s_D;
static PyObject *__pyx_kp_s_Delete_number_of_charchters_on_l;
static PyObject *__pyx_n_s_E;
static PyObject *__pyx_kp_s_Erase_Display;
static PyObject *__pyx_kp_s_Erase_Display_and_buffer;
static PyObject *__pyx_kp_s_Erase_Display_cursor_to_end;
static PyObject *__pyx_kp_s_Erase_Display_top_til_cursor;
static PyObject *__pyx_kp_s_Erase_Line;
static PyObject *__pyx_kp_s_Erase_Line_0;
static PyObject *__pyx_kp_s_Erase_number_of_charchters_on_li;
static PyObject *__pyx_n_s_F;
static PyObject *__pyx_n_s_G;
static PyObject *__pyx_n_s_G0;
static PyObject *__pyx_n_s_G1;
static PyObject *__pyx_n_s_H;
static PyObject *__pyx_n_s_Hf;
static PyObject *__pyx_kp_s_Impliment_pos_x_2_Y_3_0_1;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x3c;
static PyObject *__pyx_n_s_J;
static PyObject *__pyx_n_s_JKm;
static PyObject *__pyx_n_s_K;
static PyObject *__pyx_n_s_MemoryError;
static PyObject *__pyx_kp_s_Missing_character_0;
static PyObject *__pyx_kp_s_Msg_0_X_1_Y_2_C_3_FG_4_BG_5_Buff;
static PyObject *__pyx_n_s_OSC;
static PyObject *__pyx_n_s_P;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_kp_s_RESET_All;
static PyObject *__pyx_kp_s_Reverse_Video_Off;
static PyObject *__pyx_kp_s_Reverse_Video_On;
static PyObject *__pyx_n_s_SINGLE;
static PyObject *__pyx_kp_s_Sequence_List;
static PyObject *__pyx_kp_s_Set_BG;
static PyObject *__pyx_kp_s_Set_BOLD;
static PyObject *__pyx_kp_s_Set_Default_BG;
static PyObject *__pyx_kp_s_Set_Default_FG;
static PyObject *__pyx_kp_s_Set_FG;
static PyObject *__pyx_kp_s_Set_High_INTENSITY_BG;
static PyObject *__pyx_kp_s_Set_High_INTENSITY_FG;
static PyObject *__pyx_kp_s_Set_mode_0_x_1_2_y_2_2;
static PyObject *__pyx_kp_s_Text_0_Length_1_Timestamp_2;
static PyObject *__pyx_kp_s_VIEWPORT;
static PyObject *__pyx_n_s_X;
static PyObject *__pyx_kp_u_X_0_2_1_2_FG_2_2_BG_3_Text_4;
static PyObject *__pyx_kp_s__10;
static PyObject *__pyx_kp_s__11;
static PyObject *__pyx_kp_s__13;
static PyObject *__pyx_kp_s__16;
static PyObject *__pyx_kp_s__2;
static PyObject *__pyx_kp_s__4;
static PyObject *__pyx_kp_s__5;
static PyObject *__pyx_kp_s__6;
static PyObject *__pyx_kp_s__8;
static PyObject *__pyx_kp_s__9;
static PyObject *__pyx_n_s_add_command_sequence;
static PyObject *__pyx_n_s_add_text_sequence;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_array;
static PyObject *__pyx_n_s_b;
static PyObject *__pyx_kp_s_b_B0UK;
static PyObject *__pyx_kp_s_b_B0UK_2;
static PyObject *__pyx_kp_s_b_G;
static PyObject *__pyx_kp_s_b_cDEHMZ78;
static PyObject *__pyx_kp_s_b_d_a_zA_Z;
static PyObject *__pyx_kp_s_buffer_char_height_0;
static PyObject *__pyx_kp_s_char_buffer_size_0;
static PyObject *__pyx_n_s_char_height;
static PyObject *__pyx_kp_s_char_height_0;
static PyObject *__pyx_kp_s_char_stride_0;
static PyObject *__pyx_n_s_char_width;
static PyObject *__pyx_kp_s_char_width_0;
static PyObject *__pyx_n_s_clear_sequence;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_color_table;
static PyObject *__pyx_n_s_command;
static PyObject *__pyx_n_s_compile;
static PyObject *__pyx_n_s_d;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_s_delay;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_end;
static PyObject *__pyx_n_s_esc_type;
static PyObject *__pyx_n_s_f;
static PyObject *__pyx_n_s_file;
static PyObject *__pyx_n_s_finditer;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_g;
static PyObject *__pyx_n_s_genexpr;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_groups;
static PyObject *__pyx_n_s_h;
static PyObject *__pyx_n_s_has_escape;
static PyObject *__pyx_n_s_height;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_l;
static PyObject *__pyx_n_s_m;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_o;
static PyObject *__pyx_n_s_params;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_kp_s_px_height_0;
static PyObject *__pyx_kp_s_px_width_0;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_viewer;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_r;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_re;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_reset_mode;
static PyObject *__pyx_n_s_rgb_to_palette;
static PyObject *__pyx_n_s_round;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_set_mode;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_span;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_text;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_timestamp;
static PyObject *__pyx_n_s_ttygif_tty_viewer;
static PyObject *__pyx_n_s_type;
static PyObject *__pyx_n_s_unichr;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_kp_s_video_buffer_size_0;
static PyObject *__pyx_n_s_viewer;
static PyObject *__pyx_n_s_viewer_stream_2_sequence_locals;
static PyObject *__pyx_n_s_width;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_n_s_y;
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer___init__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_width, PyObject *__pyx_v_height, PyObject *__pyx_v_char_width, PyObject *__pyx_v_char_height, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_2draw_string(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_x, PyObject *__pyx_v_y, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_4render(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6get_text(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_8set_mode(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_cmd); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_10reset_mode(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_cmd); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12rgb_to_palette(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_r, PyObject *__pyx_v_g, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_frame(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_16has_escape(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_18clear_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_20add_text_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_timestamp, PyObject *__pyx_v_delay); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_22add_command_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_esc_type, PyObject *__pyx_v_command, PyObject *__pyx_v_params, PyObject *__pyx_v_groups, PyObject *__pyx_v_name, PyObject *__pyx_v_timestamp, PyObject *__pyx_v_delay); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_24debug_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_26get(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_28add_event(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_event); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_17viewport_px_width___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_18viewport_px_height___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_height___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_19viewport_char_width___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_16background_color___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_16background_color_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_16foreground_color___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_16foreground_color_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12video_length___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12video_length_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_11buffer_rows___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_11buffer_rows_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_1x___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_1x_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_1y___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_1y_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_fg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_fg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_bg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_bg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_2fg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_2fg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_2bg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_2bg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_30__reduce_cython__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_32__setstate_cython__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6ttygif_3tty_6viewer___pyx_unpickle_viewer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags); /* proto */
static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer_viewer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_7;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_18;
static PyObject *__pyx_int_27;
static PyObject *__pyx_int_28;
static PyObject *__pyx_int_30;
static PyObject *__pyx_int_32;
static PyObject *__pyx_int_37;
static PyObject *__pyx_int_38;
static PyObject *__pyx_int_39;
static PyObject *__pyx_int_40;
static PyObject *__pyx_int_47;
static PyObject *__pyx_int_48;
static PyObject *__pyx_int_49;
static PyObject *__pyx_int_58;
static PyObject *__pyx_int_68;
static PyObject *__pyx_int_78;
static PyObject *__pyx_int_88;
static PyObject *__pyx_int_90;
static PyObject *__pyx_int_95;
static PyObject *__pyx_int_97;
static PyObject *__pyx_int_98;
static PyObject *__pyx_int_100;
static PyObject *__pyx_int_107;
static PyObject *__pyx_int_108;
static PyObject *__pyx_int_118;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_135;
static PyObject *__pyx_int_138;
static PyObject *__pyx_int_148;
static PyObject *__pyx_int_158;
static PyObject *__pyx_int_168;
static PyObject *__pyx_int_175;
static PyObject *__pyx_int_178;
static PyObject *__pyx_int_188;
static PyObject *__pyx_int_192;
static PyObject *__pyx_int_198;
static PyObject *__pyx_int_208;
static PyObject *__pyx_int_215;
static PyObject *__pyx_int_218;
static PyObject *__pyx_int_228;
static PyObject *__pyx_int_238;
static PyObject *__pyx_int_255;
static PyObject *__pyx_int_480;
static PyObject *__pyx_int_640;
static PyObject *__pyx_int_63536012;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_slice__14;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_codeobj__17;
/* Late includes */

/* "ttygif/tty/viewer.pyx":47
 *     cdef public object          extra_text
 * 
 *     cdef ascii_safe(self,text):             # <<<<<<<<<<<<<<
 *         return ''.join([i if ord(i) < 128 else '*' for i in text])
 * 
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_ascii_safe(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  long __pyx_t_6;
  __Pyx_RefNannySetupContext("ascii_safe", 0);
  __Pyx_TraceCall("ascii_safe", __pyx_f[0], 47, 0, __PYX_ERR(0, 47, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":48
 * 
 *     cdef ascii_safe(self,text):
 *         return ''.join([i if ord(i) < 128 else '*' for i in text])             # <<<<<<<<<<<<<<
 * 
 *     cdef info(self,text):
 */
  __Pyx_TraceLine(48,0,__PYX_ERR(0, 48, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_v_text)) || PyTuple_CheckExact(__pyx_v_text)) {
    __pyx_t_2 = __pyx_v_text; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 48, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 48, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 48, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 48, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 48, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 48, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_6 = __Pyx_PyObject_Ord(__pyx_v_i); if (unlikely(__pyx_t_6 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 48, __pyx_L1_error)
    if (((__pyx_t_6 < 0x80) != 0)) {
      __Pyx_INCREF(__pyx_v_i);
      __pyx_t_5 = __pyx_v_i;
    } else {
      __Pyx_INCREF(__pyx_kp_s__2);
      __pyx_t_5 = __pyx_kp_s__2;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyString_Join(__pyx_kp_s_, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":47
 *     cdef public object          extra_text
 * 
 *     cdef ascii_safe(self,text):             # <<<<<<<<<<<<<<
 *         return ''.join([i if ord(i) < 128 else '*' for i in text])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.ascii_safe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":50
 *         return ''.join([i if ord(i) < 128 else '*' for i in text])
 * 
 *     cdef info(self,text):             # <<<<<<<<<<<<<<
 *         if self.debug_mode:
 *             print(self.ascii_safe(text))
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_info(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("info", 0);
  __Pyx_TraceCall("info", __pyx_f[0], 50, 0, __PYX_ERR(0, 50, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":51
 * 
 *     cdef info(self,text):
 *         if self.debug_mode:             # <<<<<<<<<<<<<<
 *             print(self.ascii_safe(text))
 * 
 */
  __Pyx_TraceLine(51,0,__PYX_ERR(0, 51, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 51, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "ttygif/tty/viewer.pyx":52
 *     cdef info(self,text):
 *         if self.debug_mode:
 *             print(self.ascii_safe(text))             # <<<<<<<<<<<<<<
 * 
 *     cdef new_char_buffer(self):
 */
    __Pyx_TraceLine(52,0,__PYX_ERR(0, 52, __pyx_L1_error))
    __pyx_t_2 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->ascii_safe(__pyx_v_self, __pyx_v_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ttygif/tty/viewer.pyx":51
 * 
 *     cdef info(self,text):
 *         if self.debug_mode:             # <<<<<<<<<<<<<<
 *             print(self.ascii_safe(text))
 * 
 */
  }

  /* "ttygif/tty/viewer.pyx":50
 *         return ''.join([i if ord(i) < 128 else '*' for i in text])
 * 
 *     cdef info(self,text):             # <<<<<<<<<<<<<<
 *         if self.debug_mode:
 *             print(self.ascii_safe(text))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":54
 *             print(self.ascii_safe(text))
 * 
 *     cdef new_char_buffer(self):             # <<<<<<<<<<<<<<
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_char_stride*self.viewport_char_height)
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_new_char_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  arrayobject *__pyx_v_buffer = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  __Pyx_RefNannySetupContext("new_char_buffer", 0);
  __Pyx_TraceCall("new_char_buffer", __pyx_f[0], 54, 0, __PYX_ERR(0, 54, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":55
 * 
 *     cdef new_char_buffer(self):
 *         cdef array.array buffer=array.array('B')             # <<<<<<<<<<<<<<
 *         array.resize(buffer,self.viewport_char_stride*self.viewport_char_height)
 *         memset(buffer.data.as_voidptr, self.background_color, len(buffer) * sizeof(char))
 */
  __Pyx_TraceLine(55,0,__PYX_ERR(0, 55, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_5array_array), __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_buffer = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":56
 *     cdef new_char_buffer(self):
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_char_stride*self.viewport_char_height)             # <<<<<<<<<<<<<<
 *         memset(buffer.data.as_voidptr, self.background_color, len(buffer) * sizeof(char))
 * 
 */
  __Pyx_TraceLine(56,0,__PYX_ERR(0, 56, __pyx_L1_error))
  __pyx_t_2 = resize(__pyx_v_buffer, (__pyx_v_self->viewport_char_stride * __pyx_v_self->viewport_char_height)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 56, __pyx_L1_error)

  /* "ttygif/tty/viewer.pyx":57
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_char_stride*self.viewport_char_height)
 *         memset(buffer.data.as_voidptr, self.background_color, len(buffer) * sizeof(char))             # <<<<<<<<<<<<<<
 * 
 *         return buffer
 */
  __Pyx_TraceLine(57,0,__PYX_ERR(0, 57, __pyx_L1_error))
  __pyx_t_3 = Py_SIZE(((PyObject *)__pyx_v_buffer)); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 57, __pyx_L1_error)
  (void)(memset(__pyx_v_buffer->data.as_voidptr, __pyx_v_self->background_color, (__pyx_t_3 * (sizeof(char)))));

  /* "ttygif/tty/viewer.pyx":59
 *         memset(buffer.data.as_voidptr, self.background_color, len(buffer) * sizeof(char))
 * 
 *         return buffer             # <<<<<<<<<<<<<<
 * 
 *     cdef new_video_buffer(self):
 */
  __Pyx_TraceLine(59,0,__PYX_ERR(0, 59, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_buffer));
  __pyx_r = ((PyObject *)__pyx_v_buffer);
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":54
 *             print(self.ascii_safe(text))
 * 
 *     cdef new_char_buffer(self):             # <<<<<<<<<<<<<<
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_char_stride*self.viewport_char_height)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.new_char_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_buffer);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":61
 *         return buffer
 * 
 *     cdef new_video_buffer(self):             # <<<<<<<<<<<<<<
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_px_width*self.viewport_px_height)
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_new_video_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  arrayobject *__pyx_v_buffer = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("new_video_buffer", 0);
  __Pyx_TraceCall("new_video_buffer", __pyx_f[0], 61, 0, __PYX_ERR(0, 61, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":62
 * 
 *     cdef new_video_buffer(self):
 *         cdef array.array buffer=array.array('B')             # <<<<<<<<<<<<<<
 *         array.resize(buffer,self.viewport_px_width*self.viewport_px_height)
 *         return buffer
 */
  __Pyx_TraceLine(62,0,__PYX_ERR(0, 62, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_5array_array), __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_buffer = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":63
 *     cdef new_video_buffer(self):
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_px_width*self.viewport_px_height)             # <<<<<<<<<<<<<<
 *         return buffer
 * 
 */
  __Pyx_TraceLine(63,0,__PYX_ERR(0, 63, __pyx_L1_error))
  __pyx_t_2 = resize(__pyx_v_buffer, (__pyx_v_self->viewport_px_width * __pyx_v_self->viewport_px_height)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 63, __pyx_L1_error)

  /* "ttygif/tty/viewer.pyx":64
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_px_width*self.viewport_px_height)
 *         return buffer             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self,width=640,height=480,char_width=None,char_height=None,debug=None):
 */
  __Pyx_TraceLine(64,0,__PYX_ERR(0, 64, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_buffer));
  __pyx_r = ((PyObject *)__pyx_v_buffer);
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":61
 *         return buffer
 * 
 *     cdef new_video_buffer(self):             # <<<<<<<<<<<<<<
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_px_width*self.viewport_px_height)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.new_video_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_buffer);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":66
 *         return buffer
 * 
 *     def __init__(self,width=640,height=480,char_width=None,char_height=None,debug=None):             # <<<<<<<<<<<<<<
 *         self.debug_mode                =debug
 *         self.viewport_px_width    =width
 */

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_width = 0;
  PyObject *__pyx_v_height = 0;
  PyObject *__pyx_v_char_width = 0;
  PyObject *__pyx_v_char_height = 0;
  PyObject *__pyx_v_debug = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_width,&__pyx_n_s_height,&__pyx_n_s_char_width,&__pyx_n_s_char_height,&__pyx_n_s_debug,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[0] = ((PyObject *)__pyx_int_640);
    values[1] = ((PyObject *)__pyx_int_480);
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    values[4] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_width);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_height);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_char_width);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_char_height);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 66, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_width = values[0];
    __pyx_v_height = values[1];
    __pyx_v_char_width = values[2];
    __pyx_v_char_height = values[3];
    __pyx_v_debug = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 66, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer___init__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), __pyx_v_width, __pyx_v_height, __pyx_v_char_width, __pyx_v_char_height, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer___init__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_width, PyObject *__pyx_v_height, PyObject *__pyx_v_char_width, PyObject *__pyx_v_char_height, PyObject *__pyx_v_debug) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  PyObject *__pyx_t_32 = NULL;
  PyObject *__pyx_t_33 = NULL;
  PyObject *__pyx_t_34 = NULL;
  PyObject *__pyx_t_35 = NULL;
  PyObject *__pyx_t_36 = NULL;
  PyObject *__pyx_t_37 = NULL;
  PyObject *__pyx_t_38 = NULL;
  PyObject *__pyx_t_39 = NULL;
  PyObject *__pyx_t_40 = NULL;
  PyObject *__pyx_t_41 = NULL;
  PyObject *__pyx_t_42 = NULL;
  PyObject *__pyx_t_43 = NULL;
  PyObject *__pyx_t_44 = NULL;
  PyObject *__pyx_t_45 = NULL;
  PyObject *__pyx_t_46 = NULL;
  PyObject *__pyx_t_47 = NULL;
  PyObject *__pyx_t_48 = NULL;
  PyObject *__pyx_t_49 = NULL;
  PyObject *__pyx_t_50 = NULL;
  PyObject *__pyx_t_51 = NULL;
  PyObject *__pyx_t_52 = NULL;
  PyObject *__pyx_t_53 = NULL;
  PyObject *__pyx_t_54 = NULL;
  PyObject *__pyx_t_55 = NULL;
  PyObject *__pyx_t_56 = NULL;
  PyObject *__pyx_t_57 = NULL;
  PyObject *__pyx_t_58 = NULL;
  PyObject *__pyx_t_59 = NULL;
  PyObject *__pyx_t_60 = NULL;
  PyObject *__pyx_t_61 = NULL;
  PyObject *__pyx_t_62 = NULL;
  PyObject *__pyx_t_63 = NULL;
  PyObject *__pyx_t_64 = NULL;
  PyObject *__pyx_t_65 = NULL;
  PyObject *__pyx_t_66 = NULL;
  PyObject *__pyx_t_67 = NULL;
  PyObject *__pyx_t_68 = NULL;
  PyObject *__pyx_t_69 = NULL;
  PyObject *__pyx_t_70 = NULL;
  PyObject *__pyx_t_71 = NULL;
  PyObject *__pyx_t_72 = NULL;
  PyObject *__pyx_t_73 = NULL;
  PyObject *__pyx_t_74 = NULL;
  PyObject *__pyx_t_75 = NULL;
  PyObject *__pyx_t_76 = NULL;
  PyObject *__pyx_t_77 = NULL;
  PyObject *__pyx_t_78 = NULL;
  PyObject *__pyx_t_79 = NULL;
  PyObject *__pyx_t_80 = NULL;
  PyObject *__pyx_t_81 = NULL;
  PyObject *__pyx_t_82 = NULL;
  PyObject *__pyx_t_83 = NULL;
  PyObject *__pyx_t_84 = NULL;
  PyObject *__pyx_t_85 = NULL;
  PyObject *__pyx_t_86 = NULL;
  PyObject *__pyx_t_87 = NULL;
  PyObject *__pyx_t_88 = NULL;
  PyObject *__pyx_t_89 = NULL;
  PyObject *__pyx_t_90 = NULL;
  PyObject *__pyx_t_91 = NULL;
  PyObject *__pyx_t_92 = NULL;
  PyObject *__pyx_t_93 = NULL;
  PyObject *__pyx_t_94 = NULL;
  PyObject *__pyx_t_95 = NULL;
  PyObject *__pyx_t_96 = NULL;
  PyObject *__pyx_t_97 = NULL;
  PyObject *__pyx_t_98 = NULL;
  PyObject *__pyx_t_99 = NULL;
  PyObject *__pyx_t_100 = NULL;
  PyObject *__pyx_t_101 = NULL;
  PyObject *__pyx_t_102 = NULL;
  PyObject *__pyx_t_103 = NULL;
  PyObject *__pyx_t_104 = NULL;
  PyObject *__pyx_t_105 = NULL;
  PyObject *__pyx_t_106 = NULL;
  PyObject *__pyx_t_107 = NULL;
  PyObject *__pyx_t_108 = NULL;
  PyObject *__pyx_t_109 = NULL;
  PyObject *__pyx_t_110 = NULL;
  PyObject *__pyx_t_111 = NULL;
  PyObject *__pyx_t_112 = NULL;
  PyObject *__pyx_t_113 = NULL;
  PyObject *__pyx_t_114 = NULL;
  PyObject *__pyx_t_115 = NULL;
  PyObject *__pyx_t_116 = NULL;
  PyObject *__pyx_t_117 = NULL;
  PyObject *__pyx_t_118 = NULL;
  PyObject *__pyx_t_119 = NULL;
  PyObject *__pyx_t_120 = NULL;
  PyObject *__pyx_t_121 = NULL;
  PyObject *__pyx_t_122 = NULL;
  PyObject *__pyx_t_123 = NULL;
  PyObject *__pyx_t_124 = NULL;
  PyObject *__pyx_t_125 = NULL;
  PyObject *__pyx_t_126 = NULL;
  PyObject *__pyx_t_127 = NULL;
  PyObject *__pyx_t_128 = NULL;
  PyObject *__pyx_t_129 = NULL;
  PyObject *__pyx_t_130 = NULL;
  PyObject *__pyx_t_131 = NULL;
  PyObject *__pyx_t_132 = NULL;
  PyObject *__pyx_t_133 = NULL;
  PyObject *__pyx_t_134 = NULL;
  PyObject *__pyx_t_135 = NULL;
  PyObject *__pyx_t_136 = NULL;
  PyObject *__pyx_t_137 = NULL;
  PyObject *__pyx_t_138 = NULL;
  PyObject *__pyx_t_139 = NULL;
  PyObject *__pyx_t_140 = NULL;
  PyObject *__pyx_t_141 = NULL;
  PyObject *__pyx_t_142 = NULL;
  PyObject *__pyx_t_143 = NULL;
  PyObject *__pyx_t_144 = NULL;
  PyObject *__pyx_t_145 = NULL;
  PyObject *__pyx_t_146 = NULL;
  PyObject *__pyx_t_147 = NULL;
  PyObject *__pyx_t_148 = NULL;
  PyObject *__pyx_t_149 = NULL;
  PyObject *__pyx_t_150 = NULL;
  PyObject *__pyx_t_151 = NULL;
  PyObject *__pyx_t_152 = NULL;
  PyObject *__pyx_t_153 = NULL;
  PyObject *__pyx_t_154 = NULL;
  PyObject *__pyx_t_155 = NULL;
  PyObject *__pyx_t_156 = NULL;
  PyObject *__pyx_t_157 = NULL;
  PyObject *__pyx_t_158 = NULL;
  PyObject *__pyx_t_159 = NULL;
  PyObject *__pyx_t_160 = NULL;
  PyObject *__pyx_t_161 = NULL;
  PyObject *__pyx_t_162 = NULL;
  PyObject *__pyx_t_163 = NULL;
  PyObject *__pyx_t_164 = NULL;
  PyObject *__pyx_t_165 = NULL;
  PyObject *__pyx_t_166 = NULL;
  PyObject *__pyx_t_167 = NULL;
  PyObject *__pyx_t_168 = NULL;
  PyObject *__pyx_t_169 = NULL;
  PyObject *__pyx_t_170 = NULL;
  PyObject *__pyx_t_171 = NULL;
  PyObject *__pyx_t_172 = NULL;
  PyObject *__pyx_t_173 = NULL;
  PyObject *__pyx_t_174 = NULL;
  PyObject *__pyx_t_175 = NULL;
  PyObject *__pyx_t_176 = NULL;
  PyObject *__pyx_t_177 = NULL;
  PyObject *__pyx_t_178 = NULL;
  PyObject *__pyx_t_179 = NULL;
  PyObject *__pyx_t_180 = NULL;
  PyObject *__pyx_t_181 = NULL;
  PyObject *__pyx_t_182 = NULL;
  PyObject *__pyx_t_183 = NULL;
  PyObject *__pyx_t_184 = NULL;
  PyObject *__pyx_t_185 = NULL;
  PyObject *__pyx_t_186 = NULL;
  PyObject *__pyx_t_187 = NULL;
  PyObject *__pyx_t_188 = NULL;
  PyObject *__pyx_t_189 = NULL;
  PyObject *__pyx_t_190 = NULL;
  PyObject *__pyx_t_191 = NULL;
  PyObject *__pyx_t_192 = NULL;
  PyObject *__pyx_t_193 = NULL;
  PyObject *__pyx_t_194 = NULL;
  PyObject *__pyx_t_195 = NULL;
  PyObject *__pyx_t_196 = NULL;
  PyObject *__pyx_t_197 = NULL;
  PyObject *__pyx_t_198 = NULL;
  PyObject *__pyx_t_199 = NULL;
  PyObject *__pyx_t_200 = NULL;
  PyObject *__pyx_t_201 = NULL;
  PyObject *__pyx_t_202 = NULL;
  PyObject *__pyx_t_203 = NULL;
  PyObject *__pyx_t_204 = NULL;
  PyObject *__pyx_t_205 = NULL;
  PyObject *__pyx_t_206 = NULL;
  PyObject *__pyx_t_207 = NULL;
  PyObject *__pyx_t_208 = NULL;
  PyObject *__pyx_t_209 = NULL;
  PyObject *__pyx_t_210 = NULL;
  PyObject *__pyx_t_211 = NULL;
  PyObject *__pyx_t_212 = NULL;
  PyObject *__pyx_t_213 = NULL;
  PyObject *__pyx_t_214 = NULL;
  PyObject *__pyx_t_215 = NULL;
  PyObject *__pyx_t_216 = NULL;
  PyObject *__pyx_t_217 = NULL;
  PyObject *__pyx_t_218 = NULL;
  PyObject *__pyx_t_219 = NULL;
  PyObject *__pyx_t_220 = NULL;
  PyObject *__pyx_t_221 = NULL;
  PyObject *__pyx_t_222 = NULL;
  PyObject *__pyx_t_223 = NULL;
  PyObject *__pyx_t_224 = NULL;
  PyObject *__pyx_t_225 = NULL;
  PyObject *__pyx_t_226 = NULL;
  PyObject *__pyx_t_227 = NULL;
  PyObject *__pyx_t_228 = NULL;
  PyObject *__pyx_t_229 = NULL;
  PyObject *__pyx_t_230 = NULL;
  PyObject *__pyx_t_231 = NULL;
  PyObject *__pyx_t_232 = NULL;
  PyObject *__pyx_t_233 = NULL;
  PyObject *__pyx_t_234 = NULL;
  PyObject *__pyx_t_235 = NULL;
  PyObject *__pyx_t_236 = NULL;
  PyObject *__pyx_t_237 = NULL;
  PyObject *__pyx_t_238 = NULL;
  PyObject *__pyx_t_239 = NULL;
  PyObject *__pyx_t_240 = NULL;
  PyObject *__pyx_t_241 = NULL;
  PyObject *__pyx_t_242 = NULL;
  PyObject *__pyx_t_243 = NULL;
  PyObject *__pyx_t_244 = NULL;
  PyObject *__pyx_t_245 = NULL;
  PyObject *__pyx_t_246 = NULL;
  PyObject *__pyx_t_247 = NULL;
  PyObject *__pyx_t_248 = NULL;
  PyObject *__pyx_t_249 = NULL;
  PyObject *__pyx_t_250 = NULL;
  PyObject *__pyx_t_251 = NULL;
  PyObject *__pyx_t_252 = NULL;
  PyObject *__pyx_t_253 = NULL;
  PyObject *__pyx_t_254 = NULL;
  PyObject *__pyx_t_255 = NULL;
  PyObject *__pyx_t_256 = NULL;
  PyObject *__pyx_t_257 = NULL;
  PyObject *__pyx_t_258 = NULL;
  PyObject *__pyx_t_259 = NULL;
  PyObject *__pyx_t_260 = NULL;
  PyObject *__pyx_t_261 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_TraceCall("__init__", __pyx_f[0], 66, 0, __PYX_ERR(0, 66, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":67
 * 
 *     def __init__(self,width=640,height=480,char_width=None,char_height=None,debug=None):
 *         self.debug_mode                =debug             # <<<<<<<<<<<<<<
 *         self.viewport_px_width    =width
 *         self.viewport_px_height   =height
 */
  __Pyx_TraceLine(67,0,__PYX_ERR(0, 67, __pyx_L1_error))
  __Pyx_INCREF(__pyx_v_debug);
  __Pyx_GIVEREF(__pyx_v_debug);
  __Pyx_GOTREF(__pyx_v_self->debug_mode);
  __Pyx_DECREF(__pyx_v_self->debug_mode);
  __pyx_v_self->debug_mode = __pyx_v_debug;

  /* "ttygif/tty/viewer.pyx":68
 *     def __init__(self,width=640,height=480,char_width=None,char_height=None,debug=None):
 *         self.debug_mode                =debug
 *         self.viewport_px_width    =width             # <<<<<<<<<<<<<<
 *         self.viewport_px_height   =height
 * 
 */
  __Pyx_TraceLine(68,0,__PYX_ERR(0, 68, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_width); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 68, __pyx_L1_error)
  __pyx_v_self->viewport_px_width = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":69
 *         self.debug_mode                =debug
 *         self.viewport_px_width    =width
 *         self.viewport_px_height   =height             # <<<<<<<<<<<<<<
 * 
 *         if char_width and char_height:
 */
  __Pyx_TraceLine(69,0,__PYX_ERR(0, 69, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_height); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L1_error)
  __pyx_v_self->viewport_px_height = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":71
 *         self.viewport_px_height   =height
 * 
 *         if char_width and char_height:             # <<<<<<<<<<<<<<
 *             self.viewport_char_width  = char_width
 *             self.viewport_char_height = char_height
 */
  __Pyx_TraceLine(71,0,__PYX_ERR(0, 71, __pyx_L1_error))
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_char_width); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 71, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_char_height); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 71, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":72
 * 
 *         if char_width and char_height:
 *             self.viewport_char_width  = char_width             # <<<<<<<<<<<<<<
 *             self.viewport_char_height = char_height
 *             self.viewport_px_width    = self.viewport_char_width*font.font_width
 */
    __Pyx_TraceLine(72,0,__PYX_ERR(0, 72, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_char_width); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 72, __pyx_L1_error)
    __pyx_v_self->viewport_char_width = __pyx_t_1;

    /* "ttygif/tty/viewer.pyx":73
 *         if char_width and char_height:
 *             self.viewport_char_width  = char_width
 *             self.viewport_char_height = char_height             # <<<<<<<<<<<<<<
 *             self.viewport_px_width    = self.viewport_char_width*font.font_width
 *             self.viewport_px_height   = self.viewport_char_height*font.font_height
 */
    __Pyx_TraceLine(73,0,__PYX_ERR(0, 73, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_char_height); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 73, __pyx_L1_error)
    __pyx_v_self->viewport_char_height = __pyx_t_1;

    /* "ttygif/tty/viewer.pyx":74
 *             self.viewport_char_width  = char_width
 *             self.viewport_char_height = char_height
 *             self.viewport_px_width    = self.viewport_char_width*font.font_width             # <<<<<<<<<<<<<<
 *             self.viewport_px_height   = self.viewport_char_height*font.font_height
 *         else:
 */
    __Pyx_TraceLine(74,0,__PYX_ERR(0, 74, __pyx_L1_error))
    __pyx_v_self->viewport_px_width = (__pyx_v_self->viewport_char_width * __pyx_v_6ttygif_3tty_5fonts_font->font_width);

    /* "ttygif/tty/viewer.pyx":75
 *             self.viewport_char_height = char_height
 *             self.viewport_px_width    = self.viewport_char_width*font.font_width
 *             self.viewport_px_height   = self.viewport_char_height*font.font_height             # <<<<<<<<<<<<<<
 *         else:
 *             self.viewport_char_height = self.viewport_px_height/font.font_width
 */
    __Pyx_TraceLine(75,0,__PYX_ERR(0, 75, __pyx_L1_error))
    __pyx_v_self->viewport_px_height = (__pyx_v_self->viewport_char_height * __pyx_v_6ttygif_3tty_5fonts_font->font_height);

    /* "ttygif/tty/viewer.pyx":71
 *         self.viewport_px_height   =height
 * 
 *         if char_width and char_height:             # <<<<<<<<<<<<<<
 *             self.viewport_char_width  = char_width
 *             self.viewport_char_height = char_height
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":77
 *             self.viewport_px_height   = self.viewport_char_height*font.font_height
 *         else:
 *             self.viewport_char_height = self.viewport_px_height/font.font_width             # <<<<<<<<<<<<<<
 *             self.viewport_char_width  = self.viewport_px_width/font.font_height
 *             self.viewport_px_width    = width
 */
  __Pyx_TraceLine(77,0,__PYX_ERR(0, 77, __pyx_L1_error))
  /*else*/ {
    if (unlikely(__pyx_v_6ttygif_3tty_5fonts_font->font_width == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(0, 77, __pyx_L1_error)
    }
    else if (sizeof(int) == sizeof(long) && (!(((int)-1) > 0)) && unlikely(__pyx_v_6ttygif_3tty_5fonts_font->font_width == (int)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW(__pyx_v_self->viewport_px_height))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(0, 77, __pyx_L1_error)
    }
    __pyx_v_self->viewport_char_height = __Pyx_div_int(__pyx_v_self->viewport_px_height, __pyx_v_6ttygif_3tty_5fonts_font->font_width);

    /* "ttygif/tty/viewer.pyx":78
 *         else:
 *             self.viewport_char_height = self.viewport_px_height/font.font_width
 *             self.viewport_char_width  = self.viewport_px_width/font.font_height             # <<<<<<<<<<<<<<
 *             self.viewport_px_width    = width
 *             self.viewport_px_height   = height
 */
    __Pyx_TraceLine(78,0,__PYX_ERR(0, 78, __pyx_L1_error))
    if (unlikely(__pyx_v_6ttygif_3tty_5fonts_font->font_height == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(0, 78, __pyx_L1_error)
    }
    else if (sizeof(int) == sizeof(long) && (!(((int)-1) > 0)) && unlikely(__pyx_v_6ttygif_3tty_5fonts_font->font_height == (int)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW(__pyx_v_self->viewport_px_width))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(0, 78, __pyx_L1_error)
    }
    __pyx_v_self->viewport_char_width = __Pyx_div_int(__pyx_v_self->viewport_px_width, __pyx_v_6ttygif_3tty_5fonts_font->font_height);

    /* "ttygif/tty/viewer.pyx":79
 *             self.viewport_char_height = self.viewport_px_height/font.font_width
 *             self.viewport_char_width  = self.viewport_px_width/font.font_height
 *             self.viewport_px_width    = width             # <<<<<<<<<<<<<<
 *             self.viewport_px_height   = height
 *         #fg,bg,char
 */
    __Pyx_TraceLine(79,0,__PYX_ERR(0, 79, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_width); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 79, __pyx_L1_error)
    __pyx_v_self->viewport_px_width = __pyx_t_1;

    /* "ttygif/tty/viewer.pyx":80
 *             self.viewport_char_width  = self.viewport_px_width/font.font_height
 *             self.viewport_px_width    = width
 *             self.viewport_px_height   = height             # <<<<<<<<<<<<<<
 *         #fg,bg,char
 *         self.viewport_char_stride     =self.viewport_char_width*3
 */
    __Pyx_TraceLine(80,0,__PYX_ERR(0, 80, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_height); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 80, __pyx_L1_error)
    __pyx_v_self->viewport_px_height = __pyx_t_1;
  }
  __pyx_L3:;

  /* "ttygif/tty/viewer.pyx":82
 *             self.viewport_px_height   = height
 *         #fg,bg,char
 *         self.viewport_char_stride     =self.viewport_char_width*3             # <<<<<<<<<<<<<<
 *         self.clear_sequence()
 *         self.video                =self.new_video_buffer()
 */
  __Pyx_TraceLine(82,0,__PYX_ERR(0, 82, __pyx_L1_error))
  __pyx_v_self->viewport_char_stride = (__pyx_v_self->viewport_char_width * 3);

  /* "ttygif/tty/viewer.pyx":83
 *         #fg,bg,char
 *         self.viewport_char_stride     =self.viewport_char_width*3
 *         self.clear_sequence()             # <<<<<<<<<<<<<<
 *         self.video                =self.new_video_buffer()
 *         self.buffer               =self.new_char_buffer()
 */
  __Pyx_TraceLine(83,0,__PYX_ERR(0, 83, __pyx_L1_error))
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_clear_sequence); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "ttygif/tty/viewer.pyx":84
 *         self.viewport_char_stride     =self.viewport_char_width*3
 *         self.clear_sequence()
 *         self.video                =self.new_video_buffer()             # <<<<<<<<<<<<<<
 *         self.buffer               =self.new_char_buffer()
 *         #self.buffer_length        =self.viewport_char_width*self.viewport_char_height
 */
  __Pyx_TraceLine(84,0,__PYX_ERR(0, 84, __pyx_L1_error))
  __pyx_t_4 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->new_video_buffer(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->video);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->video));
  __pyx_v_self->video = ((arrayobject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "ttygif/tty/viewer.pyx":85
 *         self.clear_sequence()
 *         self.video                =self.new_video_buffer()
 *         self.buffer               =self.new_char_buffer()             # <<<<<<<<<<<<<<
 *         #self.buffer_length        =self.viewport_char_width*self.viewport_char_height
 * 
 */
  __Pyx_TraceLine(85,0,__PYX_ERR(0, 85, __pyx_L1_error))
  __pyx_t_4 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->new_char_buffer(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->buffer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->buffer));
  __pyx_v_self->buffer = ((arrayobject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "ttygif/tty/viewer.pyx":88
 *         #self.buffer_length        =self.viewport_char_width*self.viewport_char_height
 * 
 *         self.sequence_pos         =0             # <<<<<<<<<<<<<<
 *         self.video_length         =len(self.video)
 *         self.background_color     =0
 */
  __Pyx_TraceLine(88,0,__PYX_ERR(0, 88, __pyx_L1_error))
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->sequence_pos);
  __Pyx_DECREF(__pyx_v_self->sequence_pos);
  __pyx_v_self->sequence_pos = __pyx_int_0;

  /* "ttygif/tty/viewer.pyx":89
 * 
 *         self.sequence_pos         =0
 *         self.video_length         =len(self.video)             # <<<<<<<<<<<<<<
 *         self.background_color     =0
 *         self.foreground_color     =3
 */
  __Pyx_TraceLine(89,0,__PYX_ERR(0, 89, __pyx_L1_error))
  __pyx_t_4 = ((PyObject *)__pyx_v_self->video);
  __Pyx_INCREF(__pyx_t_4);
  if (unlikely(__pyx_t_4 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 89, __pyx_L1_error)
  }
  __pyx_t_7 = Py_SIZE(__pyx_t_4); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_self->video_length = __pyx_t_7;

  /* "ttygif/tty/viewer.pyx":90
 *         self.sequence_pos         =0
 *         self.video_length         =len(self.video)
 *         self.background_color     =0             # <<<<<<<<<<<<<<
 *         self.foreground_color     =3
 *         self.window_style         ="BOTTOM"
 */
  __Pyx_TraceLine(90,0,__PYX_ERR(0, 90, __pyx_L1_error))
  __pyx_v_self->background_color = 0;

  /* "ttygif/tty/viewer.pyx":91
 *         self.video_length         =len(self.video)
 *         self.background_color     =0
 *         self.foreground_color     =3             # <<<<<<<<<<<<<<
 *         self.window_style         ="BOTTOM"
 *         self.extra_text           =""
 */
  __Pyx_TraceLine(91,0,__PYX_ERR(0, 91, __pyx_L1_error))
  __pyx_v_self->foreground_color = 3;

  /* "ttygif/tty/viewer.pyx":92
 *         self.background_color     =0
 *         self.foreground_color     =3
 *         self.window_style         ="BOTTOM"             # <<<<<<<<<<<<<<
 *         self.extra_text           =""
 *         self.last_timestamp       =0
 */
  __Pyx_TraceLine(92,0,__PYX_ERR(0, 92, __pyx_L1_error))
  __Pyx_INCREF(__pyx_n_s_BOTTOM);
  __Pyx_GIVEREF(__pyx_n_s_BOTTOM);
  __Pyx_GOTREF(__pyx_v_self->window_style);
  __Pyx_DECREF(__pyx_v_self->window_style);
  __pyx_v_self->window_style = __pyx_n_s_BOTTOM;

  /* "ttygif/tty/viewer.pyx":93
 *         self.foreground_color     =3
 *         self.window_style         ="BOTTOM"
 *         self.extra_text           =""             # <<<<<<<<<<<<<<
 *         self.last_timestamp       =0
 *         self.x=0
 */
  __Pyx_TraceLine(93,0,__PYX_ERR(0, 93, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_);
  __Pyx_GIVEREF(__pyx_kp_s_);
  __Pyx_GOTREF(__pyx_v_self->extra_text);
  __Pyx_DECREF(__pyx_v_self->extra_text);
  __pyx_v_self->extra_text = __pyx_kp_s_;

  /* "ttygif/tty/viewer.pyx":94
 *         self.window_style         ="BOTTOM"
 *         self.extra_text           =""
 *         self.last_timestamp       =0             # <<<<<<<<<<<<<<
 *         self.x=0
 *         self.y=0
 */
  __Pyx_TraceLine(94,0,__PYX_ERR(0, 94, __pyx_L1_error))
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->last_timestamp);
  __Pyx_DECREF(__pyx_v_self->last_timestamp);
  __pyx_v_self->last_timestamp = __pyx_int_0;

  /* "ttygif/tty/viewer.pyx":95
 *         self.extra_text           =""
 *         self.last_timestamp       =0
 *         self.x=0             # <<<<<<<<<<<<<<
 *         self.y=0
 *         self.def_fg=15
 */
  __Pyx_TraceLine(95,0,__PYX_ERR(0, 95, __pyx_L1_error))
  __pyx_v_self->x = 0;

  /* "ttygif/tty/viewer.pyx":96
 *         self.last_timestamp       =0
 *         self.x=0
 *         self.y=0             # <<<<<<<<<<<<<<
 *         self.def_fg=15
 *         self.def_bg=0
 */
  __Pyx_TraceLine(96,0,__PYX_ERR(0, 96, __pyx_L1_error))
  __pyx_v_self->y = 0;

  /* "ttygif/tty/viewer.pyx":97
 *         self.x=0
 *         self.y=0
 *         self.def_fg=15             # <<<<<<<<<<<<<<
 *         self.def_bg=0
 *         self.fg=self.def_fg
 */
  __Pyx_TraceLine(97,0,__PYX_ERR(0, 97, __pyx_L1_error))
  __pyx_v_self->def_fg = 15;

  /* "ttygif/tty/viewer.pyx":98
 *         self.y=0
 *         self.def_fg=15
 *         self.def_bg=0             # <<<<<<<<<<<<<<
 *         self.fg=self.def_fg
 *         self.bg=self.def_bg
 */
  __Pyx_TraceLine(98,0,__PYX_ERR(0, 98, __pyx_L1_error))
  __pyx_v_self->def_bg = 0;

  /* "ttygif/tty/viewer.pyx":99
 *         self.def_fg=15
 *         self.def_bg=0
 *         self.fg=self.def_fg             # <<<<<<<<<<<<<<
 *         self.bg=self.def_bg
 *         self.reverse_video=None
 */
  __Pyx_TraceLine(99,0,__PYX_ERR(0, 99, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_self->def_fg;
  __pyx_v_self->fg = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":100
 *         self.def_bg=0
 *         self.fg=self.def_fg
 *         self.bg=self.def_bg             # <<<<<<<<<<<<<<
 *         self.reverse_video=None
 *         self.bold=None
 */
  __Pyx_TraceLine(100,0,__PYX_ERR(0, 100, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_self->def_bg;
  __pyx_v_self->bg = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":101
 *         self.fg=self.def_fg
 *         self.bg=self.def_bg
 *         self.reverse_video=None             # <<<<<<<<<<<<<<
 *         self.bold=None
 * 
 */
  __Pyx_TraceLine(101,0,__PYX_ERR(0, 101, __pyx_L1_error))
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->reverse_video);
  __Pyx_DECREF(__pyx_v_self->reverse_video);
  __pyx_v_self->reverse_video = Py_None;

  /* "ttygif/tty/viewer.pyx":102
 *         self.bg=self.def_bg
 *         self.reverse_video=None
 *         self.bold=None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(102,0,__PYX_ERR(0, 102, __pyx_L1_error))
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->bold);
  __Pyx_DECREF(__pyx_v_self->bold);
  __pyx_v_self->bold = Py_None;

  /* "ttygif/tty/viewer.pyx":106
 * 
 *         self.color_table=[  # 16 System Colors
 *                             [0,0,0],[128,0,0],[0,128,0],[128,128,0],             # <<<<<<<<<<<<<<
 *                             [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 *                             [128,128,128],[255,0,0],[0,255,0],[255,255,0],
 */
  __Pyx_TraceLine(106,0,__PYX_ERR(0, 106, __pyx_L1_error))
  __pyx_t_4 = PyList_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_4, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_4, 2, __pyx_int_0);
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_int_0);
  __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_int_0);
  __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_8, 0, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_8, 1, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_8, 2, __pyx_int_0);

  /* "ttygif/tty/viewer.pyx":107
 *         self.color_table=[  # 16 System Colors
 *                             [0,0,0],[128,0,0],[0,128,0],[128,128,0],
 *                             [0,0,128],[128,0,128],[0,128,128],[192,192,192],             # <<<<<<<<<<<<<<
 *                             [128,128,128],[255,0,0],[0,255,0],[255,255,0],
 *                             [0,0,255],[255,0,255],[0,255,255],[255,255,255],
 */
  __Pyx_TraceLine(107,0,__PYX_ERR(0, 107, __pyx_L1_error))
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_9, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_9, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_9, 2, __pyx_int_128);
  __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_10, 0, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_10, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_10, 2, __pyx_int_128);
  __pyx_t_11 = PyList_New(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_11, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_11, 1, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_11, 2, __pyx_int_128);
  __pyx_t_12 = PyList_New(3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_INCREF(__pyx_int_192);
  __Pyx_GIVEREF(__pyx_int_192);
  PyList_SET_ITEM(__pyx_t_12, 0, __pyx_int_192);
  __Pyx_INCREF(__pyx_int_192);
  __Pyx_GIVEREF(__pyx_int_192);
  PyList_SET_ITEM(__pyx_t_12, 1, __pyx_int_192);
  __Pyx_INCREF(__pyx_int_192);
  __Pyx_GIVEREF(__pyx_int_192);
  PyList_SET_ITEM(__pyx_t_12, 2, __pyx_int_192);

  /* "ttygif/tty/viewer.pyx":108
 *                             [0,0,0],[128,0,0],[0,128,0],[128,128,0],
 *                             [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 *                             [128,128,128],[255,0,0],[0,255,0],[255,255,0],             # <<<<<<<<<<<<<<
 *                             [0,0,255],[255,0,255],[0,255,255],[255,255,255],
 *                             # xterm palette
 */
  __Pyx_TraceLine(108,0,__PYX_ERR(0, 108, __pyx_L1_error))
  __pyx_t_13 = PyList_New(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_13, 0, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_13, 1, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_13, 2, __pyx_int_128);
  __pyx_t_14 = PyList_New(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_14, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_14, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_14, 2, __pyx_int_0);
  __pyx_t_15 = PyList_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_15, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_15, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_15, 2, __pyx_int_0);
  __pyx_t_16 = PyList_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_16, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_16, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_16, 2, __pyx_int_0);

  /* "ttygif/tty/viewer.pyx":109
 *                             [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 *                             [128,128,128],[255,0,0],[0,255,0],[255,255,0],
 *                             [0,0,255],[255,0,255],[0,255,255],[255,255,255],             # <<<<<<<<<<<<<<
 *                             # xterm palette
 *                             [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],
 */
  __Pyx_TraceLine(109,0,__PYX_ERR(0, 109, __pyx_L1_error))
  __pyx_t_17 = PyList_New(3); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_17, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_17, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_17, 2, __pyx_int_255);
  __pyx_t_18 = PyList_New(3); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_18, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_18, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_18, 2, __pyx_int_255);
  __pyx_t_19 = PyList_New(3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_19, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_19, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_19, 2, __pyx_int_255);
  __pyx_t_20 = PyList_New(3); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_20, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_20, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_20, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":111
 *                             [0,0,255],[255,0,255],[0,255,255],[255,255,255],
 *                             # xterm palette
 *                             [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],             # <<<<<<<<<<<<<<
 *                             [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],
 *                             [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 */
  __Pyx_TraceLine(111,0,__PYX_ERR(0, 111, __pyx_L1_error))
  __pyx_t_21 = PyList_New(3); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_21, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_21, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_21, 2, __pyx_int_0);
  __pyx_t_22 = PyList_New(3); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_22, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_22, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_22, 2, __pyx_int_95);
  __pyx_t_23 = PyList_New(3); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_23, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_23, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_23, 2, __pyx_int_135);
  __pyx_t_24 = PyList_New(3); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_24, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_24, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_24, 2, __pyx_int_175);
  __pyx_t_25 = PyList_New(3); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_25, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_25, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_25, 2, __pyx_int_215);
  __pyx_t_26 = PyList_New(3); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_26, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_26, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_26, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":112
 *                             # xterm palette
 *                             [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],
 *                             [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],             # <<<<<<<<<<<<<<
 *                             [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 *                             [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 */
  __Pyx_TraceLine(112,0,__PYX_ERR(0, 112, __pyx_L1_error))
  __pyx_t_27 = PyList_New(3); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_27, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_27, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_27, 2, __pyx_int_0);
  __pyx_t_28 = PyList_New(3); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_28, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_28, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_28, 2, __pyx_int_95);
  __pyx_t_29 = PyList_New(3); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_29, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_29, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_29, 2, __pyx_int_135);
  __pyx_t_30 = PyList_New(3); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_30, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_30, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_30, 2, __pyx_int_175);
  __pyx_t_31 = PyList_New(3); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_31, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_31, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_31, 2, __pyx_int_215);
  __pyx_t_32 = PyList_New(3); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_32, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_32, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_32, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":113
 *                             [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],
 *                             [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],
 *                             [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],             # <<<<<<<<<<<<<<
 *                             [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 *                             [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 */
  __Pyx_TraceLine(113,0,__PYX_ERR(0, 113, __pyx_L1_error))
  __pyx_t_33 = PyList_New(3); if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_33, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_33, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_33, 2, __pyx_int_0);
  __pyx_t_34 = PyList_New(3); if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_34, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_34, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_34, 2, __pyx_int_95);
  __pyx_t_35 = PyList_New(3); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_35, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_35, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_35, 2, __pyx_int_135);
  __pyx_t_36 = PyList_New(3); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_36, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_36, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_36, 2, __pyx_int_175);
  __pyx_t_37 = PyList_New(3); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_37, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_37, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_37, 2, __pyx_int_215);
  __pyx_t_38 = PyList_New(3); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_38, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_38, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_38, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":114
 *                             [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],
 *                             [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 *                             [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],             # <<<<<<<<<<<<<<
 *                             [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 *                             [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 */
  __Pyx_TraceLine(114,0,__PYX_ERR(0, 114, __pyx_L1_error))
  __pyx_t_39 = PyList_New(3); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_39, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_39, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_39, 2, __pyx_int_0);
  __pyx_t_40 = PyList_New(3); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_40, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_40, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_40, 2, __pyx_int_95);
  __pyx_t_41 = PyList_New(3); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_41, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_41, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_41, 2, __pyx_int_135);
  __pyx_t_42 = PyList_New(3); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_42, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_42, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_42, 2, __pyx_int_175);
  __pyx_t_43 = PyList_New(3); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_43, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_43, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_43, 2, __pyx_int_215);
  __pyx_t_44 = PyList_New(3); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_44, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_44, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_44, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":115
 *                             [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 *                             [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 *                             [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],             # <<<<<<<<<<<<<<
 *                             [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 *                             [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 */
  __Pyx_TraceLine(115,0,__PYX_ERR(0, 115, __pyx_L1_error))
  __pyx_t_45 = PyList_New(3); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_45, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_45, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_45, 2, __pyx_int_0);
  __pyx_t_46 = PyList_New(3); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_46, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_46, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_46, 2, __pyx_int_95);
  __pyx_t_47 = PyList_New(3); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_47, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_47, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_47, 2, __pyx_int_135);
  __pyx_t_48 = PyList_New(3); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_48, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_48, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_48, 2, __pyx_int_175);
  __pyx_t_49 = PyList_New(3); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_49, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_49, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_49, 2, __pyx_int_215);
  __pyx_t_50 = PyList_New(3); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_50, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_50, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_50, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":116
 *                             [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 *                             [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 *                             [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],             # <<<<<<<<<<<<<<
 *                             [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 *                             [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 */
  __Pyx_TraceLine(116,0,__PYX_ERR(0, 116, __pyx_L1_error))
  __pyx_t_51 = PyList_New(3); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_51, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_51, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_51, 2, __pyx_int_0);
  __pyx_t_52 = PyList_New(3); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_52, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_52, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_52, 2, __pyx_int_95);
  __pyx_t_53 = PyList_New(3); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_53, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_53, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_53, 2, __pyx_int_135);
  __pyx_t_54 = PyList_New(3); if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_54);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_54, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_54, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_54, 2, __pyx_int_175);
  __pyx_t_55 = PyList_New(3); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_55, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_55, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_55, 2, __pyx_int_215);
  __pyx_t_56 = PyList_New(3); if (unlikely(!__pyx_t_56)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_56);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_56, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_56, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_56, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":117
 *                             [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 *                             [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 *                             [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],             # <<<<<<<<<<<<<<
 *                             [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 *                             [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 */
  __Pyx_TraceLine(117,0,__PYX_ERR(0, 117, __pyx_L1_error))
  __pyx_t_57 = PyList_New(3); if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_57, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_57, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_57, 2, __pyx_int_0);
  __pyx_t_58 = PyList_New(3); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_58, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_58, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_58, 2, __pyx_int_95);
  __pyx_t_59 = PyList_New(3); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_59, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_59, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_59, 2, __pyx_int_135);
  __pyx_t_60 = PyList_New(3); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_60, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_60, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_60, 2, __pyx_int_175);
  __pyx_t_61 = PyList_New(3); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_61, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_61, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_61, 2, __pyx_int_215);
  __pyx_t_62 = PyList_New(3); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_62, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_62, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_62, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":118
 *                             [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 *                             [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 *                             [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],             # <<<<<<<<<<<<<<
 *                             [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 *                             [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 */
  __Pyx_TraceLine(118,0,__PYX_ERR(0, 118, __pyx_L1_error))
  __pyx_t_63 = PyList_New(3); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_63, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_63, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_63, 2, __pyx_int_0);
  __pyx_t_64 = PyList_New(3); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_64, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_64, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_64, 2, __pyx_int_95);
  __pyx_t_65 = PyList_New(3); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_65, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_65, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_65, 2, __pyx_int_135);
  __pyx_t_66 = PyList_New(3); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_66, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_66, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_66, 2, __pyx_int_175);
  __pyx_t_67 = PyList_New(3); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_67, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_67, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_67, 2, __pyx_int_215);
  __pyx_t_68 = PyList_New(3); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_68, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_68, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_68, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":119
 *                             [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 *                             [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 *                             [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],             # <<<<<<<<<<<<<<
 *                             [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 *                             [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 */
  __Pyx_TraceLine(119,0,__PYX_ERR(0, 119, __pyx_L1_error))
  __pyx_t_69 = PyList_New(3); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_69, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_69, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_69, 2, __pyx_int_0);
  __pyx_t_70 = PyList_New(3); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_70, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_70, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_70, 2, __pyx_int_95);
  __pyx_t_71 = PyList_New(3); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_71, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_71, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_71, 2, __pyx_int_135);
  __pyx_t_72 = PyList_New(3); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_72, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_72, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_72, 2, __pyx_int_175);
  __pyx_t_73 = PyList_New(3); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_73, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_73, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_73, 2, __pyx_int_215);
  __pyx_t_74 = PyList_New(3); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_74, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_74, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_74, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":120
 *                             [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 *                             [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 *                             [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],             # <<<<<<<<<<<<<<
 *                             [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 *                             [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 */
  __Pyx_TraceLine(120,0,__PYX_ERR(0, 120, __pyx_L1_error))
  __pyx_t_75 = PyList_New(3); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_75, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_75, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_75, 2, __pyx_int_0);
  __pyx_t_76 = PyList_New(3); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_76, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_76, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_76, 2, __pyx_int_95);
  __pyx_t_77 = PyList_New(3); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_77, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_77, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_77, 2, __pyx_int_135);
  __pyx_t_78 = PyList_New(3); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_78, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_78, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_78, 2, __pyx_int_175);
  __pyx_t_79 = PyList_New(3); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_79, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_79, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_79, 2, __pyx_int_215);
  __pyx_t_80 = PyList_New(3); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_80, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_80, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_80, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":121
 *                             [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 *                             [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 *                             [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],             # <<<<<<<<<<<<<<
 *                             [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 *                             [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 */
  __Pyx_TraceLine(121,0,__PYX_ERR(0, 121, __pyx_L1_error))
  __pyx_t_81 = PyList_New(3); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_81, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_81, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_81, 2, __pyx_int_0);
  __pyx_t_82 = PyList_New(3); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_82, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_82, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_82, 2, __pyx_int_95);
  __pyx_t_83 = PyList_New(3); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_83, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_83, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_83, 2, __pyx_int_135);
  __pyx_t_84 = PyList_New(3); if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_84, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_84, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_84, 2, __pyx_int_175);
  __pyx_t_85 = PyList_New(3); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_85, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_85, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_85, 2, __pyx_int_215);
  __pyx_t_86 = PyList_New(3); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_86, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_86, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_86, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":122
 *                             [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 *                             [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 *                             [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],             # <<<<<<<<<<<<<<
 *                             [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 *                             [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 */
  __Pyx_TraceLine(122,0,__PYX_ERR(0, 122, __pyx_L1_error))
  __pyx_t_87 = PyList_New(3); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_87, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_87, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_87, 2, __pyx_int_0);
  __pyx_t_88 = PyList_New(3); if (unlikely(!__pyx_t_88)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_88);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_88, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_88, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_88, 2, __pyx_int_95);
  __pyx_t_89 = PyList_New(3); if (unlikely(!__pyx_t_89)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_89);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_89, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_89, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_89, 2, __pyx_int_135);
  __pyx_t_90 = PyList_New(3); if (unlikely(!__pyx_t_90)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_90);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_90, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_90, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_90, 2, __pyx_int_175);
  __pyx_t_91 = PyList_New(3); if (unlikely(!__pyx_t_91)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_91);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_91, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_91, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_91, 2, __pyx_int_215);
  __pyx_t_92 = PyList_New(3); if (unlikely(!__pyx_t_92)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_92);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_92, 0, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_92, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_92, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":123
 *                             [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 *                             [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 *                             [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],             # <<<<<<<<<<<<<<
 *                             [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 *                             [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 */
  __Pyx_TraceLine(123,0,__PYX_ERR(0, 123, __pyx_L1_error))
  __pyx_t_93 = PyList_New(3); if (unlikely(!__pyx_t_93)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_93);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_93, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_93, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_93, 2, __pyx_int_0);
  __pyx_t_94 = PyList_New(3); if (unlikely(!__pyx_t_94)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_94);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_94, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_94, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_94, 2, __pyx_int_95);
  __pyx_t_95 = PyList_New(3); if (unlikely(!__pyx_t_95)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_95, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_95, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_95, 2, __pyx_int_135);
  __pyx_t_96 = PyList_New(3); if (unlikely(!__pyx_t_96)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_96);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_96, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_96, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_96, 2, __pyx_int_175);
  __pyx_t_97 = PyList_New(3); if (unlikely(!__pyx_t_97)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_97);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_97, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_97, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_97, 2, __pyx_int_215);
  __pyx_t_98 = PyList_New(3); if (unlikely(!__pyx_t_98)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_98);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_98, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_98, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_98, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":124
 *                             [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 *                             [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 *                             [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],             # <<<<<<<<<<<<<<
 *                             [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 *                             [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 */
  __Pyx_TraceLine(124,0,__PYX_ERR(0, 124, __pyx_L1_error))
  __pyx_t_99 = PyList_New(3); if (unlikely(!__pyx_t_99)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_99);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_99, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_99, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_99, 2, __pyx_int_0);
  __pyx_t_100 = PyList_New(3); if (unlikely(!__pyx_t_100)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_100);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_100, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_100, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_100, 2, __pyx_int_95);
  __pyx_t_101 = PyList_New(3); if (unlikely(!__pyx_t_101)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_101);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_101, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_101, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_101, 2, __pyx_int_135);
  __pyx_t_102 = PyList_New(3); if (unlikely(!__pyx_t_102)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_102);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_102, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_102, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_102, 2, __pyx_int_175);
  __pyx_t_103 = PyList_New(3); if (unlikely(!__pyx_t_103)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_103);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_103, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_103, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_103, 2, __pyx_int_215);
  __pyx_t_104 = PyList_New(3); if (unlikely(!__pyx_t_104)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_104);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_104, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_104, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_104, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":125
 *                             [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 *                             [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 *                             [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],             # <<<<<<<<<<<<<<
 *                             [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 *                             [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 */
  __Pyx_TraceLine(125,0,__PYX_ERR(0, 125, __pyx_L1_error))
  __pyx_t_105 = PyList_New(3); if (unlikely(!__pyx_t_105)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_105);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_105, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_105, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_105, 2, __pyx_int_0);
  __pyx_t_106 = PyList_New(3); if (unlikely(!__pyx_t_106)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_106);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_106, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_106, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_106, 2, __pyx_int_95);
  __pyx_t_107 = PyList_New(3); if (unlikely(!__pyx_t_107)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_107);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_107, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_107, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_107, 2, __pyx_int_135);
  __pyx_t_108 = PyList_New(3); if (unlikely(!__pyx_t_108)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_108);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_108, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_108, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_108, 2, __pyx_int_175);
  __pyx_t_109 = PyList_New(3); if (unlikely(!__pyx_t_109)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_109);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_109, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_109, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_109, 2, __pyx_int_215);
  __pyx_t_110 = PyList_New(3); if (unlikely(!__pyx_t_110)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_110);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_110, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_110, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_110, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":126
 *                             [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 *                             [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 *                             [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],             # <<<<<<<<<<<<<<
 *                             [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 *                             [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 */
  __Pyx_TraceLine(126,0,__PYX_ERR(0, 126, __pyx_L1_error))
  __pyx_t_111 = PyList_New(3); if (unlikely(!__pyx_t_111)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_111);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_111, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_111, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_111, 2, __pyx_int_0);
  __pyx_t_112 = PyList_New(3); if (unlikely(!__pyx_t_112)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_112);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_112, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_112, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_112, 2, __pyx_int_95);
  __pyx_t_113 = PyList_New(3); if (unlikely(!__pyx_t_113)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_113);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_113, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_113, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_113, 2, __pyx_int_135);
  __pyx_t_114 = PyList_New(3); if (unlikely(!__pyx_t_114)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_114);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_114, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_114, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_114, 2, __pyx_int_175);
  __pyx_t_115 = PyList_New(3); if (unlikely(!__pyx_t_115)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_115);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_115, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_115, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_115, 2, __pyx_int_215);
  __pyx_t_116 = PyList_New(3); if (unlikely(!__pyx_t_116)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_116);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_116, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_116, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_116, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":127
 *                             [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 *                             [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 *                             [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],             # <<<<<<<<<<<<<<
 *                             [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 *                             [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 */
  __Pyx_TraceLine(127,0,__PYX_ERR(0, 127, __pyx_L1_error))
  __pyx_t_117 = PyList_New(3); if (unlikely(!__pyx_t_117)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_117);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_117, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_117, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_117, 2, __pyx_int_0);
  __pyx_t_118 = PyList_New(3); if (unlikely(!__pyx_t_118)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_118);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_118, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_118, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_118, 2, __pyx_int_95);
  __pyx_t_119 = PyList_New(3); if (unlikely(!__pyx_t_119)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_119);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_119, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_119, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_119, 2, __pyx_int_135);
  __pyx_t_120 = PyList_New(3); if (unlikely(!__pyx_t_120)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_120);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_120, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_120, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_120, 2, __pyx_int_175);
  __pyx_t_121 = PyList_New(3); if (unlikely(!__pyx_t_121)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_121);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_121, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_121, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_121, 2, __pyx_int_215);
  __pyx_t_122 = PyList_New(3); if (unlikely(!__pyx_t_122)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_122);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_122, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_122, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_122, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":128
 *                             [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 *                             [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 *                             [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],             # <<<<<<<<<<<<<<
 *                             [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 *                             [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 */
  __Pyx_TraceLine(128,0,__PYX_ERR(0, 128, __pyx_L1_error))
  __pyx_t_123 = PyList_New(3); if (unlikely(!__pyx_t_123)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_123);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_123, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_123, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_123, 2, __pyx_int_0);
  __pyx_t_124 = PyList_New(3); if (unlikely(!__pyx_t_124)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_124);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_124, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_124, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_124, 2, __pyx_int_95);
  __pyx_t_125 = PyList_New(3); if (unlikely(!__pyx_t_125)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_125);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_125, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_125, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_125, 2, __pyx_int_135);
  __pyx_t_126 = PyList_New(3); if (unlikely(!__pyx_t_126)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_126);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_126, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_126, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_126, 2, __pyx_int_175);
  __pyx_t_127 = PyList_New(3); if (unlikely(!__pyx_t_127)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_127);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_127, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_127, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_127, 2, __pyx_int_215);
  __pyx_t_128 = PyList_New(3); if (unlikely(!__pyx_t_128)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_128);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_128, 0, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_128, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_128, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":129
 *                             [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 *                             [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 *                             [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],             # <<<<<<<<<<<<<<
 *                             [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 *                             [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 */
  __Pyx_TraceLine(129,0,__PYX_ERR(0, 129, __pyx_L1_error))
  __pyx_t_129 = PyList_New(3); if (unlikely(!__pyx_t_129)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_129);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_129, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_129, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_129, 2, __pyx_int_0);
  __pyx_t_130 = PyList_New(3); if (unlikely(!__pyx_t_130)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_130);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_130, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_130, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_130, 2, __pyx_int_95);
  __pyx_t_131 = PyList_New(3); if (unlikely(!__pyx_t_131)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_131);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_131, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_131, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_131, 2, __pyx_int_135);
  __pyx_t_132 = PyList_New(3); if (unlikely(!__pyx_t_132)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_132);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_132, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_132, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_132, 2, __pyx_int_175);
  __pyx_t_133 = PyList_New(3); if (unlikely(!__pyx_t_133)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_133);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_133, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_133, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_133, 2, __pyx_int_215);
  __pyx_t_134 = PyList_New(3); if (unlikely(!__pyx_t_134)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_134);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_134, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_134, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_134, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":130
 *                             [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 *                             [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 *                             [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],             # <<<<<<<<<<<<<<
 *                             [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 *                             [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 */
  __Pyx_TraceLine(130,0,__PYX_ERR(0, 130, __pyx_L1_error))
  __pyx_t_135 = PyList_New(3); if (unlikely(!__pyx_t_135)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_135, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_135, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_135, 2, __pyx_int_0);
  __pyx_t_136 = PyList_New(3); if (unlikely(!__pyx_t_136)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_136);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_136, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_136, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_136, 2, __pyx_int_95);
  __pyx_t_137 = PyList_New(3); if (unlikely(!__pyx_t_137)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_137);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_137, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_137, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_137, 2, __pyx_int_135);
  __pyx_t_138 = PyList_New(3); if (unlikely(!__pyx_t_138)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_138);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_138, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_138, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_138, 2, __pyx_int_175);
  __pyx_t_139 = PyList_New(3); if (unlikely(!__pyx_t_139)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_139);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_139, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_139, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_139, 2, __pyx_int_215);
  __pyx_t_140 = PyList_New(3); if (unlikely(!__pyx_t_140)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_140);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_140, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_140, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_140, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":131
 *                             [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 *                             [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 *                             [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],             # <<<<<<<<<<<<<<
 *                             [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 *                             [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 */
  __Pyx_TraceLine(131,0,__PYX_ERR(0, 131, __pyx_L1_error))
  __pyx_t_141 = PyList_New(3); if (unlikely(!__pyx_t_141)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_141);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_141, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_141, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_141, 2, __pyx_int_0);
  __pyx_t_142 = PyList_New(3); if (unlikely(!__pyx_t_142)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_142);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_142, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_142, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_142, 2, __pyx_int_95);
  __pyx_t_143 = PyList_New(3); if (unlikely(!__pyx_t_143)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_143);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_143, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_143, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_143, 2, __pyx_int_135);
  __pyx_t_144 = PyList_New(3); if (unlikely(!__pyx_t_144)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_144);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_144, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_144, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_144, 2, __pyx_int_175);
  __pyx_t_145 = PyList_New(3); if (unlikely(!__pyx_t_145)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_145);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_145, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_145, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_145, 2, __pyx_int_215);
  __pyx_t_146 = PyList_New(3); if (unlikely(!__pyx_t_146)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_146);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_146, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_146, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_146, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":132
 *                             [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 *                             [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 *                             [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],             # <<<<<<<<<<<<<<
 *                             [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 *                             [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 */
  __Pyx_TraceLine(132,0,__PYX_ERR(0, 132, __pyx_L1_error))
  __pyx_t_147 = PyList_New(3); if (unlikely(!__pyx_t_147)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_147);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_147, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_147, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_147, 2, __pyx_int_0);
  __pyx_t_148 = PyList_New(3); if (unlikely(!__pyx_t_148)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_148);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_148, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_148, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_148, 2, __pyx_int_95);
  __pyx_t_149 = PyList_New(3); if (unlikely(!__pyx_t_149)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_149);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_149, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_149, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_149, 2, __pyx_int_135);
  __pyx_t_150 = PyList_New(3); if (unlikely(!__pyx_t_150)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_150);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_150, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_150, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_150, 2, __pyx_int_175);
  __pyx_t_151 = PyList_New(3); if (unlikely(!__pyx_t_151)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_151);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_151, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_151, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_151, 2, __pyx_int_215);
  __pyx_t_152 = PyList_New(3); if (unlikely(!__pyx_t_152)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_152);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_152, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_152, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_152, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":133
 *                             [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 *                             [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 *                             [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],             # <<<<<<<<<<<<<<
 *                             [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 *                             [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 */
  __Pyx_TraceLine(133,0,__PYX_ERR(0, 133, __pyx_L1_error))
  __pyx_t_153 = PyList_New(3); if (unlikely(!__pyx_t_153)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_153);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_153, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_153, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_153, 2, __pyx_int_0);
  __pyx_t_154 = PyList_New(3); if (unlikely(!__pyx_t_154)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_154);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_154, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_154, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_154, 2, __pyx_int_95);
  __pyx_t_155 = PyList_New(3); if (unlikely(!__pyx_t_155)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_155);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_155, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_155, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_155, 2, __pyx_int_135);
  __pyx_t_156 = PyList_New(3); if (unlikely(!__pyx_t_156)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_156);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_156, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_156, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_156, 2, __pyx_int_175);
  __pyx_t_157 = PyList_New(3); if (unlikely(!__pyx_t_157)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_157);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_157, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_157, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_157, 2, __pyx_int_215);
  __pyx_t_158 = PyList_New(3); if (unlikely(!__pyx_t_158)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_158);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_158, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_158, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_158, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":134
 *                             [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 *                             [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 *                             [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],             # <<<<<<<<<<<<<<
 *                             [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 *                             [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 */
  __Pyx_TraceLine(134,0,__PYX_ERR(0, 134, __pyx_L1_error))
  __pyx_t_159 = PyList_New(3); if (unlikely(!__pyx_t_159)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_159);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_159, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_159, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_159, 2, __pyx_int_0);
  __pyx_t_160 = PyList_New(3); if (unlikely(!__pyx_t_160)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_160);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_160, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_160, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_160, 2, __pyx_int_95);
  __pyx_t_161 = PyList_New(3); if (unlikely(!__pyx_t_161)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_161);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_161, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_161, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_161, 2, __pyx_int_135);
  __pyx_t_162 = PyList_New(3); if (unlikely(!__pyx_t_162)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_162);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_162, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_162, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_162, 2, __pyx_int_175);
  __pyx_t_163 = PyList_New(3); if (unlikely(!__pyx_t_163)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_163);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_163, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_163, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_163, 2, __pyx_int_215);
  __pyx_t_164 = PyList_New(3); if (unlikely(!__pyx_t_164)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_164);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_164, 0, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_164, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_164, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":135
 *                             [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 *                             [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 *                             [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],             # <<<<<<<<<<<<<<
 *                             [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 *                             [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 */
  __Pyx_TraceLine(135,0,__PYX_ERR(0, 135, __pyx_L1_error))
  __pyx_t_165 = PyList_New(3); if (unlikely(!__pyx_t_165)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_165);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_165, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_165, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_165, 2, __pyx_int_0);
  __pyx_t_166 = PyList_New(3); if (unlikely(!__pyx_t_166)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_166);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_166, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_166, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_166, 2, __pyx_int_95);
  __pyx_t_167 = PyList_New(3); if (unlikely(!__pyx_t_167)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_167);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_167, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_167, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_167, 2, __pyx_int_135);
  __pyx_t_168 = PyList_New(3); if (unlikely(!__pyx_t_168)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_168);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_168, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_168, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_168, 2, __pyx_int_175);
  __pyx_t_169 = PyList_New(3); if (unlikely(!__pyx_t_169)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_169);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_169, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_169, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_169, 2, __pyx_int_215);
  __pyx_t_170 = PyList_New(3); if (unlikely(!__pyx_t_170)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_170);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_170, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_170, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_170, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":136
 *                             [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 *                             [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 *                             [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],             # <<<<<<<<<<<<<<
 *                             [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 *                             [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 */
  __Pyx_TraceLine(136,0,__PYX_ERR(0, 136, __pyx_L1_error))
  __pyx_t_171 = PyList_New(3); if (unlikely(!__pyx_t_171)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_171);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_171, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_171, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_171, 2, __pyx_int_0);
  __pyx_t_172 = PyList_New(3); if (unlikely(!__pyx_t_172)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_172);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_172, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_172, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_172, 2, __pyx_int_95);
  __pyx_t_173 = PyList_New(3); if (unlikely(!__pyx_t_173)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_173);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_173, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_173, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_173, 2, __pyx_int_135);
  __pyx_t_174 = PyList_New(3); if (unlikely(!__pyx_t_174)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_174);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_174, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_174, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_174, 2, __pyx_int_175);
  __pyx_t_175 = PyList_New(3); if (unlikely(!__pyx_t_175)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_175, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_175, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_175, 2, __pyx_int_215);
  __pyx_t_176 = PyList_New(3); if (unlikely(!__pyx_t_176)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_176);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_176, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_176, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_176, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":137
 *                             [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 *                             [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 *                             [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],             # <<<<<<<<<<<<<<
 *                             [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 *                             [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 */
  __Pyx_TraceLine(137,0,__PYX_ERR(0, 137, __pyx_L1_error))
  __pyx_t_177 = PyList_New(3); if (unlikely(!__pyx_t_177)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_177);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_177, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_177, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_177, 2, __pyx_int_0);
  __pyx_t_178 = PyList_New(3); if (unlikely(!__pyx_t_178)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_178);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_178, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_178, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_178, 2, __pyx_int_95);
  __pyx_t_179 = PyList_New(3); if (unlikely(!__pyx_t_179)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_179);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_179, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_179, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_179, 2, __pyx_int_135);
  __pyx_t_180 = PyList_New(3); if (unlikely(!__pyx_t_180)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_180);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_180, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_180, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_180, 2, __pyx_int_175);
  __pyx_t_181 = PyList_New(3); if (unlikely(!__pyx_t_181)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_181);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_181, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_181, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_181, 2, __pyx_int_215);
  __pyx_t_182 = PyList_New(3); if (unlikely(!__pyx_t_182)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_182);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_182, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_182, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_182, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":138
 *                             [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 *                             [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 *                             [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],             # <<<<<<<<<<<<<<
 *                             [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 *                             [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 */
  __Pyx_TraceLine(138,0,__PYX_ERR(0, 138, __pyx_L1_error))
  __pyx_t_183 = PyList_New(3); if (unlikely(!__pyx_t_183)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_183);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_183, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_183, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_183, 2, __pyx_int_0);
  __pyx_t_184 = PyList_New(3); if (unlikely(!__pyx_t_184)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_184);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_184, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_184, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_184, 2, __pyx_int_95);
  __pyx_t_185 = PyList_New(3); if (unlikely(!__pyx_t_185)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_185);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_185, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_185, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_185, 2, __pyx_int_135);
  __pyx_t_186 = PyList_New(3); if (unlikely(!__pyx_t_186)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_186);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_186, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_186, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_186, 2, __pyx_int_175);
  __pyx_t_187 = PyList_New(3); if (unlikely(!__pyx_t_187)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_187);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_187, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_187, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_187, 2, __pyx_int_215);
  __pyx_t_188 = PyList_New(3); if (unlikely(!__pyx_t_188)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_188);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_188, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_188, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_188, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":139
 *                             [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 *                             [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 *                             [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],             # <<<<<<<<<<<<<<
 *                             [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 *                             [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 */
  __Pyx_TraceLine(139,0,__PYX_ERR(0, 139, __pyx_L1_error))
  __pyx_t_189 = PyList_New(3); if (unlikely(!__pyx_t_189)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_189);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_189, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_189, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_189, 2, __pyx_int_0);
  __pyx_t_190 = PyList_New(3); if (unlikely(!__pyx_t_190)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_190);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_190, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_190, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_190, 2, __pyx_int_95);
  __pyx_t_191 = PyList_New(3); if (unlikely(!__pyx_t_191)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_191);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_191, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_191, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_191, 2, __pyx_int_135);
  __pyx_t_192 = PyList_New(3); if (unlikely(!__pyx_t_192)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_192);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_192, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_192, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_192, 2, __pyx_int_175);
  __pyx_t_193 = PyList_New(3); if (unlikely(!__pyx_t_193)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_193);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_193, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_193, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_193, 2, __pyx_int_215);
  __pyx_t_194 = PyList_New(3); if (unlikely(!__pyx_t_194)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_194);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_194, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_194, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_194, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":140
 *                             [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 *                             [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 *                             [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],             # <<<<<<<<<<<<<<
 *                             [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 *                             [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 */
  __Pyx_TraceLine(140,0,__PYX_ERR(0, 140, __pyx_L1_error))
  __pyx_t_195 = PyList_New(3); if (unlikely(!__pyx_t_195)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_195);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_195, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_195, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_195, 2, __pyx_int_0);
  __pyx_t_196 = PyList_New(3); if (unlikely(!__pyx_t_196)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_196);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_196, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_196, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_196, 2, __pyx_int_95);
  __pyx_t_197 = PyList_New(3); if (unlikely(!__pyx_t_197)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_197);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_197, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_197, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_197, 2, __pyx_int_135);
  __pyx_t_198 = PyList_New(3); if (unlikely(!__pyx_t_198)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_198);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_198, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_198, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_198, 2, __pyx_int_175);
  __pyx_t_199 = PyList_New(3); if (unlikely(!__pyx_t_199)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_199);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_199, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_199, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_199, 2, __pyx_int_215);
  __pyx_t_200 = PyList_New(3); if (unlikely(!__pyx_t_200)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_200);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_200, 0, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_200, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_200, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":141
 *                             [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 *                             [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 *                             [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],             # <<<<<<<<<<<<<<
 *                             [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 *                             [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 */
  __Pyx_TraceLine(141,0,__PYX_ERR(0, 141, __pyx_L1_error))
  __pyx_t_201 = PyList_New(3); if (unlikely(!__pyx_t_201)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_201);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_201, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_201, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_201, 2, __pyx_int_0);
  __pyx_t_202 = PyList_New(3); if (unlikely(!__pyx_t_202)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_202);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_202, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_202, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_202, 2, __pyx_int_95);
  __pyx_t_203 = PyList_New(3); if (unlikely(!__pyx_t_203)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_203);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_203, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_203, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_203, 2, __pyx_int_135);
  __pyx_t_204 = PyList_New(3); if (unlikely(!__pyx_t_204)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_204);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_204, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_204, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_204, 2, __pyx_int_175);
  __pyx_t_205 = PyList_New(3); if (unlikely(!__pyx_t_205)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_205);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_205, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_205, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_205, 2, __pyx_int_215);
  __pyx_t_206 = PyList_New(3); if (unlikely(!__pyx_t_206)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_206);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_206, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_206, 1, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_206, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":142
 *                             [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 *                             [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 *                             [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],             # <<<<<<<<<<<<<<
 *                             [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 *                             [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 */
  __Pyx_TraceLine(142,0,__PYX_ERR(0, 142, __pyx_L1_error))
  __pyx_t_207 = PyList_New(3); if (unlikely(!__pyx_t_207)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_207);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_207, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_207, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_207, 2, __pyx_int_0);
  __pyx_t_208 = PyList_New(3); if (unlikely(!__pyx_t_208)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_208);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_208, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_208, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_208, 2, __pyx_int_95);
  __pyx_t_209 = PyList_New(3); if (unlikely(!__pyx_t_209)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_209);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_209, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_209, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_209, 2, __pyx_int_135);
  __pyx_t_210 = PyList_New(3); if (unlikely(!__pyx_t_210)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_210);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_210, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_210, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_210, 2, __pyx_int_175);
  __pyx_t_211 = PyList_New(3); if (unlikely(!__pyx_t_211)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_211);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_211, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_211, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_211, 2, __pyx_int_215);
  __pyx_t_212 = PyList_New(3); if (unlikely(!__pyx_t_212)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_212);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_212, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_212, 1, __pyx_int_95);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_212, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":143
 *                             [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 *                             [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 *                             [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],             # <<<<<<<<<<<<<<
 *                             [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 *                             [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 */
  __Pyx_TraceLine(143,0,__PYX_ERR(0, 143, __pyx_L1_error))
  __pyx_t_213 = PyList_New(3); if (unlikely(!__pyx_t_213)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_213);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_213, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_213, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_213, 2, __pyx_int_0);
  __pyx_t_214 = PyList_New(3); if (unlikely(!__pyx_t_214)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_214);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_214, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_214, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_214, 2, __pyx_int_95);
  __pyx_t_215 = PyList_New(3); if (unlikely(!__pyx_t_215)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_215, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_215, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_215, 2, __pyx_int_135);
  __pyx_t_216 = PyList_New(3); if (unlikely(!__pyx_t_216)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_216);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_216, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_216, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_216, 2, __pyx_int_175);
  __pyx_t_217 = PyList_New(3); if (unlikely(!__pyx_t_217)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_217);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_217, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_217, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_217, 2, __pyx_int_215);
  __pyx_t_218 = PyList_New(3); if (unlikely(!__pyx_t_218)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_218);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_218, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_218, 1, __pyx_int_135);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_218, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":144
 *                             [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 *                             [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 *                             [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],             # <<<<<<<<<<<<<<
 *                             [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 *                             [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 */
  __Pyx_TraceLine(144,0,__PYX_ERR(0, 144, __pyx_L1_error))
  __pyx_t_219 = PyList_New(3); if (unlikely(!__pyx_t_219)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_219);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_219, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_219, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_219, 2, __pyx_int_0);
  __pyx_t_220 = PyList_New(3); if (unlikely(!__pyx_t_220)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_220);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_220, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_220, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_220, 2, __pyx_int_95);
  __pyx_t_221 = PyList_New(3); if (unlikely(!__pyx_t_221)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_221);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_221, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_221, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_221, 2, __pyx_int_135);
  __pyx_t_222 = PyList_New(3); if (unlikely(!__pyx_t_222)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_222);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_222, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_222, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_222, 2, __pyx_int_175);
  __pyx_t_223 = PyList_New(3); if (unlikely(!__pyx_t_223)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_223);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_223, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_223, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_223, 2, __pyx_int_215);
  __pyx_t_224 = PyList_New(3); if (unlikely(!__pyx_t_224)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_224);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_224, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_224, 1, __pyx_int_175);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_224, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":145
 *                             [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 *                             [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 *                             [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],             # <<<<<<<<<<<<<<
 *                             [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 *                             [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 */
  __Pyx_TraceLine(145,0,__PYX_ERR(0, 145, __pyx_L1_error))
  __pyx_t_225 = PyList_New(3); if (unlikely(!__pyx_t_225)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_225);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_225, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_225, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_225, 2, __pyx_int_0);
  __pyx_t_226 = PyList_New(3); if (unlikely(!__pyx_t_226)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_226);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_226, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_226, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_226, 2, __pyx_int_95);
  __pyx_t_227 = PyList_New(3); if (unlikely(!__pyx_t_227)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_227);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_227, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_227, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_227, 2, __pyx_int_135);
  __pyx_t_228 = PyList_New(3); if (unlikely(!__pyx_t_228)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_228);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_228, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_228, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_228, 2, __pyx_int_175);
  __pyx_t_229 = PyList_New(3); if (unlikely(!__pyx_t_229)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_229);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_229, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_229, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_229, 2, __pyx_int_215);
  __pyx_t_230 = PyList_New(3); if (unlikely(!__pyx_t_230)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_230);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_230, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_230, 1, __pyx_int_215);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_230, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":146
 *                             [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 *                             [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 *                             [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],             # <<<<<<<<<<<<<<
 *                             [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 *                             [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 */
  __Pyx_TraceLine(146,0,__PYX_ERR(0, 146, __pyx_L1_error))
  __pyx_t_231 = PyList_New(3); if (unlikely(!__pyx_t_231)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_231);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_231, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_231, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_231, 2, __pyx_int_0);
  __pyx_t_232 = PyList_New(3); if (unlikely(!__pyx_t_232)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_232);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_232, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_232, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  PyList_SET_ITEM(__pyx_t_232, 2, __pyx_int_95);
  __pyx_t_233 = PyList_New(3); if (unlikely(!__pyx_t_233)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_233);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_233, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_233, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  PyList_SET_ITEM(__pyx_t_233, 2, __pyx_int_135);
  __pyx_t_234 = PyList_New(3); if (unlikely(!__pyx_t_234)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_234);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_234, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_234, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_175);
  __Pyx_GIVEREF(__pyx_int_175);
  PyList_SET_ITEM(__pyx_t_234, 2, __pyx_int_175);
  __pyx_t_235 = PyList_New(3); if (unlikely(!__pyx_t_235)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_235);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_235, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_235, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_215);
  __Pyx_GIVEREF(__pyx_int_215);
  PyList_SET_ITEM(__pyx_t_235, 2, __pyx_int_215);
  __pyx_t_236 = PyList_New(3); if (unlikely(!__pyx_t_236)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_236);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_236, 0, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_236, 1, __pyx_int_255);
  __Pyx_INCREF(__pyx_int_255);
  __Pyx_GIVEREF(__pyx_int_255);
  PyList_SET_ITEM(__pyx_t_236, 2, __pyx_int_255);

  /* "ttygif/tty/viewer.pyx":147
 *                             [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 *                             [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 *                             [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],             # <<<<<<<<<<<<<<
 *                             [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 *                             [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],
 */
  __Pyx_TraceLine(147,0,__PYX_ERR(0, 147, __pyx_L1_error))
  __pyx_t_237 = PyList_New(3); if (unlikely(!__pyx_t_237)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_237);
  __Pyx_INCREF(__pyx_int_8);
  __Pyx_GIVEREF(__pyx_int_8);
  PyList_SET_ITEM(__pyx_t_237, 0, __pyx_int_8);
  __Pyx_INCREF(__pyx_int_8);
  __Pyx_GIVEREF(__pyx_int_8);
  PyList_SET_ITEM(__pyx_t_237, 1, __pyx_int_8);
  __Pyx_INCREF(__pyx_int_8);
  __Pyx_GIVEREF(__pyx_int_8);
  PyList_SET_ITEM(__pyx_t_237, 2, __pyx_int_8);
  __pyx_t_238 = PyList_New(3); if (unlikely(!__pyx_t_238)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_238);
  __Pyx_INCREF(__pyx_int_18);
  __Pyx_GIVEREF(__pyx_int_18);
  PyList_SET_ITEM(__pyx_t_238, 0, __pyx_int_18);
  __Pyx_INCREF(__pyx_int_18);
  __Pyx_GIVEREF(__pyx_int_18);
  PyList_SET_ITEM(__pyx_t_238, 1, __pyx_int_18);
  __Pyx_INCREF(__pyx_int_18);
  __Pyx_GIVEREF(__pyx_int_18);
  PyList_SET_ITEM(__pyx_t_238, 2, __pyx_int_18);
  __pyx_t_239 = PyList_New(3); if (unlikely(!__pyx_t_239)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_239);
  __Pyx_INCREF(__pyx_int_28);
  __Pyx_GIVEREF(__pyx_int_28);
  PyList_SET_ITEM(__pyx_t_239, 0, __pyx_int_28);
  __Pyx_INCREF(__pyx_int_28);
  __Pyx_GIVEREF(__pyx_int_28);
  PyList_SET_ITEM(__pyx_t_239, 1, __pyx_int_28);
  __Pyx_INCREF(__pyx_int_28);
  __Pyx_GIVEREF(__pyx_int_28);
  PyList_SET_ITEM(__pyx_t_239, 2, __pyx_int_28);
  __pyx_t_240 = PyList_New(3); if (unlikely(!__pyx_t_240)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_240);
  __Pyx_INCREF(__pyx_int_38);
  __Pyx_GIVEREF(__pyx_int_38);
  PyList_SET_ITEM(__pyx_t_240, 0, __pyx_int_38);
  __Pyx_INCREF(__pyx_int_38);
  __Pyx_GIVEREF(__pyx_int_38);
  PyList_SET_ITEM(__pyx_t_240, 1, __pyx_int_38);
  __Pyx_INCREF(__pyx_int_38);
  __Pyx_GIVEREF(__pyx_int_38);
  PyList_SET_ITEM(__pyx_t_240, 2, __pyx_int_38);
  __pyx_t_241 = PyList_New(3); if (unlikely(!__pyx_t_241)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_241);
  __Pyx_INCREF(__pyx_int_48);
  __Pyx_GIVEREF(__pyx_int_48);
  PyList_SET_ITEM(__pyx_t_241, 0, __pyx_int_48);
  __Pyx_INCREF(__pyx_int_48);
  __Pyx_GIVEREF(__pyx_int_48);
  PyList_SET_ITEM(__pyx_t_241, 1, __pyx_int_48);
  __Pyx_INCREF(__pyx_int_48);
  __Pyx_GIVEREF(__pyx_int_48);
  PyList_SET_ITEM(__pyx_t_241, 2, __pyx_int_48);
  __pyx_t_242 = PyList_New(3); if (unlikely(!__pyx_t_242)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_242);
  __Pyx_INCREF(__pyx_int_58);
  __Pyx_GIVEREF(__pyx_int_58);
  PyList_SET_ITEM(__pyx_t_242, 0, __pyx_int_58);
  __Pyx_INCREF(__pyx_int_58);
  __Pyx_GIVEREF(__pyx_int_58);
  PyList_SET_ITEM(__pyx_t_242, 1, __pyx_int_58);
  __Pyx_INCREF(__pyx_int_58);
  __Pyx_GIVEREF(__pyx_int_58);
  PyList_SET_ITEM(__pyx_t_242, 2, __pyx_int_58);
  __pyx_t_243 = PyList_New(3); if (unlikely(!__pyx_t_243)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_243);
  __Pyx_INCREF(__pyx_int_68);
  __Pyx_GIVEREF(__pyx_int_68);
  PyList_SET_ITEM(__pyx_t_243, 0, __pyx_int_68);
  __Pyx_INCREF(__pyx_int_68);
  __Pyx_GIVEREF(__pyx_int_68);
  PyList_SET_ITEM(__pyx_t_243, 1, __pyx_int_68);
  __Pyx_INCREF(__pyx_int_68);
  __Pyx_GIVEREF(__pyx_int_68);
  PyList_SET_ITEM(__pyx_t_243, 2, __pyx_int_68);

  /* "ttygif/tty/viewer.pyx":148
 *                             [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 *                             [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 *                             [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],             # <<<<<<<<<<<<<<
 *                             [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],
 *                             [198,198,198],[208,208,208],[218,218,218],[228,228,228],[238,238,238]
 */
  __Pyx_TraceLine(148,0,__PYX_ERR(0, 148, __pyx_L1_error))
  __pyx_t_244 = PyList_New(3); if (unlikely(!__pyx_t_244)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_244);
  __Pyx_INCREF(__pyx_int_78);
  __Pyx_GIVEREF(__pyx_int_78);
  PyList_SET_ITEM(__pyx_t_244, 0, __pyx_int_78);
  __Pyx_INCREF(__pyx_int_78);
  __Pyx_GIVEREF(__pyx_int_78);
  PyList_SET_ITEM(__pyx_t_244, 1, __pyx_int_78);
  __Pyx_INCREF(__pyx_int_78);
  __Pyx_GIVEREF(__pyx_int_78);
  PyList_SET_ITEM(__pyx_t_244, 2, __pyx_int_78);
  __pyx_t_245 = PyList_New(3); if (unlikely(!__pyx_t_245)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_245);
  __Pyx_INCREF(__pyx_int_88);
  __Pyx_GIVEREF(__pyx_int_88);
  PyList_SET_ITEM(__pyx_t_245, 0, __pyx_int_88);
  __Pyx_INCREF(__pyx_int_88);
  __Pyx_GIVEREF(__pyx_int_88);
  PyList_SET_ITEM(__pyx_t_245, 1, __pyx_int_88);
  __Pyx_INCREF(__pyx_int_88);
  __Pyx_GIVEREF(__pyx_int_88);
  PyList_SET_ITEM(__pyx_t_245, 2, __pyx_int_88);
  __pyx_t_246 = PyList_New(3); if (unlikely(!__pyx_t_246)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_246);
  __Pyx_INCREF(__pyx_int_98);
  __Pyx_GIVEREF(__pyx_int_98);
  PyList_SET_ITEM(__pyx_t_246, 0, __pyx_int_98);
  __Pyx_INCREF(__pyx_int_98);
  __Pyx_GIVEREF(__pyx_int_98);
  PyList_SET_ITEM(__pyx_t_246, 1, __pyx_int_98);
  __Pyx_INCREF(__pyx_int_98);
  __Pyx_GIVEREF(__pyx_int_98);
  PyList_SET_ITEM(__pyx_t_246, 2, __pyx_int_98);
  __pyx_t_247 = PyList_New(3); if (unlikely(!__pyx_t_247)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_247);
  __Pyx_INCREF(__pyx_int_108);
  __Pyx_GIVEREF(__pyx_int_108);
  PyList_SET_ITEM(__pyx_t_247, 0, __pyx_int_108);
  __Pyx_INCREF(__pyx_int_108);
  __Pyx_GIVEREF(__pyx_int_108);
  PyList_SET_ITEM(__pyx_t_247, 1, __pyx_int_108);
  __Pyx_INCREF(__pyx_int_108);
  __Pyx_GIVEREF(__pyx_int_108);
  PyList_SET_ITEM(__pyx_t_247, 2, __pyx_int_108);
  __pyx_t_248 = PyList_New(3); if (unlikely(!__pyx_t_248)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_248);
  __Pyx_INCREF(__pyx_int_118);
  __Pyx_GIVEREF(__pyx_int_118);
  PyList_SET_ITEM(__pyx_t_248, 0, __pyx_int_118);
  __Pyx_INCREF(__pyx_int_118);
  __Pyx_GIVEREF(__pyx_int_118);
  PyList_SET_ITEM(__pyx_t_248, 1, __pyx_int_118);
  __Pyx_INCREF(__pyx_int_118);
  __Pyx_GIVEREF(__pyx_int_118);
  PyList_SET_ITEM(__pyx_t_248, 2, __pyx_int_118);
  __pyx_t_249 = PyList_New(3); if (unlikely(!__pyx_t_249)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_249);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_249, 0, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_249, 1, __pyx_int_128);
  __Pyx_INCREF(__pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  PyList_SET_ITEM(__pyx_t_249, 2, __pyx_int_128);

  /* "ttygif/tty/viewer.pyx":149
 *                             [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 *                             [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 *                             [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],             # <<<<<<<<<<<<<<
 *                             [198,198,198],[208,208,208],[218,218,218],[228,228,228],[238,238,238]
 *         ]
 */
  __Pyx_TraceLine(149,0,__PYX_ERR(0, 149, __pyx_L1_error))
  __pyx_t_250 = PyList_New(3); if (unlikely(!__pyx_t_250)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_250);
  __Pyx_INCREF(__pyx_int_138);
  __Pyx_GIVEREF(__pyx_int_138);
  PyList_SET_ITEM(__pyx_t_250, 0, __pyx_int_138);
  __Pyx_INCREF(__pyx_int_138);
  __Pyx_GIVEREF(__pyx_int_138);
  PyList_SET_ITEM(__pyx_t_250, 1, __pyx_int_138);
  __Pyx_INCREF(__pyx_int_138);
  __Pyx_GIVEREF(__pyx_int_138);
  PyList_SET_ITEM(__pyx_t_250, 2, __pyx_int_138);
  __pyx_t_251 = PyList_New(3); if (unlikely(!__pyx_t_251)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_251);
  __Pyx_INCREF(__pyx_int_148);
  __Pyx_GIVEREF(__pyx_int_148);
  PyList_SET_ITEM(__pyx_t_251, 0, __pyx_int_148);
  __Pyx_INCREF(__pyx_int_148);
  __Pyx_GIVEREF(__pyx_int_148);
  PyList_SET_ITEM(__pyx_t_251, 1, __pyx_int_148);
  __Pyx_INCREF(__pyx_int_148);
  __Pyx_GIVEREF(__pyx_int_148);
  PyList_SET_ITEM(__pyx_t_251, 2, __pyx_int_148);
  __pyx_t_252 = PyList_New(3); if (unlikely(!__pyx_t_252)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_252);
  __Pyx_INCREF(__pyx_int_158);
  __Pyx_GIVEREF(__pyx_int_158);
  PyList_SET_ITEM(__pyx_t_252, 0, __pyx_int_158);
  __Pyx_INCREF(__pyx_int_158);
  __Pyx_GIVEREF(__pyx_int_158);
  PyList_SET_ITEM(__pyx_t_252, 1, __pyx_int_158);
  __Pyx_INCREF(__pyx_int_158);
  __Pyx_GIVEREF(__pyx_int_158);
  PyList_SET_ITEM(__pyx_t_252, 2, __pyx_int_158);
  __pyx_t_253 = PyList_New(3); if (unlikely(!__pyx_t_253)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_253);
  __Pyx_INCREF(__pyx_int_168);
  __Pyx_GIVEREF(__pyx_int_168);
  PyList_SET_ITEM(__pyx_t_253, 0, __pyx_int_168);
  __Pyx_INCREF(__pyx_int_168);
  __Pyx_GIVEREF(__pyx_int_168);
  PyList_SET_ITEM(__pyx_t_253, 1, __pyx_int_168);
  __Pyx_INCREF(__pyx_int_168);
  __Pyx_GIVEREF(__pyx_int_168);
  PyList_SET_ITEM(__pyx_t_253, 2, __pyx_int_168);
  __pyx_t_254 = PyList_New(3); if (unlikely(!__pyx_t_254)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_254);
  __Pyx_INCREF(__pyx_int_178);
  __Pyx_GIVEREF(__pyx_int_178);
  PyList_SET_ITEM(__pyx_t_254, 0, __pyx_int_178);
  __Pyx_INCREF(__pyx_int_178);
  __Pyx_GIVEREF(__pyx_int_178);
  PyList_SET_ITEM(__pyx_t_254, 1, __pyx_int_178);
  __Pyx_INCREF(__pyx_int_178);
  __Pyx_GIVEREF(__pyx_int_178);
  PyList_SET_ITEM(__pyx_t_254, 2, __pyx_int_178);
  __pyx_t_255 = PyList_New(3); if (unlikely(!__pyx_t_255)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_255);
  __Pyx_INCREF(__pyx_int_188);
  __Pyx_GIVEREF(__pyx_int_188);
  PyList_SET_ITEM(__pyx_t_255, 0, __pyx_int_188);
  __Pyx_INCREF(__pyx_int_188);
  __Pyx_GIVEREF(__pyx_int_188);
  PyList_SET_ITEM(__pyx_t_255, 1, __pyx_int_188);
  __Pyx_INCREF(__pyx_int_188);
  __Pyx_GIVEREF(__pyx_int_188);
  PyList_SET_ITEM(__pyx_t_255, 2, __pyx_int_188);

  /* "ttygif/tty/viewer.pyx":150
 *                             [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 *                             [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],
 *                             [198,198,198],[208,208,208],[218,218,218],[228,228,228],[238,238,238]             # <<<<<<<<<<<<<<
 *         ]
 * 
 */
  __Pyx_TraceLine(150,0,__PYX_ERR(0, 150, __pyx_L1_error))
  __pyx_t_256 = PyList_New(3); if (unlikely(!__pyx_t_256)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_256);
  __Pyx_INCREF(__pyx_int_198);
  __Pyx_GIVEREF(__pyx_int_198);
  PyList_SET_ITEM(__pyx_t_256, 0, __pyx_int_198);
  __Pyx_INCREF(__pyx_int_198);
  __Pyx_GIVEREF(__pyx_int_198);
  PyList_SET_ITEM(__pyx_t_256, 1, __pyx_int_198);
  __Pyx_INCREF(__pyx_int_198);
  __Pyx_GIVEREF(__pyx_int_198);
  PyList_SET_ITEM(__pyx_t_256, 2, __pyx_int_198);
  __pyx_t_257 = PyList_New(3); if (unlikely(!__pyx_t_257)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_257);
  __Pyx_INCREF(__pyx_int_208);
  __Pyx_GIVEREF(__pyx_int_208);
  PyList_SET_ITEM(__pyx_t_257, 0, __pyx_int_208);
  __Pyx_INCREF(__pyx_int_208);
  __Pyx_GIVEREF(__pyx_int_208);
  PyList_SET_ITEM(__pyx_t_257, 1, __pyx_int_208);
  __Pyx_INCREF(__pyx_int_208);
  __Pyx_GIVEREF(__pyx_int_208);
  PyList_SET_ITEM(__pyx_t_257, 2, __pyx_int_208);
  __pyx_t_258 = PyList_New(3); if (unlikely(!__pyx_t_258)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_258);
  __Pyx_INCREF(__pyx_int_218);
  __Pyx_GIVEREF(__pyx_int_218);
  PyList_SET_ITEM(__pyx_t_258, 0, __pyx_int_218);
  __Pyx_INCREF(__pyx_int_218);
  __Pyx_GIVEREF(__pyx_int_218);
  PyList_SET_ITEM(__pyx_t_258, 1, __pyx_int_218);
  __Pyx_INCREF(__pyx_int_218);
  __Pyx_GIVEREF(__pyx_int_218);
  PyList_SET_ITEM(__pyx_t_258, 2, __pyx_int_218);
  __pyx_t_259 = PyList_New(3); if (unlikely(!__pyx_t_259)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_259);
  __Pyx_INCREF(__pyx_int_228);
  __Pyx_GIVEREF(__pyx_int_228);
  PyList_SET_ITEM(__pyx_t_259, 0, __pyx_int_228);
  __Pyx_INCREF(__pyx_int_228);
  __Pyx_GIVEREF(__pyx_int_228);
  PyList_SET_ITEM(__pyx_t_259, 1, __pyx_int_228);
  __Pyx_INCREF(__pyx_int_228);
  __Pyx_GIVEREF(__pyx_int_228);
  PyList_SET_ITEM(__pyx_t_259, 2, __pyx_int_228);
  __pyx_t_260 = PyList_New(3); if (unlikely(!__pyx_t_260)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_260);
  __Pyx_INCREF(__pyx_int_238);
  __Pyx_GIVEREF(__pyx_int_238);
  PyList_SET_ITEM(__pyx_t_260, 0, __pyx_int_238);
  __Pyx_INCREF(__pyx_int_238);
  __Pyx_GIVEREF(__pyx_int_238);
  PyList_SET_ITEM(__pyx_t_260, 1, __pyx_int_238);
  __Pyx_INCREF(__pyx_int_238);
  __Pyx_GIVEREF(__pyx_int_238);
  PyList_SET_ITEM(__pyx_t_260, 2, __pyx_int_238);

  /* "ttygif/tty/viewer.pyx":105
 * 
 * 
 *         self.color_table=[  # 16 System Colors             # <<<<<<<<<<<<<<
 *                             [0,0,0],[128,0,0],[0,128,0],[128,128,0],
 *                             [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 */
  __Pyx_TraceLine(105,0,__PYX_ERR(0, 105, __pyx_L1_error))
  __pyx_t_261 = PyList_New(256); if (unlikely(!__pyx_t_261)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_261);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_261, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_261, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_261, 2, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_261, 3, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_261, 4, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_261, 5, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_11);
  PyList_SET_ITEM(__pyx_t_261, 6, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_261, 7, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_261, 8, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_261, 9, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_15);
  PyList_SET_ITEM(__pyx_t_261, 10, __pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_16);
  PyList_SET_ITEM(__pyx_t_261, 11, __pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_17);
  PyList_SET_ITEM(__pyx_t_261, 12, __pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_18);
  PyList_SET_ITEM(__pyx_t_261, 13, __pyx_t_18);
  __Pyx_GIVEREF(__pyx_t_19);
  PyList_SET_ITEM(__pyx_t_261, 14, __pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_20);
  PyList_SET_ITEM(__pyx_t_261, 15, __pyx_t_20);
  __Pyx_GIVEREF(__pyx_t_21);
  PyList_SET_ITEM(__pyx_t_261, 16, __pyx_t_21);
  __Pyx_GIVEREF(__pyx_t_22);
  PyList_SET_ITEM(__pyx_t_261, 17, __pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_23);
  PyList_SET_ITEM(__pyx_t_261, 18, __pyx_t_23);
  __Pyx_GIVEREF(__pyx_t_24);
  PyList_SET_ITEM(__pyx_t_261, 19, __pyx_t_24);
  __Pyx_GIVEREF(__pyx_t_25);
  PyList_SET_ITEM(__pyx_t_261, 20, __pyx_t_25);
  __Pyx_GIVEREF(__pyx_t_26);
  PyList_SET_ITEM(__pyx_t_261, 21, __pyx_t_26);
  __Pyx_GIVEREF(__pyx_t_27);
  PyList_SET_ITEM(__pyx_t_261, 22, __pyx_t_27);
  __Pyx_GIVEREF(__pyx_t_28);
  PyList_SET_ITEM(__pyx_t_261, 23, __pyx_t_28);
  __Pyx_GIVEREF(__pyx_t_29);
  PyList_SET_ITEM(__pyx_t_261, 24, __pyx_t_29);
  __Pyx_GIVEREF(__pyx_t_30);
  PyList_SET_ITEM(__pyx_t_261, 25, __pyx_t_30);
  __Pyx_GIVEREF(__pyx_t_31);
  PyList_SET_ITEM(__pyx_t_261, 26, __pyx_t_31);
  __Pyx_GIVEREF(__pyx_t_32);
  PyList_SET_ITEM(__pyx_t_261, 27, __pyx_t_32);
  __Pyx_GIVEREF(__pyx_t_33);
  PyList_SET_ITEM(__pyx_t_261, 28, __pyx_t_33);
  __Pyx_GIVEREF(__pyx_t_34);
  PyList_SET_ITEM(__pyx_t_261, 29, __pyx_t_34);
  __Pyx_GIVEREF(__pyx_t_35);
  PyList_SET_ITEM(__pyx_t_261, 30, __pyx_t_35);
  __Pyx_GIVEREF(__pyx_t_36);
  PyList_SET_ITEM(__pyx_t_261, 31, __pyx_t_36);
  __Pyx_GIVEREF(__pyx_t_37);
  PyList_SET_ITEM(__pyx_t_261, 32, __pyx_t_37);
  __Pyx_GIVEREF(__pyx_t_38);
  PyList_SET_ITEM(__pyx_t_261, 33, __pyx_t_38);
  __Pyx_GIVEREF(__pyx_t_39);
  PyList_SET_ITEM(__pyx_t_261, 34, __pyx_t_39);
  __Pyx_GIVEREF(__pyx_t_40);
  PyList_SET_ITEM(__pyx_t_261, 35, __pyx_t_40);
  __Pyx_GIVEREF(__pyx_t_41);
  PyList_SET_ITEM(__pyx_t_261, 36, __pyx_t_41);
  __Pyx_GIVEREF(__pyx_t_42);
  PyList_SET_ITEM(__pyx_t_261, 37, __pyx_t_42);
  __Pyx_GIVEREF(__pyx_t_43);
  PyList_SET_ITEM(__pyx_t_261, 38, __pyx_t_43);
  __Pyx_GIVEREF(__pyx_t_44);
  PyList_SET_ITEM(__pyx_t_261, 39, __pyx_t_44);
  __Pyx_GIVEREF(__pyx_t_45);
  PyList_SET_ITEM(__pyx_t_261, 40, __pyx_t_45);
  __Pyx_GIVEREF(__pyx_t_46);
  PyList_SET_ITEM(__pyx_t_261, 41, __pyx_t_46);
  __Pyx_GIVEREF(__pyx_t_47);
  PyList_SET_ITEM(__pyx_t_261, 42, __pyx_t_47);
  __Pyx_GIVEREF(__pyx_t_48);
  PyList_SET_ITEM(__pyx_t_261, 43, __pyx_t_48);
  __Pyx_GIVEREF(__pyx_t_49);
  PyList_SET_ITEM(__pyx_t_261, 44, __pyx_t_49);
  __Pyx_GIVEREF(__pyx_t_50);
  PyList_SET_ITEM(__pyx_t_261, 45, __pyx_t_50);
  __Pyx_GIVEREF(__pyx_t_51);
  PyList_SET_ITEM(__pyx_t_261, 46, __pyx_t_51);
  __Pyx_GIVEREF(__pyx_t_52);
  PyList_SET_ITEM(__pyx_t_261, 47, __pyx_t_52);
  __Pyx_GIVEREF(__pyx_t_53);
  PyList_SET_ITEM(__pyx_t_261, 48, __pyx_t_53);
  __Pyx_GIVEREF(__pyx_t_54);
  PyList_SET_ITEM(__pyx_t_261, 49, __pyx_t_54);
  __Pyx_GIVEREF(__pyx_t_55);
  PyList_SET_ITEM(__pyx_t_261, 50, __pyx_t_55);
  __Pyx_GIVEREF(__pyx_t_56);
  PyList_SET_ITEM(__pyx_t_261, 51, __pyx_t_56);
  __Pyx_GIVEREF(__pyx_t_57);
  PyList_SET_ITEM(__pyx_t_261, 52, __pyx_t_57);
  __Pyx_GIVEREF(__pyx_t_58);
  PyList_SET_ITEM(__pyx_t_261, 53, __pyx_t_58);
  __Pyx_GIVEREF(__pyx_t_59);
  PyList_SET_ITEM(__pyx_t_261, 54, __pyx_t_59);
  __Pyx_GIVEREF(__pyx_t_60);
  PyList_SET_ITEM(__pyx_t_261, 55, __pyx_t_60);
  __Pyx_GIVEREF(__pyx_t_61);
  PyList_SET_ITEM(__pyx_t_261, 56, __pyx_t_61);
  __Pyx_GIVEREF(__pyx_t_62);
  PyList_SET_ITEM(__pyx_t_261, 57, __pyx_t_62);
  __Pyx_GIVEREF(__pyx_t_63);
  PyList_SET_ITEM(__pyx_t_261, 58, __pyx_t_63);
  __Pyx_GIVEREF(__pyx_t_64);
  PyList_SET_ITEM(__pyx_t_261, 59, __pyx_t_64);
  __Pyx_GIVEREF(__pyx_t_65);
  PyList_SET_ITEM(__pyx_t_261, 60, __pyx_t_65);
  __Pyx_GIVEREF(__pyx_t_66);
  PyList_SET_ITEM(__pyx_t_261, 61, __pyx_t_66);
  __Pyx_GIVEREF(__pyx_t_67);
  PyList_SET_ITEM(__pyx_t_261, 62, __pyx_t_67);
  __Pyx_GIVEREF(__pyx_t_68);
  PyList_SET_ITEM(__pyx_t_261, 63, __pyx_t_68);
  __Pyx_GIVEREF(__pyx_t_69);
  PyList_SET_ITEM(__pyx_t_261, 64, __pyx_t_69);
  __Pyx_GIVEREF(__pyx_t_70);
  PyList_SET_ITEM(__pyx_t_261, 65, __pyx_t_70);
  __Pyx_GIVEREF(__pyx_t_71);
  PyList_SET_ITEM(__pyx_t_261, 66, __pyx_t_71);
  __Pyx_GIVEREF(__pyx_t_72);
  PyList_SET_ITEM(__pyx_t_261, 67, __pyx_t_72);
  __Pyx_GIVEREF(__pyx_t_73);
  PyList_SET_ITEM(__pyx_t_261, 68, __pyx_t_73);
  __Pyx_GIVEREF(__pyx_t_74);
  PyList_SET_ITEM(__pyx_t_261, 69, __pyx_t_74);
  __Pyx_GIVEREF(__pyx_t_75);
  PyList_SET_ITEM(__pyx_t_261, 70, __pyx_t_75);
  __Pyx_GIVEREF(__pyx_t_76);
  PyList_SET_ITEM(__pyx_t_261, 71, __pyx_t_76);
  __Pyx_GIVEREF(__pyx_t_77);
  PyList_SET_ITEM(__pyx_t_261, 72, __pyx_t_77);
  __Pyx_GIVEREF(__pyx_t_78);
  PyList_SET_ITEM(__pyx_t_261, 73, __pyx_t_78);
  __Pyx_GIVEREF(__pyx_t_79);
  PyList_SET_ITEM(__pyx_t_261, 74, __pyx_t_79);
  __Pyx_GIVEREF(__pyx_t_80);
  PyList_SET_ITEM(__pyx_t_261, 75, __pyx_t_80);
  __Pyx_GIVEREF(__pyx_t_81);
  PyList_SET_ITEM(__pyx_t_261, 76, __pyx_t_81);
  __Pyx_GIVEREF(__pyx_t_82);
  PyList_SET_ITEM(__pyx_t_261, 77, __pyx_t_82);
  __Pyx_GIVEREF(__pyx_t_83);
  PyList_SET_ITEM(__pyx_t_261, 78, __pyx_t_83);
  __Pyx_GIVEREF(__pyx_t_84);
  PyList_SET_ITEM(__pyx_t_261, 79, __pyx_t_84);
  __Pyx_GIVEREF(__pyx_t_85);
  PyList_SET_ITEM(__pyx_t_261, 80, __pyx_t_85);
  __Pyx_GIVEREF(__pyx_t_86);
  PyList_SET_ITEM(__pyx_t_261, 81, __pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_87);
  PyList_SET_ITEM(__pyx_t_261, 82, __pyx_t_87);
  __Pyx_GIVEREF(__pyx_t_88);
  PyList_SET_ITEM(__pyx_t_261, 83, __pyx_t_88);
  __Pyx_GIVEREF(__pyx_t_89);
  PyList_SET_ITEM(__pyx_t_261, 84, __pyx_t_89);
  __Pyx_GIVEREF(__pyx_t_90);
  PyList_SET_ITEM(__pyx_t_261, 85, __pyx_t_90);
  __Pyx_GIVEREF(__pyx_t_91);
  PyList_SET_ITEM(__pyx_t_261, 86, __pyx_t_91);
  __Pyx_GIVEREF(__pyx_t_92);
  PyList_SET_ITEM(__pyx_t_261, 87, __pyx_t_92);
  __Pyx_GIVEREF(__pyx_t_93);
  PyList_SET_ITEM(__pyx_t_261, 88, __pyx_t_93);
  __Pyx_GIVEREF(__pyx_t_94);
  PyList_SET_ITEM(__pyx_t_261, 89, __pyx_t_94);
  __Pyx_GIVEREF(__pyx_t_95);
  PyList_SET_ITEM(__pyx_t_261, 90, __pyx_t_95);
  __Pyx_GIVEREF(__pyx_t_96);
  PyList_SET_ITEM(__pyx_t_261, 91, __pyx_t_96);
  __Pyx_GIVEREF(__pyx_t_97);
  PyList_SET_ITEM(__pyx_t_261, 92, __pyx_t_97);
  __Pyx_GIVEREF(__pyx_t_98);
  PyList_SET_ITEM(__pyx_t_261, 93, __pyx_t_98);
  __Pyx_GIVEREF(__pyx_t_99);
  PyList_SET_ITEM(__pyx_t_261, 94, __pyx_t_99);
  __Pyx_GIVEREF(__pyx_t_100);
  PyList_SET_ITEM(__pyx_t_261, 95, __pyx_t_100);
  __Pyx_GIVEREF(__pyx_t_101);
  PyList_SET_ITEM(__pyx_t_261, 96, __pyx_t_101);
  __Pyx_GIVEREF(__pyx_t_102);
  PyList_SET_ITEM(__pyx_t_261, 97, __pyx_t_102);
  __Pyx_GIVEREF(__pyx_t_103);
  PyList_SET_ITEM(__pyx_t_261, 98, __pyx_t_103);
  __Pyx_GIVEREF(__pyx_t_104);
  PyList_SET_ITEM(__pyx_t_261, 99, __pyx_t_104);
  __Pyx_GIVEREF(__pyx_t_105);
  PyList_SET_ITEM(__pyx_t_261, 100, __pyx_t_105);
  __Pyx_GIVEREF(__pyx_t_106);
  PyList_SET_ITEM(__pyx_t_261, 101, __pyx_t_106);
  __Pyx_GIVEREF(__pyx_t_107);
  PyList_SET_ITEM(__pyx_t_261, 102, __pyx_t_107);
  __Pyx_GIVEREF(__pyx_t_108);
  PyList_SET_ITEM(__pyx_t_261, 103, __pyx_t_108);
  __Pyx_GIVEREF(__pyx_t_109);
  PyList_SET_ITEM(__pyx_t_261, 104, __pyx_t_109);
  __Pyx_GIVEREF(__pyx_t_110);
  PyList_SET_ITEM(__pyx_t_261, 105, __pyx_t_110);
  __Pyx_GIVEREF(__pyx_t_111);
  PyList_SET_ITEM(__pyx_t_261, 106, __pyx_t_111);
  __Pyx_GIVEREF(__pyx_t_112);
  PyList_SET_ITEM(__pyx_t_261, 107, __pyx_t_112);
  __Pyx_GIVEREF(__pyx_t_113);
  PyList_SET_ITEM(__pyx_t_261, 108, __pyx_t_113);
  __Pyx_GIVEREF(__pyx_t_114);
  PyList_SET_ITEM(__pyx_t_261, 109, __pyx_t_114);
  __Pyx_GIVEREF(__pyx_t_115);
  PyList_SET_ITEM(__pyx_t_261, 110, __pyx_t_115);
  __Pyx_GIVEREF(__pyx_t_116);
  PyList_SET_ITEM(__pyx_t_261, 111, __pyx_t_116);
  __Pyx_GIVEREF(__pyx_t_117);
  PyList_SET_ITEM(__pyx_t_261, 112, __pyx_t_117);
  __Pyx_GIVEREF(__pyx_t_118);
  PyList_SET_ITEM(__pyx_t_261, 113, __pyx_t_118);
  __Pyx_GIVEREF(__pyx_t_119);
  PyList_SET_ITEM(__pyx_t_261, 114, __pyx_t_119);
  __Pyx_GIVEREF(__pyx_t_120);
  PyList_SET_ITEM(__pyx_t_261, 115, __pyx_t_120);
  __Pyx_GIVEREF(__pyx_t_121);
  PyList_SET_ITEM(__pyx_t_261, 116, __pyx_t_121);
  __Pyx_GIVEREF(__pyx_t_122);
  PyList_SET_ITEM(__pyx_t_261, 117, __pyx_t_122);
  __Pyx_GIVEREF(__pyx_t_123);
  PyList_SET_ITEM(__pyx_t_261, 118, __pyx_t_123);
  __Pyx_GIVEREF(__pyx_t_124);
  PyList_SET_ITEM(__pyx_t_261, 119, __pyx_t_124);
  __Pyx_GIVEREF(__pyx_t_125);
  PyList_SET_ITEM(__pyx_t_261, 120, __pyx_t_125);
  __Pyx_GIVEREF(__pyx_t_126);
  PyList_SET_ITEM(__pyx_t_261, 121, __pyx_t_126);
  __Pyx_GIVEREF(__pyx_t_127);
  PyList_SET_ITEM(__pyx_t_261, 122, __pyx_t_127);
  __Pyx_GIVEREF(__pyx_t_128);
  PyList_SET_ITEM(__pyx_t_261, 123, __pyx_t_128);
  __Pyx_GIVEREF(__pyx_t_129);
  PyList_SET_ITEM(__pyx_t_261, 124, __pyx_t_129);
  __Pyx_GIVEREF(__pyx_t_130);
  PyList_SET_ITEM(__pyx_t_261, 125, __pyx_t_130);
  __Pyx_GIVEREF(__pyx_t_131);
  PyList_SET_ITEM(__pyx_t_261, 126, __pyx_t_131);
  __Pyx_GIVEREF(__pyx_t_132);
  PyList_SET_ITEM(__pyx_t_261, 127, __pyx_t_132);
  __Pyx_GIVEREF(__pyx_t_133);
  PyList_SET_ITEM(__pyx_t_261, 128, __pyx_t_133);
  __Pyx_GIVEREF(__pyx_t_134);
  PyList_SET_ITEM(__pyx_t_261, 129, __pyx_t_134);
  __Pyx_GIVEREF(__pyx_t_135);
  PyList_SET_ITEM(__pyx_t_261, 130, __pyx_t_135);
  __Pyx_GIVEREF(__pyx_t_136);
  PyList_SET_ITEM(__pyx_t_261, 131, __pyx_t_136);
  __Pyx_GIVEREF(__pyx_t_137);
  PyList_SET_ITEM(__pyx_t_261, 132, __pyx_t_137);
  __Pyx_GIVEREF(__pyx_t_138);
  PyList_SET_ITEM(__pyx_t_261, 133, __pyx_t_138);
  __Pyx_GIVEREF(__pyx_t_139);
  PyList_SET_ITEM(__pyx_t_261, 134, __pyx_t_139);
  __Pyx_GIVEREF(__pyx_t_140);
  PyList_SET_ITEM(__pyx_t_261, 135, __pyx_t_140);
  __Pyx_GIVEREF(__pyx_t_141);
  PyList_SET_ITEM(__pyx_t_261, 136, __pyx_t_141);
  __Pyx_GIVEREF(__pyx_t_142);
  PyList_SET_ITEM(__pyx_t_261, 137, __pyx_t_142);
  __Pyx_GIVEREF(__pyx_t_143);
  PyList_SET_ITEM(__pyx_t_261, 138, __pyx_t_143);
  __Pyx_GIVEREF(__pyx_t_144);
  PyList_SET_ITEM(__pyx_t_261, 139, __pyx_t_144);
  __Pyx_GIVEREF(__pyx_t_145);
  PyList_SET_ITEM(__pyx_t_261, 140, __pyx_t_145);
  __Pyx_GIVEREF(__pyx_t_146);
  PyList_SET_ITEM(__pyx_t_261, 141, __pyx_t_146);
  __Pyx_GIVEREF(__pyx_t_147);
  PyList_SET_ITEM(__pyx_t_261, 142, __pyx_t_147);
  __Pyx_GIVEREF(__pyx_t_148);
  PyList_SET_ITEM(__pyx_t_261, 143, __pyx_t_148);
  __Pyx_GIVEREF(__pyx_t_149);
  PyList_SET_ITEM(__pyx_t_261, 144, __pyx_t_149);
  __Pyx_GIVEREF(__pyx_t_150);
  PyList_SET_ITEM(__pyx_t_261, 145, __pyx_t_150);
  __Pyx_GIVEREF(__pyx_t_151);
  PyList_SET_ITEM(__pyx_t_261, 146, __pyx_t_151);
  __Pyx_GIVEREF(__pyx_t_152);
  PyList_SET_ITEM(__pyx_t_261, 147, __pyx_t_152);
  __Pyx_GIVEREF(__pyx_t_153);
  PyList_SET_ITEM(__pyx_t_261, 148, __pyx_t_153);
  __Pyx_GIVEREF(__pyx_t_154);
  PyList_SET_ITEM(__pyx_t_261, 149, __pyx_t_154);
  __Pyx_GIVEREF(__pyx_t_155);
  PyList_SET_ITEM(__pyx_t_261, 150, __pyx_t_155);
  __Pyx_GIVEREF(__pyx_t_156);
  PyList_SET_ITEM(__pyx_t_261, 151, __pyx_t_156);
  __Pyx_GIVEREF(__pyx_t_157);
  PyList_SET_ITEM(__pyx_t_261, 152, __pyx_t_157);
  __Pyx_GIVEREF(__pyx_t_158);
  PyList_SET_ITEM(__pyx_t_261, 153, __pyx_t_158);
  __Pyx_GIVEREF(__pyx_t_159);
  PyList_SET_ITEM(__pyx_t_261, 154, __pyx_t_159);
  __Pyx_GIVEREF(__pyx_t_160);
  PyList_SET_ITEM(__pyx_t_261, 155, __pyx_t_160);
  __Pyx_GIVEREF(__pyx_t_161);
  PyList_SET_ITEM(__pyx_t_261, 156, __pyx_t_161);
  __Pyx_GIVEREF(__pyx_t_162);
  PyList_SET_ITEM(__pyx_t_261, 157, __pyx_t_162);
  __Pyx_GIVEREF(__pyx_t_163);
  PyList_SET_ITEM(__pyx_t_261, 158, __pyx_t_163);
  __Pyx_GIVEREF(__pyx_t_164);
  PyList_SET_ITEM(__pyx_t_261, 159, __pyx_t_164);
  __Pyx_GIVEREF(__pyx_t_165);
  PyList_SET_ITEM(__pyx_t_261, 160, __pyx_t_165);
  __Pyx_GIVEREF(__pyx_t_166);
  PyList_SET_ITEM(__pyx_t_261, 161, __pyx_t_166);
  __Pyx_GIVEREF(__pyx_t_167);
  PyList_SET_ITEM(__pyx_t_261, 162, __pyx_t_167);
  __Pyx_GIVEREF(__pyx_t_168);
  PyList_SET_ITEM(__pyx_t_261, 163, __pyx_t_168);
  __Pyx_GIVEREF(__pyx_t_169);
  PyList_SET_ITEM(__pyx_t_261, 164, __pyx_t_169);
  __Pyx_GIVEREF(__pyx_t_170);
  PyList_SET_ITEM(__pyx_t_261, 165, __pyx_t_170);
  __Pyx_GIVEREF(__pyx_t_171);
  PyList_SET_ITEM(__pyx_t_261, 166, __pyx_t_171);
  __Pyx_GIVEREF(__pyx_t_172);
  PyList_SET_ITEM(__pyx_t_261, 167, __pyx_t_172);
  __Pyx_GIVEREF(__pyx_t_173);
  PyList_SET_ITEM(__pyx_t_261, 168, __pyx_t_173);
  __Pyx_GIVEREF(__pyx_t_174);
  PyList_SET_ITEM(__pyx_t_261, 169, __pyx_t_174);
  __Pyx_GIVEREF(__pyx_t_175);
  PyList_SET_ITEM(__pyx_t_261, 170, __pyx_t_175);
  __Pyx_GIVEREF(__pyx_t_176);
  PyList_SET_ITEM(__pyx_t_261, 171, __pyx_t_176);
  __Pyx_GIVEREF(__pyx_t_177);
  PyList_SET_ITEM(__pyx_t_261, 172, __pyx_t_177);
  __Pyx_GIVEREF(__pyx_t_178);
  PyList_SET_ITEM(__pyx_t_261, 173, __pyx_t_178);
  __Pyx_GIVEREF(__pyx_t_179);
  PyList_SET_ITEM(__pyx_t_261, 174, __pyx_t_179);
  __Pyx_GIVEREF(__pyx_t_180);
  PyList_SET_ITEM(__pyx_t_261, 175, __pyx_t_180);
  __Pyx_GIVEREF(__pyx_t_181);
  PyList_SET_ITEM(__pyx_t_261, 176, __pyx_t_181);
  __Pyx_GIVEREF(__pyx_t_182);
  PyList_SET_ITEM(__pyx_t_261, 177, __pyx_t_182);
  __Pyx_GIVEREF(__pyx_t_183);
  PyList_SET_ITEM(__pyx_t_261, 178, __pyx_t_183);
  __Pyx_GIVEREF(__pyx_t_184);
  PyList_SET_ITEM(__pyx_t_261, 179, __pyx_t_184);
  __Pyx_GIVEREF(__pyx_t_185);
  PyList_SET_ITEM(__pyx_t_261, 180, __pyx_t_185);
  __Pyx_GIVEREF(__pyx_t_186);
  PyList_SET_ITEM(__pyx_t_261, 181, __pyx_t_186);
  __Pyx_GIVEREF(__pyx_t_187);
  PyList_SET_ITEM(__pyx_t_261, 182, __pyx_t_187);
  __Pyx_GIVEREF(__pyx_t_188);
  PyList_SET_ITEM(__pyx_t_261, 183, __pyx_t_188);
  __Pyx_GIVEREF(__pyx_t_189);
  PyList_SET_ITEM(__pyx_t_261, 184, __pyx_t_189);
  __Pyx_GIVEREF(__pyx_t_190);
  PyList_SET_ITEM(__pyx_t_261, 185, __pyx_t_190);
  __Pyx_GIVEREF(__pyx_t_191);
  PyList_SET_ITEM(__pyx_t_261, 186, __pyx_t_191);
  __Pyx_GIVEREF(__pyx_t_192);
  PyList_SET_ITEM(__pyx_t_261, 187, __pyx_t_192);
  __Pyx_GIVEREF(__pyx_t_193);
  PyList_SET_ITEM(__pyx_t_261, 188, __pyx_t_193);
  __Pyx_GIVEREF(__pyx_t_194);
  PyList_SET_ITEM(__pyx_t_261, 189, __pyx_t_194);
  __Pyx_GIVEREF(__pyx_t_195);
  PyList_SET_ITEM(__pyx_t_261, 190, __pyx_t_195);
  __Pyx_GIVEREF(__pyx_t_196);
  PyList_SET_ITEM(__pyx_t_261, 191, __pyx_t_196);
  __Pyx_GIVEREF(__pyx_t_197);
  PyList_SET_ITEM(__pyx_t_261, 192, __pyx_t_197);
  __Pyx_GIVEREF(__pyx_t_198);
  PyList_SET_ITEM(__pyx_t_261, 193, __pyx_t_198);
  __Pyx_GIVEREF(__pyx_t_199);
  PyList_SET_ITEM(__pyx_t_261, 194, __pyx_t_199);
  __Pyx_GIVEREF(__pyx_t_200);
  PyList_SET_ITEM(__pyx_t_261, 195, __pyx_t_200);
  __Pyx_GIVEREF(__pyx_t_201);
  PyList_SET_ITEM(__pyx_t_261, 196, __pyx_t_201);
  __Pyx_GIVEREF(__pyx_t_202);
  PyList_SET_ITEM(__pyx_t_261, 197, __pyx_t_202);
  __Pyx_GIVEREF(__pyx_t_203);
  PyList_SET_ITEM(__pyx_t_261, 198, __pyx_t_203);
  __Pyx_GIVEREF(__pyx_t_204);
  PyList_SET_ITEM(__pyx_t_261, 199, __pyx_t_204);
  __Pyx_GIVEREF(__pyx_t_205);
  PyList_SET_ITEM(__pyx_t_261, 200, __pyx_t_205);
  __Pyx_GIVEREF(__pyx_t_206);
  PyList_SET_ITEM(__pyx_t_261, 201, __pyx_t_206);
  __Pyx_GIVEREF(__pyx_t_207);
  PyList_SET_ITEM(__pyx_t_261, 202, __pyx_t_207);
  __Pyx_GIVEREF(__pyx_t_208);
  PyList_SET_ITEM(__pyx_t_261, 203, __pyx_t_208);
  __Pyx_GIVEREF(__pyx_t_209);
  PyList_SET_ITEM(__pyx_t_261, 204, __pyx_t_209);
  __Pyx_GIVEREF(__pyx_t_210);
  PyList_SET_ITEM(__pyx_t_261, 205, __pyx_t_210);
  __Pyx_GIVEREF(__pyx_t_211);
  PyList_SET_ITEM(__pyx_t_261, 206, __pyx_t_211);
  __Pyx_GIVEREF(__pyx_t_212);
  PyList_SET_ITEM(__pyx_t_261, 207, __pyx_t_212);
  __Pyx_GIVEREF(__pyx_t_213);
  PyList_SET_ITEM(__pyx_t_261, 208, __pyx_t_213);
  __Pyx_GIVEREF(__pyx_t_214);
  PyList_SET_ITEM(__pyx_t_261, 209, __pyx_t_214);
  __Pyx_GIVEREF(__pyx_t_215);
  PyList_SET_ITEM(__pyx_t_261, 210, __pyx_t_215);
  __Pyx_GIVEREF(__pyx_t_216);
  PyList_SET_ITEM(__pyx_t_261, 211, __pyx_t_216);
  __Pyx_GIVEREF(__pyx_t_217);
  PyList_SET_ITEM(__pyx_t_261, 212, __pyx_t_217);
  __Pyx_GIVEREF(__pyx_t_218);
  PyList_SET_ITEM(__pyx_t_261, 213, __pyx_t_218);
  __Pyx_GIVEREF(__pyx_t_219);
  PyList_SET_ITEM(__pyx_t_261, 214, __pyx_t_219);
  __Pyx_GIVEREF(__pyx_t_220);
  PyList_SET_ITEM(__pyx_t_261, 215, __pyx_t_220);
  __Pyx_GIVEREF(__pyx_t_221);
  PyList_SET_ITEM(__pyx_t_261, 216, __pyx_t_221);
  __Pyx_GIVEREF(__pyx_t_222);
  PyList_SET_ITEM(__pyx_t_261, 217, __pyx_t_222);
  __Pyx_GIVEREF(__pyx_t_223);
  PyList_SET_ITEM(__pyx_t_261, 218, __pyx_t_223);
  __Pyx_GIVEREF(__pyx_t_224);
  PyList_SET_ITEM(__pyx_t_261, 219, __pyx_t_224);
  __Pyx_GIVEREF(__pyx_t_225);
  PyList_SET_ITEM(__pyx_t_261, 220, __pyx_t_225);
  __Pyx_GIVEREF(__pyx_t_226);
  PyList_SET_ITEM(__pyx_t_261, 221, __pyx_t_226);
  __Pyx_GIVEREF(__pyx_t_227);
  PyList_SET_ITEM(__pyx_t_261, 222, __pyx_t_227);
  __Pyx_GIVEREF(__pyx_t_228);
  PyList_SET_ITEM(__pyx_t_261, 223, __pyx_t_228);
  __Pyx_GIVEREF(__pyx_t_229);
  PyList_SET_ITEM(__pyx_t_261, 224, __pyx_t_229);
  __Pyx_GIVEREF(__pyx_t_230);
  PyList_SET_ITEM(__pyx_t_261, 225, __pyx_t_230);
  __Pyx_GIVEREF(__pyx_t_231);
  PyList_SET_ITEM(__pyx_t_261, 226, __pyx_t_231);
  __Pyx_GIVEREF(__pyx_t_232);
  PyList_SET_ITEM(__pyx_t_261, 227, __pyx_t_232);
  __Pyx_GIVEREF(__pyx_t_233);
  PyList_SET_ITEM(__pyx_t_261, 228, __pyx_t_233);
  __Pyx_GIVEREF(__pyx_t_234);
  PyList_SET_ITEM(__pyx_t_261, 229, __pyx_t_234);
  __Pyx_GIVEREF(__pyx_t_235);
  PyList_SET_ITEM(__pyx_t_261, 230, __pyx_t_235);
  __Pyx_GIVEREF(__pyx_t_236);
  PyList_SET_ITEM(__pyx_t_261, 231, __pyx_t_236);
  __Pyx_GIVEREF(__pyx_t_237);
  PyList_SET_ITEM(__pyx_t_261, 232, __pyx_t_237);
  __Pyx_GIVEREF(__pyx_t_238);
  PyList_SET_ITEM(__pyx_t_261, 233, __pyx_t_238);
  __Pyx_GIVEREF(__pyx_t_239);
  PyList_SET_ITEM(__pyx_t_261, 234, __pyx_t_239);
  __Pyx_GIVEREF(__pyx_t_240);
  PyList_SET_ITEM(__pyx_t_261, 235, __pyx_t_240);
  __Pyx_GIVEREF(__pyx_t_241);
  PyList_SET_ITEM(__pyx_t_261, 236, __pyx_t_241);
  __Pyx_GIVEREF(__pyx_t_242);
  PyList_SET_ITEM(__pyx_t_261, 237, __pyx_t_242);
  __Pyx_GIVEREF(__pyx_t_243);
  PyList_SET_ITEM(__pyx_t_261, 238, __pyx_t_243);
  __Pyx_GIVEREF(__pyx_t_244);
  PyList_SET_ITEM(__pyx_t_261, 239, __pyx_t_244);
  __Pyx_GIVEREF(__pyx_t_245);
  PyList_SET_ITEM(__pyx_t_261, 240, __pyx_t_245);
  __Pyx_GIVEREF(__pyx_t_246);
  PyList_SET_ITEM(__pyx_t_261, 241, __pyx_t_246);
  __Pyx_GIVEREF(__pyx_t_247);
  PyList_SET_ITEM(__pyx_t_261, 242, __pyx_t_247);
  __Pyx_GIVEREF(__pyx_t_248);
  PyList_SET_ITEM(__pyx_t_261, 243, __pyx_t_248);
  __Pyx_GIVEREF(__pyx_t_249);
  PyList_SET_ITEM(__pyx_t_261, 244, __pyx_t_249);
  __Pyx_GIVEREF(__pyx_t_250);
  PyList_SET_ITEM(__pyx_t_261, 245, __pyx_t_250);
  __Pyx_GIVEREF(__pyx_t_251);
  PyList_SET_ITEM(__pyx_t_261, 246, __pyx_t_251);
  __Pyx_GIVEREF(__pyx_t_252);
  PyList_SET_ITEM(__pyx_t_261, 247, __pyx_t_252);
  __Pyx_GIVEREF(__pyx_t_253);
  PyList_SET_ITEM(__pyx_t_261, 248, __pyx_t_253);
  __Pyx_GIVEREF(__pyx_t_254);
  PyList_SET_ITEM(__pyx_t_261, 249, __pyx_t_254);
  __Pyx_GIVEREF(__pyx_t_255);
  PyList_SET_ITEM(__pyx_t_261, 250, __pyx_t_255);
  __Pyx_GIVEREF(__pyx_t_256);
  PyList_SET_ITEM(__pyx_t_261, 251, __pyx_t_256);
  __Pyx_GIVEREF(__pyx_t_257);
  PyList_SET_ITEM(__pyx_t_261, 252, __pyx_t_257);
  __Pyx_GIVEREF(__pyx_t_258);
  PyList_SET_ITEM(__pyx_t_261, 253, __pyx_t_258);
  __Pyx_GIVEREF(__pyx_t_259);
  PyList_SET_ITEM(__pyx_t_261, 254, __pyx_t_259);
  __Pyx_GIVEREF(__pyx_t_260);
  PyList_SET_ITEM(__pyx_t_261, 255, __pyx_t_260);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_t_11 = 0;
  __pyx_t_12 = 0;
  __pyx_t_13 = 0;
  __pyx_t_14 = 0;
  __pyx_t_15 = 0;
  __pyx_t_16 = 0;
  __pyx_t_17 = 0;
  __pyx_t_18 = 0;
  __pyx_t_19 = 0;
  __pyx_t_20 = 0;
  __pyx_t_21 = 0;
  __pyx_t_22 = 0;
  __pyx_t_23 = 0;
  __pyx_t_24 = 0;
  __pyx_t_25 = 0;
  __pyx_t_26 = 0;
  __pyx_t_27 = 0;
  __pyx_t_28 = 0;
  __pyx_t_29 = 0;
  __pyx_t_30 = 0;
  __pyx_t_31 = 0;
  __pyx_t_32 = 0;
  __pyx_t_33 = 0;
  __pyx_t_34 = 0;
  __pyx_t_35 = 0;
  __pyx_t_36 = 0;
  __pyx_t_37 = 0;
  __pyx_t_38 = 0;
  __pyx_t_39 = 0;
  __pyx_t_40 = 0;
  __pyx_t_41 = 0;
  __pyx_t_42 = 0;
  __pyx_t_43 = 0;
  __pyx_t_44 = 0;
  __pyx_t_45 = 0;
  __pyx_t_46 = 0;
  __pyx_t_47 = 0;
  __pyx_t_48 = 0;
  __pyx_t_49 = 0;
  __pyx_t_50 = 0;
  __pyx_t_51 = 0;
  __pyx_t_52 = 0;
  __pyx_t_53 = 0;
  __pyx_t_54 = 0;
  __pyx_t_55 = 0;
  __pyx_t_56 = 0;
  __pyx_t_57 = 0;
  __pyx_t_58 = 0;
  __pyx_t_59 = 0;
  __pyx_t_60 = 0;
  __pyx_t_61 = 0;
  __pyx_t_62 = 0;
  __pyx_t_63 = 0;
  __pyx_t_64 = 0;
  __pyx_t_65 = 0;
  __pyx_t_66 = 0;
  __pyx_t_67 = 0;
  __pyx_t_68 = 0;
  __pyx_t_69 = 0;
  __pyx_t_70 = 0;
  __pyx_t_71 = 0;
  __pyx_t_72 = 0;
  __pyx_t_73 = 0;
  __pyx_t_74 = 0;
  __pyx_t_75 = 0;
  __pyx_t_76 = 0;
  __pyx_t_77 = 0;
  __pyx_t_78 = 0;
  __pyx_t_79 = 0;
  __pyx_t_80 = 0;
  __pyx_t_81 = 0;
  __pyx_t_82 = 0;
  __pyx_t_83 = 0;
  __pyx_t_84 = 0;
  __pyx_t_85 = 0;
  __pyx_t_86 = 0;
  __pyx_t_87 = 0;
  __pyx_t_88 = 0;
  __pyx_t_89 = 0;
  __pyx_t_90 = 0;
  __pyx_t_91 = 0;
  __pyx_t_92 = 0;
  __pyx_t_93 = 0;
  __pyx_t_94 = 0;
  __pyx_t_95 = 0;
  __pyx_t_96 = 0;
  __pyx_t_97 = 0;
  __pyx_t_98 = 0;
  __pyx_t_99 = 0;
  __pyx_t_100 = 0;
  __pyx_t_101 = 0;
  __pyx_t_102 = 0;
  __pyx_t_103 = 0;
  __pyx_t_104 = 0;
  __pyx_t_105 = 0;
  __pyx_t_106 = 0;
  __pyx_t_107 = 0;
  __pyx_t_108 = 0;
  __pyx_t_109 = 0;
  __pyx_t_110 = 0;
  __pyx_t_111 = 0;
  __pyx_t_112 = 0;
  __pyx_t_113 = 0;
  __pyx_t_114 = 0;
  __pyx_t_115 = 0;
  __pyx_t_116 = 0;
  __pyx_t_117 = 0;
  __pyx_t_118 = 0;
  __pyx_t_119 = 0;
  __pyx_t_120 = 0;
  __pyx_t_121 = 0;
  __pyx_t_122 = 0;
  __pyx_t_123 = 0;
  __pyx_t_124 = 0;
  __pyx_t_125 = 0;
  __pyx_t_126 = 0;
  __pyx_t_127 = 0;
  __pyx_t_128 = 0;
  __pyx_t_129 = 0;
  __pyx_t_130 = 0;
  __pyx_t_131 = 0;
  __pyx_t_132 = 0;
  __pyx_t_133 = 0;
  __pyx_t_134 = 0;
  __pyx_t_135 = 0;
  __pyx_t_136 = 0;
  __pyx_t_137 = 0;
  __pyx_t_138 = 0;
  __pyx_t_139 = 0;
  __pyx_t_140 = 0;
  __pyx_t_141 = 0;
  __pyx_t_142 = 0;
  __pyx_t_143 = 0;
  __pyx_t_144 = 0;
  __pyx_t_145 = 0;
  __pyx_t_146 = 0;
  __pyx_t_147 = 0;
  __pyx_t_148 = 0;
  __pyx_t_149 = 0;
  __pyx_t_150 = 0;
  __pyx_t_151 = 0;
  __pyx_t_152 = 0;
  __pyx_t_153 = 0;
  __pyx_t_154 = 0;
  __pyx_t_155 = 0;
  __pyx_t_156 = 0;
  __pyx_t_157 = 0;
  __pyx_t_158 = 0;
  __pyx_t_159 = 0;
  __pyx_t_160 = 0;
  __pyx_t_161 = 0;
  __pyx_t_162 = 0;
  __pyx_t_163 = 0;
  __pyx_t_164 = 0;
  __pyx_t_165 = 0;
  __pyx_t_166 = 0;
  __pyx_t_167 = 0;
  __pyx_t_168 = 0;
  __pyx_t_169 = 0;
  __pyx_t_170 = 0;
  __pyx_t_171 = 0;
  __pyx_t_172 = 0;
  __pyx_t_173 = 0;
  __pyx_t_174 = 0;
  __pyx_t_175 = 0;
  __pyx_t_176 = 0;
  __pyx_t_177 = 0;
  __pyx_t_178 = 0;
  __pyx_t_179 = 0;
  __pyx_t_180 = 0;
  __pyx_t_181 = 0;
  __pyx_t_182 = 0;
  __pyx_t_183 = 0;
  __pyx_t_184 = 0;
  __pyx_t_185 = 0;
  __pyx_t_186 = 0;
  __pyx_t_187 = 0;
  __pyx_t_188 = 0;
  __pyx_t_189 = 0;
  __pyx_t_190 = 0;
  __pyx_t_191 = 0;
  __pyx_t_192 = 0;
  __pyx_t_193 = 0;
  __pyx_t_194 = 0;
  __pyx_t_195 = 0;
  __pyx_t_196 = 0;
  __pyx_t_197 = 0;
  __pyx_t_198 = 0;
  __pyx_t_199 = 0;
  __pyx_t_200 = 0;
  __pyx_t_201 = 0;
  __pyx_t_202 = 0;
  __pyx_t_203 = 0;
  __pyx_t_204 = 0;
  __pyx_t_205 = 0;
  __pyx_t_206 = 0;
  __pyx_t_207 = 0;
  __pyx_t_208 = 0;
  __pyx_t_209 = 0;
  __pyx_t_210 = 0;
  __pyx_t_211 = 0;
  __pyx_t_212 = 0;
  __pyx_t_213 = 0;
  __pyx_t_214 = 0;
  __pyx_t_215 = 0;
  __pyx_t_216 = 0;
  __pyx_t_217 = 0;
  __pyx_t_218 = 0;
  __pyx_t_219 = 0;
  __pyx_t_220 = 0;
  __pyx_t_221 = 0;
  __pyx_t_222 = 0;
  __pyx_t_223 = 0;
  __pyx_t_224 = 0;
  __pyx_t_225 = 0;
  __pyx_t_226 = 0;
  __pyx_t_227 = 0;
  __pyx_t_228 = 0;
  __pyx_t_229 = 0;
  __pyx_t_230 = 0;
  __pyx_t_231 = 0;
  __pyx_t_232 = 0;
  __pyx_t_233 = 0;
  __pyx_t_234 = 0;
  __pyx_t_235 = 0;
  __pyx_t_236 = 0;
  __pyx_t_237 = 0;
  __pyx_t_238 = 0;
  __pyx_t_239 = 0;
  __pyx_t_240 = 0;
  __pyx_t_241 = 0;
  __pyx_t_242 = 0;
  __pyx_t_243 = 0;
  __pyx_t_244 = 0;
  __pyx_t_245 = 0;
  __pyx_t_246 = 0;
  __pyx_t_247 = 0;
  __pyx_t_248 = 0;
  __pyx_t_249 = 0;
  __pyx_t_250 = 0;
  __pyx_t_251 = 0;
  __pyx_t_252 = 0;
  __pyx_t_253 = 0;
  __pyx_t_254 = 0;
  __pyx_t_255 = 0;
  __pyx_t_256 = 0;
  __pyx_t_257 = 0;
  __pyx_t_258 = 0;
  __pyx_t_259 = 0;
  __pyx_t_260 = 0;
  __Pyx_GIVEREF(__pyx_t_261);
  __Pyx_GOTREF(__pyx_v_self->color_table);
  __Pyx_DECREF(__pyx_v_self->color_table);
  __pyx_v_self->color_table = __pyx_t_261;
  __pyx_t_261 = 0;

  /* "ttygif/tty/viewer.pyx":66
 *         return buffer
 * 
 *     def __init__(self,width=640,height=480,char_width=None,char_height=None,debug=None):             # <<<<<<<<<<<<<<
 *         self.debug_mode                =debug
 *         self.viewport_px_width    =width
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_XDECREF(__pyx_t_30);
  __Pyx_XDECREF(__pyx_t_31);
  __Pyx_XDECREF(__pyx_t_32);
  __Pyx_XDECREF(__pyx_t_33);
  __Pyx_XDECREF(__pyx_t_34);
  __Pyx_XDECREF(__pyx_t_35);
  __Pyx_XDECREF(__pyx_t_36);
  __Pyx_XDECREF(__pyx_t_37);
  __Pyx_XDECREF(__pyx_t_38);
  __Pyx_XDECREF(__pyx_t_39);
  __Pyx_XDECREF(__pyx_t_40);
  __Pyx_XDECREF(__pyx_t_41);
  __Pyx_XDECREF(__pyx_t_42);
  __Pyx_XDECREF(__pyx_t_43);
  __Pyx_XDECREF(__pyx_t_44);
  __Pyx_XDECREF(__pyx_t_45);
  __Pyx_XDECREF(__pyx_t_46);
  __Pyx_XDECREF(__pyx_t_47);
  __Pyx_XDECREF(__pyx_t_48);
  __Pyx_XDECREF(__pyx_t_49);
  __Pyx_XDECREF(__pyx_t_50);
  __Pyx_XDECREF(__pyx_t_51);
  __Pyx_XDECREF(__pyx_t_52);
  __Pyx_XDECREF(__pyx_t_53);
  __Pyx_XDECREF(__pyx_t_54);
  __Pyx_XDECREF(__pyx_t_55);
  __Pyx_XDECREF(__pyx_t_56);
  __Pyx_XDECREF(__pyx_t_57);
  __Pyx_XDECREF(__pyx_t_58);
  __Pyx_XDECREF(__pyx_t_59);
  __Pyx_XDECREF(__pyx_t_60);
  __Pyx_XDECREF(__pyx_t_61);
  __Pyx_XDECREF(__pyx_t_62);
  __Pyx_XDECREF(__pyx_t_63);
  __Pyx_XDECREF(__pyx_t_64);
  __Pyx_XDECREF(__pyx_t_65);
  __Pyx_XDECREF(__pyx_t_66);
  __Pyx_XDECREF(__pyx_t_67);
  __Pyx_XDECREF(__pyx_t_68);
  __Pyx_XDECREF(__pyx_t_69);
  __Pyx_XDECREF(__pyx_t_70);
  __Pyx_XDECREF(__pyx_t_71);
  __Pyx_XDECREF(__pyx_t_72);
  __Pyx_XDECREF(__pyx_t_73);
  __Pyx_XDECREF(__pyx_t_74);
  __Pyx_XDECREF(__pyx_t_75);
  __Pyx_XDECREF(__pyx_t_76);
  __Pyx_XDECREF(__pyx_t_77);
  __Pyx_XDECREF(__pyx_t_78);
  __Pyx_XDECREF(__pyx_t_79);
  __Pyx_XDECREF(__pyx_t_80);
  __Pyx_XDECREF(__pyx_t_81);
  __Pyx_XDECREF(__pyx_t_82);
  __Pyx_XDECREF(__pyx_t_83);
  __Pyx_XDECREF(__pyx_t_84);
  __Pyx_XDECREF(__pyx_t_85);
  __Pyx_XDECREF(__pyx_t_86);
  __Pyx_XDECREF(__pyx_t_87);
  __Pyx_XDECREF(__pyx_t_88);
  __Pyx_XDECREF(__pyx_t_89);
  __Pyx_XDECREF(__pyx_t_90);
  __Pyx_XDECREF(__pyx_t_91);
  __Pyx_XDECREF(__pyx_t_92);
  __Pyx_XDECREF(__pyx_t_93);
  __Pyx_XDECREF(__pyx_t_94);
  __Pyx_XDECREF(__pyx_t_95);
  __Pyx_XDECREF(__pyx_t_96);
  __Pyx_XDECREF(__pyx_t_97);
  __Pyx_XDECREF(__pyx_t_98);
  __Pyx_XDECREF(__pyx_t_99);
  __Pyx_XDECREF(__pyx_t_100);
  __Pyx_XDECREF(__pyx_t_101);
  __Pyx_XDECREF(__pyx_t_102);
  __Pyx_XDECREF(__pyx_t_103);
  __Pyx_XDECREF(__pyx_t_104);
  __Pyx_XDECREF(__pyx_t_105);
  __Pyx_XDECREF(__pyx_t_106);
  __Pyx_XDECREF(__pyx_t_107);
  __Pyx_XDECREF(__pyx_t_108);
  __Pyx_XDECREF(__pyx_t_109);
  __Pyx_XDECREF(__pyx_t_110);
  __Pyx_XDECREF(__pyx_t_111);
  __Pyx_XDECREF(__pyx_t_112);
  __Pyx_XDECREF(__pyx_t_113);
  __Pyx_XDECREF(__pyx_t_114);
  __Pyx_XDECREF(__pyx_t_115);
  __Pyx_XDECREF(__pyx_t_116);
  __Pyx_XDECREF(__pyx_t_117);
  __Pyx_XDECREF(__pyx_t_118);
  __Pyx_XDECREF(__pyx_t_119);
  __Pyx_XDECREF(__pyx_t_120);
  __Pyx_XDECREF(__pyx_t_121);
  __Pyx_XDECREF(__pyx_t_122);
  __Pyx_XDECREF(__pyx_t_123);
  __Pyx_XDECREF(__pyx_t_124);
  __Pyx_XDECREF(__pyx_t_125);
  __Pyx_XDECREF(__pyx_t_126);
  __Pyx_XDECREF(__pyx_t_127);
  __Pyx_XDECREF(__pyx_t_128);
  __Pyx_XDECREF(__pyx_t_129);
  __Pyx_XDECREF(__pyx_t_130);
  __Pyx_XDECREF(__pyx_t_131);
  __Pyx_XDECREF(__pyx_t_132);
  __Pyx_XDECREF(__pyx_t_133);
  __Pyx_XDECREF(__pyx_t_134);
  __Pyx_XDECREF(__pyx_t_135);
  __Pyx_XDECREF(__pyx_t_136);
  __Pyx_XDECREF(__pyx_t_137);
  __Pyx_XDECREF(__pyx_t_138);
  __Pyx_XDECREF(__pyx_t_139);
  __Pyx_XDECREF(__pyx_t_140);
  __Pyx_XDECREF(__pyx_t_141);
  __Pyx_XDECREF(__pyx_t_142);
  __Pyx_XDECREF(__pyx_t_143);
  __Pyx_XDECREF(__pyx_t_144);
  __Pyx_XDECREF(__pyx_t_145);
  __Pyx_XDECREF(__pyx_t_146);
  __Pyx_XDECREF(__pyx_t_147);
  __Pyx_XDECREF(__pyx_t_148);
  __Pyx_XDECREF(__pyx_t_149);
  __Pyx_XDECREF(__pyx_t_150);
  __Pyx_XDECREF(__pyx_t_151);
  __Pyx_XDECREF(__pyx_t_152);
  __Pyx_XDECREF(__pyx_t_153);
  __Pyx_XDECREF(__pyx_t_154);
  __Pyx_XDECREF(__pyx_t_155);
  __Pyx_XDECREF(__pyx_t_156);
  __Pyx_XDECREF(__pyx_t_157);
  __Pyx_XDECREF(__pyx_t_158);
  __Pyx_XDECREF(__pyx_t_159);
  __Pyx_XDECREF(__pyx_t_160);
  __Pyx_XDECREF(__pyx_t_161);
  __Pyx_XDECREF(__pyx_t_162);
  __Pyx_XDECREF(__pyx_t_163);
  __Pyx_XDECREF(__pyx_t_164);
  __Pyx_XDECREF(__pyx_t_165);
  __Pyx_XDECREF(__pyx_t_166);
  __Pyx_XDECREF(__pyx_t_167);
  __Pyx_XDECREF(__pyx_t_168);
  __Pyx_XDECREF(__pyx_t_169);
  __Pyx_XDECREF(__pyx_t_170);
  __Pyx_XDECREF(__pyx_t_171);
  __Pyx_XDECREF(__pyx_t_172);
  __Pyx_XDECREF(__pyx_t_173);
  __Pyx_XDECREF(__pyx_t_174);
  __Pyx_XDECREF(__pyx_t_175);
  __Pyx_XDECREF(__pyx_t_176);
  __Pyx_XDECREF(__pyx_t_177);
  __Pyx_XDECREF(__pyx_t_178);
  __Pyx_XDECREF(__pyx_t_179);
  __Pyx_XDECREF(__pyx_t_180);
  __Pyx_XDECREF(__pyx_t_181);
  __Pyx_XDECREF(__pyx_t_182);
  __Pyx_XDECREF(__pyx_t_183);
  __Pyx_XDECREF(__pyx_t_184);
  __Pyx_XDECREF(__pyx_t_185);
  __Pyx_XDECREF(__pyx_t_186);
  __Pyx_XDECREF(__pyx_t_187);
  __Pyx_XDECREF(__pyx_t_188);
  __Pyx_XDECREF(__pyx_t_189);
  __Pyx_XDECREF(__pyx_t_190);
  __Pyx_XDECREF(__pyx_t_191);
  __Pyx_XDECREF(__pyx_t_192);
  __Pyx_XDECREF(__pyx_t_193);
  __Pyx_XDECREF(__pyx_t_194);
  __Pyx_XDECREF(__pyx_t_195);
  __Pyx_XDECREF(__pyx_t_196);
  __Pyx_XDECREF(__pyx_t_197);
  __Pyx_XDECREF(__pyx_t_198);
  __Pyx_XDECREF(__pyx_t_199);
  __Pyx_XDECREF(__pyx_t_200);
  __Pyx_XDECREF(__pyx_t_201);
  __Pyx_XDECREF(__pyx_t_202);
  __Pyx_XDECREF(__pyx_t_203);
  __Pyx_XDECREF(__pyx_t_204);
  __Pyx_XDECREF(__pyx_t_205);
  __Pyx_XDECREF(__pyx_t_206);
  __Pyx_XDECREF(__pyx_t_207);
  __Pyx_XDECREF(__pyx_t_208);
  __Pyx_XDECREF(__pyx_t_209);
  __Pyx_XDECREF(__pyx_t_210);
  __Pyx_XDECREF(__pyx_t_211);
  __Pyx_XDECREF(__pyx_t_212);
  __Pyx_XDECREF(__pyx_t_213);
  __Pyx_XDECREF(__pyx_t_214);
  __Pyx_XDECREF(__pyx_t_215);
  __Pyx_XDECREF(__pyx_t_216);
  __Pyx_XDECREF(__pyx_t_217);
  __Pyx_XDECREF(__pyx_t_218);
  __Pyx_XDECREF(__pyx_t_219);
  __Pyx_XDECREF(__pyx_t_220);
  __Pyx_XDECREF(__pyx_t_221);
  __Pyx_XDECREF(__pyx_t_222);
  __Pyx_XDECREF(__pyx_t_223);
  __Pyx_XDECREF(__pyx_t_224);
  __Pyx_XDECREF(__pyx_t_225);
  __Pyx_XDECREF(__pyx_t_226);
  __Pyx_XDECREF(__pyx_t_227);
  __Pyx_XDECREF(__pyx_t_228);
  __Pyx_XDECREF(__pyx_t_229);
  __Pyx_XDECREF(__pyx_t_230);
  __Pyx_XDECREF(__pyx_t_231);
  __Pyx_XDECREF(__pyx_t_232);
  __Pyx_XDECREF(__pyx_t_233);
  __Pyx_XDECREF(__pyx_t_234);
  __Pyx_XDECREF(__pyx_t_235);
  __Pyx_XDECREF(__pyx_t_236);
  __Pyx_XDECREF(__pyx_t_237);
  __Pyx_XDECREF(__pyx_t_238);
  __Pyx_XDECREF(__pyx_t_239);
  __Pyx_XDECREF(__pyx_t_240);
  __Pyx_XDECREF(__pyx_t_241);
  __Pyx_XDECREF(__pyx_t_242);
  __Pyx_XDECREF(__pyx_t_243);
  __Pyx_XDECREF(__pyx_t_244);
  __Pyx_XDECREF(__pyx_t_245);
  __Pyx_XDECREF(__pyx_t_246);
  __Pyx_XDECREF(__pyx_t_247);
  __Pyx_XDECREF(__pyx_t_248);
  __Pyx_XDECREF(__pyx_t_249);
  __Pyx_XDECREF(__pyx_t_250);
  __Pyx_XDECREF(__pyx_t_251);
  __Pyx_XDECREF(__pyx_t_252);
  __Pyx_XDECREF(__pyx_t_253);
  __Pyx_XDECREF(__pyx_t_254);
  __Pyx_XDECREF(__pyx_t_255);
  __Pyx_XDECREF(__pyx_t_256);
  __Pyx_XDECREF(__pyx_t_257);
  __Pyx_XDECREF(__pyx_t_258);
  __Pyx_XDECREF(__pyx_t_259);
  __Pyx_XDECREF(__pyx_t_260);
  __Pyx_XDECREF(__pyx_t_261);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":153
 *         ]
 * 
 *     def draw_string(self,x,y,data):             # <<<<<<<<<<<<<<
 *         for i in data:
 *             self.draw_character3(ord(i),x,y,0,0,15)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_3draw_string(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_3draw_string(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_x = 0;
  PyObject *__pyx_v_y = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_string (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x,&__pyx_n_s_y,&__pyx_n_s_data,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_x)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("draw_string", 1, 3, 3, 1); __PYX_ERR(0, 153, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("draw_string", 1, 3, 3, 2); __PYX_ERR(0, 153, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "draw_string") < 0)) __PYX_ERR(0, 153, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_x = values[0];
    __pyx_v_y = values[1];
    __pyx_v_data = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("draw_string", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 153, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.draw_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_2draw_string(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), __pyx_v_x, __pyx_v_y, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_2draw_string(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_x, PyObject *__pyx_v_y, PyObject *__pyx_v_data) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  long __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("draw_string", 0);
  __Pyx_TraceCall("draw_string", __pyx_f[0], 153, 0, __PYX_ERR(0, 153, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_x);

  /* "ttygif/tty/viewer.pyx":154
 * 
 *     def draw_string(self,x,y,data):
 *         for i in data:             # <<<<<<<<<<<<<<
 *             self.draw_character3(ord(i),x,y,0,0,15)
 *             x+=1
 */
  __Pyx_TraceLine(154,0,__PYX_ERR(0, 154, __pyx_L1_error))
  if (likely(PyList_CheckExact(__pyx_v_data)) || PyTuple_CheckExact(__pyx_v_data)) {
    __pyx_t_1 = __pyx_v_data; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 154, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 154, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 154, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "ttygif/tty/viewer.pyx":155
 *     def draw_string(self,x,y,data):
 *         for i in data:
 *             self.draw_character3(ord(i),x,y,0,0,15)             # <<<<<<<<<<<<<<
 *             x+=1
 * 
 */
    __Pyx_TraceLine(155,0,__PYX_ERR(0, 155, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyObject_Ord(__pyx_v_i); if (unlikely(__pyx_t_5 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 155, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_x); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 155, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 155, __pyx_L1_error)
    __pyx_t_4 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->draw_character3(__pyx_v_self, __pyx_t_5, __pyx_t_6, __pyx_t_7, 0, 0, 15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "ttygif/tty/viewer.pyx":156
 *         for i in data:
 *             self.draw_character3(ord(i),x,y,0,0,15)
 *             x+=1             # <<<<<<<<<<<<<<
 * 
 *     cdef draw_character3(self,int character,int x,int y,int offset,int foreground_color,int background_color):
 */
    __Pyx_TraceLine(156,0,__PYX_ERR(0, 156, __pyx_L1_error))
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_x, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "ttygif/tty/viewer.pyx":154
 * 
 *     def draw_string(self,x,y,data):
 *         for i in data:             # <<<<<<<<<<<<<<
 *             self.draw_character3(ord(i),x,y,0,0,15)
 *             x+=1
 */
    __Pyx_TraceLine(154,0,__PYX_ERR(0, 154, __pyx_L1_error))
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":153
 *         ]
 * 
 *     def draw_string(self,x,y,data):             # <<<<<<<<<<<<<<
 *         for i in data:
 *             self.draw_character3(ord(i),x,y,0,0,15)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.draw_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":158
 *             x+=1
 * 
 *     cdef draw_character3(self,int character,int x,int y,int offset,int foreground_color,int background_color):             # <<<<<<<<<<<<<<
 *         cdef int fs            = font.width
 *         cdef int fw            = font.font_width
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_draw_character3(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, int __pyx_v_character, int __pyx_v_x, int __pyx_v_y, CYTHON_UNUSED int __pyx_v_offset, int __pyx_v_foreground_color, int __pyx_v_background_color) {
  int __pyx_v_fs;
  int __pyx_v_fw;
  int __pyx_v_fh;
  int __pyx_v_fox;
  int __pyx_v_foy;
  int __pyx_v_fsx;
  int __pyx_v_fsy;
  int __pyx_v_transparent;
  int __pyx_v_cx;
  int __pyx_v_cy;
  int __pyx_v_pre_x;
  int __pyx_v_pre_y;
  int __pyx_v_pre;
  int __pyx_v_sy;
  int __pyx_v_sx;
  int __pyx_v_screen_pos;
  int __pyx_v_char_pos;
  int __pyx_v_fx;
  int __pyx_v_fy;
  int __pyx_v_new_line_stride;
  int __pyx_v_new_char_line_stride;
  PyObject *__pyx_v_loop = NULL;
  PyObject *__pyx_v_pixel = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("draw_character3", 0);
  __Pyx_TraceCall("draw_character3", __pyx_f[0], 158, 0, __PYX_ERR(0, 158, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":159
 * 
 *     cdef draw_character3(self,int character,int x,int y,int offset,int foreground_color,int background_color):
 *         cdef int fs            = font.width             # <<<<<<<<<<<<<<
 *         cdef int fw            = font.font_width
 *         cdef int fh            = font.font_height
 */
  __Pyx_TraceLine(159,0,__PYX_ERR(0, 159, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->width;
  __pyx_v_fs = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":160
 *     cdef draw_character3(self,int character,int x,int y,int offset,int foreground_color,int background_color):
 *         cdef int fs            = font.width
 *         cdef int fw            = font.font_width             # <<<<<<<<<<<<<<
 *         cdef int fh            = font.font_height
 *         cdef int fox           = font.offset_x
 */
  __Pyx_TraceLine(160,0,__PYX_ERR(0, 160, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->font_width;
  __pyx_v_fw = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":161
 *         cdef int fs            = font.width
 *         cdef int fw            = font.font_width
 *         cdef int fh            = font.font_height             # <<<<<<<<<<<<<<
 *         cdef int fox           = font.offset_x
 *         cdef int foy           = font.offset_y
 */
  __Pyx_TraceLine(161,0,__PYX_ERR(0, 161, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->font_height;
  __pyx_v_fh = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":162
 *         cdef int fw            = font.font_width
 *         cdef int fh            = font.font_height
 *         cdef int fox           = font.offset_x             # <<<<<<<<<<<<<<
 *         cdef int foy           = font.offset_y
 *         cdef int fsx           = font.spacing_x
 */
  __Pyx_TraceLine(162,0,__PYX_ERR(0, 162, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->offset_x;
  __pyx_v_fox = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":163
 *         cdef int fh            = font.font_height
 *         cdef int fox           = font.offset_x
 *         cdef int foy           = font.offset_y             # <<<<<<<<<<<<<<
 *         cdef int fsx           = font.spacing_x
 *         cdef int fsy           = font.spacing_y
 */
  __Pyx_TraceLine(163,0,__PYX_ERR(0, 163, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->offset_y;
  __pyx_v_foy = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":164
 *         cdef int fox           = font.offset_x
 *         cdef int foy           = font.offset_y
 *         cdef int fsx           = font.spacing_x             # <<<<<<<<<<<<<<
 *         cdef int fsy           = font.spacing_y
 *         cdef int transparent   = font.transparent
 */
  __Pyx_TraceLine(164,0,__PYX_ERR(0, 164, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->spacing_x;
  __pyx_v_fsx = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":165
 *         cdef int foy           = font.offset_y
 *         cdef int fsx           = font.spacing_x
 *         cdef int fsy           = font.spacing_y             # <<<<<<<<<<<<<<
 *         cdef int transparent   = font.transparent
 *         cdef int cx            = int(character%font.chars_per_line)
 */
  __Pyx_TraceLine(165,0,__PYX_ERR(0, 165, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->spacing_y;
  __pyx_v_fsy = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":166
 *         cdef int fsx           = font.spacing_x
 *         cdef int fsy           = font.spacing_y
 *         cdef int transparent   = font.transparent             # <<<<<<<<<<<<<<
 *         cdef int cx            = int(character%font.chars_per_line)
 *         cdef int cy            = int(character/font.chars_per_line)
 */
  __Pyx_TraceLine(166,0,__PYX_ERR(0, 166, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_6ttygif_3tty_5fonts_font->transparent;
  __pyx_v_transparent = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":167
 *         cdef int fsy           = font.spacing_y
 *         cdef int transparent   = font.transparent
 *         cdef int cx            = int(character%font.chars_per_line)             # <<<<<<<<<<<<<<
 *         cdef int cy            = int(character/font.chars_per_line)
 *         cdef int pre_x         = fox+cx*fw
 */
  __Pyx_TraceLine(167,0,__PYX_ERR(0, 167, __pyx_L1_error))
  if (unlikely(__pyx_v_6ttygif_3tty_5fonts_font->chars_per_line == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 167, __pyx_L1_error)
  }
  __pyx_v_cx = __Pyx_mod_int(__pyx_v_character, __pyx_v_6ttygif_3tty_5fonts_font->chars_per_line);

  /* "ttygif/tty/viewer.pyx":168
 *         cdef int transparent   = font.transparent
 *         cdef int cx            = int(character%font.chars_per_line)
 *         cdef int cy            = int(character/font.chars_per_line)             # <<<<<<<<<<<<<<
 *         cdef int pre_x         = fox+cx*fw
 *         cdef int pre_y         = foy+cy*fh*fs
 */
  __Pyx_TraceLine(168,0,__PYX_ERR(0, 168, __pyx_L1_error))
  if (unlikely(__pyx_v_6ttygif_3tty_5fonts_font->chars_per_line == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 168, __pyx_L1_error)
  }
  else if (sizeof(int) == sizeof(long) && (!(((int)-1) > 0)) && unlikely(__pyx_v_6ttygif_3tty_5fonts_font->chars_per_line == (int)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW(__pyx_v_character))) {
    PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
    __PYX_ERR(0, 168, __pyx_L1_error)
  }
  __pyx_v_cy = __Pyx_div_int(__pyx_v_character, __pyx_v_6ttygif_3tty_5fonts_font->chars_per_line);

  /* "ttygif/tty/viewer.pyx":169
 *         cdef int cx            = int(character%font.chars_per_line)
 *         cdef int cy            = int(character/font.chars_per_line)
 *         cdef int pre_x         = fox+cx*fw             # <<<<<<<<<<<<<<
 *         cdef int pre_y         = foy+cy*fh*fs
 *         cdef int pre           = pre_x+pre_y
 */
  __Pyx_TraceLine(169,0,__PYX_ERR(0, 169, __pyx_L1_error))
  __pyx_v_pre_x = (__pyx_v_fox + (__pyx_v_cx * __pyx_v_fw));

  /* "ttygif/tty/viewer.pyx":170
 *         cdef int cy            = int(character/font.chars_per_line)
 *         cdef int pre_x         = fox+cx*fw
 *         cdef int pre_y         = foy+cy*fh*fs             # <<<<<<<<<<<<<<
 *         cdef int pre           = pre_x+pre_y
 *         cdef int sy            = fh+fsy
 */
  __Pyx_TraceLine(170,0,__PYX_ERR(0, 170, __pyx_L1_error))
  __pyx_v_pre_y = (__pyx_v_foy + ((__pyx_v_cy * __pyx_v_fh) * __pyx_v_fs));

  /* "ttygif/tty/viewer.pyx":171
 *         cdef int pre_x         = fox+cx*fw
 *         cdef int pre_y         = foy+cy*fh*fs
 *         cdef int pre           = pre_x+pre_y             # <<<<<<<<<<<<<<
 *         cdef int sy            = fh+fsy
 *         cdef int sx            = fw+fsx
 */
  __Pyx_TraceLine(171,0,__PYX_ERR(0, 171, __pyx_L1_error))
  __pyx_v_pre = (__pyx_v_pre_x + __pyx_v_pre_y);

  /* "ttygif/tty/viewer.pyx":172
 *         cdef int pre_y         = foy+cy*fh*fs
 *         cdef int pre           = pre_x+pre_y
 *         cdef int sy            = fh+fsy             # <<<<<<<<<<<<<<
 *         cdef int sx            = fw+fsx
 *         cdef int screen_pos    = sx*x+sy*y*self.viewport_px_width
 */
  __Pyx_TraceLine(172,0,__PYX_ERR(0, 172, __pyx_L1_error))
  __pyx_v_sy = (__pyx_v_fh + __pyx_v_fsy);

  /* "ttygif/tty/viewer.pyx":173
 *         cdef int pre           = pre_x+pre_y
 *         cdef int sy            = fh+fsy
 *         cdef int sx            = fw+fsx             # <<<<<<<<<<<<<<
 *         cdef int screen_pos    = sx*x+sy*y*self.viewport_px_width
 *         cdef int char_pos      = pre
 */
  __Pyx_TraceLine(173,0,__PYX_ERR(0, 173, __pyx_L1_error))
  __pyx_v_sx = (__pyx_v_fw + __pyx_v_fsx);

  /* "ttygif/tty/viewer.pyx":174
 *         cdef int sy            = fh+fsy
 *         cdef int sx            = fw+fsx
 *         cdef int screen_pos    = sx*x+sy*y*self.viewport_px_width             # <<<<<<<<<<<<<<
 *         cdef int char_pos      = pre
 *         cdef int fx            = 0
 */
  __Pyx_TraceLine(174,0,__PYX_ERR(0, 174, __pyx_L1_error))
  __pyx_v_screen_pos = ((__pyx_v_sx * __pyx_v_x) + ((__pyx_v_sy * __pyx_v_y) * __pyx_v_self->viewport_px_width));

  /* "ttygif/tty/viewer.pyx":175
 *         cdef int sx            = fw+fsx
 *         cdef int screen_pos    = sx*x+sy*y*self.viewport_px_width
 *         cdef int char_pos      = pre             # <<<<<<<<<<<<<<
 *         cdef int fx            = 0
 *         cdef int fy            = 0
 */
  __Pyx_TraceLine(175,0,__PYX_ERR(0, 175, __pyx_L1_error))
  __pyx_v_char_pos = __pyx_v_pre;

  /* "ttygif/tty/viewer.pyx":176
 *         cdef int screen_pos    = sx*x+sy*y*self.viewport_px_width
 *         cdef int char_pos      = pre
 *         cdef int fx            = 0             # <<<<<<<<<<<<<<
 *         cdef int fy            = 0
 *         cdef int new_line_stride      =self.viewport_px_width-(fw+fsx)
 */
  __Pyx_TraceLine(176,0,__PYX_ERR(0, 176, __pyx_L1_error))
  __pyx_v_fx = 0;

  /* "ttygif/tty/viewer.pyx":177
 *         cdef int char_pos      = pre
 *         cdef int fx            = 0
 *         cdef int fy            = 0             # <<<<<<<<<<<<<<
 *         cdef int new_line_stride      =self.viewport_px_width-(fw+fsx)
 *         cdef int new_char_line_stride =fs-(fw+fsx)
 */
  __Pyx_TraceLine(177,0,__PYX_ERR(0, 177, __pyx_L1_error))
  __pyx_v_fy = 0;

  /* "ttygif/tty/viewer.pyx":178
 *         cdef int fx            = 0
 *         cdef int fy            = 0
 *         cdef int new_line_stride      =self.viewport_px_width-(fw+fsx)             # <<<<<<<<<<<<<<
 *         cdef int new_char_line_stride =fs-(fw+fsx)
 * 
 */
  __Pyx_TraceLine(178,0,__PYX_ERR(0, 178, __pyx_L1_error))
  __pyx_v_new_line_stride = (__pyx_v_self->viewport_px_width - (__pyx_v_fw + __pyx_v_fsx));

  /* "ttygif/tty/viewer.pyx":179
 *         cdef int fy            = 0
 *         cdef int new_line_stride      =self.viewport_px_width-(fw+fsx)
 *         cdef int new_char_line_stride =fs-(fw+fsx)             # <<<<<<<<<<<<<<
 * 
 *         loop=True
 */
  __Pyx_TraceLine(179,0,__PYX_ERR(0, 179, __pyx_L1_error))
  __pyx_v_new_char_line_stride = (__pyx_v_fs - (__pyx_v_fw + __pyx_v_fsx));

  /* "ttygif/tty/viewer.pyx":181
 *         cdef int new_char_line_stride =fs-(fw+fsx)
 * 
 *         loop=True             # <<<<<<<<<<<<<<
 * 
 *         while loop:
 */
  __Pyx_TraceLine(181,0,__PYX_ERR(0, 181, __pyx_L1_error))
  __Pyx_INCREF(Py_True);
  __pyx_v_loop = Py_True;

  /* "ttygif/tty/viewer.pyx":183
 *         loop=True
 * 
 *         while loop:             # <<<<<<<<<<<<<<
 *             pixel=font.graphic[char_pos]
 *             if pixel!=transparent:
 */
  __Pyx_TraceLine(183,0,__PYX_ERR(0, 183, __pyx_L1_error))
  while (1) {
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_loop); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 183, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "ttygif/tty/viewer.pyx":184
 * 
 *         while loop:
 *             pixel=font.graphic[char_pos]             # <<<<<<<<<<<<<<
 *             if pixel!=transparent:
 *                 self.video[screen_pos]=foreground_color
 */
    __Pyx_TraceLine(184,0,__PYX_ERR(0, 184, __pyx_L1_error))
    __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_6ttygif_3tty_5fonts_font->graphic), __pyx_v_char_pos, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_pixel, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "ttygif/tty/viewer.pyx":185
 *         while loop:
 *             pixel=font.graphic[char_pos]
 *             if pixel!=transparent:             # <<<<<<<<<<<<<<
 *                 self.video[screen_pos]=foreground_color
 *             else:
 */
    __Pyx_TraceLine(185,0,__PYX_ERR(0, 185, __pyx_L1_error))
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_transparent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_pixel, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 185, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 185, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":186
 *             pixel=font.graphic[char_pos]
 *             if pixel!=transparent:
 *                 self.video[screen_pos]=foreground_color             # <<<<<<<<<<<<<<
 *             else:
 *                 self.video[screen_pos]=background_color
 */
      __Pyx_TraceLine(186,0,__PYX_ERR(0, 186, __pyx_L1_error))
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_foreground_color); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self->video), __pyx_v_screen_pos, __pyx_t_4, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0)) __PYX_ERR(0, 186, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "ttygif/tty/viewer.pyx":185
 *         while loop:
 *             pixel=font.graphic[char_pos]
 *             if pixel!=transparent:             # <<<<<<<<<<<<<<
 *                 self.video[screen_pos]=foreground_color
 *             else:
 */
      goto __pyx_L5;
    }

    /* "ttygif/tty/viewer.pyx":188
 *                 self.video[screen_pos]=foreground_color
 *             else:
 *                 self.video[screen_pos]=background_color             # <<<<<<<<<<<<<<
 *             char_pos+=1
 *             fx+=1
 */
    __Pyx_TraceLine(188,0,__PYX_ERR(0, 188, __pyx_L1_error))
    /*else*/ {
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_background_color); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self->video), __pyx_v_screen_pos, __pyx_t_4, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0)) __PYX_ERR(0, 188, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L5:;

    /* "ttygif/tty/viewer.pyx":189
 *             else:
 *                 self.video[screen_pos]=background_color
 *             char_pos+=1             # <<<<<<<<<<<<<<
 *             fx+=1
 *             screen_pos+=1
 */
    __Pyx_TraceLine(189,0,__PYX_ERR(0, 189, __pyx_L1_error))
    __pyx_v_char_pos = (__pyx_v_char_pos + 1);

    /* "ttygif/tty/viewer.pyx":190
 *                 self.video[screen_pos]=background_color
 *             char_pos+=1
 *             fx+=1             # <<<<<<<<<<<<<<
 *             screen_pos+=1
 *             if fx==sx:
 */
    __Pyx_TraceLine(190,0,__PYX_ERR(0, 190, __pyx_L1_error))
    __pyx_v_fx = (__pyx_v_fx + 1);

    /* "ttygif/tty/viewer.pyx":191
 *             char_pos+=1
 *             fx+=1
 *             screen_pos+=1             # <<<<<<<<<<<<<<
 *             if fx==sx:
 *                 fx=0
 */
    __Pyx_TraceLine(191,0,__PYX_ERR(0, 191, __pyx_L1_error))
    __pyx_v_screen_pos = (__pyx_v_screen_pos + 1);

    /* "ttygif/tty/viewer.pyx":192
 *             fx+=1
 *             screen_pos+=1
 *             if fx==sx:             # <<<<<<<<<<<<<<
 *                 fx=0
 *                 fy+=1
 */
    __Pyx_TraceLine(192,0,__PYX_ERR(0, 192, __pyx_L1_error))
    __pyx_t_2 = ((__pyx_v_fx == __pyx_v_sx) != 0);
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":193
 *             screen_pos+=1
 *             if fx==sx:
 *                 fx=0             # <<<<<<<<<<<<<<
 *                 fy+=1
 *                 char_pos+=new_char_line_stride
 */
      __Pyx_TraceLine(193,0,__PYX_ERR(0, 193, __pyx_L1_error))
      __pyx_v_fx = 0;

      /* "ttygif/tty/viewer.pyx":194
 *             if fx==sx:
 *                 fx=0
 *                 fy+=1             # <<<<<<<<<<<<<<
 *                 char_pos+=new_char_line_stride
 *                 screen_pos+=new_line_stride
 */
      __Pyx_TraceLine(194,0,__PYX_ERR(0, 194, __pyx_L1_error))
      __pyx_v_fy = (__pyx_v_fy + 1);

      /* "ttygif/tty/viewer.pyx":195
 *                 fx=0
 *                 fy+=1
 *                 char_pos+=new_char_line_stride             # <<<<<<<<<<<<<<
 *                 screen_pos+=new_line_stride
 *                 if fy==sy:
 */
      __Pyx_TraceLine(195,0,__PYX_ERR(0, 195, __pyx_L1_error))
      __pyx_v_char_pos = (__pyx_v_char_pos + __pyx_v_new_char_line_stride);

      /* "ttygif/tty/viewer.pyx":196
 *                 fy+=1
 *                 char_pos+=new_char_line_stride
 *                 screen_pos+=new_line_stride             # <<<<<<<<<<<<<<
 *                 if fy==sy:
 *                     loop=None
 */
      __Pyx_TraceLine(196,0,__PYX_ERR(0, 196, __pyx_L1_error))
      __pyx_v_screen_pos = (__pyx_v_screen_pos + __pyx_v_new_line_stride);

      /* "ttygif/tty/viewer.pyx":197
 *                 char_pos+=new_char_line_stride
 *                 screen_pos+=new_line_stride
 *                 if fy==sy:             # <<<<<<<<<<<<<<
 *                     loop=None
 * 
 */
      __Pyx_TraceLine(197,0,__PYX_ERR(0, 197, __pyx_L1_error))
      __pyx_t_2 = ((__pyx_v_fy == __pyx_v_sy) != 0);
      if (__pyx_t_2) {

        /* "ttygif/tty/viewer.pyx":198
 *                 screen_pos+=new_line_stride
 *                 if fy==sy:
 *                     loop=None             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __Pyx_TraceLine(198,0,__PYX_ERR(0, 198, __pyx_L1_error))
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_loop, Py_None);

        /* "ttygif/tty/viewer.pyx":197
 *                 char_pos+=new_char_line_stride
 *                 screen_pos+=new_line_stride
 *                 if fy==sy:             # <<<<<<<<<<<<<<
 *                     loop=None
 * 
 */
      }

      /* "ttygif/tty/viewer.pyx":192
 *             fx+=1
 *             screen_pos+=1
 *             if fx==sx:             # <<<<<<<<<<<<<<
 *                 fx=0
 *                 fy+=1
 */
    }
  }

  /* "ttygif/tty/viewer.pyx":158
 *             x+=1
 * 
 *     cdef draw_character3(self,int character,int x,int y,int offset,int foreground_color,int background_color):             # <<<<<<<<<<<<<<
 *         cdef int fs            = font.width
 *         cdef int fw            = font.font_width
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.draw_character3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_pixel);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":202
 * 
 * 
 *     cdef get_buffer_height(self):             # <<<<<<<<<<<<<<
 *         #print self.buffer_rows,"ROWS"
 *         height=self.buffer_rows*font.font_height
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_get_buffer_height(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_v_height;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_buffer_height", 0);
  __Pyx_TraceCall("get_buffer_height", __pyx_f[0], 202, 0, __PYX_ERR(0, 202, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":204
 *     cdef get_buffer_height(self):
 *         #print self.buffer_rows,"ROWS"
 *         height=self.buffer_rows*font.font_height             # <<<<<<<<<<<<<<
 *         return height
 * 
 */
  __Pyx_TraceLine(204,0,__PYX_ERR(0, 204, __pyx_L1_error))
  __pyx_v_height = (__pyx_v_self->buffer_rows * __pyx_v_6ttygif_3tty_5fonts_font->font_height);

  /* "ttygif/tty/viewer.pyx":205
 *         #print self.buffer_rows,"ROWS"
 *         height=self.buffer_rows*font.font_height
 *         return height             # <<<<<<<<<<<<<<
 * 
 *     # todo save as gif..
 */
  __Pyx_TraceLine(205,0,__PYX_ERR(0, 205, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_height); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":202
 * 
 * 
 *     cdef get_buffer_height(self):             # <<<<<<<<<<<<<<
 *         #print self.buffer_rows,"ROWS"
 *         height=self.buffer_rows*font.font_height
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.get_buffer_height", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":209
 *     # todo save as gif..
 *     # pre test with canvas extension
 *     def render(self):             # <<<<<<<<<<<<<<
 *         self.sequence_to_buffer()
 *         memset(self.video.data.as_voidptr, self.background_color, self.video_length * sizeof(char))
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_5render(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_5render(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("render (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_4render(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_4render(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_v_loop = NULL;
  int __pyx_v_pos;
  int __pyx_v_buffer_len;
  int __pyx_v_fg;
  int __pyx_v_bg;
  int __pyx_v_x;
  int __pyx_v_y;
  int __pyx_v_character;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  long __pyx_t_5;
  __Pyx_RefNannySetupContext("render", 0);
  __Pyx_TraceCall("render", __pyx_f[0], 209, 0, __PYX_ERR(0, 209, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":210
 *     # pre test with canvas extension
 *     def render(self):
 *         self.sequence_to_buffer()             # <<<<<<<<<<<<<<
 *         memset(self.video.data.as_voidptr, self.background_color, self.video_length * sizeof(char))
 * 
 */
  __Pyx_TraceLine(210,0,__PYX_ERR(0, 210, __pyx_L1_error))
  __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->sequence_to_buffer(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":211
 *     def render(self):
 *         self.sequence_to_buffer()
 *         memset(self.video.data.as_voidptr, self.background_color, self.video_length * sizeof(char))             # <<<<<<<<<<<<<<
 * 
 *         loop=True
 */
  __Pyx_TraceLine(211,0,__PYX_ERR(0, 211, __pyx_L1_error))
  (void)(memset(__pyx_v_self->video->data.as_voidptr, __pyx_v_self->background_color, (__pyx_v_self->video_length * (sizeof(char)))));

  /* "ttygif/tty/viewer.pyx":213
 *         memset(self.video.data.as_voidptr, self.background_color, self.video_length * sizeof(char))
 * 
 *         loop=True             # <<<<<<<<<<<<<<
 *         cdef int pos=0
 *         cdef int buffer_len=len(self.buffer)
 */
  __Pyx_TraceLine(213,0,__PYX_ERR(0, 213, __pyx_L1_error))
  __Pyx_INCREF(Py_True);
  __pyx_v_loop = Py_True;

  /* "ttygif/tty/viewer.pyx":214
 * 
 *         loop=True
 *         cdef int pos=0             # <<<<<<<<<<<<<<
 *         cdef int buffer_len=len(self.buffer)
 *         cdef int fg=0
 */
  __Pyx_TraceLine(214,0,__PYX_ERR(0, 214, __pyx_L1_error))
  __pyx_v_pos = 0;

  /* "ttygif/tty/viewer.pyx":215
 *         loop=True
 *         cdef int pos=0
 *         cdef int buffer_len=len(self.buffer)             # <<<<<<<<<<<<<<
 *         cdef int fg=0
 *         cdef int bg=0
 */
  __Pyx_TraceLine(215,0,__PYX_ERR(0, 215, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->buffer);
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 215, __pyx_L1_error)
  }
  __pyx_t_2 = Py_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_buffer_len = __pyx_t_2;

  /* "ttygif/tty/viewer.pyx":216
 *         cdef int pos=0
 *         cdef int buffer_len=len(self.buffer)
 *         cdef int fg=0             # <<<<<<<<<<<<<<
 *         cdef int bg=0
 *         cdef int x=0
 */
  __Pyx_TraceLine(216,0,__PYX_ERR(0, 216, __pyx_L1_error))
  __pyx_v_fg = 0;

  /* "ttygif/tty/viewer.pyx":217
 *         cdef int buffer_len=len(self.buffer)
 *         cdef int fg=0
 *         cdef int bg=0             # <<<<<<<<<<<<<<
 *         cdef int x=0
 *         cdef int y=0
 */
  __Pyx_TraceLine(217,0,__PYX_ERR(0, 217, __pyx_L1_error))
  __pyx_v_bg = 0;

  /* "ttygif/tty/viewer.pyx":218
 *         cdef int fg=0
 *         cdef int bg=0
 *         cdef int x=0             # <<<<<<<<<<<<<<
 *         cdef int y=0
 *         cdef int character=0
 */
  __Pyx_TraceLine(218,0,__PYX_ERR(0, 218, __pyx_L1_error))
  __pyx_v_x = 0;

  /* "ttygif/tty/viewer.pyx":219
 *         cdef int bg=0
 *         cdef int x=0
 *         cdef int y=0             # <<<<<<<<<<<<<<
 *         cdef int character=0
 * 
 */
  __Pyx_TraceLine(219,0,__PYX_ERR(0, 219, __pyx_L1_error))
  __pyx_v_y = 0;

  /* "ttygif/tty/viewer.pyx":220
 *         cdef int x=0
 *         cdef int y=0
 *         cdef int character=0             # <<<<<<<<<<<<<<
 * 
 *         while loop:
 */
  __Pyx_TraceLine(220,0,__PYX_ERR(0, 220, __pyx_L1_error))
  __pyx_v_character = 0;

  /* "ttygif/tty/viewer.pyx":222
 *         cdef int character=0
 * 
 *         while loop:             # <<<<<<<<<<<<<<
 *             fg=self.buffer[pos]
 *             bg=self.buffer[pos+1]
 */
  __Pyx_TraceLine(222,0,__PYX_ERR(0, 222, __pyx_L1_error))
  while (1) {
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_loop); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 222, __pyx_L1_error)
    if (!__pyx_t_3) break;

    /* "ttygif/tty/viewer.pyx":223
 * 
 *         while loop:
 *             fg=self.buffer[pos]             # <<<<<<<<<<<<<<
 *             bg=self.buffer[pos+1]
 * 
 */
    __Pyx_TraceLine(223,0,__PYX_ERR(0, 223, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_self->buffer), __pyx_v_pos, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_fg = __pyx_t_4;

    /* "ttygif/tty/viewer.pyx":224
 *         while loop:
 *             fg=self.buffer[pos]
 *             bg=self.buffer[pos+1]             # <<<<<<<<<<<<<<
 * 
 *             character=self.buffer[pos+2]
 */
    __Pyx_TraceLine(224,0,__PYX_ERR(0, 224, __pyx_L1_error))
    __pyx_t_5 = (__pyx_v_pos + 1);
    __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_self->buffer), __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_bg = __pyx_t_4;

    /* "ttygif/tty/viewer.pyx":226
 *             bg=self.buffer[pos+1]
 * 
 *             character=self.buffer[pos+2]             # <<<<<<<<<<<<<<
 *             self.draw_character3(character,x,y,0,fg,bg)
 *             x+=1
 */
    __Pyx_TraceLine(226,0,__PYX_ERR(0, 226, __pyx_L1_error))
    __pyx_t_5 = (__pyx_v_pos + 2);
    __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_self->buffer), __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_character = __pyx_t_4;

    /* "ttygif/tty/viewer.pyx":227
 * 
 *             character=self.buffer[pos+2]
 *             self.draw_character3(character,x,y,0,fg,bg)             # <<<<<<<<<<<<<<
 *             x+=1
 *             if x>=self.viewport_char_width:
 */
    __Pyx_TraceLine(227,0,__PYX_ERR(0, 227, __pyx_L1_error))
    __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->draw_character3(__pyx_v_self, __pyx_v_character, __pyx_v_x, __pyx_v_y, 0, __pyx_v_fg, __pyx_v_bg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":228
 *             character=self.buffer[pos+2]
 *             self.draw_character3(character,x,y,0,fg,bg)
 *             x+=1             # <<<<<<<<<<<<<<
 *             if x>=self.viewport_char_width:
 *                 x=0
 */
    __Pyx_TraceLine(228,0,__PYX_ERR(0, 228, __pyx_L1_error))
    __pyx_v_x = (__pyx_v_x + 1);

    /* "ttygif/tty/viewer.pyx":229
 *             self.draw_character3(character,x,y,0,fg,bg)
 *             x+=1
 *             if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                 x=0
 *                 y+=1
 */
    __Pyx_TraceLine(229,0,__PYX_ERR(0, 229, __pyx_L1_error))
    __pyx_t_3 = ((__pyx_v_x >= __pyx_v_self->viewport_char_width) != 0);
    if (__pyx_t_3) {

      /* "ttygif/tty/viewer.pyx":230
 *             x+=1
 *             if x>=self.viewport_char_width:
 *                 x=0             # <<<<<<<<<<<<<<
 *                 y+=1
 *             pos+=3
 */
      __Pyx_TraceLine(230,0,__PYX_ERR(0, 230, __pyx_L1_error))
      __pyx_v_x = 0;

      /* "ttygif/tty/viewer.pyx":231
 *             if x>=self.viewport_char_width:
 *                 x=0
 *                 y+=1             # <<<<<<<<<<<<<<
 *             pos+=3
 *             if pos>=buffer_len:
 */
      __Pyx_TraceLine(231,0,__PYX_ERR(0, 231, __pyx_L1_error))
      __pyx_v_y = (__pyx_v_y + 1);

      /* "ttygif/tty/viewer.pyx":229
 *             self.draw_character3(character,x,y,0,fg,bg)
 *             x+=1
 *             if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                 x=0
 *                 y+=1
 */
    }

    /* "ttygif/tty/viewer.pyx":232
 *                 x=0
 *                 y+=1
 *             pos+=3             # <<<<<<<<<<<<<<
 *             if pos>=buffer_len:
 *                 loop=None
 */
    __Pyx_TraceLine(232,0,__PYX_ERR(0, 232, __pyx_L1_error))
    __pyx_v_pos = (__pyx_v_pos + 3);

    /* "ttygif/tty/viewer.pyx":233
 *                 y+=1
 *             pos+=3
 *             if pos>=buffer_len:             # <<<<<<<<<<<<<<
 *                 loop=None
 * 
 */
    __Pyx_TraceLine(233,0,__PYX_ERR(0, 233, __pyx_L1_error))
    __pyx_t_3 = ((__pyx_v_pos >= __pyx_v_buffer_len) != 0);
    if (__pyx_t_3) {

      /* "ttygif/tty/viewer.pyx":234
 *             pos+=3
 *             if pos>=buffer_len:
 *                 loop=None             # <<<<<<<<<<<<<<
 * 
 *     # convert the text stream to a text formated grid
 */
      __Pyx_TraceLine(234,0,__PYX_ERR(0, 234, __pyx_L1_error))
      __Pyx_INCREF(Py_None);
      __Pyx_DECREF_SET(__pyx_v_loop, Py_None);

      /* "ttygif/tty/viewer.pyx":233
 *                 y+=1
 *             pos+=3
 *             if pos>=buffer_len:             # <<<<<<<<<<<<<<
 *                 loop=None
 * 
 */
    }
  }

  /* "ttygif/tty/viewer.pyx":209
 *     # todo save as gif..
 *     # pre test with canvas extension
 *     def render(self):             # <<<<<<<<<<<<<<
 *         self.sequence_to_buffer()
 *         memset(self.video.data.as_voidptr, self.background_color, self.video_length * sizeof(char))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.render", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":237
 * 
 *     # convert the text stream to a text formated grid
 *     cdef debug(self):             # <<<<<<<<<<<<<<
 *         print("VIEWPORT:")
 *         print("  px height:          {0}".format(self.viewport_px_height))
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_debug(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  __Pyx_RefNannySetupContext("debug", 0);
  __Pyx_TraceCall("debug", __pyx_f[0], 237, 0, __PYX_ERR(0, 237, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":238
 *     # convert the text stream to a text formated grid
 *     cdef debug(self):
 *         print("VIEWPORT:")             # <<<<<<<<<<<<<<
 *         print("  px height:          {0}".format(self.viewport_px_height))
 *         print("  px width:           {0}".format(self.viewport_px_width))
 */
  __Pyx_TraceLine(238,0,__PYX_ERR(0, 238, __pyx_L1_error))
  if (__Pyx_PrintOne(0, __pyx_kp_s_VIEWPORT) < 0) __PYX_ERR(0, 238, __pyx_L1_error)

  /* "ttygif/tty/viewer.pyx":239
 *     cdef debug(self):
 *         print("VIEWPORT:")
 *         print("  px height:          {0}".format(self.viewport_px_height))             # <<<<<<<<<<<<<<
 *         print("  px width:           {0}".format(self.viewport_px_width))
 *         print("  video buffer size:  {0}".format(len(self.video)))
 */
  __Pyx_TraceLine(239,0,__PYX_ERR(0, 239, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_px_height_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_height); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":240
 *         print("VIEWPORT:")
 *         print("  px height:          {0}".format(self.viewport_px_height))
 *         print("  px width:           {0}".format(self.viewport_px_width))             # <<<<<<<<<<<<<<
 *         print("  video buffer size:  {0}".format(len(self.video)))
 * 
 */
  __Pyx_TraceLine(240,0,__PYX_ERR(0, 240, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_px_width_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_width); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":241
 *         print("  px height:          {0}".format(self.viewport_px_height))
 *         print("  px width:           {0}".format(self.viewport_px_width))
 *         print("  video buffer size:  {0}".format(len(self.video)))             # <<<<<<<<<<<<<<
 * 
 *         print("Buffer:")
 */
  __Pyx_TraceLine(241,0,__PYX_ERR(0, 241, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_video_buffer_size_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_v_self->video);
  __Pyx_INCREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 241, __pyx_L1_error)
  }
  __pyx_t_5 = Py_SIZE(__pyx_t_3); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":243
 *         print("  video buffer size:  {0}".format(len(self.video)))
 * 
 *         print("Buffer:")             # <<<<<<<<<<<<<<
 *         print("  char height:        {0}".format(self.viewport_char_height))
 *         print("  char width:         {0}".format(self.viewport_char_width))
 */
  __Pyx_TraceLine(243,0,__PYX_ERR(0, 243, __pyx_L1_error))
  if (__Pyx_PrintOne(0, __pyx_kp_s_Buffer) < 0) __PYX_ERR(0, 243, __pyx_L1_error)

  /* "ttygif/tty/viewer.pyx":244
 * 
 *         print("Buffer:")
 *         print("  char height:        {0}".format(self.viewport_char_height))             # <<<<<<<<<<<<<<
 *         print("  char width:         {0}".format(self.viewport_char_width))
 *         print("  char stride:        {0}".format(self.viewport_char_stride))
 */
  __Pyx_TraceLine(244,0,__PYX_ERR(0, 244, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_char_height_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_height); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":245
 *         print("Buffer:")
 *         print("  char height:        {0}".format(self.viewport_char_height))
 *         print("  char width:         {0}".format(self.viewport_char_width))             # <<<<<<<<<<<<<<
 *         print("  char stride:        {0}".format(self.viewport_char_stride))
 *         print("  char buffer size:   {0}".format(len(self.buffer)))
 */
  __Pyx_TraceLine(245,0,__PYX_ERR(0, 245, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_char_width_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":246
 *         print("  char height:        {0}".format(self.viewport_char_height))
 *         print("  char width:         {0}".format(self.viewport_char_width))
 *         print("  char stride:        {0}".format(self.viewport_char_stride))             # <<<<<<<<<<<<<<
 *         print("  char buffer size:   {0}".format(len(self.buffer)))
 *         print("  buffer char height: {0}".format(self.buffer_rows))
 */
  __Pyx_TraceLine(246,0,__PYX_ERR(0, 246, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_char_stride_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_stride); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":247
 *         print("  char width:         {0}".format(self.viewport_char_width))
 *         print("  char stride:        {0}".format(self.viewport_char_stride))
 *         print("  char buffer size:   {0}".format(len(self.buffer)))             # <<<<<<<<<<<<<<
 *         print("  buffer char height: {0}".format(self.buffer_rows))
 * 
 */
  __Pyx_TraceLine(247,0,__PYX_ERR(0, 247, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_char_buffer_size_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_v_self->buffer);
  __Pyx_INCREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 247, __pyx_L1_error)
  }
  __pyx_t_5 = Py_SIZE(__pyx_t_3); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":248
 *         print("  char stride:        {0}".format(self.viewport_char_stride))
 *         print("  char buffer size:   {0}".format(len(self.buffer)))
 *         print("  buffer char height: {0}".format(self.buffer_rows))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(248,0,__PYX_ERR(0, 248, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_buffer_char_height_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->buffer_rows); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":237
 * 
 *     # convert the text stream to a text formated grid
 *     cdef debug(self):             # <<<<<<<<<<<<<<
 *         print("VIEWPORT:")
 *         print("  px height:          {0}".format(self.viewport_px_height))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.debug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":252
 * 
 * 
 *     cdef shift_buffer(self,array.array buffer):             # <<<<<<<<<<<<<<
 *         cdef int buffer_length=len(buffer)
 *         cdef int index=self.viewport_char_width
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_shift_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, arrayobject *__pyx_v_buffer) {
  int __pyx_v_buffer_length;
  int __pyx_v_index;
  CYTHON_UNUSED long __pyx_v_i;
  int __pyx_v_row_pos;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  long __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("shift_buffer", 0);
  __Pyx_TraceCall("shift_buffer", __pyx_f[0], 252, 0, __PYX_ERR(0, 252, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":253
 * 
 *     cdef shift_buffer(self,array.array buffer):
 *         cdef int buffer_length=len(buffer)             # <<<<<<<<<<<<<<
 *         cdef int index=self.viewport_char_width
 *         for i in range(0,index):
 */
  __Pyx_TraceLine(253,0,__PYX_ERR(0, 253, __pyx_L1_error))
  if (unlikely(((PyObject *)__pyx_v_buffer) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 253, __pyx_L1_error)
  }
  __pyx_t_1 = Py_SIZE(((PyObject *)__pyx_v_buffer)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 253, __pyx_L1_error)
  __pyx_v_buffer_length = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":254
 *     cdef shift_buffer(self,array.array buffer):
 *         cdef int buffer_length=len(buffer)
 *         cdef int index=self.viewport_char_width             # <<<<<<<<<<<<<<
 *         for i in range(0,index):
 *             buffer.pop(0)
 */
  __Pyx_TraceLine(254,0,__PYX_ERR(0, 254, __pyx_L1_error))
  __pyx_t_2 = __pyx_v_self->viewport_char_width;
  __pyx_v_index = __pyx_t_2;

  /* "ttygif/tty/viewer.pyx":255
 *         cdef int buffer_length=len(buffer)
 *         cdef int index=self.viewport_char_width
 *         for i in range(0,index):             # <<<<<<<<<<<<<<
 *             buffer.pop(0)
 *             buffer.pop(0)
 */
  __Pyx_TraceLine(255,0,__PYX_ERR(0, 255, __pyx_L1_error))
  __pyx_t_2 = __pyx_v_index;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "ttygif/tty/viewer.pyx":256
 *         cdef int index=self.viewport_char_width
 *         for i in range(0,index):
 *             buffer.pop(0)             # <<<<<<<<<<<<<<
 *             buffer.pop(0)
 *             buffer.pop(0)
 */
    __Pyx_TraceLine(256,0,__PYX_ERR(0, 256, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyObject_PopIndex(((PyObject *)__pyx_v_buffer), __pyx_int_0, 0, 1, Py_ssize_t, PyInt_FromSsize_t); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "ttygif/tty/viewer.pyx":257
 *         for i in range(0,index):
 *             buffer.pop(0)
 *             buffer.pop(0)             # <<<<<<<<<<<<<<
 *             buffer.pop(0)
 *         cdef int row_pos=buffer_length-self.viewport_char_stride
 */
    __Pyx_TraceLine(257,0,__PYX_ERR(0, 257, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyObject_PopIndex(((PyObject *)__pyx_v_buffer), __pyx_int_0, 0, 1, Py_ssize_t, PyInt_FromSsize_t); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "ttygif/tty/viewer.pyx":258
 *             buffer.pop(0)
 *             buffer.pop(0)
 *             buffer.pop(0)             # <<<<<<<<<<<<<<
 *         cdef int row_pos=buffer_length-self.viewport_char_stride
 *         array.resize(buffer,buffer_length)
 */
    __Pyx_TraceLine(258,0,__PYX_ERR(0, 258, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyObject_PopIndex(((PyObject *)__pyx_v_buffer), __pyx_int_0, 0, 1, Py_ssize_t, PyInt_FromSsize_t); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "ttygif/tty/viewer.pyx":259
 *             buffer.pop(0)
 *             buffer.pop(0)
 *         cdef int row_pos=buffer_length-self.viewport_char_stride             # <<<<<<<<<<<<<<
 *         array.resize(buffer,buffer_length)
 *         memset(&buffer.data.as_uchars[row_pos],0,self.viewport_char_stride)
 */
  __Pyx_TraceLine(259,0,__PYX_ERR(0, 259, __pyx_L1_error))
  __pyx_v_row_pos = (__pyx_v_buffer_length - __pyx_v_self->viewport_char_stride);

  /* "ttygif/tty/viewer.pyx":260
 *             buffer.pop(0)
 *         cdef int row_pos=buffer_length-self.viewport_char_stride
 *         array.resize(buffer,buffer_length)             # <<<<<<<<<<<<<<
 *         memset(&buffer.data.as_uchars[row_pos],0,self.viewport_char_stride)
 * 
 */
  __Pyx_TraceLine(260,0,__PYX_ERR(0, 260, __pyx_L1_error))
  __pyx_t_2 = resize(__pyx_v_buffer, __pyx_v_buffer_length); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 260, __pyx_L1_error)

  /* "ttygif/tty/viewer.pyx":261
 *         cdef int row_pos=buffer_length-self.viewport_char_stride
 *         array.resize(buffer,buffer_length)
 *         memset(&buffer.data.as_uchars[row_pos],0,self.viewport_char_stride)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(261,0,__PYX_ERR(0, 261, __pyx_L1_error))
  (void)(memset((&(__pyx_v_buffer->data.as_uchars[__pyx_v_row_pos])), 0, __pyx_v_self->viewport_char_stride));

  /* "ttygif/tty/viewer.pyx":252
 * 
 * 
 *     cdef shift_buffer(self,array.array buffer):             # <<<<<<<<<<<<<<
 *         cdef int buffer_length=len(buffer)
 *         cdef int index=self.viewport_char_width
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.shift_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":264
 * 
 * 
 *     def get_text(self):             # <<<<<<<<<<<<<<
 *         loop=True
 *         cdef int pos=0
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_7get_text(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_7get_text(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_text (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6get_text(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6get_text(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_v_loop = NULL;
  int __pyx_v_pos;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_text = NULL;
  Py_ssize_t __pyx_v_buffer_length;
  PyObject *__pyx_v_character = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  long __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("get_text", 0);
  __Pyx_TraceCall("get_text", __pyx_f[0], 264, 0, __PYX_ERR(0, 264, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":265
 * 
 *     def get_text(self):
 *         loop=True             # <<<<<<<<<<<<<<
 *         cdef int pos=0
 *         x=0
 */
  __Pyx_TraceLine(265,0,__PYX_ERR(0, 265, __pyx_L1_error))
  __Pyx_INCREF(Py_True);
  __pyx_v_loop = Py_True;

  /* "ttygif/tty/viewer.pyx":266
 *     def get_text(self):
 *         loop=True
 *         cdef int pos=0             # <<<<<<<<<<<<<<
 *         x=0
 *         y=0
 */
  __Pyx_TraceLine(266,0,__PYX_ERR(0, 266, __pyx_L1_error))
  __pyx_v_pos = 0;

  /* "ttygif/tty/viewer.pyx":267
 *         loop=True
 *         cdef int pos=0
 *         x=0             # <<<<<<<<<<<<<<
 *         y=0
 *         text=""
 */
  __Pyx_TraceLine(267,0,__PYX_ERR(0, 267, __pyx_L1_error))
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_x = __pyx_int_0;

  /* "ttygif/tty/viewer.pyx":268
 *         cdef int pos=0
 *         x=0
 *         y=0             # <<<<<<<<<<<<<<
 *         text=""
 *         buffer_length=len(self.buffer)
 */
  __Pyx_TraceLine(268,0,__PYX_ERR(0, 268, __pyx_L1_error))
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_y = __pyx_int_0;

  /* "ttygif/tty/viewer.pyx":269
 *         x=0
 *         y=0
 *         text=""             # <<<<<<<<<<<<<<
 *         buffer_length=len(self.buffer)
 *         while loop:
 */
  __Pyx_TraceLine(269,0,__PYX_ERR(0, 269, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_);
  __pyx_v_text = __pyx_kp_s_;

  /* "ttygif/tty/viewer.pyx":270
 *         y=0
 *         text=""
 *         buffer_length=len(self.buffer)             # <<<<<<<<<<<<<<
 *         while loop:
 *             character=self.buffer[pos+2]
 */
  __Pyx_TraceLine(270,0,__PYX_ERR(0, 270, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->buffer);
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 270, __pyx_L1_error)
  }
  __pyx_t_2 = Py_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_buffer_length = __pyx_t_2;

  /* "ttygif/tty/viewer.pyx":271
 *         text=""
 *         buffer_length=len(self.buffer)
 *         while loop:             # <<<<<<<<<<<<<<
 *             character=self.buffer[pos+2]
 *             text+=unichr(character)
 */
  __Pyx_TraceLine(271,0,__PYX_ERR(0, 271, __pyx_L1_error))
  while (1) {
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_loop); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 271, __pyx_L1_error)
    if (!__pyx_t_3) break;

    /* "ttygif/tty/viewer.pyx":272
 *         buffer_length=len(self.buffer)
 *         while loop:
 *             character=self.buffer[pos+2]             # <<<<<<<<<<<<<<
 *             text+=unichr(character)
 *             x+=1
 */
    __Pyx_TraceLine(272,0,__PYX_ERR(0, 272, __pyx_L1_error))
    __pyx_t_4 = (__pyx_v_pos + 2);
    __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_self->buffer), __pyx_t_4, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_character, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":273
 *         while loop:
 *             character=self.buffer[pos+2]
 *             text+=unichr(character)             # <<<<<<<<<<<<<<
 *             x+=1
 *             if x>=self.viewport_char_width:
 */
    __Pyx_TraceLine(273,0,__PYX_ERR(0, 273, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_unichr, __pyx_v_character); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_v_text, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "ttygif/tty/viewer.pyx":274
 *             character=self.buffer[pos+2]
 *             text+=unichr(character)
 *             x+=1             # <<<<<<<<<<<<<<
 *             if x>=self.viewport_char_width:
 *                 text+="\n"
 */
    __Pyx_TraceLine(274,0,__PYX_ERR(0, 274, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_x, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "ttygif/tty/viewer.pyx":275
 *             text+=unichr(character)
 *             x+=1
 *             if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                 text+="\n"
 *                 x=0
 */
    __Pyx_TraceLine(275,0,__PYX_ERR(0, 275, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_x, __pyx_t_5, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "ttygif/tty/viewer.pyx":276
 *             x+=1
 *             if x>=self.viewport_char_width:
 *                 text+="\n"             # <<<<<<<<<<<<<<
 *                 x=0
 *                 y+=1
 */
      __Pyx_TraceLine(276,0,__PYX_ERR(0, 276, __pyx_L1_error))
      __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_text, __pyx_kp_s__4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":277
 *             if x>=self.viewport_char_width:
 *                 text+="\n"
 *                 x=0             # <<<<<<<<<<<<<<
 *                 y+=1
 *             pos+=3
 */
      __Pyx_TraceLine(277,0,__PYX_ERR(0, 277, __pyx_L1_error))
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

      /* "ttygif/tty/viewer.pyx":278
 *                 text+="\n"
 *                 x=0
 *                 y+=1             # <<<<<<<<<<<<<<
 *             pos+=3
 *             if pos>=buffer_length:
 */
      __Pyx_TraceLine(278,0,__PYX_ERR(0, 278, __pyx_L1_error))
      __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_y, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":275
 *             text+=unichr(character)
 *             x+=1
 *             if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                 text+="\n"
 *                 x=0
 */
    }

    /* "ttygif/tty/viewer.pyx":279
 *                 x=0
 *                 y+=1
 *             pos+=3             # <<<<<<<<<<<<<<
 *             if pos>=buffer_length:
 *                 loop=None
 */
    __Pyx_TraceLine(279,0,__PYX_ERR(0, 279, __pyx_L1_error))
    __pyx_v_pos = (__pyx_v_pos + 3);

    /* "ttygif/tty/viewer.pyx":280
 *                 y+=1
 *             pos+=3
 *             if pos>=buffer_length:             # <<<<<<<<<<<<<<
 *                 loop=None
 *         text+="\n"
 */
    __Pyx_TraceLine(280,0,__PYX_ERR(0, 280, __pyx_L1_error))
    __pyx_t_3 = ((__pyx_v_pos >= __pyx_v_buffer_length) != 0);
    if (__pyx_t_3) {

      /* "ttygif/tty/viewer.pyx":281
 *             pos+=3
 *             if pos>=buffer_length:
 *                 loop=None             # <<<<<<<<<<<<<<
 *         text+="\n"
 *         return text
 */
      __Pyx_TraceLine(281,0,__PYX_ERR(0, 281, __pyx_L1_error))
      __Pyx_INCREF(Py_None);
      __Pyx_DECREF_SET(__pyx_v_loop, Py_None);

      /* "ttygif/tty/viewer.pyx":280
 *                 y+=1
 *             pos+=3
 *             if pos>=buffer_length:             # <<<<<<<<<<<<<<
 *                 loop=None
 *         text+="\n"
 */
    }
  }

  /* "ttygif/tty/viewer.pyx":282
 *             if pos>=buffer_length:
 *                 loop=None
 *         text+="\n"             # <<<<<<<<<<<<<<
 *         return text
 * 
 */
  __Pyx_TraceLine(282,0,__PYX_ERR(0, 282, __pyx_L1_error))
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_text, __pyx_kp_s__4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":283
 *                 loop=None
 *         text+="\n"
 *         return text             # <<<<<<<<<<<<<<
 * 
 *     #4045017243 2
 */
  __Pyx_TraceLine(283,0,__PYX_ERR(0, 283, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = __pyx_v_text;
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":264
 * 
 * 
 *     def get_text(self):             # <<<<<<<<<<<<<<
 *         loop=True
 *         cdef int pos=0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.get_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_character);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":290
 * 
 * 
 *     cdef write_buffer(self,int x,int y,int c,array.array buffer):             # <<<<<<<<<<<<<<
 *         if c>255:
 *             err_msg="Charactrer out of range -{0}".format(c)
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_write_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, int __pyx_v_x, int __pyx_v_y, int __pyx_v_c, arrayobject *__pyx_v_buffer) {
  PyObject *__pyx_v_err_msg = NULL;
  int __pyx_v_pos;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  long __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  Py_ssize_t __pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  __Pyx_RefNannySetupContext("write_buffer", 0);
  __Pyx_TraceCall("write_buffer", __pyx_f[0], 290, 0, __PYX_ERR(0, 290, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":291
 * 
 *     cdef write_buffer(self,int x,int y,int c,array.array buffer):
 *         if c>255:             # <<<<<<<<<<<<<<
 *             err_msg="Charactrer out of range -{0}".format(c)
 *             raise Exception(err_msg)
 */
  __Pyx_TraceLine(291,0,__PYX_ERR(0, 291, __pyx_L1_error))
  __pyx_t_1 = ((__pyx_v_c > 0xFF) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "ttygif/tty/viewer.pyx":292
 *     cdef write_buffer(self,int x,int y,int c,array.array buffer):
 *         if c>255:
 *             err_msg="Charactrer out of range -{0}".format(c)             # <<<<<<<<<<<<<<
 *             raise Exception(err_msg)
 *         cdef int pos=x*3+y*self.viewport_char_stride
 */
    __Pyx_TraceLine(292,0,__PYX_ERR(0, 292, __pyx_L1_error))
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Charactrer_out_of_range_0, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_c); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_err_msg = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "ttygif/tty/viewer.pyx":293
 *         if c>255:
 *             err_msg="Charactrer out of range -{0}".format(c)
 *             raise Exception(err_msg)             # <<<<<<<<<<<<<<
 *         cdef int pos=x*3+y*self.viewport_char_stride
 *         try:
 */
    __Pyx_TraceLine(293,0,__PYX_ERR(0, 293, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_v_err_msg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 293, __pyx_L1_error)

    /* "ttygif/tty/viewer.pyx":291
 * 
 *     cdef write_buffer(self,int x,int y,int c,array.array buffer):
 *         if c>255:             # <<<<<<<<<<<<<<
 *             err_msg="Charactrer out of range -{0}".format(c)
 *             raise Exception(err_msg)
 */
  }

  /* "ttygif/tty/viewer.pyx":294
 *             err_msg="Charactrer out of range -{0}".format(c)
 *             raise Exception(err_msg)
 *         cdef int pos=x*3+y*self.viewport_char_stride             # <<<<<<<<<<<<<<
 *         try:
 *             #print x,y,pos,len(buffer),c
 */
  __Pyx_TraceLine(294,0,__PYX_ERR(0, 294, __pyx_L1_error))
  __pyx_v_pos = ((__pyx_v_x * 3) + (__pyx_v_y * __pyx_v_self->viewport_char_stride));

  /* "ttygif/tty/viewer.pyx":295
 *             raise Exception(err_msg)
 *         cdef int pos=x*3+y*self.viewport_char_stride
 *         try:             # <<<<<<<<<<<<<<
 *             #print x,y,pos,len(buffer),c
 * 
 */
  __Pyx_TraceLine(295,0,__PYX_ERR(0, 295, __pyx_L1_error))
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "ttygif/tty/viewer.pyx":298
 *             #print x,y,pos,len(buffer),c
 * 
 *             if self.reverse_video:             # <<<<<<<<<<<<<<
 *                 buffer[pos]=self.bg
 *                 buffer[pos+1]=self.fg
 */
      __Pyx_TraceLine(298,0,__PYX_ERR(0, 298, __pyx_L4_error))
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->reverse_video); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 298, __pyx_L4_error)
      if (__pyx_t_1) {

        /* "ttygif/tty/viewer.pyx":299
 * 
 *             if self.reverse_video:
 *                 buffer[pos]=self.bg             # <<<<<<<<<<<<<<
 *                 buffer[pos+1]=self.fg
 *                 buffer[pos+2]=c
 */
        __Pyx_TraceLine(299,0,__PYX_ERR(0, 299, __pyx_L4_error))
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_buffer), __pyx_v_pos, __pyx_t_2, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0)) __PYX_ERR(0, 299, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ttygif/tty/viewer.pyx":300
 *             if self.reverse_video:
 *                 buffer[pos]=self.bg
 *                 buffer[pos+1]=self.fg             # <<<<<<<<<<<<<<
 *                 buffer[pos+2]=c
 *             else:
 */
        __Pyx_TraceLine(300,0,__PYX_ERR(0, 300, __pyx_L4_error))
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = (__pyx_v_pos + 1);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_buffer), __pyx_t_9, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(0, 300, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ttygif/tty/viewer.pyx":301
 *                 buffer[pos]=self.bg
 *                 buffer[pos+1]=self.fg
 *                 buffer[pos+2]=c             # <<<<<<<<<<<<<<
 *             else:
 *                 buffer[pos]=self.fg
 */
        __Pyx_TraceLine(301,0,__PYX_ERR(0, 301, __pyx_L4_error))
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_c); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 301, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = (__pyx_v_pos + 2);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_buffer), __pyx_t_9, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(0, 301, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ttygif/tty/viewer.pyx":298
 *             #print x,y,pos,len(buffer),c
 * 
 *             if self.reverse_video:             # <<<<<<<<<<<<<<
 *                 buffer[pos]=self.bg
 *                 buffer[pos+1]=self.fg
 */
        goto __pyx_L10;
      }

      /* "ttygif/tty/viewer.pyx":303
 *                 buffer[pos+2]=c
 *             else:
 *                 buffer[pos]=self.fg             # <<<<<<<<<<<<<<
 *                 buffer[pos+1]=self.bg
 *                 buffer[pos+2]=c
 */
      __Pyx_TraceLine(303,0,__PYX_ERR(0, 303, __pyx_L4_error))
      /*else*/ {
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 303, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_buffer), __pyx_v_pos, __pyx_t_2, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0)) __PYX_ERR(0, 303, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ttygif/tty/viewer.pyx":304
 *             else:
 *                 buffer[pos]=self.fg
 *                 buffer[pos+1]=self.bg             # <<<<<<<<<<<<<<
 *                 buffer[pos+2]=c
 *         except Exception as ex:
 */
        __Pyx_TraceLine(304,0,__PYX_ERR(0, 304, __pyx_L4_error))
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 304, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = (__pyx_v_pos + 1);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_buffer), __pyx_t_9, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(0, 304, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ttygif/tty/viewer.pyx":305
 *                 buffer[pos]=self.fg
 *                 buffer[pos+1]=self.bg
 *                 buffer[pos+2]=c             # <<<<<<<<<<<<<<
 *         except Exception as ex:
 *             err_msg="Msg:{0} X:{1},Y:{2},C:{3},FG:{4},BG:{5},Buffer Len:{6}".format(ex,x,y,c,self.fg,self.bg,len(buffer))
 */
        __Pyx_TraceLine(305,0,__PYX_ERR(0, 305, __pyx_L4_error))
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_c); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 305, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = (__pyx_v_pos + 2);
        if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_buffer), __pyx_t_9, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(0, 305, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L10:;

      /* "ttygif/tty/viewer.pyx":295
 *             raise Exception(err_msg)
 *         cdef int pos=x*3+y*self.viewport_char_stride
 *         try:             # <<<<<<<<<<<<<<
 *             #print x,y,pos,len(buffer),c
 * 
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "ttygif/tty/viewer.pyx":306
 *                 buffer[pos+1]=self.bg
 *                 buffer[pos+2]=c
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             err_msg="Msg:{0} X:{1},Y:{2},C:{3},FG:{4},BG:{5},Buffer Len:{6}".format(ex,x,y,c,self.fg,self.bg,len(buffer))
 * 
 */
    __Pyx_TraceLine(306,0,__PYX_ERR(0, 306, __pyx_L6_except_error))
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("ttygif.tty.viewer.viewer.write_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 306, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_ex = __pyx_t_3;

      /* "ttygif/tty/viewer.pyx":307
 *                 buffer[pos+2]=c
 *         except Exception as ex:
 *             err_msg="Msg:{0} X:{1},Y:{2},C:{3},FG:{4},BG:{5},Buffer Len:{6}".format(ex,x,y,c,self.fg,self.bg,len(buffer))             # <<<<<<<<<<<<<<
 * 
 *             raise Exception (err_msg)
 */
      __Pyx_TraceLine(307,0,__PYX_ERR(0, 307, __pyx_L6_except_error))
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Msg_0_X_1_Y_2_C_3_FG_4_BG_5_Buff, __pyx_n_s_format); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_x); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_v_y); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_14 = __Pyx_PyInt_From_int(__pyx_v_c); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_15 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_16);
      if (unlikely(((PyObject *)__pyx_v_buffer) == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 307, __pyx_L6_except_error)
      }
      __pyx_t_17 = Py_SIZE(((PyObject *)__pyx_v_buffer)); if (unlikely(__pyx_t_17 == ((Py_ssize_t)-1))) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __pyx_t_18 = PyInt_FromSsize_t(__pyx_t_17); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 307, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_18);
      __pyx_t_19 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_19)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_19);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[8] = {__pyx_t_19, __pyx_v_ex, __pyx_t_12, __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_18};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_10, 7+__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 307, __pyx_L6_except_error)
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[8] = {__pyx_t_19, __pyx_v_ex, __pyx_t_12, __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_18};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_10, 7+__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 307, __pyx_L6_except_error)
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
      } else
      #endif
      {
        __pyx_t_20 = PyTuple_New(7+__pyx_t_10); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 307, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_20);
        if (__pyx_t_19) {
          __Pyx_GIVEREF(__pyx_t_19); PyTuple_SET_ITEM(__pyx_t_20, 0, __pyx_t_19); __pyx_t_19 = NULL;
        }
        __Pyx_INCREF(__pyx_v_ex);
        __Pyx_GIVEREF(__pyx_v_ex);
        PyTuple_SET_ITEM(__pyx_t_20, 0+__pyx_t_10, __pyx_v_ex);
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_20, 1+__pyx_t_10, __pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_20, 2+__pyx_t_10, __pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_20, 3+__pyx_t_10, __pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_15);
        PyTuple_SET_ITEM(__pyx_t_20, 4+__pyx_t_10, __pyx_t_15);
        __Pyx_GIVEREF(__pyx_t_16);
        PyTuple_SET_ITEM(__pyx_t_20, 5+__pyx_t_10, __pyx_t_16);
        __Pyx_GIVEREF(__pyx_t_18);
        PyTuple_SET_ITEM(__pyx_t_20, 6+__pyx_t_10, __pyx_t_18);
        __pyx_t_12 = 0;
        __pyx_t_13 = 0;
        __pyx_t_14 = 0;
        __pyx_t_15 = 0;
        __pyx_t_16 = 0;
        __pyx_t_18 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_20, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 307, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_v_err_msg = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "ttygif/tty/viewer.pyx":309
 *             err_msg="Msg:{0} X:{1},Y:{2},C:{3},FG:{4},BG:{5},Buffer Len:{6}".format(ex,x,y,c,self.fg,self.bg,len(buffer))
 * 
 *             raise Exception (err_msg)             # <<<<<<<<<<<<<<
 * 
 *     def set_mode(self,cmd):
 */
      __Pyx_TraceLine(309,0,__PYX_ERR(0, 309, __pyx_L6_except_error))
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_v_err_msg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 309, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 309, __pyx_L6_except_error)
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "ttygif/tty/viewer.pyx":295
 *             raise Exception(err_msg)
 *         cdef int pos=x*3+y*self.viewport_char_stride
 *         try:             # <<<<<<<<<<<<<<
 *             #print x,y,pos,len(buffer),c
 * 
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L9_try_end:;
  }

  /* "ttygif/tty/viewer.pyx":290
 * 
 * 
 *     cdef write_buffer(self,int x,int y,int c,array.array buffer):             # <<<<<<<<<<<<<<
 *         if c>255:
 *             err_msg="Charactrer out of range -{0}".format(c)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.write_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_err_msg);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":311
 *             raise Exception (err_msg)
 * 
 *     def set_mode(self,cmd):             # <<<<<<<<<<<<<<
 *         dm=self.debug_mode
 *         self.debug_mode=None
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_9set_mode(PyObject *__pyx_v_self, PyObject *__pyx_v_cmd); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_9set_mode(PyObject *__pyx_v_self, PyObject *__pyx_v_cmd) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_mode (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_8set_mode(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_cmd));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_8set_mode(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_cmd) {
  PyObject *__pyx_v_dm = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("set_mode", 0);
  __Pyx_TraceCall("set_mode", __pyx_f[0], 311, 0, __PYX_ERR(0, 311, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":312
 * 
 *     def set_mode(self,cmd):
 *         dm=self.debug_mode             # <<<<<<<<<<<<<<
 *         self.debug_mode=None
 *         if cmd==0:
 */
  __Pyx_TraceLine(312,0,__PYX_ERR(0, 312, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_self->debug_mode;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_dm = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":313
 *     def set_mode(self,cmd):
 *         dm=self.debug_mode
 *         self.debug_mode=None             # <<<<<<<<<<<<<<
 *         if cmd==0:
 *             self.fg=self.def_fg
 */
  __Pyx_TraceLine(313,0,__PYX_ERR(0, 313, __pyx_L1_error))
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->debug_mode);
  __Pyx_DECREF(__pyx_v_self->debug_mode);
  __pyx_v_self->debug_mode = Py_None;

  /* "ttygif/tty/viewer.pyx":314
 *         dm=self.debug_mode
 *         self.debug_mode=None
 *         if cmd==0:             # <<<<<<<<<<<<<<
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg
 */
  __Pyx_TraceLine(314,0,__PYX_ERR(0, 314, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":315
 *         self.debug_mode=None
 *         if cmd==0:
 *             self.fg=self.def_fg             # <<<<<<<<<<<<<<
 *             self.bg=self.def_bg
 *             self.bold=None
 */
    __Pyx_TraceLine(315,0,__PYX_ERR(0, 315, __pyx_L1_error))
    __pyx_t_3 = __pyx_v_self->def_fg;
    __pyx_v_self->fg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":316
 *         if cmd==0:
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg             # <<<<<<<<<<<<<<
 *             self.bold=None
 *             self.reverse_video=None
 */
    __Pyx_TraceLine(316,0,__PYX_ERR(0, 316, __pyx_L1_error))
    __pyx_t_3 = __pyx_v_self->def_bg;
    __pyx_v_self->bg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":317
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg
 *             self.bold=None             # <<<<<<<<<<<<<<
 *             self.reverse_video=None
 *             if self.debug_mode:
 */
    __Pyx_TraceLine(317,0,__PYX_ERR(0, 317, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->bold);
    __Pyx_DECREF(__pyx_v_self->bold);
    __pyx_v_self->bold = Py_None;

    /* "ttygif/tty/viewer.pyx":318
 *             self.bg=self.def_bg
 *             self.bold=None
 *             self.reverse_video=None             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("RESET All")
 */
    __Pyx_TraceLine(318,0,__PYX_ERR(0, 318, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->reverse_video);
    __Pyx_DECREF(__pyx_v_self->reverse_video);
    __pyx_v_self->reverse_video = Py_None;

    /* "ttygif/tty/viewer.pyx":319
 *             self.bold=None
 *             self.reverse_video=None
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("RESET All")
 *         elif cmd==1:
 */
    __Pyx_TraceLine(319,0,__PYX_ERR(0, 319, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 319, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":320
 *             self.reverse_video=None
 *             if self.debug_mode:
 *                 self.info("RESET All")             # <<<<<<<<<<<<<<
 *         elif cmd==1:
 *             self.bold=True
 */
      __Pyx_TraceLine(320,0,__PYX_ERR(0, 320, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_RESET_All); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":319
 *             self.bold=None
 *             self.reverse_video=None
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("RESET All")
 *         elif cmd==1:
 */
    }

    /* "ttygif/tty/viewer.pyx":314
 *         dm=self.debug_mode
 *         self.debug_mode=None
 *         if cmd==0:             # <<<<<<<<<<<<<<
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":321
 *             if self.debug_mode:
 *                 self.info("RESET All")
 *         elif cmd==1:             # <<<<<<<<<<<<<<
 *             self.bold=True
 *             if self.debug_mode:
 */
  __Pyx_TraceLine(321,0,__PYX_ERR(0, 321, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":322
 *                 self.info("RESET All")
 *         elif cmd==1:
 *             self.bold=True             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set BOLD")
 */
    __Pyx_TraceLine(322,0,__PYX_ERR(0, 322, __pyx_L1_error))
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    __Pyx_GOTREF(__pyx_v_self->bold);
    __Pyx_DECREF(__pyx_v_self->bold);
    __pyx_v_self->bold = Py_True;

    /* "ttygif/tty/viewer.pyx":323
 *         elif cmd==1:
 *             self.bold=True
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set BOLD")
 *         elif cmd==7:
 */
    __Pyx_TraceLine(323,0,__PYX_ERR(0, 323, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 323, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":324
 *             self.bold=True
 *             if self.debug_mode:
 *                 self.info("Set BOLD")             # <<<<<<<<<<<<<<
 *         elif cmd==7:
 *             if self.debug_mode:
 */
      __Pyx_TraceLine(324,0,__PYX_ERR(0, 324, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_BOLD); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":323
 *         elif cmd==1:
 *             self.bold=True
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set BOLD")
 *         elif cmd==7:
 */
    }

    /* "ttygif/tty/viewer.pyx":321
 *             if self.debug_mode:
 *                 self.info("RESET All")
 *         elif cmd==1:             # <<<<<<<<<<<<<<
 *             self.bold=True
 *             if self.debug_mode:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":325
 *             if self.debug_mode:
 *                 self.info("Set BOLD")
 *         elif cmd==7:             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Reverse Video On")
 */
  __Pyx_TraceLine(325,0,__PYX_ERR(0, 325, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_7, 7, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":326
 *                 self.info("Set BOLD")
 *         elif cmd==7:
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Reverse Video On")
 *             self.reverse_video=True
 */
    __Pyx_TraceLine(326,0,__PYX_ERR(0, 326, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 326, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":327
 *         elif cmd==7:
 *             if self.debug_mode:
 *                 self.info("Reverse Video On")             # <<<<<<<<<<<<<<
 *             self.reverse_video=True
 *         elif cmd==27:
 */
      __Pyx_TraceLine(327,0,__PYX_ERR(0, 327, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Reverse_Video_On); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":326
 *                 self.info("Set BOLD")
 *         elif cmd==7:
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Reverse Video On")
 *             self.reverse_video=True
 */
    }

    /* "ttygif/tty/viewer.pyx":328
 *             if self.debug_mode:
 *                 self.info("Reverse Video On")
 *             self.reverse_video=True             # <<<<<<<<<<<<<<
 *         elif cmd==27:
 *             if self.debug_mode:
 */
    __Pyx_TraceLine(328,0,__PYX_ERR(0, 328, __pyx_L1_error))
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    __Pyx_GOTREF(__pyx_v_self->reverse_video);
    __Pyx_DECREF(__pyx_v_self->reverse_video);
    __pyx_v_self->reverse_video = Py_True;

    /* "ttygif/tty/viewer.pyx":325
 *             if self.debug_mode:
 *                 self.info("Set BOLD")
 *         elif cmd==7:             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Reverse Video On")
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":329
 *                 self.info("Reverse Video On")
 *             self.reverse_video=True
 *         elif cmd==27:             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Reverse Video Off")
 */
  __Pyx_TraceLine(329,0,__PYX_ERR(0, 329, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_27, 27, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":330
 *             self.reverse_video=True
 *         elif cmd==27:
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Reverse Video Off")
 *             self.reverse_video=None
 */
    __Pyx_TraceLine(330,0,__PYX_ERR(0, 330, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 330, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":331
 *         elif cmd==27:
 *             if self.debug_mode:
 *                 self.info("Reverse Video Off")             # <<<<<<<<<<<<<<
 *             self.reverse_video=None
 *         elif cmd>=30 and cmd<=37:
 */
      __Pyx_TraceLine(331,0,__PYX_ERR(0, 331, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Reverse_Video_Off); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":330
 *             self.reverse_video=True
 *         elif cmd==27:
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Reverse Video Off")
 *             self.reverse_video=None
 */
    }

    /* "ttygif/tty/viewer.pyx":332
 *             if self.debug_mode:
 *                 self.info("Reverse Video Off")
 *             self.reverse_video=None             # <<<<<<<<<<<<<<
 *         elif cmd>=30 and cmd<=37:
 *             self.fg=cmd-30
 */
    __Pyx_TraceLine(332,0,__PYX_ERR(0, 332, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->reverse_video);
    __Pyx_DECREF(__pyx_v_self->reverse_video);
    __pyx_v_self->reverse_video = Py_None;

    /* "ttygif/tty/viewer.pyx":329
 *                 self.info("Reverse Video On")
 *             self.reverse_video=True
 *         elif cmd==27:             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Reverse Video Off")
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":333
 *                 self.info("Reverse Video Off")
 *             self.reverse_video=None
 *         elif cmd>=30 and cmd<=37:             # <<<<<<<<<<<<<<
 *             self.fg=cmd-30
 *             if self.bold:
 */
  __Pyx_TraceLine(333,0,__PYX_ERR(0, 333, __pyx_L1_error))
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_30, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 333, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_37, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 333, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":334
 *             self.reverse_video=None
 *         elif cmd>=30 and cmd<=37:
 *             self.fg=cmd-30             # <<<<<<<<<<<<<<
 *             if self.bold:
 *                 self.fg+=8
 */
    __Pyx_TraceLine(334,0,__PYX_ERR(0, 334, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_v_cmd, __pyx_int_30, 30, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 334, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_self->fg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":335
 *         elif cmd>=30 and cmd<=37:
 *             self.fg=cmd-30
 *             if self.bold:             # <<<<<<<<<<<<<<
 *                 self.fg+=8
 *             if self.debug_mode:
 */
    __Pyx_TraceLine(335,0,__PYX_ERR(0, 335, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->bold); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 335, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":336
 *             self.fg=cmd-30
 *             if self.bold:
 *                 self.fg+=8             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set FG")
 */
      __Pyx_TraceLine(336,0,__PYX_ERR(0, 336, __pyx_L1_error))
      __pyx_v_self->fg = (__pyx_v_self->fg + 8);

      /* "ttygif/tty/viewer.pyx":335
 *         elif cmd>=30 and cmd<=37:
 *             self.fg=cmd-30
 *             if self.bold:             # <<<<<<<<<<<<<<
 *                 self.fg+=8
 *             if self.debug_mode:
 */
    }

    /* "ttygif/tty/viewer.pyx":337
 *             if self.bold:
 *                 self.fg+=8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set FG")
 *         elif cmd==39:
 */
    __Pyx_TraceLine(337,0,__PYX_ERR(0, 337, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 337, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":338
 *                 self.fg+=8
 *             if self.debug_mode:
 *                 self.info("Set FG")             # <<<<<<<<<<<<<<
 *         elif cmd==39:
 *             self.fg=self.def_fg
 */
      __Pyx_TraceLine(338,0,__PYX_ERR(0, 338, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_FG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":337
 *             if self.bold:
 *                 self.fg+=8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set FG")
 *         elif cmd==39:
 */
    }

    /* "ttygif/tty/viewer.pyx":333
 *                 self.info("Reverse Video Off")
 *             self.reverse_video=None
 *         elif cmd>=30 and cmd<=37:             # <<<<<<<<<<<<<<
 *             self.fg=cmd-30
 *             if self.bold:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":339
 *             if self.debug_mode:
 *                 self.info("Set FG")
 *         elif cmd==39:             # <<<<<<<<<<<<<<
 *             self.fg=self.def_fg
 *             if self.debug_mode:
 */
  __Pyx_TraceLine(339,0,__PYX_ERR(0, 339, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_39, 39, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 339, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":340
 *                 self.info("Set FG")
 *         elif cmd==39:
 *             self.fg=self.def_fg             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set Default FG")
 */
    __Pyx_TraceLine(340,0,__PYX_ERR(0, 340, __pyx_L1_error))
    __pyx_t_3 = __pyx_v_self->def_fg;
    __pyx_v_self->fg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":341
 *         elif cmd==39:
 *             self.fg=self.def_fg
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set Default FG")
 *         elif cmd>=40 and cmd<=47:
 */
    __Pyx_TraceLine(341,0,__PYX_ERR(0, 341, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 341, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":342
 *             self.fg=self.def_fg
 *             if self.debug_mode:
 *                 self.info("Set Default FG")             # <<<<<<<<<<<<<<
 *         elif cmd>=40 and cmd<=47:
 *             self.bg=cmd-40
 */
      __Pyx_TraceLine(342,0,__PYX_ERR(0, 342, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_Default_FG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 342, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":341
 *         elif cmd==39:
 *             self.fg=self.def_fg
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set Default FG")
 *         elif cmd>=40 and cmd<=47:
 */
    }

    /* "ttygif/tty/viewer.pyx":339
 *             if self.debug_mode:
 *                 self.info("Set FG")
 *         elif cmd==39:             # <<<<<<<<<<<<<<
 *             self.fg=self.def_fg
 *             if self.debug_mode:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":343
 *             if self.debug_mode:
 *                 self.info("Set Default FG")
 *         elif cmd>=40 and cmd<=47:             # <<<<<<<<<<<<<<
 *             self.bg=cmd-40
 *             if self.bold:
 */
  __Pyx_TraceLine(343,0,__PYX_ERR(0, 343, __pyx_L1_error))
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_40, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 343, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_47, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 343, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L13_bool_binop_done:;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":344
 *                 self.info("Set Default FG")
 *         elif cmd>=40 and cmd<=47:
 *             self.bg=cmd-40             # <<<<<<<<<<<<<<
 *             if self.bold:
 *                 self.fg+=8
 */
    __Pyx_TraceLine(344,0,__PYX_ERR(0, 344, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_v_cmd, __pyx_int_40, 40, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 344, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_self->bg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":345
 *         elif cmd>=40 and cmd<=47:
 *             self.bg=cmd-40
 *             if self.bold:             # <<<<<<<<<<<<<<
 *                 self.fg+=8
 *             if self.debug_mode:
 */
    __Pyx_TraceLine(345,0,__PYX_ERR(0, 345, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->bold); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 345, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":346
 *             self.bg=cmd-40
 *             if self.bold:
 *                 self.fg+=8             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set BG")
 */
      __Pyx_TraceLine(346,0,__PYX_ERR(0, 346, __pyx_L1_error))
      __pyx_v_self->fg = (__pyx_v_self->fg + 8);

      /* "ttygif/tty/viewer.pyx":345
 *         elif cmd>=40 and cmd<=47:
 *             self.bg=cmd-40
 *             if self.bold:             # <<<<<<<<<<<<<<
 *                 self.fg+=8
 *             if self.debug_mode:
 */
    }

    /* "ttygif/tty/viewer.pyx":347
 *             if self.bold:
 *                 self.fg+=8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set BG")
 *         elif cmd==49:
 */
    __Pyx_TraceLine(347,0,__PYX_ERR(0, 347, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 347, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":348
 *                 self.fg+=8
 *             if self.debug_mode:
 *                 self.info("Set BG")             # <<<<<<<<<<<<<<
 *         elif cmd==49:
 *             self.bg=self.def_bg
 */
      __Pyx_TraceLine(348,0,__PYX_ERR(0, 348, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_BG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 348, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":347
 *             if self.bold:
 *                 self.fg+=8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set BG")
 *         elif cmd==49:
 */
    }

    /* "ttygif/tty/viewer.pyx":343
 *             if self.debug_mode:
 *                 self.info("Set Default FG")
 *         elif cmd>=40 and cmd<=47:             # <<<<<<<<<<<<<<
 *             self.bg=cmd-40
 *             if self.bold:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":349
 *             if self.debug_mode:
 *                 self.info("Set BG")
 *         elif cmd==49:             # <<<<<<<<<<<<<<
 *             self.bg=self.def_bg
 *             if self.debug_mode:
 */
  __Pyx_TraceLine(349,0,__PYX_ERR(0, 349, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_49, 49, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":350
 *                 self.info("Set BG")
 *         elif cmd==49:
 *             self.bg=self.def_bg             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set Default BG")
 */
    __Pyx_TraceLine(350,0,__PYX_ERR(0, 350, __pyx_L1_error))
    __pyx_t_3 = __pyx_v_self->def_bg;
    __pyx_v_self->bg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":351
 *         elif cmd==49:
 *             self.bg=self.def_bg
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set Default BG")
 *         elif cmd>=90 and cmd<=97:
 */
    __Pyx_TraceLine(351,0,__PYX_ERR(0, 351, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 351, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":352
 *             self.bg=self.def_bg
 *             if self.debug_mode:
 *                 self.info("Set Default BG")             # <<<<<<<<<<<<<<
 *         elif cmd>=90 and cmd<=97:
 *             self.fg=cmd-90+8
 */
      __Pyx_TraceLine(352,0,__PYX_ERR(0, 352, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_Default_BG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":351
 *         elif cmd==49:
 *             self.bg=self.def_bg
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set Default BG")
 *         elif cmd>=90 and cmd<=97:
 */
    }

    /* "ttygif/tty/viewer.pyx":349
 *             if self.debug_mode:
 *                 self.info("Set BG")
 *         elif cmd==49:             # <<<<<<<<<<<<<<
 *             self.bg=self.def_bg
 *             if self.debug_mode:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":353
 *             if self.debug_mode:
 *                 self.info("Set Default BG")
 *         elif cmd>=90 and cmd<=97:             # <<<<<<<<<<<<<<
 *             self.fg=cmd-90+8
 *             if self.debug_mode:
 */
  __Pyx_TraceLine(353,0,__PYX_ERR(0, 353, __pyx_L1_error))
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_90, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 353, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L18_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_97, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 353, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L18_bool_binop_done:;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":354
 *                 self.info("Set Default BG")
 *         elif cmd>=90 and cmd<=97:
 *             self.fg=cmd-90+8             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set High INTENSITY FG")
 */
    __Pyx_TraceLine(354,0,__PYX_ERR(0, 354, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_v_cmd, __pyx_int_90, 90, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_8, 8, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 354, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_self->fg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":355
 *         elif cmd>=90 and cmd<=97:
 *             self.fg=cmd-90+8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set High INTENSITY FG")
 *         elif cmd>=100 and cmd<=107:
 */
    __Pyx_TraceLine(355,0,__PYX_ERR(0, 355, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 355, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":356
 *             self.fg=cmd-90+8
 *             if self.debug_mode:
 *                 self.info("Set High INTENSITY FG")             # <<<<<<<<<<<<<<
 *         elif cmd>=100 and cmd<=107:
 *             self.bg=cmd-100+8
 */
      __Pyx_TraceLine(356,0,__PYX_ERR(0, 356, __pyx_L1_error))
      __pyx_t_5 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_High_INTENSITY_FG); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 356, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "ttygif/tty/viewer.pyx":355
 *         elif cmd>=90 and cmd<=97:
 *             self.fg=cmd-90+8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set High INTENSITY FG")
 *         elif cmd>=100 and cmd<=107:
 */
    }

    /* "ttygif/tty/viewer.pyx":353
 *             if self.debug_mode:
 *                 self.info("Set Default BG")
 *         elif cmd>=90 and cmd<=97:             # <<<<<<<<<<<<<<
 *             self.fg=cmd-90+8
 *             if self.debug_mode:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":357
 *             if self.debug_mode:
 *                 self.info("Set High INTENSITY FG")
 *         elif cmd>=100 and cmd<=107:             # <<<<<<<<<<<<<<
 *             self.bg=cmd-100+8
 *             if self.debug_mode:
 */
  __Pyx_TraceLine(357,0,__PYX_ERR(0, 357, __pyx_L1_error))
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_100, Py_GE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 357, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L21_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_107, Py_LE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 357, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L21_bool_binop_done:;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":358
 *                 self.info("Set High INTENSITY FG")
 *         elif cmd>=100 and cmd<=107:
 *             self.bg=cmd-100+8             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set High INTENSITY BG")
 */
    __Pyx_TraceLine(358,0,__PYX_ERR(0, 358, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_cmd, __pyx_int_100, 0x64, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_5, __pyx_int_8, 8, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 358, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_self->bg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":359
 *         elif cmd>=100 and cmd<=107:
 *             self.bg=cmd-100+8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set High INTENSITY BG")
 *         self.debug_mode=dm
 */
    __Pyx_TraceLine(359,0,__PYX_ERR(0, 359, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 359, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":360
 *             self.bg=cmd-100+8
 *             if self.debug_mode:
 *                 self.info("Set High INTENSITY BG")             # <<<<<<<<<<<<<<
 *         self.debug_mode=dm
 * 
 */
      __Pyx_TraceLine(360,0,__PYX_ERR(0, 360, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_High_INTENSITY_BG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 360, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":359
 *         elif cmd>=100 and cmd<=107:
 *             self.bg=cmd-100+8
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set High INTENSITY BG")
 *         self.debug_mode=dm
 */
    }

    /* "ttygif/tty/viewer.pyx":357
 *             if self.debug_mode:
 *                 self.info("Set High INTENSITY FG")
 *         elif cmd>=100 and cmd<=107:             # <<<<<<<<<<<<<<
 *             self.bg=cmd-100+8
 *             if self.debug_mode:
 */
  }
  __pyx_L3:;

  /* "ttygif/tty/viewer.pyx":361
 *             if self.debug_mode:
 *                 self.info("Set High INTENSITY BG")
 *         self.debug_mode=dm             # <<<<<<<<<<<<<<
 * 
 *     def reset_mode(self,cmd):
 */
  __Pyx_TraceLine(361,0,__PYX_ERR(0, 361, __pyx_L1_error))
  __Pyx_INCREF(__pyx_v_dm);
  __Pyx_GIVEREF(__pyx_v_dm);
  __Pyx_GOTREF(__pyx_v_self->debug_mode);
  __Pyx_DECREF(__pyx_v_self->debug_mode);
  __pyx_v_self->debug_mode = __pyx_v_dm;

  /* "ttygif/tty/viewer.pyx":311
 *             raise Exception (err_msg)
 * 
 *     def set_mode(self,cmd):             # <<<<<<<<<<<<<<
 *         dm=self.debug_mode
 *         self.debug_mode=None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.set_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dm);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":363
 *         self.debug_mode=dm
 * 
 *     def reset_mode(self,cmd):             # <<<<<<<<<<<<<<
 *         if cmd==0:
 *             self.fg=self.def_fg
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_11reset_mode(PyObject *__pyx_v_self, PyObject *__pyx_v_cmd); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_11reset_mode(PyObject *__pyx_v_self, PyObject *__pyx_v_cmd) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset_mode (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_10reset_mode(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_cmd));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_10reset_mode(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_cmd) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("reset_mode", 0);
  __Pyx_TraceCall("reset_mode", __pyx_f[0], 363, 0, __PYX_ERR(0, 363, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":364
 * 
 *     def reset_mode(self,cmd):
 *         if cmd==0:             # <<<<<<<<<<<<<<
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg
 */
  __Pyx_TraceLine(364,0,__PYX_ERR(0, 364, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":365
 *     def reset_mode(self,cmd):
 *         if cmd==0:
 *             self.fg=self.def_fg             # <<<<<<<<<<<<<<
 *             self.bg=self.def_bg
 *             self.bold=None
 */
    __Pyx_TraceLine(365,0,__PYX_ERR(0, 365, __pyx_L1_error))
    __pyx_t_3 = __pyx_v_self->def_fg;
    __pyx_v_self->fg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":366
 *         if cmd==0:
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg             # <<<<<<<<<<<<<<
 *             self.bold=None
 *             self.reverse_video=None
 */
    __Pyx_TraceLine(366,0,__PYX_ERR(0, 366, __pyx_L1_error))
    __pyx_t_3 = __pyx_v_self->def_bg;
    __pyx_v_self->bg = __pyx_t_3;

    /* "ttygif/tty/viewer.pyx":367
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg
 *             self.bold=None             # <<<<<<<<<<<<<<
 *             self.reverse_video=None
 *             if self.debug_mode:
 */
    __Pyx_TraceLine(367,0,__PYX_ERR(0, 367, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->bold);
    __Pyx_DECREF(__pyx_v_self->bold);
    __pyx_v_self->bold = Py_None;

    /* "ttygif/tty/viewer.pyx":368
 *             self.bg=self.def_bg
 *             self.bold=None
 *             self.reverse_video=None             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("RESET All")
 */
    __Pyx_TraceLine(368,0,__PYX_ERR(0, 368, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->reverse_video);
    __Pyx_DECREF(__pyx_v_self->reverse_video);
    __pyx_v_self->reverse_video = Py_None;

    /* "ttygif/tty/viewer.pyx":369
 *             self.bold=None
 *             self.reverse_video=None
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("RESET All")
 *         elif cmd==1:
 */
    __Pyx_TraceLine(369,0,__PYX_ERR(0, 369, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 369, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":370
 *             self.reverse_video=None
 *             if self.debug_mode:
 *                 self.info("RESET All")             # <<<<<<<<<<<<<<
 *         elif cmd==1:
 *             self.bold=None
 */
      __Pyx_TraceLine(370,0,__PYX_ERR(0, 370, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_RESET_All); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":369
 *             self.bold=None
 *             self.reverse_video=None
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("RESET All")
 *         elif cmd==1:
 */
    }

    /* "ttygif/tty/viewer.pyx":364
 * 
 *     def reset_mode(self,cmd):
 *         if cmd==0:             # <<<<<<<<<<<<<<
 *             self.fg=self.def_fg
 *             self.bg=self.def_bg
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":371
 *             if self.debug_mode:
 *                 self.info("RESET All")
 *         elif cmd==1:             # <<<<<<<<<<<<<<
 *             self.bold=None
 *             if self.debug_mode:
 */
  __Pyx_TraceLine(371,0,__PYX_ERR(0, 371, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":372
 *                 self.info("RESET All")
 *         elif cmd==1:
 *             self.bold=None             # <<<<<<<<<<<<<<
 *             if self.debug_mode:
 *                 self.info("Set BOLD")
 */
    __Pyx_TraceLine(372,0,__PYX_ERR(0, 372, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->bold);
    __Pyx_DECREF(__pyx_v_self->bold);
    __pyx_v_self->bold = Py_None;

    /* "ttygif/tty/viewer.pyx":373
 *         elif cmd==1:
 *             self.bold=None
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set BOLD")
 *         elif cmd==7:
 */
    __Pyx_TraceLine(373,0,__PYX_ERR(0, 373, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 373, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "ttygif/tty/viewer.pyx":374
 *             self.bold=None
 *             if self.debug_mode:
 *                 self.info("Set BOLD")             # <<<<<<<<<<<<<<
 *         elif cmd==7:
 *             self.reverse_video=None
 */
      __Pyx_TraceLine(374,0,__PYX_ERR(0, 374, __pyx_L1_error))
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Set_BOLD); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":373
 *         elif cmd==1:
 *             self.bold=None
 *             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                 self.info("Set BOLD")
 *         elif cmd==7:
 */
    }

    /* "ttygif/tty/viewer.pyx":371
 *             if self.debug_mode:
 *                 self.info("RESET All")
 *         elif cmd==1:             # <<<<<<<<<<<<<<
 *             self.bold=None
 *             if self.debug_mode:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":375
 *             if self.debug_mode:
 *                 self.info("Set BOLD")
 *         elif cmd==7:             # <<<<<<<<<<<<<<
 *             self.reverse_video=None
 * 
 */
  __Pyx_TraceLine(375,0,__PYX_ERR(0, 375, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_7, 7, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":376
 *                 self.info("Set BOLD")
 *         elif cmd==7:
 *             self.reverse_video=None             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_TraceLine(376,0,__PYX_ERR(0, 376, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->reverse_video);
    __Pyx_DECREF(__pyx_v_self->reverse_video);
    __pyx_v_self->reverse_video = Py_None;

    /* "ttygif/tty/viewer.pyx":375
 *             if self.debug_mode:
 *                 self.info("Set BOLD")
 *         elif cmd==7:             # <<<<<<<<<<<<<<
 *             self.reverse_video=None
 * 
 */
  }
  __pyx_L3:;

  /* "ttygif/tty/viewer.pyx":363
 *         self.debug_mode=dm
 * 
 *     def reset_mode(self,cmd):             # <<<<<<<<<<<<<<
 *         if cmd==0:
 *             self.fg=self.def_fg
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.reset_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":379
 * 
 * 
 *     def rgb_to_palette(self,r,g,b):             # <<<<<<<<<<<<<<
 *         last_distance=-1
 *         mappeded_color=-1
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_13rgb_to_palette(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_13rgb_to_palette(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_r = 0;
  PyObject *__pyx_v_g = 0;
  PyObject *__pyx_v_b = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rgb_to_palette (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_r,&__pyx_n_s_g,&__pyx_n_s_b,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_r)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_g)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rgb_to_palette", 1, 3, 3, 1); __PYX_ERR(0, 379, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_b)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rgb_to_palette", 1, 3, 3, 2); __PYX_ERR(0, 379, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "rgb_to_palette") < 0)) __PYX_ERR(0, 379, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_r = values[0];
    __pyx_v_g = values[1];
    __pyx_v_b = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rgb_to_palette", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 379, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.rgb_to_palette", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12rgb_to_palette(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), __pyx_v_r, __pyx_v_g, __pyx_v_b);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12rgb_to_palette(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_r, PyObject *__pyx_v_g, PyObject *__pyx_v_b) {
  PyObject *__pyx_v_last_distance = NULL;
  Py_ssize_t __pyx_v_mappeded_color;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_v_color = NULL;
  PyObject *__pyx_v_color_distance = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("rgb_to_palette", 0);
  __Pyx_TraceCall("rgb_to_palette", __pyx_f[0], 379, 0, __PYX_ERR(0, 379, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":380
 * 
 *     def rgb_to_palette(self,r,g,b):
 *         last_distance=-1             # <<<<<<<<<<<<<<
 *         mappeded_color=-1
 * 
 */
  __Pyx_TraceLine(380,0,__PYX_ERR(0, 380, __pyx_L1_error))
  __Pyx_INCREF(__pyx_int_neg_1);
  __pyx_v_last_distance = __pyx_int_neg_1;

  /* "ttygif/tty/viewer.pyx":381
 *     def rgb_to_palette(self,r,g,b):
 *         last_distance=-1
 *         mappeded_color=-1             # <<<<<<<<<<<<<<
 * 
 *         for i in range(0,len(self.color_table)):
 */
  __Pyx_TraceLine(381,0,__PYX_ERR(0, 381, __pyx_L1_error))
  __pyx_v_mappeded_color = -1L;

  /* "ttygif/tty/viewer.pyx":383
 *         mappeded_color=-1
 * 
 *         for i in range(0,len(self.color_table)):             # <<<<<<<<<<<<<<
 *             color=self.color_table[i]
 * 
 */
  __Pyx_TraceLine(383,0,__PYX_ERR(0, 383, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_self->color_table;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "ttygif/tty/viewer.pyx":384
 * 
 *         for i in range(0,len(self.color_table)):
 *             color=self.color_table[i]             # <<<<<<<<<<<<<<
 * 
 *             color_distance=(r-color[0])*(r-color[0])+(g-color[1])*(g-color[1])+(b-color[2])*(b-color[2])
 */
    __Pyx_TraceLine(384,0,__PYX_ERR(0, 384, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_self->color_table, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_color, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":386
 *             color=self.color_table[i]
 * 
 *             color_distance=(r-color[0])*(r-color[0])+(g-color[1])*(g-color[1])+(b-color[2])*(b-color[2])             # <<<<<<<<<<<<<<
 *             if last_distance==-1 or color_distance<last_distance:
 *                 last_distance=color_distance
 */
    __Pyx_TraceLine(386,0,__PYX_ERR(0, 386, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_color, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyNumber_Subtract(__pyx_v_r, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_color, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyNumber_Subtract(__pyx_v_r, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Multiply(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_color, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyNumber_Subtract(__pyx_v_g, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_color, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyNumber_Subtract(__pyx_v_g, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Multiply(__pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_Add(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_color, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyNumber_Subtract(__pyx_v_b, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_color, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyNumber_Subtract(__pyx_v_b, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Multiply(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_color_distance, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "ttygif/tty/viewer.pyx":387
 * 
 *             color_distance=(r-color[0])*(r-color[0])+(g-color[1])*(g-color[1])+(b-color[2])*(b-color[2])
 *             if last_distance==-1 or color_distance<last_distance:             # <<<<<<<<<<<<<<
 *                 last_distance=color_distance
 *                 mappeded_color=i
 */
    __Pyx_TraceLine(387,0,__PYX_ERR(0, 387, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_v_last_distance, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!__pyx_t_9) {
    } else {
      __pyx_t_8 = __pyx_t_9;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_color_distance, __pyx_v_last_distance, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 387, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_8 = __pyx_t_9;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_8) {

      /* "ttygif/tty/viewer.pyx":388
 *             color_distance=(r-color[0])*(r-color[0])+(g-color[1])*(g-color[1])+(b-color[2])*(b-color[2])
 *             if last_distance==-1 or color_distance<last_distance:
 *                 last_distance=color_distance             # <<<<<<<<<<<<<<
 *                 mappeded_color=i
 * 
 */
      __Pyx_TraceLine(388,0,__PYX_ERR(0, 388, __pyx_L1_error))
      __Pyx_INCREF(__pyx_v_color_distance);
      __Pyx_DECREF_SET(__pyx_v_last_distance, __pyx_v_color_distance);

      /* "ttygif/tty/viewer.pyx":389
 *             if last_distance==-1 or color_distance<last_distance:
 *                 last_distance=color_distance
 *                 mappeded_color=i             # <<<<<<<<<<<<<<
 * 
 *         #print r,g,b,mappeded_color#color_distance,color[0],color[1],color[2]
 */
      __Pyx_TraceLine(389,0,__PYX_ERR(0, 389, __pyx_L1_error))
      __pyx_v_mappeded_color = __pyx_v_i;

      /* "ttygif/tty/viewer.pyx":387
 * 
 *             color_distance=(r-color[0])*(r-color[0])+(g-color[1])*(g-color[1])+(b-color[2])*(b-color[2])
 *             if last_distance==-1 or color_distance<last_distance:             # <<<<<<<<<<<<<<
 *                 last_distance=color_distance
 *                 mappeded_color=i
 */
    }
  }

  /* "ttygif/tty/viewer.pyx":392
 * 
 *         #print r,g,b,mappeded_color#color_distance,color[0],color[1],color[2]
 *         return mappeded_color             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(392,0,__PYX_ERR(0, 392, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_mappeded_color); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":379
 * 
 * 
 *     def rgb_to_palette(self,r,g,b):             # <<<<<<<<<<<<<<
 *         last_distance=-1
 *         mappeded_color=-1
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.rgb_to_palette", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_last_distance);
  __Pyx_XDECREF(__pyx_v_color);
  __Pyx_XDECREF(__pyx_v_color_distance);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":396
 * 
 *     # commands pre parsed on add_event
 *     cdef sequence_to_buffer(self):             # <<<<<<<<<<<<<<
 * 
 *         cdef int pos=0
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_sequence_to_buffer(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_v_pos;
  CYTHON_UNUSED int __pyx_v_cursor;
  PyObject *__pyx_v_buffer = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_overflow = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_new_sequence_pos = NULL;
  PyObject *__pyx_v_event = NULL;
  PyObject *__pyx_v_character = NULL;
  long __pyx_v_char_ord;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_command = NULL;
  PyObject *__pyx_v_esc_type = NULL;
  PyObject *__pyx_v_groups = NULL;
  PyObject *__pyx_v_cmd = NULL;
  PyObject *__pyx_v_x2 = NULL;
  PyObject *__pyx_v_char_to_erase = NULL;
  PyObject *__pyx_v_stride = NULL;
  PyObject *__pyx_v_temp = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  long __pyx_t_15;
  int __pyx_t_16;
  int __pyx_t_17;
  __Pyx_RefNannySetupContext("sequence_to_buffer", 0);
  __Pyx_TraceCall("sequence_to_buffer", __pyx_f[0], 396, 0, __PYX_ERR(0, 396, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":398
 *     cdef sequence_to_buffer(self):
 * 
 *         cdef int pos=0             # <<<<<<<<<<<<<<
 *         cdef int cursor = 0
 *         # pre buffer
 */
  __Pyx_TraceLine(398,0,__PYX_ERR(0, 398, __pyx_L1_error))
  __pyx_v_pos = 0;

  /* "ttygif/tty/viewer.pyx":399
 * 
 *         cdef int pos=0
 *         cdef int cursor = 0             # <<<<<<<<<<<<<<
 *         # pre buffer
 *         buffer=self.buffer
 */
  __Pyx_TraceLine(399,0,__PYX_ERR(0, 399, __pyx_L1_error))
  __pyx_v_cursor = 0;

  /* "ttygif/tty/viewer.pyx":401
 *         cdef int cursor = 0
 *         # pre buffer
 *         buffer=self.buffer             # <<<<<<<<<<<<<<
 *         overflow=None
 * 
 */
  __Pyx_TraceLine(401,0,__PYX_ERR(0, 401, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)__pyx_v_self->buffer);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_buffer = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":402
 *         # pre buffer
 *         buffer=self.buffer
 *         overflow=None             # <<<<<<<<<<<<<<
 * 
 *         x=self.x
 */
  __Pyx_TraceLine(402,0,__PYX_ERR(0, 402, __pyx_L1_error))
  __Pyx_INCREF(Py_None);
  __pyx_v_overflow = Py_None;

  /* "ttygif/tty/viewer.pyx":404
 *         overflow=None
 * 
 *         x=self.x             # <<<<<<<<<<<<<<
 *         y=self.y
 *         #print("Start X:{0},Y:{1}".format(x,y))
 */
  __Pyx_TraceLine(404,0,__PYX_ERR(0, 404, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->x); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_x = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":405
 * 
 *         x=self.x
 *         y=self.y             # <<<<<<<<<<<<<<
 *         #print("Start X:{0},Y:{1}".format(x,y))
 * 
 */
  __Pyx_TraceLine(405,0,__PYX_ERR(0, 405, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->y); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_y = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":409
 * 
 * 
 *         cursor=0             # <<<<<<<<<<<<<<
 *         new_sequence_pos=self.sequence_pos #self.sequence_pos:
 *         for event in self.sequence[self.sequence_pos:]:
 */
  __Pyx_TraceLine(409,0,__PYX_ERR(0, 409, __pyx_L1_error))
  __pyx_v_cursor = 0;

  /* "ttygif/tty/viewer.pyx":410
 * 
 *         cursor=0
 *         new_sequence_pos=self.sequence_pos #self.sequence_pos:             # <<<<<<<<<<<<<<
 *         for event in self.sequence[self.sequence_pos:]:
 *             new_sequence_pos+=1
 */
  __Pyx_TraceLine(410,0,__PYX_ERR(0, 410, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_self->sequence_pos;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_new_sequence_pos = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":411
 *         cursor=0
 *         new_sequence_pos=self.sequence_pos #self.sequence_pos:
 *         for event in self.sequence[self.sequence_pos:]:             # <<<<<<<<<<<<<<
 *             new_sequence_pos+=1
 *             if event['type']=='text':
 */
  __Pyx_TraceLine(411,0,__PYX_ERR(0, 411, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_self->sequence, 0, 0, &__pyx_v_self->sequence_pos, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 411, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 411, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 411, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 411, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 411, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_event, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":412
 *         new_sequence_pos=self.sequence_pos #self.sequence_pos:
 *         for event in self.sequence[self.sequence_pos:]:
 *             new_sequence_pos+=1             # <<<<<<<<<<<<<<
 *             if event['type']=='text':
 *                 if self.debug_mode:
 */
    __Pyx_TraceLine(412,0,__PYX_ERR(0, 412, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_new_sequence_pos, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_new_sequence_pos, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":413
 *         for event in self.sequence[self.sequence_pos:]:
 *             new_sequence_pos+=1
 *             if event['type']=='text':             # <<<<<<<<<<<<<<
 *                 if self.debug_mode:
 *                     self.info(u"X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}".format(x,y,self.fg,self.bg,event['data']))
 */
    __Pyx_TraceLine(413,0,__PYX_ERR(0, 413, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_event, __pyx_n_s_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_text, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 413, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "ttygif/tty/viewer.pyx":414
 *             new_sequence_pos+=1
 *             if event['type']=='text':
 *                 if self.debug_mode:             # <<<<<<<<<<<<<<
 *                     self.info(u"X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}".format(x,y,self.fg,self.bg,event['data']))
 *                 for character in event['data']:
 */
      __Pyx_TraceLine(414,0,__PYX_ERR(0, 414, __pyx_L1_error))
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 414, __pyx_L1_error)
      if (__pyx_t_5) {

        /* "ttygif/tty/viewer.pyx":415
 *             if event['type']=='text':
 *                 if self.debug_mode:
 *                     self.info(u"X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}".format(x,y,self.fg,self.bg,event['data']))             # <<<<<<<<<<<<<<
 *                 for character in event['data']:
 *                     # new line or wrap
 */
        __Pyx_TraceLine(415,0,__PYX_ERR(0, 415, __pyx_L1_error))
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_X_0_2_1_2_FG_2_2_BG_3_Text_4, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyObject_Dict_GetItem(__pyx_v_event, __pyx_n_s_data); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[6] = {__pyx_t_10, __pyx_v_x, __pyx_v_y, __pyx_t_7, __pyx_t_8, __pyx_t_9};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 5+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[6] = {__pyx_t_10, __pyx_v_x, __pyx_v_y, __pyx_t_7, __pyx_t_8, __pyx_t_9};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 5+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(5+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 415, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__pyx_t_10) {
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
          }
          __Pyx_INCREF(__pyx_v_x);
          __Pyx_GIVEREF(__pyx_v_x);
          PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_v_x);
          __Pyx_INCREF(__pyx_v_y);
          __Pyx_GIVEREF(__pyx_v_y);
          PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_v_y);
          __Pyx_GIVEREF(__pyx_t_7);
          PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_8);
          PyTuple_SET_ITEM(__pyx_t_12, 3+__pyx_t_11, __pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_9);
          PyTuple_SET_ITEM(__pyx_t_12, 4+__pyx_t_11, __pyx_t_9);
          __pyx_t_7 = 0;
          __pyx_t_8 = 0;
          __pyx_t_9 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "ttygif/tty/viewer.pyx":414
 *             new_sequence_pos+=1
 *             if event['type']=='text':
 *                 if self.debug_mode:             # <<<<<<<<<<<<<<
 *                     self.info(u"X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}".format(x,y,self.fg,self.bg,event['data']))
 *                 for character in event['data']:
 */
      }

      /* "ttygif/tty/viewer.pyx":416
 *                 if self.debug_mode:
 *                     self.info(u"X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}".format(x,y,self.fg,self.bg,event['data']))
 *                 for character in event['data']:             # <<<<<<<<<<<<<<
 *                     # new line or wrap
 *                     char_ord=ord(character)
 */
      __Pyx_TraceLine(416,0,__PYX_ERR(0, 416, __pyx_L1_error))
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_event, __pyx_n_s_data); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
        __pyx_t_1 = __pyx_t_6; __Pyx_INCREF(__pyx_t_1); __pyx_t_13 = 0;
        __pyx_t_14 = NULL;
      } else {
        __pyx_t_13 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_14 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 416, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      for (;;) {
        if (likely(!__pyx_t_14)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_13); __Pyx_INCREF(__pyx_t_6); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 416, __pyx_L1_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_1, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 416, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          } else {
            if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_13); __Pyx_INCREF(__pyx_t_6); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 416, __pyx_L1_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_1, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 416, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          }
        } else {
          __pyx_t_6 = __pyx_t_14(__pyx_t_1);
          if (unlikely(!__pyx_t_6)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 416, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_character, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "ttygif/tty/viewer.pyx":418
 *                 for character in event['data']:
 *                     # new line or wrap
 *                     char_ord=ord(character)             # <<<<<<<<<<<<<<
 *                     # handle non printable codes here
 *                     #prinset char_ord
 */
        __Pyx_TraceLine(418,0,__PYX_ERR(0, 418, __pyx_L1_error))
        __pyx_t_15 = __Pyx_PyObject_Ord(__pyx_v_character); if (unlikely(__pyx_t_15 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 418, __pyx_L1_error)
        __pyx_v_char_ord = __pyx_t_15;

        /* "ttygif/tty/viewer.pyx":421
 *                     # handle non printable codes here
 *                     #prinset char_ord
 *                     if char_ord<32:             # <<<<<<<<<<<<<<
 *                         if char_ord==0x08:
 *                             x-=1
 */
        __Pyx_TraceLine(421,0,__PYX_ERR(0, 421, __pyx_L1_error))
        __pyx_t_5 = ((__pyx_v_char_ord < 32) != 0);
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":422
 *                     #prinset char_ord
 *                     if char_ord<32:
 *                         if char_ord==0x08:             # <<<<<<<<<<<<<<
 *                             x-=1
 *                             if x<0:
 */
          __Pyx_TraceLine(422,0,__PYX_ERR(0, 422, __pyx_L1_error))
          __pyx_t_5 = ((__pyx_v_char_ord == 0x08) != 0);
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":423
 *                     if char_ord<32:
 *                         if char_ord==0x08:
 *                             x-=1             # <<<<<<<<<<<<<<
 *                             if x<0:
 *                                 x=0
 */
            __Pyx_TraceLine(423,0,__PYX_ERR(0, 423, __pyx_L1_error))
            __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_v_x, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 423, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_6);
            __pyx_t_6 = 0;

            /* "ttygif/tty/viewer.pyx":424
 *                         if char_ord==0x08:
 *                             x-=1
 *                             if x<0:             # <<<<<<<<<<<<<<
 *                                 x=0
 *                         if char_ord==0x0A:
 */
            __Pyx_TraceLine(424,0,__PYX_ERR(0, 424, __pyx_L1_error))
            __pyx_t_6 = PyObject_RichCompare(__pyx_v_x, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 424, __pyx_L1_error)
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 424, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (__pyx_t_5) {

              /* "ttygif/tty/viewer.pyx":425
 *                             x-=1
 *                             if x<0:
 *                                 x=0             # <<<<<<<<<<<<<<
 *                         if char_ord==0x0A:
 *                             x=0
 */
              __Pyx_TraceLine(425,0,__PYX_ERR(0, 425, __pyx_L1_error))
              __Pyx_INCREF(__pyx_int_0);
              __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

              /* "ttygif/tty/viewer.pyx":424
 *                         if char_ord==0x08:
 *                             x-=1
 *                             if x<0:             # <<<<<<<<<<<<<<
 *                                 x=0
 *                         if char_ord==0x0A:
 */
            }

            /* "ttygif/tty/viewer.pyx":422
 *                     #prinset char_ord
 *                     if char_ord<32:
 *                         if char_ord==0x08:             # <<<<<<<<<<<<<<
 *                             x-=1
 *                             if x<0:
 */
          }

          /* "ttygif/tty/viewer.pyx":426
 *                             if x<0:
 *                                 x=0
 *                         if char_ord==0x0A:             # <<<<<<<<<<<<<<
 *                             x=0
 *                             y+=1
 */
          __Pyx_TraceLine(426,0,__PYX_ERR(0, 426, __pyx_L1_error))
          __pyx_t_5 = ((__pyx_v_char_ord == 0x0A) != 0);
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":427
 *                                 x=0
 *                         if char_ord==0x0A:
 *                             x=0             # <<<<<<<<<<<<<<
 *                             y+=1
 *                             if y>=self.viewport_char_height:
 */
            __Pyx_TraceLine(427,0,__PYX_ERR(0, 427, __pyx_L1_error))
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

            /* "ttygif/tty/viewer.pyx":428
 *                         if char_ord==0x0A:
 *                             x=0
 *                             y+=1             # <<<<<<<<<<<<<<
 *                             if y>=self.viewport_char_height:
 *                                 y=self.viewport_char_height-1
 */
            __Pyx_TraceLine(428,0,__PYX_ERR(0, 428, __pyx_L1_error))
            __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_y, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 428, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_6);
            __pyx_t_6 = 0;

            /* "ttygif/tty/viewer.pyx":429
 *                             x=0
 *                             y+=1
 *                             if y>=self.viewport_char_height:             # <<<<<<<<<<<<<<
 *                                 y=self.viewport_char_height-1
 *                                 self.shift_buffer(buffer)
 */
            __Pyx_TraceLine(429,0,__PYX_ERR(0, 429, __pyx_L1_error))
            __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_height); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 429, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_12 = PyObject_RichCompare(__pyx_v_y, __pyx_t_6, Py_GE); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 429, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (__pyx_t_5) {

              /* "ttygif/tty/viewer.pyx":430
 *                             y+=1
 *                             if y>=self.viewport_char_height:
 *                                 y=self.viewport_char_height-1             # <<<<<<<<<<<<<<
 *                                 self.shift_buffer(buffer)
 *                         continue
 */
              __Pyx_TraceLine(430,0,__PYX_ERR(0, 430, __pyx_L1_error))
              __pyx_t_12 = __Pyx_PyInt_From_long((__pyx_v_self->viewport_char_height - 1)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 430, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_12);
              __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":431
 *                             if y>=self.viewport_char_height:
 *                                 y=self.viewport_char_height-1
 *                                 self.shift_buffer(buffer)             # <<<<<<<<<<<<<<
 *                         continue
 *                     if x>=self.viewport_char_width:
 */
              __Pyx_TraceLine(431,0,__PYX_ERR(0, 431, __pyx_L1_error))
              if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 431, __pyx_L1_error)
              __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->shift_buffer(__pyx_v_self, ((arrayobject *)__pyx_v_buffer)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 431, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":429
 *                             x=0
 *                             y+=1
 *                             if y>=self.viewport_char_height:             # <<<<<<<<<<<<<<
 *                                 y=self.viewport_char_height-1
 *                                 self.shift_buffer(buffer)
 */
            }

            /* "ttygif/tty/viewer.pyx":426
 *                             if x<0:
 *                                 x=0
 *                         if char_ord==0x0A:             # <<<<<<<<<<<<<<
 *                             x=0
 *                             y+=1
 */
          }

          /* "ttygif/tty/viewer.pyx":432
 *                                 y=self.viewport_char_height-1
 *                                 self.shift_buffer(buffer)
 *                         continue             # <<<<<<<<<<<<<<
 *                     if x>=self.viewport_char_width:
 *                         x=0
 */
          __Pyx_TraceLine(432,0,__PYX_ERR(0, 432, __pyx_L1_error))
          goto __pyx_L7_continue;

          /* "ttygif/tty/viewer.pyx":421
 *                     # handle non printable codes here
 *                     #prinset char_ord
 *                     if char_ord<32:             # <<<<<<<<<<<<<<
 *                         if char_ord==0x08:
 *                             x-=1
 */
        }

        /* "ttygif/tty/viewer.pyx":433
 *                                 self.shift_buffer(buffer)
 *                         continue
 *                     if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                         x=0
 *                         y+=1
 */
        __Pyx_TraceLine(433,0,__PYX_ERR(0, 433, __pyx_L1_error))
        __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 433, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_6 = PyObject_RichCompare(__pyx_v_x, __pyx_t_12, Py_GE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 433, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 433, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":434
 *                         continue
 *                     if x>=self.viewport_char_width:
 *                         x=0             # <<<<<<<<<<<<<<
 *                         y+=1
 *                         if y>=self.viewport_char_height:
 */
          __Pyx_TraceLine(434,0,__PYX_ERR(0, 434, __pyx_L1_error))
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

          /* "ttygif/tty/viewer.pyx":435
 *                     if x>=self.viewport_char_width:
 *                         x=0
 *                         y+=1             # <<<<<<<<<<<<<<
 *                         if y>=self.viewport_char_height:
 *                             y=self.viewport_char_height-1
 */
          __Pyx_TraceLine(435,0,__PYX_ERR(0, 435, __pyx_L1_error))
          __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_y, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 435, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "ttygif/tty/viewer.pyx":436
 *                         x=0
 *                         y+=1
 *                         if y>=self.viewport_char_height:             # <<<<<<<<<<<<<<
 *                             y=self.viewport_char_height-1
 *                             self.shift_buffer(buffer)
 */
          __Pyx_TraceLine(436,0,__PYX_ERR(0, 436, __pyx_L1_error))
          __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_height); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 436, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = PyObject_RichCompare(__pyx_v_y, __pyx_t_6, Py_GE); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 436, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 436, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":437
 *                         y+=1
 *                         if y>=self.viewport_char_height:
 *                             y=self.viewport_char_height-1             # <<<<<<<<<<<<<<
 *                             self.shift_buffer(buffer)
 *                     self.write_buffer(x,y,char_ord,buffer)
 */
            __Pyx_TraceLine(437,0,__PYX_ERR(0, 437, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyInt_From_long((__pyx_v_self->viewport_char_height - 1)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 437, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":438
 *                         if y>=self.viewport_char_height:
 *                             y=self.viewport_char_height-1
 *                             self.shift_buffer(buffer)             # <<<<<<<<<<<<<<
 *                     self.write_buffer(x,y,char_ord,buffer)
 *                     x+=1
 */
            __Pyx_TraceLine(438,0,__PYX_ERR(0, 438, __pyx_L1_error))
            if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 438, __pyx_L1_error)
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->shift_buffer(__pyx_v_self, ((arrayobject *)__pyx_v_buffer)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 438, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":436
 *                         x=0
 *                         y+=1
 *                         if y>=self.viewport_char_height:             # <<<<<<<<<<<<<<
 *                             y=self.viewport_char_height-1
 *                             self.shift_buffer(buffer)
 */
          }

          /* "ttygif/tty/viewer.pyx":433
 *                                 self.shift_buffer(buffer)
 *                         continue
 *                     if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                         x=0
 *                         y+=1
 */
        }

        /* "ttygif/tty/viewer.pyx":439
 *                             y=self.viewport_char_height-1
 *                             self.shift_buffer(buffer)
 *                     self.write_buffer(x,y,char_ord,buffer)             # <<<<<<<<<<<<<<
 *                     x+=1
 *                 continue
 */
        __Pyx_TraceLine(439,0,__PYX_ERR(0, 439, __pyx_L1_error))
        __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_x); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 439, __pyx_L1_error)
        __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 439, __pyx_L1_error)
        if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 439, __pyx_L1_error)
        __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->write_buffer(__pyx_v_self, __pyx_t_11, __pyx_t_16, __pyx_v_char_ord, ((arrayobject *)__pyx_v_buffer)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "ttygif/tty/viewer.pyx":440
 *                             self.shift_buffer(buffer)
 *                     self.write_buffer(x,y,char_ord,buffer)
 *                     x+=1             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
        __Pyx_TraceLine(440,0,__PYX_ERR(0, 440, __pyx_L1_error))
        __pyx_t_12 = __Pyx_PyInt_AddObjC(__pyx_v_x, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 440, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_12);
        __pyx_t_12 = 0;

        /* "ttygif/tty/viewer.pyx":416
 *                 if self.debug_mode:
 *                     self.info(u"X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}".format(x,y,self.fg,self.bg,event['data']))
 *                 for character in event['data']:             # <<<<<<<<<<<<<<
 *                     # new line or wrap
 *                     char_ord=ord(character)
 */
        __Pyx_TraceLine(416,0,__PYX_ERR(0, 416, __pyx_L1_error))
        __pyx_L7_continue:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":441
 *                     self.write_buffer(x,y,char_ord,buffer)
 *                     x+=1
 *                 continue             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_TraceLine(441,0,__PYX_ERR(0, 441, __pyx_L1_error))
      goto __pyx_L3_continue;

      /* "ttygif/tty/viewer.pyx":413
 *         for event in self.sequence[self.sequence_pos:]:
 *             new_sequence_pos+=1
 *             if event['type']=='text':             # <<<<<<<<<<<<<<
 *                 if self.debug_mode:
 *                     self.info(u"X:{0:<2} {1:<2},FG:{2:<2},BG:{3},Text: {4}".format(x,y,self.fg,self.bg,event['data']))
 */
    }

    /* "ttygif/tty/viewer.pyx":445
 * 
 *             #print cursor,start, end
 *             params   =event['params']             # <<<<<<<<<<<<<<
 *             command  =event['command']
 *             esc_type =event['esc_type']
 */
    __Pyx_TraceLine(445,0,__PYX_ERR(0, 445, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_event, __pyx_n_s_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_params, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":446
 *             #print cursor,start, end
 *             params   =event['params']
 *             command  =event['command']             # <<<<<<<<<<<<<<
 *             esc_type =event['esc_type']
 *             groups   =event['groups']
 */
    __Pyx_TraceLine(446,0,__PYX_ERR(0, 446, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_event, __pyx_n_s_command); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_command, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":447
 *             params   =event['params']
 *             command  =event['command']
 *             esc_type =event['esc_type']             # <<<<<<<<<<<<<<
 *             groups   =event['groups']
 * 
 */
    __Pyx_TraceLine(447,0,__PYX_ERR(0, 447, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_event, __pyx_n_s_esc_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_esc_type, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":448
 *             command  =event['command']
 *             esc_type =event['esc_type']
 *             groups   =event['groups']             # <<<<<<<<<<<<<<
 * 
 *             if esc_type=='OSC':
 */
    __Pyx_TraceLine(448,0,__PYX_ERR(0, 448, __pyx_L1_error))
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_event, __pyx_n_s_groups); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_groups, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":450
 *             groups   =event['groups']
 * 
 *             if esc_type=='OSC':             # <<<<<<<<<<<<<<
 *                 continue
 *             elif esc_type=='SINGLE':
 */
    __Pyx_TraceLine(450,0,__PYX_ERR(0, 450, __pyx_L1_error))
    __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_esc_type, __pyx_n_s_OSC, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 450, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "ttygif/tty/viewer.pyx":451
 * 
 *             if esc_type=='OSC':
 *                 continue             # <<<<<<<<<<<<<<
 *             elif esc_type=='SINGLE':
 *                 command=groups[1]
 */
      __Pyx_TraceLine(451,0,__PYX_ERR(0, 451, __pyx_L1_error))
      goto __pyx_L3_continue;

      /* "ttygif/tty/viewer.pyx":450
 *             groups   =event['groups']
 * 
 *             if esc_type=='OSC':             # <<<<<<<<<<<<<<
 *                 continue
 *             elif esc_type=='SINGLE':
 */
    }

    /* "ttygif/tty/viewer.pyx":452
 *             if esc_type=='OSC':
 *                 continue
 *             elif esc_type=='SINGLE':             # <<<<<<<<<<<<<<
 *                 command=groups[1]
 *             elif esc_type=='CHAR_SET':
 */
    __Pyx_TraceLine(452,0,__PYX_ERR(0, 452, __pyx_L1_error))
    __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_esc_type, __pyx_n_s_SINGLE, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 452, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "ttygif/tty/viewer.pyx":453
 *                 continue
 *             elif esc_type=='SINGLE':
 *                 command=groups[1]             # <<<<<<<<<<<<<<
 *             elif esc_type=='CHAR_SET':
 *                 command=groups[3]
 */
      __Pyx_TraceLine(453,0,__PYX_ERR(0, 453, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":452
 *             if esc_type=='OSC':
 *                 continue
 *             elif esc_type=='SINGLE':             # <<<<<<<<<<<<<<
 *                 command=groups[1]
 *             elif esc_type=='CHAR_SET':
 */
      goto __pyx_L16;
    }

    /* "ttygif/tty/viewer.pyx":454
 *             elif esc_type=='SINGLE':
 *                 command=groups[1]
 *             elif esc_type=='CHAR_SET':             # <<<<<<<<<<<<<<
 *                 command=groups[3]
 *             elif esc_type=='G0':
 */
    __Pyx_TraceLine(454,0,__PYX_ERR(0, 454, __pyx_L1_error))
    __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_esc_type, __pyx_n_s_CHAR_SET, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 454, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "ttygif/tty/viewer.pyx":455
 *                 command=groups[1]
 *             elif esc_type=='CHAR_SET':
 *                 command=groups[3]             # <<<<<<<<<<<<<<
 *             elif esc_type=='G0':
 *                 command=groups[5]
 */
      __Pyx_TraceLine(455,0,__PYX_ERR(0, 455, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":454
 *             elif esc_type=='SINGLE':
 *                 command=groups[1]
 *             elif esc_type=='CHAR_SET':             # <<<<<<<<<<<<<<
 *                 command=groups[3]
 *             elif esc_type=='G0':
 */
      goto __pyx_L16;
    }

    /* "ttygif/tty/viewer.pyx":456
 *             elif esc_type=='CHAR_SET':
 *                 command=groups[3]
 *             elif esc_type=='G0':             # <<<<<<<<<<<<<<
 *                 command=groups[5]
 *             elif esc_type=='G1':
 */
    __Pyx_TraceLine(456,0,__PYX_ERR(0, 456, __pyx_L1_error))
    __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_esc_type, __pyx_n_s_G0, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 456, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "ttygif/tty/viewer.pyx":457
 *                 command=groups[3]
 *             elif esc_type=='G0':
 *                 command=groups[5]             # <<<<<<<<<<<<<<
 *             elif esc_type=='G1':
 *                 command=groups[7]
 */
      __Pyx_TraceLine(457,0,__PYX_ERR(0, 457, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 457, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":456
 *             elif esc_type=='CHAR_SET':
 *                 command=groups[3]
 *             elif esc_type=='G0':             # <<<<<<<<<<<<<<
 *                 command=groups[5]
 *             elif esc_type=='G1':
 */
      goto __pyx_L16;
    }

    /* "ttygif/tty/viewer.pyx":458
 *             elif esc_type=='G0':
 *                 command=groups[5]
 *             elif esc_type=='G1':             # <<<<<<<<<<<<<<
 *                 command=groups[7]
 *             elif esc_type=='CSI':
 */
    __Pyx_TraceLine(458,0,__PYX_ERR(0, 458, __pyx_L1_error))
    __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_esc_type, __pyx_n_s_G1, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 458, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "ttygif/tty/viewer.pyx":459
 *                 command=groups[5]
 *             elif esc_type=='G1':
 *                 command=groups[7]             # <<<<<<<<<<<<<<
 *             elif esc_type=='CSI':
 *                 if command=='m':
 */
      __Pyx_TraceLine(459,0,__PYX_ERR(0, 459, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 459, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":458
 *             elif esc_type=='G0':
 *                 command=groups[5]
 *             elif esc_type=='G1':             # <<<<<<<<<<<<<<
 *                 command=groups[7]
 *             elif esc_type=='CSI':
 */
      goto __pyx_L16;
    }

    /* "ttygif/tty/viewer.pyx":460
 *             elif esc_type=='G1':
 *                 command=groups[7]
 *             elif esc_type=='CSI':             # <<<<<<<<<<<<<<
 *                 if command=='m':
 *                     if 38 in params:
 */
    __Pyx_TraceLine(460,0,__PYX_ERR(0, 460, __pyx_L1_error))
    __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_esc_type, __pyx_n_s_CSI, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 460, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "ttygif/tty/viewer.pyx":461
 *                 command=groups[7]
 *             elif esc_type=='CSI':
 *                 if command=='m':             # <<<<<<<<<<<<<<
 *                     if 38 in params:
 *                         if params[1]==2:
 */
      __Pyx_TraceLine(461,0,__PYX_ERR(0, 461, __pyx_L1_error))
      __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_m, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 461, __pyx_L1_error)
      if (__pyx_t_5) {

        /* "ttygif/tty/viewer.pyx":462
 *             elif esc_type=='CSI':
 *                 if command=='m':
 *                     if 38 in params:             # <<<<<<<<<<<<<<
 *                         if params[1]==2:
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])
 */
        __Pyx_TraceLine(462,0,__PYX_ERR(0, 462, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_int_38, __pyx_v_params, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 462, __pyx_L1_error)
        __pyx_t_17 = (__pyx_t_5 != 0);
        if (__pyx_t_17) {

          /* "ttygif/tty/viewer.pyx":463
 *                 if command=='m':
 *                     if 38 in params:
 *                         if params[1]==2:             # <<<<<<<<<<<<<<
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])
 *                         if params[1]==5:
 */
          __Pyx_TraceLine(463,0,__PYX_ERR(0, 463, __pyx_L1_error))
          __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 463, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 463, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_17) {

            /* "ttygif/tty/viewer.pyx":464
 *                     if 38 in params:
 *                         if params[1]==2:
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])             # <<<<<<<<<<<<<<
 *                         if params[1]==5:
 *                             self.fg=params[2]
 */
            __Pyx_TraceLine(464,0,__PYX_ERR(0, 464, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rgb_to_palette); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 464, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_params, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 464, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_params, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 464, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_params, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 464, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_7 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_6, __pyx_t_9, __pyx_t_8};
              __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 464, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_6, __pyx_t_9, __pyx_t_8};
              __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 464, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 464, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              if (__pyx_t_7) {
                __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_6);
              PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_16, __pyx_t_6);
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_16, __pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_16, __pyx_t_8);
              __pyx_t_6 = 0;
              __pyx_t_9 = 0;
              __pyx_t_8 = 0;
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 464, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_t_12); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 464, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_v_self->fg = __pyx_t_16;

            /* "ttygif/tty/viewer.pyx":463
 *                 if command=='m':
 *                     if 38 in params:
 *                         if params[1]==2:             # <<<<<<<<<<<<<<
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])
 *                         if params[1]==5:
 */
          }

          /* "ttygif/tty/viewer.pyx":465
 *                         if params[1]==2:
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])
 *                         if params[1]==5:             # <<<<<<<<<<<<<<
 *                             self.fg=params[2]
 *                         #if self.debug_mode:
 */
          __Pyx_TraceLine(465,0,__PYX_ERR(0, 465, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 465, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_12, __pyx_int_5, 5, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 465, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_17) {

            /* "ttygif/tty/viewer.pyx":466
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])
 *                         if params[1]==5:
 *                             self.fg=params[2]             # <<<<<<<<<<<<<<
 *                         #if self.debug_mode:
 *                             #self.info("Set FG:{0}".format(params))
 */
            __Pyx_TraceLine(466,0,__PYX_ERR(0, 466, __pyx_L1_error))
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 466, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_v_self->fg = __pyx_t_16;

            /* "ttygif/tty/viewer.pyx":465
 *                         if params[1]==2:
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])
 *                         if params[1]==5:             # <<<<<<<<<<<<<<
 *                             self.fg=params[2]
 *                         #if self.debug_mode:
 */
          }

          /* "ttygif/tty/viewer.pyx":462
 *             elif esc_type=='CSI':
 *                 if command=='m':
 *                     if 38 in params:             # <<<<<<<<<<<<<<
 *                         if params[1]==2:
 *                               self.fg=self.rgb_to_palette(params[2],params[3],params[4])
 */
          goto __pyx_L18;
        }

        /* "ttygif/tty/viewer.pyx":469
 *                         #if self.debug_mode:
 *                             #self.info("Set FG:{0}".format(params))
 *                     elif 48 in params:             # <<<<<<<<<<<<<<
 *                             if params[1]==2:
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])
 */
        __Pyx_TraceLine(469,0,__PYX_ERR(0, 469, __pyx_L1_error))
        __pyx_t_17 = (__Pyx_PySequence_ContainsTF(__pyx_int_48, __pyx_v_params, Py_EQ)); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 469, __pyx_L1_error)
        __pyx_t_5 = (__pyx_t_17 != 0);
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":470
 *                             #self.info("Set FG:{0}".format(params))
 *                     elif 48 in params:
 *                             if params[1]==2:             # <<<<<<<<<<<<<<
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])
 *                             if params[1]==5:
 */
          __Pyx_TraceLine(470,0,__PYX_ERR(0, 470, __pyx_L1_error))
          __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 470, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 470, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 470, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":471
 *                     elif 48 in params:
 *                             if params[1]==2:
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])             # <<<<<<<<<<<<<<
 *                             if params[1]==5:
 *                                 self.bg=params[2]
 */
            __Pyx_TraceLine(471,0,__PYX_ERR(0, 471, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rgb_to_palette); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 471, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_params, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 471, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_params, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 471, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_params, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 471, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_6 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_6)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_10, __pyx_t_8, __pyx_t_9};
              __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 471, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_10, __pyx_t_8, __pyx_t_9};
              __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 471, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 471, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              if (__pyx_t_6) {
                __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_10);
              PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_16, __pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_16, __pyx_t_8);
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_16, __pyx_t_9);
              __pyx_t_10 = 0;
              __pyx_t_8 = 0;
              __pyx_t_9 = 0;
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 471, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_t_12); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 471, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_v_self->bg = __pyx_t_16;

            /* "ttygif/tty/viewer.pyx":470
 *                             #self.info("Set FG:{0}".format(params))
 *                     elif 48 in params:
 *                             if params[1]==2:             # <<<<<<<<<<<<<<
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])
 *                             if params[1]==5:
 */
          }

          /* "ttygif/tty/viewer.pyx":472
 *                             if params[1]==2:
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])
 *                             if params[1]==5:             # <<<<<<<<<<<<<<
 *                                 self.bg=params[2]
 *                             #if self.debug_mode:
 */
          __Pyx_TraceLine(472,0,__PYX_ERR(0, 472, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 472, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_12, __pyx_int_5, 5, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 472, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 472, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":473
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])
 *                             if params[1]==5:
 *                                 self.bg=params[2]             # <<<<<<<<<<<<<<
 *                             #if self.debug_mode:
 *                                 #self.info("Set BG:{0}".format(params))
 */
            __Pyx_TraceLine(473,0,__PYX_ERR(0, 473, __pyx_L1_error))
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 473, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_v_self->bg = __pyx_t_16;

            /* "ttygif/tty/viewer.pyx":472
 *                             if params[1]==2:
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])
 *                             if params[1]==5:             # <<<<<<<<<<<<<<
 *                                 self.bg=params[2]
 *                             #if self.debug_mode:
 */
          }

          /* "ttygif/tty/viewer.pyx":469
 *                         #if self.debug_mode:
 *                             #self.info("Set FG:{0}".format(params))
 *                     elif 48 in params:             # <<<<<<<<<<<<<<
 *                             if params[1]==2:
 *                                 self.bg=self.rgb_to_palette(params[2],params[3],params[4])
 */
          goto __pyx_L18;
        }

        /* "ttygif/tty/viewer.pyx":477
 *                                 #self.info("Set BG:{0}".format(params))
 *                     else:
 *                         for cmd in params:             # <<<<<<<<<<<<<<
 *                            self.set_mode(cmd)
 *                 else:
 */
        __Pyx_TraceLine(477,0,__PYX_ERR(0, 477, __pyx_L1_error))
        /*else*/ {
          if (likely(PyList_CheckExact(__pyx_v_params)) || PyTuple_CheckExact(__pyx_v_params)) {
            __pyx_t_1 = __pyx_v_params; __Pyx_INCREF(__pyx_t_1); __pyx_t_13 = 0;
            __pyx_t_14 = NULL;
          } else {
            __pyx_t_13 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_14 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 477, __pyx_L1_error)
          }
          for (;;) {
            if (likely(!__pyx_t_14)) {
              if (likely(PyList_CheckExact(__pyx_t_1))) {
                if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_1)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_12 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 477, __pyx_L1_error)
                #else
                __pyx_t_12 = PySequence_ITEM(__pyx_t_1, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 477, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_12);
                #endif
              } else {
                if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 477, __pyx_L1_error)
                #else
                __pyx_t_12 = PySequence_ITEM(__pyx_t_1, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 477, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_12);
                #endif
              }
            } else {
              __pyx_t_12 = __pyx_t_14(__pyx_t_1);
              if (unlikely(!__pyx_t_12)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 477, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_XDECREF_SET(__pyx_v_cmd, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":478
 *                     else:
 *                         for cmd in params:
 *                            self.set_mode(cmd)             # <<<<<<<<<<<<<<
 *                 else:
 *                     if command=='A': # move cursor up
 */
            __Pyx_TraceLine(478,0,__PYX_ERR(0, 478, __pyx_L1_error))
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_mode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 478, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_9 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_7, function);
              }
            }
            __pyx_t_12 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_9, __pyx_v_cmd) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_cmd);
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 478, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":477
 *                                 #self.info("Set BG:{0}".format(params))
 *                     else:
 *                         for cmd in params:             # <<<<<<<<<<<<<<
 *                            self.set_mode(cmd)
 *                 else:
 */
            __Pyx_TraceLine(477,0,__PYX_ERR(0, 477, __pyx_L1_error))
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L18:;

        /* "ttygif/tty/viewer.pyx":461
 *                 command=groups[7]
 *             elif esc_type=='CSI':
 *                 if command=='m':             # <<<<<<<<<<<<<<
 *                     if 38 in params:
 *                         if params[1]==2:
 */
        goto __pyx_L17;
      }

      /* "ttygif/tty/viewer.pyx":480
 *                            self.set_mode(cmd)
 *                 else:
 *                     if command=='A': # move cursor up             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
      __Pyx_TraceLine(480,0,__PYX_ERR(0, 480, __pyx_L1_error))
      /*else*/ {
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_A, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 480, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":481
 *                 else:
 *                     if command=='A': # move cursor up
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y-=params[0]
 */
          __Pyx_TraceLine(481,0,__PYX_ERR(0, 481, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 481, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":482
 *                     if command=='A': # move cursor up
 *                         if self.debug_mode:
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         y-=params[0]
 *                         if y<0:
 */
            __Pyx_TraceLine(482,0,__PYX_ERR(0, 482, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_Up_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 482, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 482, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_9 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_7, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_7, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 482, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (__pyx_t_9) {
                __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_7);
              PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_16, __pyx_t_7);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_7 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 482, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":481
 *                 else:
 *                     if command=='A': # move cursor up
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y-=params[0]
 */
          }

          /* "ttygif/tty/viewer.pyx":483
 *                         if self.debug_mode:
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y-=params[0]             # <<<<<<<<<<<<<<
 *                         if y<0:
 *                             y=0;
 */
          __Pyx_TraceLine(483,0,__PYX_ERR(0, 483, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 483, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = PyNumber_InPlaceSubtract(__pyx_v_y, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":484
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y-=params[0]
 *                         if y<0:             # <<<<<<<<<<<<<<
 *                             y=0;
 *                     elif command=='B': # move cursor down
 */
          __Pyx_TraceLine(484,0,__PYX_ERR(0, 484, __pyx_L1_error))
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_y, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 484, __pyx_L1_error)
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 484, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":485
 *                         y-=params[0]
 *                         if y<0:
 *                             y=0;             # <<<<<<<<<<<<<<
 *                     elif command=='B': # move cursor down
 *                         if self.debug_mode:
 */
            __Pyx_TraceLine(485,0,__PYX_ERR(0, 485, __pyx_L1_error))
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_DECREF_SET(__pyx_v_y, __pyx_int_0);

            /* "ttygif/tty/viewer.pyx":484
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y-=params[0]
 *                         if y<0:             # <<<<<<<<<<<<<<
 *                             y=0;
 *                     elif command=='B': # move cursor down
 */
          }

          /* "ttygif/tty/viewer.pyx":480
 *                            self.set_mode(cmd)
 *                 else:
 *                     if command=='A': # move cursor up             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Up:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":486
 *                         if y<0:
 *                             y=0;
 *                     elif command=='B': # move cursor down             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(486,0,__PYX_ERR(0, 486, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_B, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 486, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":487
 *                             y=0;
 *                     elif command=='B': # move cursor down
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y+=params[0]
 */
          __Pyx_TraceLine(487,0,__PYX_ERR(0, 487, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 487, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":488
 *                     elif command=='B': # move cursor down
 *                         if self.debug_mode:
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         y+=params[0]
 *                         if y>=self.viewport_char_height:
 */
            __Pyx_TraceLine(488,0,__PYX_ERR(0, 488, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_Down_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 488, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 488, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_7 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 488, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (__pyx_t_7) {
                __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_16, __pyx_t_8);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_8 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 488, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":487
 *                             y=0;
 *                     elif command=='B': # move cursor down
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y+=params[0]
 */
          }

          /* "ttygif/tty/viewer.pyx":489
 *                         if self.debug_mode:
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y+=params[0]             # <<<<<<<<<<<<<<
 *                         if y>=self.viewport_char_height:
 *                             y=self.viewport_char_height-1
 */
          __Pyx_TraceLine(489,0,__PYX_ERR(0, 489, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 489, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_y, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 489, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":490
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y+=params[0]
 *                         if y>=self.viewport_char_height:             # <<<<<<<<<<<<<<
 *                             y=self.viewport_char_height-1
 * 
 */
          __Pyx_TraceLine(490,0,__PYX_ERR(0, 490, __pyx_L1_error))
          __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_height); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 490, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = PyObject_RichCompare(__pyx_v_y, __pyx_t_1, Py_GE); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 490, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 490, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":491
 *                         y+=params[0]
 *                         if y>=self.viewport_char_height:
 *                             y=self.viewport_char_height-1             # <<<<<<<<<<<<<<
 * 
 *                     elif command=='C': # move cursor foreward
 */
            __Pyx_TraceLine(491,0,__PYX_ERR(0, 491, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyInt_From_long((__pyx_v_self->viewport_char_height - 1)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 491, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":490
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y+=params[0]
 *                         if y>=self.viewport_char_height:             # <<<<<<<<<<<<<<
 *                             y=self.viewport_char_height-1
 * 
 */
          }

          /* "ttygif/tty/viewer.pyx":486
 *                         if y<0:
 *                             y=0;
 *                     elif command=='B': # move cursor down             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Down:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":493
 *                             y=self.viewport_char_height-1
 * 
 *                     elif command=='C': # move cursor foreward             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(493,0,__PYX_ERR(0, 493, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_C, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 493, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":494
 * 
 *                     elif command=='C': # move cursor foreward
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x+=params[0]
 */
          __Pyx_TraceLine(494,0,__PYX_ERR(0, 494, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 494, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":495
 *                     elif command=='C': # move cursor foreward
 *                         if self.debug_mode:
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         x+=params[0]
 *                         if x>=self.viewport_char_width:
 */
            __Pyx_TraceLine(495,0,__PYX_ERR(0, 495, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_Right_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 495, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 495, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_8 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_9, __pyx_v_x, __pyx_v_y};
              __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 495, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_9, __pyx_v_x, __pyx_v_y};
              __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 495, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 495, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              if (__pyx_t_8) {
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_16, __pyx_t_9);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_9 = 0;
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 495, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 495, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "ttygif/tty/viewer.pyx":494
 * 
 *                     elif command=='C': # move cursor foreward
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x+=params[0]
 */
          }

          /* "ttygif/tty/viewer.pyx":496
 *                         if self.debug_mode:
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x+=params[0]             # <<<<<<<<<<<<<<
 *                         if x>=self.viewport_char_width:
 *                             x=self.viewport_char_width-1
 */
          __Pyx_TraceLine(496,0,__PYX_ERR(0, 496, __pyx_L1_error))
          __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 496, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = PyNumber_InPlaceAdd(__pyx_v_x, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 496, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "ttygif/tty/viewer.pyx":497
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x+=params[0]
 *                         if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                             x=self.viewport_char_width-1
 * 
 */
          __Pyx_TraceLine(497,0,__PYX_ERR(0, 497, __pyx_L1_error))
          __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 497, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_x, __pyx_t_12, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 497, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 497, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":498
 *                         x+=params[0]
 *                         if x>=self.viewport_char_width:
 *                             x=self.viewport_char_width-1             # <<<<<<<<<<<<<<
 * 
 *                     elif command=='D': # move cursor back
 */
            __Pyx_TraceLine(498,0,__PYX_ERR(0, 498, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_From_long((__pyx_v_self->viewport_char_width - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "ttygif/tty/viewer.pyx":497
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x+=params[0]
 *                         if x>=self.viewport_char_width:             # <<<<<<<<<<<<<<
 *                             x=self.viewport_char_width-1
 * 
 */
          }

          /* "ttygif/tty/viewer.pyx":493
 *                             y=self.viewport_char_height-1
 * 
 *                     elif command=='C': # move cursor foreward             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Right:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":500
 *                             x=self.viewport_char_width-1
 * 
 *                     elif command=='D': # move cursor back             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(500,0,__PYX_ERR(0, 500, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_D, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 500, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":501
 * 
 *                     elif command=='D': # move cursor back
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x-=params[0]
 */
          __Pyx_TraceLine(501,0,__PYX_ERR(0, 501, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 501, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":502
 *                     elif command=='D': # move cursor back
 *                         if self.debug_mode:
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         x-=params[0]
 *                         if x<0:
 */
            __Pyx_TraceLine(502,0,__PYX_ERR(0, 502, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_Left_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 502, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 502, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_9 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_7, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_7, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 502, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (__pyx_t_9) {
                __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_7);
              PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_16, __pyx_t_7);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_7 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 502, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":501
 * 
 *                     elif command=='D': # move cursor back
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x-=params[0]
 */
          }

          /* "ttygif/tty/viewer.pyx":503
 *                         if self.debug_mode:
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x-=params[0]             # <<<<<<<<<<<<<<
 *                         if x<0:
 *                             x=0
 */
          __Pyx_TraceLine(503,0,__PYX_ERR(0, 503, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 503, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = PyNumber_InPlaceSubtract(__pyx_v_x, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 503, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":504
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x-=params[0]
 *                         if x<0:             # <<<<<<<<<<<<<<
 *                             x=0
 *                     elif command=='E': # move cursor next line
 */
          __Pyx_TraceLine(504,0,__PYX_ERR(0, 504, __pyx_L1_error))
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_x, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 504, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":505
 *                         x-=params[0]
 *                         if x<0:
 *                             x=0             # <<<<<<<<<<<<<<
 *                     elif command=='E': # move cursor next line
 *                         if self.debug_mode:
 */
            __Pyx_TraceLine(505,0,__PYX_ERR(0, 505, __pyx_L1_error))
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

            /* "ttygif/tty/viewer.pyx":504
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x-=params[0]
 *                         if x<0:             # <<<<<<<<<<<<<<
 *                             x=0
 *                     elif command=='E': # move cursor next line
 */
          }

          /* "ttygif/tty/viewer.pyx":500
 *                             x=self.viewport_char_width-1
 * 
 *                     elif command=='D': # move cursor back             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Left:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":506
 *                         if x<0:
 *                             x=0
 *                     elif command=='E': # move cursor next line             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Next Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(506,0,__PYX_ERR(0, 506, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_E, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 506, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":507
 *                             x=0
 *                     elif command=='E': # move cursor next line
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Next Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0
 */
          __Pyx_TraceLine(507,0,__PYX_ERR(0, 507, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 507, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":508
 *                     elif command=='E': # move cursor next line
 *                         if self.debug_mode:
 *                             self.info("Cursor Next Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         x=0
 *                         y+=params[0]
 */
            __Pyx_TraceLine(508,0,__PYX_ERR(0, 508, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_Next_Line_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 508, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 508, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_7 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 508, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (__pyx_t_7) {
                __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_16, __pyx_t_8);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_8 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 508, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":507
 *                             x=0
 *                     elif command=='E': # move cursor next line
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Next Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0
 */
          }

          /* "ttygif/tty/viewer.pyx":509
 *                         if self.debug_mode:
 *                             self.info("Cursor Next Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0             # <<<<<<<<<<<<<<
 *                         y+=params[0]
 * 
 */
          __Pyx_TraceLine(509,0,__PYX_ERR(0, 509, __pyx_L1_error))
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

          /* "ttygif/tty/viewer.pyx":510
 *                             self.info("Cursor Next Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0
 *                         y+=params[0]             # <<<<<<<<<<<<<<
 * 
 *                     elif command=='F': # move cursor previous  line
 */
          __Pyx_TraceLine(510,0,__PYX_ERR(0, 510, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 510, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_y, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 510, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":506
 *                         if x<0:
 *                             x=0
 *                     elif command=='E': # move cursor next line             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Next Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":512
 *                         y+=params[0]
 * 
 *                     elif command=='F': # move cursor previous  line             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Previous Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(512,0,__PYX_ERR(0, 512, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_F, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 512, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":513
 * 
 *                     elif command=='F': # move cursor previous  line
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Previous Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0
 */
          __Pyx_TraceLine(513,0,__PYX_ERR(0, 513, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 513, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":514
 *                     elif command=='F': # move cursor previous  line
 *                         if self.debug_mode:
 *                             self.info("Cursor Previous Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         x=0
 *                         y-=params[0]
 */
            __Pyx_TraceLine(514,0,__PYX_ERR(0, 514, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_Previous_Line_0_x_1_2_y_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 514, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 514, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_8 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_9, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_9, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 514, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              if (__pyx_t_8) {
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_16, __pyx_t_9);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_9 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 514, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":513
 * 
 *                     elif command=='F': # move cursor previous  line
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Previous Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0
 */
          }

          /* "ttygif/tty/viewer.pyx":515
 *                         if self.debug_mode:
 *                             self.info("Cursor Previous Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0             # <<<<<<<<<<<<<<
 *                         y-=params[0]
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 */
          __Pyx_TraceLine(515,0,__PYX_ERR(0, 515, __pyx_L1_error))
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

          /* "ttygif/tty/viewer.pyx":516
 *                             self.info("Cursor Previous Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=0
 *                         y-=params[0]             # <<<<<<<<<<<<<<
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:
 */
          __Pyx_TraceLine(516,0,__PYX_ERR(0, 516, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 516, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = PyNumber_InPlaceSubtract(__pyx_v_y, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 516, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":512
 *                         y+=params[0]
 * 
 *                     elif command=='F': # move cursor previous  line             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Previous Line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":517
 *                         x=0
 *                         y-=params[0]
 *                     elif command=='G': # move cursor to HORIZONTAL pos X             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(517,0,__PYX_ERR(0, 517, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_G, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 517, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":518
 *                         y-=params[0]
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1
 */
          __Pyx_TraceLine(518,0,__PYX_ERR(0, 518, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 518, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":519
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         x=params[0]-1
 *                     elif command=='`': # move cursor to HORIZONTAL pos X
 */
            __Pyx_TraceLine(519,0,__PYX_ERR(0, 519, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_X_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 519, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 519, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_9 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_7, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_7, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 519, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (__pyx_t_9) {
                __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_7);
              PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_16, __pyx_t_7);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_7 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 519, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":518
 *                         y-=params[0]
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1
 */
          }

          /* "ttygif/tty/viewer.pyx":520
 *                         if self.debug_mode:
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1             # <<<<<<<<<<<<<<
 *                     elif command=='`': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:
 */
          __Pyx_TraceLine(520,0,__PYX_ERR(0, 520, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 520, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_t_12, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 520, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":517
 *                         x=0
 *                         y-=params[0]
 *                     elif command=='G': # move cursor to HORIZONTAL pos X             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":521
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1
 *                     elif command=='`': # move cursor to HORIZONTAL pos X             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor (~) X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(521,0,__PYX_ERR(0, 521, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_kp_s__5, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 521, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":522
 *                         x=params[0]-1
 *                     elif command=='`': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor (~) X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1
 */
          __Pyx_TraceLine(522,0,__PYX_ERR(0, 522, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 522, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":523
 *                     elif command=='`': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:
 *                             self.info("Cursor (~) X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         x=params[0]-1
 * 
 */
            __Pyx_TraceLine(523,0,__PYX_ERR(0, 523, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_X_0_x_1_2_y_2_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 523, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 523, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_7 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 3+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(3+__pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 523, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (__pyx_t_7) {
                __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_16, __pyx_t_8);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_16, __pyx_v_y);
              __pyx_t_8 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 523, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":522
 *                         x=params[0]-1
 *                     elif command=='`': # move cursor to HORIZONTAL pos X
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor (~) X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1
 */
          }

          /* "ttygif/tty/viewer.pyx":524
 *                         if self.debug_mode:
 *                             self.info("Cursor (~) X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1             # <<<<<<<<<<<<<<
 * 
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 */
          __Pyx_TraceLine(524,0,__PYX_ERR(0, 524, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 524, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_t_12, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":521
 *                             self.info("Cursor X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         x=params[0]-1
 *                     elif command=='`': # move cursor to HORIZONTAL pos X             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor (~) X:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":526
 *                         x=params[0]-1
 * 
 *                     elif command=='H' or command=='f': # move cursor to x,y pos             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Pos:{0},{1}".format(params[1],params[0]))
 */
        __Pyx_TraceLine(526,0,__PYX_ERR(0, 526, __pyx_L1_error))
        __pyx_t_17 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_H, Py_EQ)); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 526, __pyx_L1_error)
        if (!__pyx_t_17) {
        } else {
          __pyx_t_5 = __pyx_t_17;
          goto __pyx_L38_bool_binop_done;
        }
        __pyx_t_17 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_f, Py_EQ)); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 526, __pyx_L1_error)
        __pyx_t_5 = __pyx_t_17;
        __pyx_L38_bool_binop_done:;
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":527
 * 
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Pos:{0},{1}".format(params[1],params[0]))
 *                         x=params[1]-1
 */
          __Pyx_TraceLine(527,0,__PYX_ERR(0, 527, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 527, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":528
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 *                         if self.debug_mode:
 *                             self.info("Cursor Pos:{0},{1}".format(params[1],params[0]))             # <<<<<<<<<<<<<<
 *                         x=params[1]-1
 *                         y=params[0]-1
 */
            __Pyx_TraceLine(528,0,__PYX_ERR(0, 528, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_Pos_0_1, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 528, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_params, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 528, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 528, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_7 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_9, __pyx_t_8};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 528, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_9, __pyx_t_8};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 528, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(2+__pyx_t_16); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 528, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              if (__pyx_t_7) {
                __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_16, __pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_16, __pyx_t_8);
              __pyx_t_9 = 0;
              __pyx_t_8 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 528, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 528, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":527
 * 
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor Pos:{0},{1}".format(params[1],params[0]))
 *                         x=params[1]-1
 */
          }

          /* "ttygif/tty/viewer.pyx":529
 *                         if self.debug_mode:
 *                             self.info("Cursor Pos:{0},{1}".format(params[1],params[0]))
 *                         x=params[1]-1             # <<<<<<<<<<<<<<
 *                         y=params[0]-1
 * 
 */
          __Pyx_TraceLine(529,0,__PYX_ERR(0, 529, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 529, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_t_12, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "ttygif/tty/viewer.pyx":530
 *                             self.info("Cursor Pos:{0},{1}".format(params[1],params[0]))
 *                         x=params[1]-1
 *                         y=params[0]-1             # <<<<<<<<<<<<<<
 * 
 *                     elif command=='J': # erase display
 */
          __Pyx_TraceLine(530,0,__PYX_ERR(0, 530, __pyx_L1_error))
          __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 530, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = __Pyx_PyInt_SubtractObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 530, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "ttygif/tty/viewer.pyx":526
 *                         x=params[0]-1
 * 
 *                     elif command=='H' or command=='f': # move cursor to x,y pos             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor Pos:{0},{1}".format(params[1],params[0]))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":532
 *                         y=params[0]-1
 * 
 *                     elif command=='J': # erase display             # <<<<<<<<<<<<<<
 *                         if params[0]==0:
 *                             if self.debug_mode:
 */
        __Pyx_TraceLine(532,0,__PYX_ERR(0, 532, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_J, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 532, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":533
 * 
 *                     elif command=='J': # erase display
 *                         if params[0]==0:             # <<<<<<<<<<<<<<
 *                             if self.debug_mode:
 *                                 self.info("Erase Display cursor to end")
 */
          __Pyx_TraceLine(533,0,__PYX_ERR(0, 533, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 533, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_12, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 533, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 533, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":534
 *                     elif command=='J': # erase display
 *                         if params[0]==0:
 *                             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                                 self.info("Erase Display cursor to end")
 *                             pos=x+y*self.viewport_char_width
 */
            __Pyx_TraceLine(534,0,__PYX_ERR(0, 534, __pyx_L1_error))
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 534, __pyx_L1_error)
            if (__pyx_t_5) {

              /* "ttygif/tty/viewer.pyx":535
 *                         if params[0]==0:
 *                             if self.debug_mode:
 *                                 self.info("Erase Display cursor to end")             # <<<<<<<<<<<<<<
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(pos,self.viewport_char_height*self.viewport_char_width):
 */
              __Pyx_TraceLine(535,0,__PYX_ERR(0, 535, __pyx_L1_error))
              __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Erase_Display_cursor_to_end); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

              /* "ttygif/tty/viewer.pyx":534
 *                     elif command=='J': # erase display
 *                         if params[0]==0:
 *                             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                                 self.info("Erase Display cursor to end")
 *                             pos=x+y*self.viewport_char_width
 */
            }

            /* "ttygif/tty/viewer.pyx":536
 *                             if self.debug_mode:
 *                                 self.info("Erase Display cursor to end")
 *                             pos=x+y*self.viewport_char_width             # <<<<<<<<<<<<<<
 *                             for x in range(pos,self.viewport_char_height*self.viewport_char_width):
 *                                 buffer[x*3+0]=self.fg
 */
            __Pyx_TraceLine(536,0,__PYX_ERR(0, 536, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_12 = PyNumber_Multiply(__pyx_v_y, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 536, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Add(__pyx_v_x, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 536, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_v_pos = __pyx_t_16;

            /* "ttygif/tty/viewer.pyx":537
 *                                 self.info("Erase Display cursor to end")
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(pos,self.viewport_char_height*self.viewport_char_width):             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg
 */
            __Pyx_TraceLine(537,0,__PYX_ERR(0, 537, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 537, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_12 = __Pyx_PyInt_From_int((__pyx_v_self->viewport_char_height * __pyx_v_self->viewport_char_width)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 537, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 537, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_GIVEREF(__pyx_t_1);
            PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_12);
            PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_12);
            __pyx_t_1 = 0;
            __pyx_t_12 = 0;
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_10, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 537, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
              __pyx_t_10 = __pyx_t_12; __Pyx_INCREF(__pyx_t_10); __pyx_t_13 = 0;
              __pyx_t_14 = NULL;
            } else {
              __pyx_t_13 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 537, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_14 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 537, __pyx_L1_error)
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            for (;;) {
              if (likely(!__pyx_t_14)) {
                if (likely(PyList_CheckExact(__pyx_t_10))) {
                  if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 537, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 537, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                } else {
                  if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 537, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 537, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                }
              } else {
                __pyx_t_12 = __pyx_t_14(__pyx_t_10);
                if (unlikely(!__pyx_t_12)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                    else __PYX_ERR(0, 537, __pyx_L1_error)
                  }
                  break;
                }
                __Pyx_GOTREF(__pyx_t_12);
              }
              __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_12);
              __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":538
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(pos,self.viewport_char_height*self.viewport_char_width):
 *                                 buffer[x*3+0]=self.fg             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+1]=self.bg
 *                                 buffer[x*3+2]=32
 */
              __Pyx_TraceLine(538,0,__PYX_ERR(0, 538, __pyx_L1_error))
              __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 538, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_1 = PyNumber_Multiply(__pyx_v_x, __pyx_int_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_0, 0, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 538, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_8, __pyx_t_12) < 0)) __PYX_ERR(0, 538, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":539
 *                             for x in range(pos,self.viewport_char_height*self.viewport_char_width):
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+2]=32
 *                         if params[0]==1:
 */
              __Pyx_TraceLine(539,0,__PYX_ERR(0, 539, __pyx_L1_error))
              __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 539, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_8 = PyNumber_Multiply(__pyx_v_x, __pyx_int_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 539, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_8, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 539, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_1, __pyx_t_12) < 0)) __PYX_ERR(0, 539, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":540
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg
 *                                 buffer[x*3+2]=32             # <<<<<<<<<<<<<<
 *                         if params[0]==1:
 *                             if self.debug_mode:
 */
              __Pyx_TraceLine(540,0,__PYX_ERR(0, 540, __pyx_L1_error))
              __pyx_t_12 = PyNumber_Multiply(__pyx_v_x, __pyx_int_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 540, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_12, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_1, __pyx_int_32) < 0)) __PYX_ERR(0, 540, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

              /* "ttygif/tty/viewer.pyx":537
 *                                 self.info("Erase Display cursor to end")
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(pos,self.viewport_char_height*self.viewport_char_width):             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg
 */
              __Pyx_TraceLine(537,0,__PYX_ERR(0, 537, __pyx_L1_error))
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":533
 * 
 *                     elif command=='J': # erase display
 *                         if params[0]==0:             # <<<<<<<<<<<<<<
 *                             if self.debug_mode:
 *                                 self.info("Erase Display cursor to end")
 */
          }

          /* "ttygif/tty/viewer.pyx":541
 *                                 buffer[x*3+1]=self.bg
 *                                 buffer[x*3+2]=32
 *                         if params[0]==1:             # <<<<<<<<<<<<<<
 *                             if self.debug_mode:
 *                                 self.info("Erase Display top til cursor")
 */
          __Pyx_TraceLine(541,0,__PYX_ERR(0, 541, __pyx_L1_error))
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 541, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_10, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 541, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":542
 *                                 buffer[x*3+2]=32
 *                         if params[0]==1:
 *                             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                                 self.info("Erase Display top til cursor")
 *                             pos=x+y*self.viewport_char_width
 */
            __Pyx_TraceLine(542,0,__PYX_ERR(0, 542, __pyx_L1_error))
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 542, __pyx_L1_error)
            if (__pyx_t_5) {

              /* "ttygif/tty/viewer.pyx":543
 *                         if params[0]==1:
 *                             if self.debug_mode:
 *                                 self.info("Erase Display top til cursor")             # <<<<<<<<<<<<<<
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(0,pos+1):
 */
              __Pyx_TraceLine(543,0,__PYX_ERR(0, 543, __pyx_L1_error))
              __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Erase_Display_top_til_cursor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

              /* "ttygif/tty/viewer.pyx":542
 *                                 buffer[x*3+2]=32
 *                         if params[0]==1:
 *                             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                                 self.info("Erase Display top til cursor")
 *                             pos=x+y*self.viewport_char_width
 */
            }

            /* "ttygif/tty/viewer.pyx":544
 *                             if self.debug_mode:
 *                                 self.info("Erase Display top til cursor")
 *                             pos=x+y*self.viewport_char_width             # <<<<<<<<<<<<<<
 *                             for x in range(0,pos+1):
 *                                 buffer[x*3+0]=self.fg
 */
            __Pyx_TraceLine(544,0,__PYX_ERR(0, 544, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 544, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_10 = PyNumber_Multiply(__pyx_v_y, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 544, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Add(__pyx_v_x, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 544, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 544, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_v_pos = __pyx_t_16;

            /* "ttygif/tty/viewer.pyx":545
 *                                 self.info("Erase Display top til cursor")
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(0,pos+1):             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg
 */
            __Pyx_TraceLine(545,0,__PYX_ERR(0, 545, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_From_long((__pyx_v_pos + 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 545, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_GIVEREF(__pyx_int_0);
            PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_int_0);
            __Pyx_GIVEREF(__pyx_t_1);
            PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_1);
            __pyx_t_1 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
              __pyx_t_10 = __pyx_t_1; __Pyx_INCREF(__pyx_t_10); __pyx_t_13 = 0;
              __pyx_t_14 = NULL;
            } else {
              __pyx_t_13 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 545, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_14 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 545, __pyx_L1_error)
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            for (;;) {
              if (likely(!__pyx_t_14)) {
                if (likely(PyList_CheckExact(__pyx_t_10))) {
                  if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_1 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_1); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 545, __pyx_L1_error)
                  #else
                  __pyx_t_1 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  #endif
                } else {
                  if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_1); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 545, __pyx_L1_error)
                  #else
                  __pyx_t_1 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  #endif
                }
              } else {
                __pyx_t_1 = __pyx_t_14(__pyx_t_10);
                if (unlikely(!__pyx_t_1)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                    else __PYX_ERR(0, 545, __pyx_L1_error)
                  }
                  break;
                }
                __Pyx_GOTREF(__pyx_t_1);
              }
              __Pyx_DECREF_SET(__pyx_v_x, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "ttygif/tty/viewer.pyx":546
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(0,pos+1):
 *                                 buffer[x*3+0]=self.fg             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+1]=self.bg
 *                                 buffer[x*3+2]=32
 */
              __Pyx_TraceLine(546,0,__PYX_ERR(0, 546, __pyx_L1_error))
              __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_12 = PyNumber_Multiply(__pyx_v_x, __pyx_int_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 546, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_t_12, __pyx_int_0, 0, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 546, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_8, __pyx_t_1) < 0)) __PYX_ERR(0, 546, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

              /* "ttygif/tty/viewer.pyx":547
 *                             for x in range(0,pos+1):
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+2]=32
 * 
 */
              __Pyx_TraceLine(547,0,__PYX_ERR(0, 547, __pyx_L1_error))
              __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_8 = PyNumber_Multiply(__pyx_v_x, __pyx_int_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 547, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_t_12 = __Pyx_PyInt_AddObjC(__pyx_t_8, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 547, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_12, __pyx_t_1) < 0)) __PYX_ERR(0, 547, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

              /* "ttygif/tty/viewer.pyx":548
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg
 *                                 buffer[x*3+2]=32             # <<<<<<<<<<<<<<
 * 
 *                         if params[0]==2:
 */
              __Pyx_TraceLine(548,0,__PYX_ERR(0, 548, __pyx_L1_error))
              __pyx_t_1 = PyNumber_Multiply(__pyx_v_x, __pyx_int_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 548, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_12 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 548, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_12, __pyx_int_32) < 0)) __PYX_ERR(0, 548, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":545
 *                                 self.info("Erase Display top til cursor")
 *                             pos=x+y*self.viewport_char_width
 *                             for x in range(0,pos+1):             # <<<<<<<<<<<<<<
 *                                 buffer[x*3+0]=self.fg
 *                                 buffer[x*3+1]=self.bg
 */
              __Pyx_TraceLine(545,0,__PYX_ERR(0, 545, __pyx_L1_error))
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":541
 *                                 buffer[x*3+1]=self.bg
 *                                 buffer[x*3+2]=32
 *                         if params[0]==1:             # <<<<<<<<<<<<<<
 *                             if self.debug_mode:
 *                                 self.info("Erase Display top til cursor")
 */
          }

          /* "ttygif/tty/viewer.pyx":550
 *                                 buffer[x*3+2]=32
 * 
 *                         if params[0]==2:             # <<<<<<<<<<<<<<
 *                             if self.debug_mode:
 *                                 self.info("Erase Display and buffer")
 */
          __Pyx_TraceLine(550,0,__PYX_ERR(0, 550, __pyx_L1_error))
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 550, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = __Pyx_PyInt_EqObjC(__pyx_t_10, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 550, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 550, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":551
 * 
 *                         if params[0]==2:
 *                             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                                 self.info("Erase Display and buffer")
 *                             buffer=self.new_char_buffer()
 */
            __Pyx_TraceLine(551,0,__PYX_ERR(0, 551, __pyx_L1_error))
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 551, __pyx_L1_error)
            if (__pyx_t_5) {

              /* "ttygif/tty/viewer.pyx":552
 *                         if params[0]==2:
 *                             if self.debug_mode:
 *                                 self.info("Erase Display and buffer")             # <<<<<<<<<<<<<<
 *                             buffer=self.new_char_buffer()
 * 
 */
              __Pyx_TraceLine(552,0,__PYX_ERR(0, 552, __pyx_L1_error))
              __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_kp_s_Erase_Display_and_buffer); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 552, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":551
 * 
 *                         if params[0]==2:
 *                             if self.debug_mode:             # <<<<<<<<<<<<<<
 *                                 self.info("Erase Display and buffer")
 *                             buffer=self.new_char_buffer()
 */
            }

            /* "ttygif/tty/viewer.pyx":553
 *                             if self.debug_mode:
 *                                 self.info("Erase Display and buffer")
 *                             buffer=self.new_char_buffer()             # <<<<<<<<<<<<<<
 * 
 *                     elif command=='K': # erase line
 */
            __Pyx_TraceLine(553,0,__PYX_ERR(0, 553, __pyx_L1_error))
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->new_char_buffer(__pyx_v_self); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 553, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF_SET(__pyx_v_buffer, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":550
 *                                 buffer[x*3+2]=32
 * 
 *                         if params[0]==2:             # <<<<<<<<<<<<<<
 *                             if self.debug_mode:
 *                                 self.info("Erase Display and buffer")
 */
          }

          /* "ttygif/tty/viewer.pyx":532
 *                         y=params[0]-1
 * 
 *                     elif command=='J': # erase display             # <<<<<<<<<<<<<<
 *                         if params[0]==0:
 *                             if self.debug_mode:
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":555
 *                             buffer=self.new_char_buffer()
 * 
 *                     elif command=='K': # erase line             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Erase Line: {0}".format(params[0]))
 */
        __Pyx_TraceLine(555,0,__PYX_ERR(0, 555, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_K, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 555, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":556
 * 
 *                     elif command=='K': # erase line
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Erase Line: {0}".format(params[0]))
 *                         if params[0]==0:
 */
          __Pyx_TraceLine(556,0,__PYX_ERR(0, 556, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 556, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":557
 *                     elif command=='K': # erase line
 *                         if self.debug_mode:
 *                             self.info("Erase Line: {0}".format(params[0]))             # <<<<<<<<<<<<<<
 *                         if params[0]==0:
 *                             for x2 in range(x,self.viewport_char_width):
 */
            __Pyx_TraceLine(557,0,__PYX_ERR(0, 557, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Erase_Line_0, __pyx_n_s_format); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 557, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_8 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
              }
            }
            __pyx_t_12 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_1);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 557, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_10 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 557, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":556
 * 
 *                     elif command=='K': # erase line
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Erase Line: {0}".format(params[0]))
 *                         if params[0]==0:
 */
          }

          /* "ttygif/tty/viewer.pyx":558
 *                         if self.debug_mode:
 *                             self.info("Erase Line: {0}".format(params[0]))
 *                         if params[0]==0:             # <<<<<<<<<<<<<<
 *                             for x2 in range(x,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 */
          __Pyx_TraceLine(558,0,__PYX_ERR(0, 558, __pyx_L1_error))
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 558, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = __Pyx_PyInt_EqObjC(__pyx_t_10, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 558, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 558, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":559
 *                             self.info("Erase Line: {0}".format(params[0]))
 *                         if params[0]==0:
 *                             for x2 in range(x,self.viewport_char_width):             # <<<<<<<<<<<<<<
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==1:
 */
            __Pyx_TraceLine(559,0,__PYX_ERR(0, 559, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 559, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 559, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_INCREF(__pyx_v_x);
            __Pyx_GIVEREF(__pyx_v_x);
            PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_x);
            __Pyx_GIVEREF(__pyx_t_12);
            PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_12);
            __pyx_t_12 = 0;
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_10, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 559, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
              __pyx_t_10 = __pyx_t_12; __Pyx_INCREF(__pyx_t_10); __pyx_t_13 = 0;
              __pyx_t_14 = NULL;
            } else {
              __pyx_t_13 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 559, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_14 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 559, __pyx_L1_error)
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            for (;;) {
              if (likely(!__pyx_t_14)) {
                if (likely(PyList_CheckExact(__pyx_t_10))) {
                  if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 559, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 559, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                } else {
                  if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 559, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 559, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                }
              } else {
                __pyx_t_12 = __pyx_t_14(__pyx_t_10);
                if (unlikely(!__pyx_t_12)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                    else __PYX_ERR(0, 559, __pyx_L1_error)
                  }
                  break;
                }
                __Pyx_GOTREF(__pyx_t_12);
              }
              __Pyx_XDECREF_SET(__pyx_v_x2, __pyx_t_12);
              __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":560
 *                         if params[0]==0:
 *                             for x2 in range(x,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)             # <<<<<<<<<<<<<<
 *                         elif params[0]==1:
 *                             for x2 in range(0,x+1):
 */
              __Pyx_TraceLine(560,0,__PYX_ERR(0, 560, __pyx_L1_error))
              __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_v_x2); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 560, __pyx_L1_error)
              __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 560, __pyx_L1_error)
              if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 560, __pyx_L1_error)
              __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->write_buffer(__pyx_v_self, __pyx_t_16, __pyx_t_11, 32, ((arrayobject *)__pyx_v_buffer)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 560, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":559
 *                             self.info("Erase Line: {0}".format(params[0]))
 *                         if params[0]==0:
 *                             for x2 in range(x,self.viewport_char_width):             # <<<<<<<<<<<<<<
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==1:
 */
              __Pyx_TraceLine(559,0,__PYX_ERR(0, 559, __pyx_L1_error))
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":558
 *                         if self.debug_mode:
 *                             self.info("Erase Line: {0}".format(params[0]))
 *                         if params[0]==0:             # <<<<<<<<<<<<<<
 *                             for x2 in range(x,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 */
            goto __pyx_L52;
          }

          /* "ttygif/tty/viewer.pyx":561
 *                             for x2 in range(x,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==1:             # <<<<<<<<<<<<<<
 *                             for x2 in range(0,x+1):
 *                                 self.write_buffer(x2,y,32,buffer)
 */
          __Pyx_TraceLine(561,0,__PYX_ERR(0, 561, __pyx_L1_error))
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 561, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = __Pyx_PyInt_EqObjC(__pyx_t_10, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 561, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 561, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":562
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==1:
 *                             for x2 in range(0,x+1):             # <<<<<<<<<<<<<<
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==2:
 */
            __Pyx_TraceLine(562,0,__PYX_ERR(0, 562, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyInt_AddObjC(__pyx_v_x, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 562, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 562, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_GIVEREF(__pyx_int_0);
            PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_int_0);
            __Pyx_GIVEREF(__pyx_t_12);
            PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_12);
            __pyx_t_12 = 0;
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_10, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 562, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
              __pyx_t_10 = __pyx_t_12; __Pyx_INCREF(__pyx_t_10); __pyx_t_13 = 0;
              __pyx_t_14 = NULL;
            } else {
              __pyx_t_13 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 562, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_14 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 562, __pyx_L1_error)
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            for (;;) {
              if (likely(!__pyx_t_14)) {
                if (likely(PyList_CheckExact(__pyx_t_10))) {
                  if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 562, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 562, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                } else {
                  if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 562, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 562, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                }
              } else {
                __pyx_t_12 = __pyx_t_14(__pyx_t_10);
                if (unlikely(!__pyx_t_12)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                    else __PYX_ERR(0, 562, __pyx_L1_error)
                  }
                  break;
                }
                __Pyx_GOTREF(__pyx_t_12);
              }
              __Pyx_XDECREF_SET(__pyx_v_x2, __pyx_t_12);
              __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":563
 *                         elif params[0]==1:
 *                             for x2 in range(0,x+1):
 *                                 self.write_buffer(x2,y,32,buffer)             # <<<<<<<<<<<<<<
 *                         elif params[0]==2:
 *                             for x2 in range(0,self.viewport_char_width):
 */
              __Pyx_TraceLine(563,0,__PYX_ERR(0, 563, __pyx_L1_error))
              __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_x2); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 563, __pyx_L1_error)
              __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 563, __pyx_L1_error)
              if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 563, __pyx_L1_error)
              __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->write_buffer(__pyx_v_self, __pyx_t_11, __pyx_t_16, 32, ((arrayobject *)__pyx_v_buffer)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 563, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":562
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==1:
 *                             for x2 in range(0,x+1):             # <<<<<<<<<<<<<<
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==2:
 */
              __Pyx_TraceLine(562,0,__PYX_ERR(0, 562, __pyx_L1_error))
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":561
 *                             for x2 in range(x,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==1:             # <<<<<<<<<<<<<<
 *                             for x2 in range(0,x+1):
 *                                 self.write_buffer(x2,y,32,buffer)
 */
            goto __pyx_L52;
          }

          /* "ttygif/tty/viewer.pyx":564
 *                             for x2 in range(0,x+1):
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==2:             # <<<<<<<<<<<<<<
 *                             for x2 in range(0,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 */
          __Pyx_TraceLine(564,0,__PYX_ERR(0, 564, __pyx_L1_error))
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 564, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = __Pyx_PyInt_EqObjC(__pyx_t_10, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 564, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 564, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":565
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==2:
 *                             for x2 in range(0,self.viewport_char_width):             # <<<<<<<<<<<<<<
 *                                 self.write_buffer(x2,y,32,buffer)
 *                     elif command=='d': # move cursor to Vertivcal pos y
 */
            __Pyx_TraceLine(565,0,__PYX_ERR(0, 565, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 565, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 565, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_GIVEREF(__pyx_int_0);
            PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_int_0);
            __Pyx_GIVEREF(__pyx_t_12);
            PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_12);
            __pyx_t_12 = 0;
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_10, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 565, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
              __pyx_t_10 = __pyx_t_12; __Pyx_INCREF(__pyx_t_10); __pyx_t_13 = 0;
              __pyx_t_14 = NULL;
            } else {
              __pyx_t_13 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 565, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_14 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 565, __pyx_L1_error)
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            for (;;) {
              if (likely(!__pyx_t_14)) {
                if (likely(PyList_CheckExact(__pyx_t_10))) {
                  if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 565, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 565, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                } else {
                  if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 565, __pyx_L1_error)
                  #else
                  __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 565, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_12);
                  #endif
                }
              } else {
                __pyx_t_12 = __pyx_t_14(__pyx_t_10);
                if (unlikely(!__pyx_t_12)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                    else __PYX_ERR(0, 565, __pyx_L1_error)
                  }
                  break;
                }
                __Pyx_GOTREF(__pyx_t_12);
              }
              __Pyx_XDECREF_SET(__pyx_v_x2, __pyx_t_12);
              __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":566
 *                         elif params[0]==2:
 *                             for x2 in range(0,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)             # <<<<<<<<<<<<<<
 *                     elif command=='d': # move cursor to Vertivcal pos y
 *                         if self.debug_mode:
 */
              __Pyx_TraceLine(566,0,__PYX_ERR(0, 566, __pyx_L1_error))
              __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_v_x2); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 566, __pyx_L1_error)
              __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 566, __pyx_L1_error)
              if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 566, __pyx_L1_error)
              __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->write_buffer(__pyx_v_self, __pyx_t_16, __pyx_t_11, 32, ((arrayobject *)__pyx_v_buffer)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 566, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "ttygif/tty/viewer.pyx":565
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==2:
 *                             for x2 in range(0,self.viewport_char_width):             # <<<<<<<<<<<<<<
 *                                 self.write_buffer(x2,y,32,buffer)
 *                     elif command=='d': # move cursor to Vertivcal pos y
 */
              __Pyx_TraceLine(565,0,__PYX_ERR(0, 565, __pyx_L1_error))
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":564
 *                             for x2 in range(0,x+1):
 *                                 self.write_buffer(x2,y,32,buffer)
 *                         elif params[0]==2:             # <<<<<<<<<<<<<<
 *                             for x2 in range(0,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 */
          }
          __pyx_L52:;

          /* "ttygif/tty/viewer.pyx":555
 *                             buffer=self.new_char_buffer()
 * 
 *                     elif command=='K': # erase line             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Erase Line: {0}".format(params[0]))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":567
 *                             for x2 in range(0,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 *                     elif command=='d': # move cursor to Vertivcal pos y             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor (d) Y{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(567,0,__PYX_ERR(0, 567, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_d, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 567, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":568
 *                                 self.write_buffer(x2,y,32,buffer)
 *                     elif command=='d': # move cursor to Vertivcal pos y
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor (d) Y{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y=params[0]-1
 */
          __Pyx_TraceLine(568,0,__PYX_ERR(0, 568, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 568, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":569
 *                     elif command=='d': # move cursor to Vertivcal pos y
 *                         if self.debug_mode:
 *                             self.info("Cursor (d) Y{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         y=params[0]-1
 *                         x=0
 */
            __Pyx_TraceLine(569,0,__PYX_ERR(0, 569, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Cursor_d_Y_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 569, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 569, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_8 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_1, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 569, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_1, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 569, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 569, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (__pyx_t_8) {
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_11, __pyx_t_1);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_11, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_11, __pyx_v_y);
              __pyx_t_1 = 0;
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_9, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 569, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 569, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":568
 *                                 self.write_buffer(x2,y,32,buffer)
 *                     elif command=='d': # move cursor to Vertivcal pos y
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Cursor (d) Y{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y=params[0]-1
 */
          }

          /* "ttygif/tty/viewer.pyx":570
 *                         if self.debug_mode:
 *                             self.info("Cursor (d) Y{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y=params[0]-1             # <<<<<<<<<<<<<<
 *                         x=0
 *                     #elif command=='e':
 */
          __Pyx_TraceLine(570,0,__PYX_ERR(0, 570, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 570, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_10 = __Pyx_PyInt_SubtractObjC(__pyx_t_12, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 570, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_y, __pyx_t_10);
          __pyx_t_10 = 0;

          /* "ttygif/tty/viewer.pyx":571
 *                             self.info("Cursor (d) Y{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         y=params[0]-1
 *                         x=0             # <<<<<<<<<<<<<<
 *                     #elif command=='e':
 *                     #    if self.debug_mode:
 */
          __Pyx_TraceLine(571,0,__PYX_ERR(0, 571, __pyx_L1_error))
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_DECREF_SET(__pyx_v_x, __pyx_int_0);

          /* "ttygif/tty/viewer.pyx":567
 *                             for x2 in range(0,self.viewport_char_width):
 *                                 self.write_buffer(x2,y,32,buffer)
 *                     elif command=='d': # move cursor to Vertivcal pos y             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Cursor (d) Y{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":576
 *                     #        self.info("Cursor Down rows:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                     #    y+=params[0]
 *                     elif command=='h':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(576,0,__PYX_ERR(0, 576, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_h, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 576, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":577
 *                     #    y+=params[0]
 *                     elif command=='h':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.set_mode(params)
 */
          __Pyx_TraceLine(577,0,__PYX_ERR(0, 577, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 577, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":578
 *                     elif command=='h':
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                             self.set_mode(params)
 *                     elif command=='l':
 */
            __Pyx_TraceLine(578,0,__PYX_ERR(0, 578, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Set_mode_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 578, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 578, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_1 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_1, __pyx_t_9, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 578, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_1, __pyx_t_9, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 578, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 578, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (__pyx_t_1) {
                __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1); __pyx_t_1 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_11, __pyx_t_9);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_11, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_11, __pyx_v_y);
              __pyx_t_9 = 0;
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_8, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 578, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 578, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":579
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.set_mode(params)             # <<<<<<<<<<<<<<
 *                     elif command=='l':
 *                         if self.debug_mode:
 */
            __Pyx_TraceLine(579,0,__PYX_ERR(0, 579, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_mode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 579, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_8 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
              }
            }
            __pyx_t_12 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_v_params) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_params);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 579, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":577
 *                     #    y+=params[0]
 *                     elif command=='h':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.set_mode(params)
 */
          }

          /* "ttygif/tty/viewer.pyx":576
 *                     #        self.info("Cursor Down rows:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                     #    y+=params[0]
 *                     elif command=='h':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":580
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.set_mode(params)
 *                     elif command=='l':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(580,0,__PYX_ERR(0, 580, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_l, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 580, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":581
 *                             self.set_mode(params)
 *                     elif command=='l':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.reset_mode(params)
 */
          __Pyx_TraceLine(581,0,__PYX_ERR(0, 581, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 581, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":582
 *                     elif command=='l':
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                             self.reset_mode(params)
 *                     elif command=='P':
 */
            __Pyx_TraceLine(582,0,__PYX_ERR(0, 582, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Set_mode_0_x_1_2_y_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 582, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 582, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_9 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 582, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_8, __pyx_v_x, __pyx_v_y};
              __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 582, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_1 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 582, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              if (__pyx_t_9) {
                __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_9); __pyx_t_9 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_11, __pyx_t_8);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_11, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_11, __pyx_v_y);
              __pyx_t_8 = 0;
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_1, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 582, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_10 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 582, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":583
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.reset_mode(params)             # <<<<<<<<<<<<<<
 *                     elif command=='P':
 *                         if self.debug_mode:
 */
            __Pyx_TraceLine(583,0,__PYX_ERR(0, 583, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_reset_mode); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 583, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_1 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
              }
            }
            __pyx_t_10 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_1, __pyx_v_params) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_params);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 583, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":581
 *                             self.set_mode(params)
 *                     elif command=='l':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.reset_mode(params)
 */
          }

          /* "ttygif/tty/viewer.pyx":580
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.set_mode(params)
 *                     elif command=='l':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":584
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.reset_mode(params)
 *                     elif command=='P':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(584,0,__PYX_ERR(0, 584, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_P, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 584, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":585
 *                             self.reset_mode(params)
 *                     elif command=='P':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         char_to_erase=params[0]
 */
          __Pyx_TraceLine(585,0,__PYX_ERR(0, 585, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 585, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":586
 *                     elif command=='P':
 *                         if self.debug_mode:
 *                             self.info("Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         char_to_erase=params[0]
 *                         stride=self.viewport_char_width-x
 */
            __Pyx_TraceLine(586,0,__PYX_ERR(0, 586, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Erase_number_of_charchters_on_li, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 586, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 586, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_8 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_1, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 586, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_1, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 586, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 586, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (__pyx_t_8) {
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_11, __pyx_t_1);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_11, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_11, __pyx_v_y);
              __pyx_t_1 = 0;
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_9, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 586, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 586, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":585
 *                             self.reset_mode(params)
 *                     elif command=='P':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         char_to_erase=params[0]
 */
          }

          /* "ttygif/tty/viewer.pyx":587
 *                         if self.debug_mode:
 *                             self.info("Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         char_to_erase=params[0]             # <<<<<<<<<<<<<<
 *                         stride=self.viewport_char_width-x
 *                         temp=[0,0,0]*stride
 */
          __Pyx_TraceLine(587,0,__PYX_ERR(0, 587, __pyx_L1_error))
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 587, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_XDECREF_SET(__pyx_v_char_to_erase, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "ttygif/tty/viewer.pyx":588
 *                             self.info("Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         char_to_erase=params[0]
 *                         stride=self.viewport_char_width-x             # <<<<<<<<<<<<<<
 *                         temp=[0,0,0]*stride
 *                         for x2 in range(x,stride-char_to_erase):
 */
          __Pyx_TraceLine(588,0,__PYX_ERR(0, 588, __pyx_L1_error))
          __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 588, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_10 = PyNumber_Subtract(__pyx_t_12, __pyx_v_x); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 588, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF_SET(__pyx_v_stride, __pyx_t_10);
          __pyx_t_10 = 0;

          /* "ttygif/tty/viewer.pyx":589
 *                         char_to_erase=params[0]
 *                         stride=self.viewport_char_width-x
 *                         temp=[0,0,0]*stride             # <<<<<<<<<<<<<<
 *                         for x2 in range(x,stride-char_to_erase):
 *                             t=(x2-x)*3
 */
          __Pyx_TraceLine(589,0,__PYX_ERR(0, 589, __pyx_L1_error))
          __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_GIVEREF(__pyx_int_0);
          PyList_SET_ITEM(__pyx_t_10, 0, __pyx_int_0);
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_GIVEREF(__pyx_int_0);
          PyList_SET_ITEM(__pyx_t_10, 1, __pyx_int_0);
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_GIVEREF(__pyx_int_0);
          PyList_SET_ITEM(__pyx_t_10, 2, __pyx_int_0);
          { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_10, __pyx_v_stride); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 589, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_temp);
            __Pyx_DECREF(__pyx_t_10);
            __pyx_t_10 = __pyx_temp;
          }
          __Pyx_XDECREF_SET(__pyx_v_temp, ((PyObject*)__pyx_t_10));
          __pyx_t_10 = 0;

          /* "ttygif/tty/viewer.pyx":590
 *                         stride=self.viewport_char_width-x
 *                         temp=[0,0,0]*stride
 *                         for x2 in range(x,stride-char_to_erase):             # <<<<<<<<<<<<<<
 *                             t=(x2-x)*3
 *                             b=(char_to_erase+x2)*3  +y*self.viewport_char_stride
 */
          __Pyx_TraceLine(590,0,__PYX_ERR(0, 590, __pyx_L1_error))
          __pyx_t_10 = PyNumber_Subtract(__pyx_v_stride, __pyx_v_char_to_erase); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 590, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 590, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_INCREF(__pyx_v_x);
          __Pyx_GIVEREF(__pyx_v_x);
          PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_x);
          __Pyx_GIVEREF(__pyx_t_10);
          PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_10);
          __pyx_t_10 = 0;
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_12, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 590, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (likely(PyList_CheckExact(__pyx_t_10)) || PyTuple_CheckExact(__pyx_t_10)) {
            __pyx_t_12 = __pyx_t_10; __Pyx_INCREF(__pyx_t_12); __pyx_t_13 = 0;
            __pyx_t_14 = NULL;
          } else {
            __pyx_t_13 = -1; __pyx_t_12 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 590, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_14 = Py_TYPE(__pyx_t_12)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 590, __pyx_L1_error)
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          for (;;) {
            if (likely(!__pyx_t_14)) {
              if (likely(PyList_CheckExact(__pyx_t_12))) {
                if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_12)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyList_GET_ITEM(__pyx_t_12, __pyx_t_13); __Pyx_INCREF(__pyx_t_10); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 590, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_12, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 590, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              } else {
                if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_12)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_12, __pyx_t_13); __Pyx_INCREF(__pyx_t_10); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 590, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_12, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 590, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              }
            } else {
              __pyx_t_10 = __pyx_t_14(__pyx_t_12);
              if (unlikely(!__pyx_t_10)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 590, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_10);
            }
            __Pyx_XDECREF_SET(__pyx_v_x2, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":591
 *                         temp=[0,0,0]*stride
 *                         for x2 in range(x,stride-char_to_erase):
 *                             t=(x2-x)*3             # <<<<<<<<<<<<<<
 *                             b=(char_to_erase+x2)*3  +y*self.viewport_char_stride
 *                             temp[t+0]=buffer[b+0]
 */
            __Pyx_TraceLine(591,0,__PYX_ERR(0, 591, __pyx_L1_error))
            __pyx_t_10 = PyNumber_Subtract(__pyx_v_x2, __pyx_v_x); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 591, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_9 = PyNumber_Multiply(__pyx_t_10, __pyx_int_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 591, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_9);
            __pyx_t_9 = 0;

            /* "ttygif/tty/viewer.pyx":592
 *                         for x2 in range(x,stride-char_to_erase):
 *                             t=(x2-x)*3
 *                             b=(char_to_erase+x2)*3  +y*self.viewport_char_stride             # <<<<<<<<<<<<<<
 *                             temp[t+0]=buffer[b+0]
 *                             temp[t+1]=buffer[b+1]
 */
            __Pyx_TraceLine(592,0,__PYX_ERR(0, 592, __pyx_L1_error))
            __pyx_t_9 = PyNumber_Add(__pyx_v_char_to_erase, __pyx_v_x2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 592, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_10 = PyNumber_Multiply(__pyx_t_9, __pyx_int_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 592, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_stride); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 592, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_1 = PyNumber_Multiply(__pyx_v_y, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_9 = PyNumber_Add(__pyx_t_10, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 592, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF_SET(__pyx_v_b, __pyx_t_9);
            __pyx_t_9 = 0;

            /* "ttygif/tty/viewer.pyx":593
 *                             t=(x2-x)*3
 *                             b=(char_to_erase+x2)*3  +y*self.viewport_char_stride
 *                             temp[t+0]=buffer[b+0]             # <<<<<<<<<<<<<<
 *                             temp[t+1]=buffer[b+1]
 *                             temp[t+2]=buffer[b+2]
 */
            __Pyx_TraceLine(593,0,__PYX_ERR(0, 593, __pyx_L1_error))
            __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_v_b, __pyx_int_0, 0, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 593, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_buffer, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_v_t, __pyx_int_0, 0, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 593, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            if (unlikely(PyObject_SetItem(__pyx_v_temp, __pyx_t_9, __pyx_t_1) < 0)) __PYX_ERR(0, 593, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "ttygif/tty/viewer.pyx":594
 *                             b=(char_to_erase+x2)*3  +y*self.viewport_char_stride
 *                             temp[t+0]=buffer[b+0]
 *                             temp[t+1]=buffer[b+1]             # <<<<<<<<<<<<<<
 *                             temp[t+2]=buffer[b+2]
 * 
 */
            __Pyx_TraceLine(594,0,__PYX_ERR(0, 594, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_b, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_v_buffer, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 594, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_t, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (unlikely(PyObject_SetItem(__pyx_v_temp, __pyx_t_1, __pyx_t_9) < 0)) __PYX_ERR(0, 594, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

            /* "ttygif/tty/viewer.pyx":595
 *                             temp[t+0]=buffer[b+0]
 *                             temp[t+1]=buffer[b+1]
 *                             temp[t+2]=buffer[b+2]             # <<<<<<<<<<<<<<
 * 
 *                         for x2 in range(x,stride):
 */
            __Pyx_TraceLine(595,0,__PYX_ERR(0, 595, __pyx_L1_error))
            __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_v_b, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 595, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_buffer, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_v_t, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 595, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            if (unlikely(PyObject_SetItem(__pyx_v_temp, __pyx_t_9, __pyx_t_1) < 0)) __PYX_ERR(0, 595, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "ttygif/tty/viewer.pyx":590
 *                         stride=self.viewport_char_width-x
 *                         temp=[0,0,0]*stride
 *                         for x2 in range(x,stride-char_to_erase):             # <<<<<<<<<<<<<<
 *                             t=(x2-x)*3
 *                             b=(char_to_erase+x2)*3  +y*self.viewport_char_stride
 */
            __Pyx_TraceLine(590,0,__PYX_ERR(0, 590, __pyx_L1_error))
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "ttygif/tty/viewer.pyx":597
 *                             temp[t+2]=buffer[b+2]
 * 
 *                         for x2 in range(x,stride):             # <<<<<<<<<<<<<<
 *                             t=(x2-x)*3
 *                             b=x2*3+y*self.viewport_char_stride
 */
          __Pyx_TraceLine(597,0,__PYX_ERR(0, 597, __pyx_L1_error))
          __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 597, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_INCREF(__pyx_v_x);
          __Pyx_GIVEREF(__pyx_v_x);
          PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_x);
          __Pyx_INCREF(__pyx_v_stride);
          __Pyx_GIVEREF(__pyx_v_stride);
          PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_v_stride);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
            __pyx_t_12 = __pyx_t_1; __Pyx_INCREF(__pyx_t_12); __pyx_t_13 = 0;
            __pyx_t_14 = NULL;
          } else {
            __pyx_t_13 = -1; __pyx_t_12 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 597, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_14 = Py_TYPE(__pyx_t_12)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 597, __pyx_L1_error)
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          for (;;) {
            if (likely(!__pyx_t_14)) {
              if (likely(PyList_CheckExact(__pyx_t_12))) {
                if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_12)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_1 = PyList_GET_ITEM(__pyx_t_12, __pyx_t_13); __Pyx_INCREF(__pyx_t_1); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 597, __pyx_L1_error)
                #else
                __pyx_t_1 = PySequence_ITEM(__pyx_t_12, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_1);
                #endif
              } else {
                if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_12)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_12, __pyx_t_13); __Pyx_INCREF(__pyx_t_1); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 597, __pyx_L1_error)
                #else
                __pyx_t_1 = PySequence_ITEM(__pyx_t_12, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_1);
                #endif
              }
            } else {
              __pyx_t_1 = __pyx_t_14(__pyx_t_12);
              if (unlikely(!__pyx_t_1)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 597, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_1);
            }
            __Pyx_XDECREF_SET(__pyx_v_x2, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "ttygif/tty/viewer.pyx":598
 * 
 *                         for x2 in range(x,stride):
 *                             t=(x2-x)*3             # <<<<<<<<<<<<<<
 *                             b=x2*3+y*self.viewport_char_stride
 *                             buffer[b+0]=temp[t+0]
 */
            __Pyx_TraceLine(598,0,__PYX_ERR(0, 598, __pyx_L1_error))
            __pyx_t_1 = PyNumber_Subtract(__pyx_v_x2, __pyx_v_x); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_9 = PyNumber_Multiply(__pyx_t_1, __pyx_int_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 598, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_9);
            __pyx_t_9 = 0;

            /* "ttygif/tty/viewer.pyx":599
 *                         for x2 in range(x,stride):
 *                             t=(x2-x)*3
 *                             b=x2*3+y*self.viewport_char_stride             # <<<<<<<<<<<<<<
 *                             buffer[b+0]=temp[t+0]
 *                             buffer[b+1]=temp[t+1]
 */
            __Pyx_TraceLine(599,0,__PYX_ERR(0, 599, __pyx_L1_error))
            __pyx_t_9 = PyNumber_Multiply(__pyx_v_x2, __pyx_int_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 599, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_stride); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_10 = PyNumber_Multiply(__pyx_v_y, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 599, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Add(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF_SET(__pyx_v_b, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "ttygif/tty/viewer.pyx":600
 *                             t=(x2-x)*3
 *                             b=x2*3+y*self.viewport_char_stride
 *                             buffer[b+0]=temp[t+0]             # <<<<<<<<<<<<<<
 *                             buffer[b+1]=temp[t+1]
 *                             buffer[b+2]=temp[t+2]
 */
            __Pyx_TraceLine(600,0,__PYX_ERR(0, 600, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_t, __pyx_int_0, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_v_temp, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 600, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_b, __pyx_int_0, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_1, __pyx_t_10) < 0)) __PYX_ERR(0, 600, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":601
 *                             b=x2*3+y*self.viewport_char_stride
 *                             buffer[b+0]=temp[t+0]
 *                             buffer[b+1]=temp[t+1]             # <<<<<<<<<<<<<<
 *                             buffer[b+2]=temp[t+2]
 * 
 */
            __Pyx_TraceLine(601,0,__PYX_ERR(0, 601, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_t, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 601, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_temp, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 601, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_b, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 601, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_10, __pyx_t_1) < 0)) __PYX_ERR(0, 601, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "ttygif/tty/viewer.pyx":602
 *                             buffer[b+0]=temp[t+0]
 *                             buffer[b+1]=temp[t+1]
 *                             buffer[b+2]=temp[t+2]             # <<<<<<<<<<<<<<
 * 
 * 
 */
            __Pyx_TraceLine(602,0,__PYX_ERR(0, 602, __pyx_L1_error))
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_t, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_v_temp, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 602, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_b, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (unlikely(PyObject_SetItem(__pyx_v_buffer, __pyx_t_1, __pyx_t_10) < 0)) __PYX_ERR(0, 602, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":597
 *                             temp[t+2]=buffer[b+2]
 * 
 *                         for x2 in range(x,stride):             # <<<<<<<<<<<<<<
 *                             t=(x2-x)*3
 *                             b=x2*3+y*self.viewport_char_stride
 */
            __Pyx_TraceLine(597,0,__PYX_ERR(0, 597, __pyx_L1_error))
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "ttygif/tty/viewer.pyx":584
 *                             self.info("Set mode:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                             self.reset_mode(params)
 *                     elif command=='P':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Erase number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":605
 * 
 * 
 *                     elif command=='X':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Delete number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
        __Pyx_TraceLine(605,0,__PYX_ERR(0, 605, __pyx_L1_error))
        __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_X, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 605, __pyx_L1_error)
        if (__pyx_t_5) {

          /* "ttygif/tty/viewer.pyx":606
 * 
 *                     elif command=='X':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Delete number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         #b=self.bg
 */
          __Pyx_TraceLine(606,0,__PYX_ERR(0, 606, __pyx_L1_error))
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 606, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":607
 *                     elif command=='X':
 *                         if self.debug_mode:
 *                             self.info("Delete number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))             # <<<<<<<<<<<<<<
 *                         #b=self.bg
 *                         #self.bg=14
 */
            __Pyx_TraceLine(607,0,__PYX_ERR(0, 607, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Delete_number_of_charchters_on_l, __pyx_n_s_format); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 607, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_9 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_1, __pyx_v_x, __pyx_v_y};
              __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 607, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_1, __pyx_v_x, __pyx_v_y};
              __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 607, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 607, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (__pyx_t_9) {
                __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_11, __pyx_t_1);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_11, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_11, __pyx_v_y);
              __pyx_t_1 = 0;
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 607, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_10 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 607, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":606
 * 
 *                     elif command=='X':
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Delete number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 *                         #b=self.bg
 */
          }

          /* "ttygif/tty/viewer.pyx":610
 *                         #b=self.bg
 *                         #self.bg=14
 *                         for x2 in range(x,x+params[0]):             # <<<<<<<<<<<<<<
 *                             self.write_buffer(x2,y,0,buffer)
 *                         #self.bg=b
 */
          __Pyx_TraceLine(610,0,__PYX_ERR(0, 610, __pyx_L1_error))
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_params, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 610, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = PyNumber_Add(__pyx_v_x, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 610, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 610, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_v_x);
          __Pyx_GIVEREF(__pyx_v_x);
          PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_x);
          __Pyx_GIVEREF(__pyx_t_12);
          PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_12);
          __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_10, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 610, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
            __pyx_t_10 = __pyx_t_12; __Pyx_INCREF(__pyx_t_10); __pyx_t_13 = 0;
            __pyx_t_14 = NULL;
          } else {
            __pyx_t_13 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 610, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_14 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 610, __pyx_L1_error)
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          for (;;) {
            if (likely(!__pyx_t_14)) {
              if (likely(PyList_CheckExact(__pyx_t_10))) {
                if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_10)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_12 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 610, __pyx_L1_error)
                #else
                __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 610, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_12);
                #endif
              } else {
                if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 610, __pyx_L1_error)
                #else
                __pyx_t_12 = PySequence_ITEM(__pyx_t_10, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 610, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_12);
                #endif
              }
            } else {
              __pyx_t_12 = __pyx_t_14(__pyx_t_10);
              if (unlikely(!__pyx_t_12)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 610, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_XDECREF_SET(__pyx_v_x2, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":611
 *                         #self.bg=14
 *                         for x2 in range(x,x+params[0]):
 *                             self.write_buffer(x2,y,0,buffer)             # <<<<<<<<<<<<<<
 *                         #self.bg=b
 * 
 */
            __Pyx_TraceLine(611,0,__PYX_ERR(0, 611, __pyx_L1_error))
            __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_x2); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 611, __pyx_L1_error)
            __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 611, __pyx_L1_error)
            if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 611, __pyx_L1_error)
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->write_buffer(__pyx_v_self, __pyx_t_11, __pyx_t_16, 0, ((arrayobject *)__pyx_v_buffer)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 611, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":610
 *                         #b=self.bg
 *                         #self.bg=14
 *                         for x2 in range(x,x+params[0]):             # <<<<<<<<<<<<<<
 *                             self.write_buffer(x2,y,0,buffer)
 *                         #self.bg=b
 */
            __Pyx_TraceLine(610,0,__PYX_ERR(0, 610, __pyx_L1_error))
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "ttygif/tty/viewer.pyx":605
 * 
 * 
 *                     elif command=='X':             # <<<<<<<<<<<<<<
 *                         if self.debug_mode:
 *                             self.info("Delete number of charchters on line:{0},x:{1:<2},y:{2:<2}".format(params[0],x,y))
 */
          goto __pyx_L25;
        }

        /* "ttygif/tty/viewer.pyx":615
 * 
 *                     else:
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Impliment: pos x:{2},Y:{3} - {0}-{1}".format(command,params,x,y))
 * 
 */
        __Pyx_TraceLine(615,0,__PYX_ERR(0, 615, __pyx_L1_error))
        /*else*/ {
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->debug_mode); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 615, __pyx_L1_error)
          if (__pyx_t_5) {

            /* "ttygif/tty/viewer.pyx":616
 *                     else:
 *                         if self.debug_mode:
 *                             self.info("Impliment: pos x:{2},Y:{3} - {0}-{1}".format(command,params,x,y))             # <<<<<<<<<<<<<<
 * 
 * 
 */
            __Pyx_TraceLine(616,0,__PYX_ERR(0, 616, __pyx_L1_error))
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Impliment_pos_x_2_Y_3_0_1, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 616, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_8 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[5] = {__pyx_t_8, __pyx_v_command, __pyx_v_params, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 4+__pyx_t_16); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 616, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_10);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[5] = {__pyx_t_8, __pyx_v_command, __pyx_v_params, __pyx_v_x, __pyx_v_y};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_16, 4+__pyx_t_16); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 616, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_10);
            } else
            #endif
            {
              __pyx_t_1 = PyTuple_New(4+__pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              if (__pyx_t_8) {
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_8); __pyx_t_8 = NULL;
              }
              __Pyx_INCREF(__pyx_v_command);
              __Pyx_GIVEREF(__pyx_v_command);
              PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_16, __pyx_v_command);
              __Pyx_INCREF(__pyx_v_params);
              __Pyx_GIVEREF(__pyx_v_params);
              PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_16, __pyx_v_params);
              __Pyx_INCREF(__pyx_v_x);
              __Pyx_GIVEREF(__pyx_v_x);
              PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_16, __pyx_v_x);
              __Pyx_INCREF(__pyx_v_y);
              __Pyx_GIVEREF(__pyx_v_y);
              PyTuple_SET_ITEM(__pyx_t_1, 3+__pyx_t_16, __pyx_v_y);
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_1, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 616, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->info(__pyx_v_self, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 616, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "ttygif/tty/viewer.pyx":615
 * 
 *                     else:
 *                         if self.debug_mode:             # <<<<<<<<<<<<<<
 *                             self.info("Impliment: pos x:{2},Y:{3} - {0}-{1}".format(command,params,x,y))
 * 
 */
          }
        }
        __pyx_L25:;
      }
      __pyx_L17:;

      /* "ttygif/tty/viewer.pyx":460
 *             elif esc_type=='G1':
 *                 command=groups[7]
 *             elif esc_type=='CSI':             # <<<<<<<<<<<<<<
 *                 if command=='m':
 *                     if 38 in params:
 */
    }
    __pyx_L16:;

    /* "ttygif/tty/viewer.pyx":411
 *         cursor=0
 *         new_sequence_pos=self.sequence_pos #self.sequence_pos:
 *         for event in self.sequence[self.sequence_pos:]:             # <<<<<<<<<<<<<<
 *             new_sequence_pos+=1
 *             if event['type']=='text':
 */
    __Pyx_TraceLine(411,0,__PYX_ERR(0, 411, __pyx_L1_error))
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/tty/viewer.pyx":621
 * 
 * 
 *         self.buffer_rows=self.viewport_char_height             # <<<<<<<<<<<<<<
 *         self.buffer=buffer
 *         self.sequence_pos=new_sequence_pos
 */
  __Pyx_TraceLine(621,0,__PYX_ERR(0, 621, __pyx_L1_error))
  __pyx_t_16 = __pyx_v_self->viewport_char_height;
  __pyx_v_self->buffer_rows = __pyx_t_16;

  /* "ttygif/tty/viewer.pyx":622
 * 
 *         self.buffer_rows=self.viewport_char_height
 *         self.buffer=buffer             # <<<<<<<<<<<<<<
 *         self.sequence_pos=new_sequence_pos
 * 
 */
  __Pyx_TraceLine(622,0,__PYX_ERR(0, 622, __pyx_L1_error))
  if (!(likely(((__pyx_v_buffer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_buffer, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(0, 622, __pyx_L1_error)
  __pyx_t_2 = __pyx_v_buffer;
  __Pyx_INCREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->buffer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->buffer));
  __pyx_v_self->buffer = ((arrayobject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "ttygif/tty/viewer.pyx":623
 *         self.buffer_rows=self.viewport_char_height
 *         self.buffer=buffer
 *         self.sequence_pos=new_sequence_pos             # <<<<<<<<<<<<<<
 * 
 *         #print("END X:{0},Y:{1}".format(x,y))
 */
  __Pyx_TraceLine(623,0,__PYX_ERR(0, 623, __pyx_L1_error))
  __Pyx_INCREF(__pyx_v_new_sequence_pos);
  __Pyx_GIVEREF(__pyx_v_new_sequence_pos);
  __Pyx_GOTREF(__pyx_v_self->sequence_pos);
  __Pyx_DECREF(__pyx_v_self->sequence_pos);
  __pyx_v_self->sequence_pos = __pyx_v_new_sequence_pos;

  /* "ttygif/tty/viewer.pyx":627
 *         #print("END X:{0},Y:{1}".format(x,y))
 * 
 *         self.x=x             # <<<<<<<<<<<<<<
 *         self.y=y
 * 
 */
  __Pyx_TraceLine(627,0,__PYX_ERR(0, 627, __pyx_L1_error))
  __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_v_x); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 627, __pyx_L1_error)
  __pyx_v_self->x = __pyx_t_16;

  /* "ttygif/tty/viewer.pyx":628
 * 
 *         self.x=x
 *         self.y=y             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(628,0,__PYX_ERR(0, 628, __pyx_L1_error))
  __pyx_t_16 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_16 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 628, __pyx_L1_error)
  __pyx_v_self->y = __pyx_t_16;

  /* "ttygif/tty/viewer.pyx":396
 * 
 *     # commands pre parsed on add_event
 *     cdef sequence_to_buffer(self):             # <<<<<<<<<<<<<<
 * 
 *         cdef int pos=0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.sequence_to_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_buffer);
  __Pyx_XDECREF(__pyx_v_overflow);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_new_sequence_pos);
  __Pyx_XDECREF(__pyx_v_event);
  __Pyx_XDECREF(__pyx_v_character);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_command);
  __Pyx_XDECREF(__pyx_v_esc_type);
  __Pyx_XDECREF(__pyx_v_groups);
  __Pyx_XDECREF(__pyx_v_cmd);
  __Pyx_XDECREF(__pyx_v_x2);
  __Pyx_XDECREF(__pyx_v_char_to_erase);
  __Pyx_XDECREF(__pyx_v_stride);
  __Pyx_XDECREF(__pyx_v_temp);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_b);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "ttygif/tty/viewer.pyx":682
 *                 command=groups[10]
 *                 if command in 'Hf':
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))             # <<<<<<<<<<<<<<
 *                     while len(params) < 2:
 *                         params = params + (1,)
 */

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *)__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr(__pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 682, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_2generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_viewer_stream_2_sequence_locals, __pyx_n_s_ttygif_tty_viewer); if (unlikely(!gen)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.stream_2_sequence.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  Py_ssize_t __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __Pyx_TraceCall("genexpr", __pyx_f[0], 682, 0, __PYX_ERR(0, 682, __pyx_L1_error));
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_TraceReturn(Py_None, 0);
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 682, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_paramstring)) { __Pyx_RaiseClosureNameError("paramstring"); __PYX_ERR(0, 682, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_paramstring, __pyx_n_s_split); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_kp_s__6) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_s__6);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 682, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 682, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 682, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 682, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_p);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_p, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_cur_scope->__pyx_v_p); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 682, __pyx_L1_error)
    if (((__pyx_t_6 != 0) != 0)) {
      __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_cur_scope->__pyx_v_p); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __pyx_t_3;
      __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_int_1);
      __pyx_t_1 = __pyx_int_1;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    __Pyx_XGIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_4;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_5;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_TraceReturn(__pyx_r, 0);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_2);
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_5 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 682, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_5generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "ttygif/tty/viewer.pyx":690
 *                 else:
 * 
 *                     params = tuple(int(p) for p in paramstring.split(';') if len(p) != 0)             # <<<<<<<<<<<<<<
 *                     if len(params) == 0:
 *                         if command in 'JKm':
 */

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *)__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr(__pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 690, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_5generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_viewer_stream_2_sequence_locals, __pyx_n_s_ttygif_tty_viewer); if (unlikely(!gen)) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.stream_2_sequence.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_5generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __Pyx_TraceCall("genexpr", __pyx_f[0], 690, 0, __PYX_ERR(0, 690, __pyx_L1_error));
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_TraceReturn(Py_None, 0);
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 690, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_paramstring)) { __Pyx_RaiseClosureNameError("paramstring"); __PYX_ERR(0, 690, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_paramstring, __pyx_n_s_split); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_kp_s__6) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_s__6);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 690, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 690, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 690, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 690, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_p);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_p, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_cur_scope->__pyx_v_p); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 690, __pyx_L1_error)
    __pyx_t_7 = ((__pyx_t_6 != 0) != 0);
    if (__pyx_t_7) {
      __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_cur_scope->__pyx_v_p); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      __Pyx_XGIVEREF(__pyx_t_2);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_4;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_5;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_TraceReturn(__pyx_r, 0);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_2);
      __pyx_t_4 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_5 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 690, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":631
 * 
 * 
 *     cdef stream_2_sequence(self,text,timestamp,delay):             # <<<<<<<<<<<<<<
 * 
 *         # patterns for filtering out commands from the stream
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_stream_2_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_timestamp, PyObject *__pyx_v_delay) {
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *__pyx_cur_scope;
  PyObject *__pyx_v_ANSI_SINGLE = NULL;
  PyObject *__pyx_v_ANSI_CHAR_SET = NULL;
  PyObject *__pyx_v_ANSI_G0 = NULL;
  PyObject *__pyx_v_ANSI_G1 = NULL;
  PyObject *__pyx_v_ANSI_CSI_RE = NULL;
  PyObject *__pyx_v_ANSI_OSC = NULL;
  PyObject *__pyx_v_ESC_SEQUENCES = NULL;
  PyObject *__pyx_v_ANSI_REGEX = NULL;
  PyObject *__pyx_v_ANSI = NULL;
  PyObject *__pyx_v_cursor = NULL;
  PyObject *__pyx_v_match = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_end = NULL;
  PyObject *__pyx_v_command = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_esc_type = NULL;
  PyObject *__pyx_v_groups = NULL;
  PyObject *__pyx_v_cmd = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_reverse_video = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  __Pyx_RefNannySetupContext("stream_2_sequence", 0);
  __pyx_cur_scope = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *)__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence(__pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 631, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __Pyx_TraceCall("stream_2_sequence", __pyx_f[0], 631, 0, __PYX_ERR(0, 631, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":634
 * 
 *         # patterns for filtering out commands from the stream
 *         ANSI_SINGLE   ='[\001b|\033]([cDEHMZ78>=])'             # <<<<<<<<<<<<<<
 *         ANSI_CHAR_SET = '[\001b|\033]\\%([@G*])'
 *         ANSI_G0       = '[\001b|\033]\\(([B0UK])'
 */
  __Pyx_TraceLine(634,0,__PYX_ERR(0, 634, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_b_cDEHMZ78);
  __pyx_v_ANSI_SINGLE = __pyx_kp_s_b_cDEHMZ78;

  /* "ttygif/tty/viewer.pyx":635
 *         # patterns for filtering out commands from the stream
 *         ANSI_SINGLE   ='[\001b|\033]([cDEHMZ78>=])'
 *         ANSI_CHAR_SET = '[\001b|\033]\\%([@G*])'             # <<<<<<<<<<<<<<
 *         ANSI_G0       = '[\001b|\033]\\(([B0UK])'
 *         ANSI_G1       = '[\001b|\033]\\)([B0UK])'
 */
  __Pyx_TraceLine(635,0,__PYX_ERR(0, 635, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_b_G);
  __pyx_v_ANSI_CHAR_SET = __pyx_kp_s_b_G;

  /* "ttygif/tty/viewer.pyx":636
 *         ANSI_SINGLE   ='[\001b|\033]([cDEHMZ78>=])'
 *         ANSI_CHAR_SET = '[\001b|\033]\\%([@G*])'
 *         ANSI_G0       = '[\001b|\033]\\(([B0UK])'             # <<<<<<<<<<<<<<
 *         ANSI_G1       = '[\001b|\033]\\)([B0UK])'
 *         ANSI_CSI_RE   = '[\001b|\033]\\[((?:\\d|;|<|>|=|\?)*)([a-zA-Z])\002?'
 */
  __Pyx_TraceLine(636,0,__PYX_ERR(0, 636, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_b_B0UK);
  __pyx_v_ANSI_G0 = __pyx_kp_s_b_B0UK;

  /* "ttygif/tty/viewer.pyx":637
 *         ANSI_CHAR_SET = '[\001b|\033]\\%([@G*])'
 *         ANSI_G0       = '[\001b|\033]\\(([B0UK])'
 *         ANSI_G1       = '[\001b|\033]\\)([B0UK])'             # <<<<<<<<<<<<<<
 *         ANSI_CSI_RE   = '[\001b|\033]\\[((?:\\d|;|<|>|=|\?)*)([a-zA-Z])\002?'
 *         # guessed on this one
 */
  __Pyx_TraceLine(637,0,__PYX_ERR(0, 637, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_b_B0UK_2);
  __pyx_v_ANSI_G1 = __pyx_kp_s_b_B0UK_2;

  /* "ttygif/tty/viewer.pyx":638
 *         ANSI_G0       = '[\001b|\033]\\(([B0UK])'
 *         ANSI_G1       = '[\001b|\033]\\)([B0UK])'
 *         ANSI_CSI_RE   = '[\001b|\033]\\[((?:\\d|;|<|>|=|\?)*)([a-zA-Z])\002?'             # <<<<<<<<<<<<<<
 *         # guessed on this one
 *         #ANSI_OSC_777_REGEX='[\0x1b|\033]\]777[;]([._:A-Za-z0-9\-\s]*)[;]([._:A-Za-z0-9\-\s]*)[;]([._:A-Za-z0-9\-\s]*)'
 */
  __Pyx_TraceLine(638,0,__PYX_ERR(0, 638, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_b_d_a_zA_Z);
  __pyx_v_ANSI_CSI_RE = __pyx_kp_s_b_d_a_zA_Z;

  /* "ttygif/tty/viewer.pyx":641
 *         # guessed on this one
 *         #ANSI_OSC_777_REGEX='[\0x1b|\033]\]777[;]([._:A-Za-z0-9\-\s]*)[;]([._:A-Za-z0-9\-\s]*)[;]([._:A-Za-z0-9\-\s]*)'
 *         ANSI_OSC ='(?:\001?\\]|\x9d).*?(?:\001?\\\\|[\a\x9c])'             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(641,0,__PYX_ERR(0, 641, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s__8);
  __pyx_v_ANSI_OSC = __pyx_kp_s__8;

  /* "ttygif/tty/viewer.pyx":644
 * 
 * 
 *         ESC_SEQUENCES=[ANSI_SINGLE,ANSI_CHAR_SET,ANSI_G0,ANSI_G1,ANSI_CSI_RE,ANSI_OSC]             # <<<<<<<<<<<<<<
 * 
 *         ANSI_REGEX="("+")|(".join(ESC_SEQUENCES)+")"
 */
  __Pyx_TraceLine(644,0,__PYX_ERR(0, 644, __pyx_L1_error))
  __pyx_t_1 = PyList_New(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_ANSI_SINGLE);
  __Pyx_GIVEREF(__pyx_v_ANSI_SINGLE);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_ANSI_SINGLE);
  __Pyx_INCREF(__pyx_v_ANSI_CHAR_SET);
  __Pyx_GIVEREF(__pyx_v_ANSI_CHAR_SET);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_ANSI_CHAR_SET);
  __Pyx_INCREF(__pyx_v_ANSI_G0);
  __Pyx_GIVEREF(__pyx_v_ANSI_G0);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_v_ANSI_G0);
  __Pyx_INCREF(__pyx_v_ANSI_G1);
  __Pyx_GIVEREF(__pyx_v_ANSI_G1);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_v_ANSI_G1);
  __Pyx_INCREF(__pyx_v_ANSI_CSI_RE);
  __Pyx_GIVEREF(__pyx_v_ANSI_CSI_RE);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_v_ANSI_CSI_RE);
  __Pyx_INCREF(__pyx_v_ANSI_OSC);
  __Pyx_GIVEREF(__pyx_v_ANSI_OSC);
  PyList_SET_ITEM(__pyx_t_1, 5, __pyx_v_ANSI_OSC);
  __pyx_v_ESC_SEQUENCES = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":646
 *         ESC_SEQUENCES=[ANSI_SINGLE,ANSI_CHAR_SET,ANSI_G0,ANSI_G1,ANSI_CSI_RE,ANSI_OSC]
 * 
 *         ANSI_REGEX="("+")|(".join(ESC_SEQUENCES)+")"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_TraceLine(646,0,__PYX_ERR(0, 646, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyString_Join(__pyx_kp_s__10, __pyx_v_ESC_SEQUENCES); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_s__9, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_kp_s__11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_ANSI_REGEX = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":649
 * 
 * 
 *         ANSI=re.compile(ANSI_REGEX)             # <<<<<<<<<<<<<<
 *         cursor=0
 *         for match in ANSI.finditer(text):
 */
  __Pyx_TraceLine(649,0,__PYX_ERR(0, 649, __pyx_L1_error))
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_compile); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_ANSI_REGEX) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_ANSI_REGEX);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_ANSI = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":650
 * 
 *         ANSI=re.compile(ANSI_REGEX)
 *         cursor=0             # <<<<<<<<<<<<<<
 *         for match in ANSI.finditer(text):
 *             name=""
 */
  __Pyx_TraceLine(650,0,__PYX_ERR(0, 650, __pyx_L1_error))
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_cursor = __pyx_int_0;

  /* "ttygif/tty/viewer.pyx":651
 *         ANSI=re.compile(ANSI_REGEX)
 *         cursor=0
 *         for match in ANSI.finditer(text):             # <<<<<<<<<<<<<<
 *             name=""
 *             start, end = match.span()
 */
  __Pyx_TraceLine(651,0,__PYX_ERR(0, 651, __pyx_L1_error))
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ANSI, __pyx_n_s_finditer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_text);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 651, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 651, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 651, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 651, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 651, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_match, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":652
 *         cursor=0
 *         for match in ANSI.finditer(text):
 *             name=""             # <<<<<<<<<<<<<<
 *             start, end = match.span()
 *             self.add_text_sequence(text[cursor:start],timestamp,delay)
 */
    __Pyx_TraceLine(652,0,__PYX_ERR(0, 652, __pyx_L1_error))
    __Pyx_INCREF(__pyx_kp_s_);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_kp_s_);

    /* "ttygif/tty/viewer.pyx":653
 *         for match in ANSI.finditer(text):
 *             name=""
 *             start, end = match.span()             # <<<<<<<<<<<<<<
 *             self.add_text_sequence(text[cursor:start],timestamp,delay)
 *             cursor = end
 */
    __Pyx_TraceLine(653,0,__PYX_ERR(0, 653, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_match, __pyx_n_s_span); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 653, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_2 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_2)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 653, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 653, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_start, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_end, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "ttygif/tty/viewer.pyx":654
 *             name=""
 *             start, end = match.span()
 *             self.add_text_sequence(text[cursor:start],timestamp,delay)             # <<<<<<<<<<<<<<
 *             cursor = end
 *             command=None
 */
    __Pyx_TraceLine(654,0,__PYX_ERR(0, 654, __pyx_L1_error))
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_add_text_sequence); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_text, 0, 0, &__pyx_v_cursor, &__pyx_v_start, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_9 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_2, __pyx_v_timestamp, __pyx_v_delay};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_2, __pyx_v_timestamp, __pyx_v_delay};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_t_2);
      __Pyx_INCREF(__pyx_v_timestamp);
      __Pyx_GIVEREF(__pyx_v_timestamp);
      PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_v_timestamp);
      __Pyx_INCREF(__pyx_v_delay);
      __Pyx_GIVEREF(__pyx_v_delay);
      PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_9, __pyx_v_delay);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":655
 *             start, end = match.span()
 *             self.add_text_sequence(text[cursor:start],timestamp,delay)
 *             cursor = end             # <<<<<<<<<<<<<<
 *             command=None
 *             params=None
 */
    __Pyx_TraceLine(655,0,__PYX_ERR(0, 655, __pyx_L1_error))
    __Pyx_INCREF(__pyx_v_end);
    __Pyx_DECREF_SET(__pyx_v_cursor, __pyx_v_end);

    /* "ttygif/tty/viewer.pyx":656
 *             self.add_text_sequence(text[cursor:start],timestamp,delay)
 *             cursor = end
 *             command=None             # <<<<<<<<<<<<<<
 *             params=None
 *             esc_type=None
 */
    __Pyx_TraceLine(656,0,__PYX_ERR(0, 656, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF_SET(__pyx_v_command, Py_None);

    /* "ttygif/tty/viewer.pyx":657
 *             cursor = end
 *             command=None
 *             params=None             # <<<<<<<<<<<<<<
 *             esc_type=None
 *             groups=match.groups()
 */
    __Pyx_TraceLine(657,0,__PYX_ERR(0, 657, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF_SET(__pyx_v_params, Py_None);

    /* "ttygif/tty/viewer.pyx":658
 *             command=None
 *             params=None
 *             esc_type=None             # <<<<<<<<<<<<<<
 *             groups=match.groups()
 *             if groups[0]:
 */
    __Pyx_TraceLine(658,0,__PYX_ERR(0, 658, __pyx_L1_error))
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF_SET(__pyx_v_esc_type, Py_None);

    /* "ttygif/tty/viewer.pyx":659
 *             params=None
 *             esc_type=None
 *             groups=match.groups()             # <<<<<<<<<<<<<<
 *             if groups[0]:
 *                 esc_type='SINGLE'
 */
    __Pyx_TraceLine(659,0,__PYX_ERR(0, 659, __pyx_L1_error))
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_match, __pyx_n_s_groups); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_groups, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":660
 *             esc_type=None
 *             groups=match.groups()
 *             if groups[0]:             # <<<<<<<<<<<<<<
 *                 esc_type='SINGLE'
 *                 command=groups[1]
 */
    __Pyx_TraceLine(660,0,__PYX_ERR(0, 660, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 660, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_11) {

      /* "ttygif/tty/viewer.pyx":661
 *             groups=match.groups()
 *             if groups[0]:
 *                 esc_type='SINGLE'             # <<<<<<<<<<<<<<
 *                 command=groups[1]
 *             elif groups[2]:
 */
      __Pyx_TraceLine(661,0,__PYX_ERR(0, 661, __pyx_L1_error))
      __Pyx_INCREF(__pyx_n_s_SINGLE);
      __Pyx_DECREF_SET(__pyx_v_esc_type, __pyx_n_s_SINGLE);

      /* "ttygif/tty/viewer.pyx":662
 *             if groups[0]:
 *                 esc_type='SINGLE'
 *                 command=groups[1]             # <<<<<<<<<<<<<<
 *             elif groups[2]:
 *                 esc_type='CHAR_SET'
 */
      __Pyx_TraceLine(662,0,__PYX_ERR(0, 662, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":660
 *             esc_type=None
 *             groups=match.groups()
 *             if groups[0]:             # <<<<<<<<<<<<<<
 *                 esc_type='SINGLE'
 *                 command=groups[1]
 */
      goto __pyx_L7;
    }

    /* "ttygif/tty/viewer.pyx":663
 *                 esc_type='SINGLE'
 *                 command=groups[1]
 *             elif groups[2]:             # <<<<<<<<<<<<<<
 *                 esc_type='CHAR_SET'
 *                 command=groups[3]
 */
    __Pyx_TraceLine(663,0,__PYX_ERR(0, 663, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 663, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_11) {

      /* "ttygif/tty/viewer.pyx":664
 *                 command=groups[1]
 *             elif groups[2]:
 *                 esc_type='CHAR_SET'             # <<<<<<<<<<<<<<
 *                 command=groups[3]
 *             elif groups[4]:
 */
      __Pyx_TraceLine(664,0,__PYX_ERR(0, 664, __pyx_L1_error))
      __Pyx_INCREF(__pyx_n_s_CHAR_SET);
      __Pyx_DECREF_SET(__pyx_v_esc_type, __pyx_n_s_CHAR_SET);

      /* "ttygif/tty/viewer.pyx":665
 *             elif groups[2]:
 *                 esc_type='CHAR_SET'
 *                 command=groups[3]             # <<<<<<<<<<<<<<
 *             elif groups[4]:
 *                 esc_type='G0'
 */
      __Pyx_TraceLine(665,0,__PYX_ERR(0, 665, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 665, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":663
 *                 esc_type='SINGLE'
 *                 command=groups[1]
 *             elif groups[2]:             # <<<<<<<<<<<<<<
 *                 esc_type='CHAR_SET'
 *                 command=groups[3]
 */
      goto __pyx_L7;
    }

    /* "ttygif/tty/viewer.pyx":666
 *                 esc_type='CHAR_SET'
 *                 command=groups[3]
 *             elif groups[4]:             # <<<<<<<<<<<<<<
 *                 esc_type='G0'
 *                 command=groups[5]
 */
    __Pyx_TraceLine(666,0,__PYX_ERR(0, 666, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_11) {

      /* "ttygif/tty/viewer.pyx":667
 *                 command=groups[3]
 *             elif groups[4]:
 *                 esc_type='G0'             # <<<<<<<<<<<<<<
 *                 command=groups[5]
 *             elif groups[6]:
 */
      __Pyx_TraceLine(667,0,__PYX_ERR(0, 667, __pyx_L1_error))
      __Pyx_INCREF(__pyx_n_s_G0);
      __Pyx_DECREF_SET(__pyx_v_esc_type, __pyx_n_s_G0);

      /* "ttygif/tty/viewer.pyx":668
 *             elif groups[4]:
 *                 esc_type='G0'
 *                 command=groups[5]             # <<<<<<<<<<<<<<
 *             elif groups[6]:
 *                 esc_type='G1'
 */
      __Pyx_TraceLine(668,0,__PYX_ERR(0, 668, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":666
 *                 esc_type='CHAR_SET'
 *                 command=groups[3]
 *             elif groups[4]:             # <<<<<<<<<<<<<<
 *                 esc_type='G0'
 *                 command=groups[5]
 */
      goto __pyx_L7;
    }

    /* "ttygif/tty/viewer.pyx":669
 *                 esc_type='G0'
 *                 command=groups[5]
 *             elif groups[6]:             # <<<<<<<<<<<<<<
 *                 esc_type='G1'
 *                 command=groups[7]
 */
    __Pyx_TraceLine(669,0,__PYX_ERR(0, 669, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 669, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_11) {

      /* "ttygif/tty/viewer.pyx":670
 *                 command=groups[5]
 *             elif groups[6]:
 *                 esc_type='G1'             # <<<<<<<<<<<<<<
 *                 command=groups[7]
 *             elif groups[11]:
 */
      __Pyx_TraceLine(670,0,__PYX_ERR(0, 670, __pyx_L1_error))
      __Pyx_INCREF(__pyx_n_s_G1);
      __Pyx_DECREF_SET(__pyx_v_esc_type, __pyx_n_s_G1);

      /* "ttygif/tty/viewer.pyx":671
 *             elif groups[6]:
 *                 esc_type='G1'
 *                 command=groups[7]             # <<<<<<<<<<<<<<
 *             elif groups[11]:
 *                 esc_type='OSC'
 */
      __Pyx_TraceLine(671,0,__PYX_ERR(0, 671, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":669
 *                 esc_type='G0'
 *                 command=groups[5]
 *             elif groups[6]:             # <<<<<<<<<<<<<<
 *                 esc_type='G1'
 *                 command=groups[7]
 */
      goto __pyx_L7;
    }

    /* "ttygif/tty/viewer.pyx":672
 *                 esc_type='G1'
 *                 command=groups[7]
 *             elif groups[11]:             # <<<<<<<<<<<<<<
 *                 esc_type='OSC'
 *                 command=groups[11]
 */
    __Pyx_TraceLine(672,0,__PYX_ERR(0, 672, __pyx_L1_error))
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 11, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 672, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_11) {

      /* "ttygif/tty/viewer.pyx":673
 *                 command=groups[7]
 *             elif groups[11]:
 *                 esc_type='OSC'             # <<<<<<<<<<<<<<
 *                 command=groups[11]
 *                 params=[groups[11]]
 */
      __Pyx_TraceLine(673,0,__PYX_ERR(0, 673, __pyx_L1_error))
      __Pyx_INCREF(__pyx_n_s_OSC);
      __Pyx_DECREF_SET(__pyx_v_esc_type, __pyx_n_s_OSC);

      /* "ttygif/tty/viewer.pyx":674
 *             elif groups[11]:
 *                 esc_type='OSC'
 *                 command=groups[11]             # <<<<<<<<<<<<<<
 *                 params=[groups[11]]
 * 
 */
      __Pyx_TraceLine(674,0,__PYX_ERR(0, 674, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 11, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "ttygif/tty/viewer.pyx":675
 *                 esc_type='OSC'
 *                 command=groups[11]
 *                 params=[groups[11]]             # <<<<<<<<<<<<<<
 * 
 *             elif groups[8]:
 */
      __Pyx_TraceLine(675,0,__PYX_ERR(0, 675, __pyx_L1_error))
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_groups, 11, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_1);
      PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
      __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_params, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "ttygif/tty/viewer.pyx":672
 *                 esc_type='G1'
 *                 command=groups[7]
 *             elif groups[11]:             # <<<<<<<<<<<<<<
 *                 esc_type='OSC'
 *                 command=groups[11]
 */
      goto __pyx_L7;
    }

    /* "ttygif/tty/viewer.pyx":677
 *                 params=[groups[11]]
 * 
 *             elif groups[8]:             # <<<<<<<<<<<<<<
 *                 esc_type='CSI'
 *                 paramstring=groups[9]
 */
    __Pyx_TraceLine(677,0,__PYX_ERR(0, 677, __pyx_L1_error))
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_groups, 8, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_11) {

      /* "ttygif/tty/viewer.pyx":678
 * 
 *             elif groups[8]:
 *                 esc_type='CSI'             # <<<<<<<<<<<<<<
 *                 paramstring=groups[9]
 *                 command=groups[10]
 */
      __Pyx_TraceLine(678,0,__PYX_ERR(0, 678, __pyx_L1_error))
      __Pyx_INCREF(__pyx_n_s_CSI);
      __Pyx_DECREF_SET(__pyx_v_esc_type, __pyx_n_s_CSI);

      /* "ttygif/tty/viewer.pyx":679
 *             elif groups[8]:
 *                 esc_type='CSI'
 *                 paramstring=groups[9]             # <<<<<<<<<<<<<<
 *                 command=groups[10]
 *                 if command in 'Hf':
 */
      __Pyx_TraceLine(679,0,__PYX_ERR(0, 679, __pyx_L1_error))
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_groups, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 679, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_paramstring);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_paramstring, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      __pyx_t_6 = 0;

      /* "ttygif/tty/viewer.pyx":680
 *                 esc_type='CSI'
 *                 paramstring=groups[9]
 *                 command=groups[10]             # <<<<<<<<<<<<<<
 *                 if command in 'Hf':
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))
 */
      __Pyx_TraceLine(680,0,__PYX_ERR(0, 680, __pyx_L1_error))
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_groups, 10, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 680, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF_SET(__pyx_v_command, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "ttygif/tty/viewer.pyx":681
 *                 paramstring=groups[9]
 *                 command=groups[10]
 *                 if command in 'Hf':             # <<<<<<<<<<<<<<
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))
 *                     while len(params) < 2:
 */
      __Pyx_TraceLine(681,0,__PYX_ERR(0, 681, __pyx_L1_error))
      __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_v_command, __pyx_n_s_Hf, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 681, __pyx_L1_error)
      __pyx_t_12 = (__pyx_t_11 != 0);
      if (__pyx_t_12) {

        /* "ttygif/tty/viewer.pyx":682
 *                 command=groups[10]
 *                 if command in 'Hf':
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))             # <<<<<<<<<<<<<<
 *                     while len(params) < 2:
 *                         params = params + (1,)
 */
        __Pyx_TraceLine(682,0,__PYX_ERR(0, 682, __pyx_L1_error))
        __pyx_t_6 = __pyx_pf_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_params, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "ttygif/tty/viewer.pyx":683
 *                 if command in 'Hf':
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))
 *                     while len(params) < 2:             # <<<<<<<<<<<<<<
 *                         params = params + (1,)
 *                 #        DEC Private Mode (DECSET/DECRST) sequences
 */
        __Pyx_TraceLine(683,0,__PYX_ERR(0, 683, __pyx_L1_error))
        while (1) {
          __pyx_t_13 = PyObject_Length(__pyx_v_params); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 683, __pyx_L1_error)
          __pyx_t_12 = ((__pyx_t_13 < 2) != 0);
          if (!__pyx_t_12) break;

          /* "ttygif/tty/viewer.pyx":684
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))
 *                     while len(params) < 2:
 *                         params = params + (1,)             # <<<<<<<<<<<<<<
 *                 #        DEC Private Mode (DECSET/DECRST) sequences
 *                 elif paramstring and len(paramstring)>0 and paramstring[0]=='?':
 */
          __Pyx_TraceLine(684,0,__PYX_ERR(0, 684, __pyx_L1_error))
          __pyx_t_1 = PyNumber_Add(__pyx_v_params, __pyx_tuple__12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 684, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_params, __pyx_t_1);
          __pyx_t_1 = 0;
        }

        /* "ttygif/tty/viewer.pyx":681
 *                 paramstring=groups[9]
 *                 command=groups[10]
 *                 if command in 'Hf':             # <<<<<<<<<<<<<<
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))
 *                     while len(params) < 2:
 */
        goto __pyx_L8;
      }

      /* "ttygif/tty/viewer.pyx":686
 *                         params = params + (1,)
 *                 #        DEC Private Mode (DECSET/DECRST) sequences
 *                 elif paramstring and len(paramstring)>0 and paramstring[0]=='?':             # <<<<<<<<<<<<<<
 *                     params=['?',paramstring[1:-1],paramstring[-1]]
 *                 else:
 */
      __Pyx_TraceLine(686,0,__PYX_ERR(0, 686, __pyx_L1_error))
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_paramstring); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 686, __pyx_L1_error)
      if (__pyx_t_11) {
      } else {
        __pyx_t_12 = __pyx_t_11;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_1 = __pyx_cur_scope->__pyx_v_paramstring;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_13 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_11 = ((__pyx_t_13 > 0) != 0);
      if (__pyx_t_11) {
      } else {
        __pyx_t_12 = __pyx_t_11;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_paramstring, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s__13, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_12 = __pyx_t_11;
      __pyx_L11_bool_binop_done:;
      if (__pyx_t_12) {

        /* "ttygif/tty/viewer.pyx":687
 *                 #        DEC Private Mode (DECSET/DECRST) sequences
 *                 elif paramstring and len(paramstring)>0 and paramstring[0]=='?':
 *                     params=['?',paramstring[1:-1],paramstring[-1]]             # <<<<<<<<<<<<<<
 *                 else:
 * 
 */
        __Pyx_TraceLine(687,0,__PYX_ERR(0, 687, __pyx_L1_error))
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_paramstring, 1, -1L, NULL, NULL, &__pyx_slice__14, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_paramstring, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 687, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 687, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_kp_s__13);
        __Pyx_GIVEREF(__pyx_kp_s__13);
        PyList_SET_ITEM(__pyx_t_10, 0, __pyx_kp_s__13);
        __Pyx_GIVEREF(__pyx_t_1);
        PyList_SET_ITEM(__pyx_t_10, 1, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_6);
        PyList_SET_ITEM(__pyx_t_10, 2, __pyx_t_6);
        __pyx_t_1 = 0;
        __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_params, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "ttygif/tty/viewer.pyx":686
 *                         params = params + (1,)
 *                 #        DEC Private Mode (DECSET/DECRST) sequences
 *                 elif paramstring and len(paramstring)>0 and paramstring[0]=='?':             # <<<<<<<<<<<<<<
 *                     params=['?',paramstring[1:-1],paramstring[-1]]
 *                 else:
 */
        goto __pyx_L8;
      }

      /* "ttygif/tty/viewer.pyx":690
 *                 else:
 * 
 *                     params = tuple(int(p) for p in paramstring.split(';') if len(p) != 0)             # <<<<<<<<<<<<<<
 *                     if len(params) == 0:
 *                         if command in 'JKm':
 */
      __Pyx_TraceLine(690,0,__PYX_ERR(0, 690, __pyx_L1_error))
      /*else*/ {
        __pyx_t_10 = __pyx_pf_6ttygif_3tty_6viewer_6viewer_17stream_2_sequence_3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 690, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_6 = __Pyx_PySequence_Tuple(__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 690, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF_SET(__pyx_v_params, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "ttygif/tty/viewer.pyx":691
 * 
 *                     params = tuple(int(p) for p in paramstring.split(';') if len(p) != 0)
 *                     if len(params) == 0:             # <<<<<<<<<<<<<<
 *                         if command in 'JKm':
 *                             params = (0,)
 */
        __Pyx_TraceLine(691,0,__PYX_ERR(0, 691, __pyx_L1_error))
        __pyx_t_13 = PyObject_Length(__pyx_v_params); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 691, __pyx_L1_error)
        __pyx_t_12 = ((__pyx_t_13 == 0) != 0);
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":692
 *                     params = tuple(int(p) for p in paramstring.split(';') if len(p) != 0)
 *                     if len(params) == 0:
 *                         if command in 'JKm':             # <<<<<<<<<<<<<<
 *                             params = (0,)
 *                         elif command in 'ABCD':
 */
          __Pyx_TraceLine(692,0,__PYX_ERR(0, 692, __pyx_L1_error))
          __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_v_command, __pyx_n_s_JKm, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 692, __pyx_L1_error)
          __pyx_t_11 = (__pyx_t_12 != 0);
          if (__pyx_t_11) {

            /* "ttygif/tty/viewer.pyx":693
 *                     if len(params) == 0:
 *                         if command in 'JKm':
 *                             params = (0,)             # <<<<<<<<<<<<<<
 *                         elif command in 'ABCD':
 *                             params = (1,)
 */
            __Pyx_TraceLine(693,0,__PYX_ERR(0, 693, __pyx_L1_error))
            __Pyx_INCREF(__pyx_tuple__15);
            __Pyx_DECREF_SET(__pyx_v_params, __pyx_tuple__15);

            /* "ttygif/tty/viewer.pyx":692
 *                     params = tuple(int(p) for p in paramstring.split(';') if len(p) != 0)
 *                     if len(params) == 0:
 *                         if command in 'JKm':             # <<<<<<<<<<<<<<
 *                             params = (0,)
 *                         elif command in 'ABCD':
 */
            goto __pyx_L15;
          }

          /* "ttygif/tty/viewer.pyx":694
 *                         if command in 'JKm':
 *                             params = (0,)
 *                         elif command in 'ABCD':             # <<<<<<<<<<<<<<
 *                             params = (1,)
 * 
 */
          __Pyx_TraceLine(694,0,__PYX_ERR(0, 694, __pyx_L1_error))
          __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_v_command, __pyx_n_s_ABCD, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 694, __pyx_L1_error)
          __pyx_t_12 = (__pyx_t_11 != 0);
          if (__pyx_t_12) {

            /* "ttygif/tty/viewer.pyx":695
 *                             params = (0,)
 *                         elif command in 'ABCD':
 *                             params = (1,)             # <<<<<<<<<<<<<<
 * 
 *                 if command=='m':
 */
            __Pyx_TraceLine(695,0,__PYX_ERR(0, 695, __pyx_L1_error))
            __Pyx_INCREF(__pyx_tuple__12);
            __Pyx_DECREF_SET(__pyx_v_params, __pyx_tuple__12);

            /* "ttygif/tty/viewer.pyx":694
 *                         if command in 'JKm':
 *                             params = (0,)
 *                         elif command in 'ABCD':             # <<<<<<<<<<<<<<
 *                             params = (1,)
 * 
 */
          }
          __pyx_L15:;

          /* "ttygif/tty/viewer.pyx":691
 * 
 *                     params = tuple(int(p) for p in paramstring.split(';') if len(p) != 0)
 *                     if len(params) == 0:             # <<<<<<<<<<<<<<
 *                         if command in 'JKm':
 *                             params = (0,)
 */
        }
      }
      __pyx_L8:;

      /* "ttygif/tty/viewer.pyx":697
 *                             params = (1,)
 * 
 *                 if command=='m':             # <<<<<<<<<<<<<<
 *                     if 38 in params:
 *                         name="Set FG"
 */
      __Pyx_TraceLine(697,0,__PYX_ERR(0, 697, __pyx_L1_error))
      __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_m, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 697, __pyx_L1_error)
      if (__pyx_t_12) {

        /* "ttygif/tty/viewer.pyx":698
 * 
 *                 if command=='m':
 *                     if 38 in params:             # <<<<<<<<<<<<<<
 *                         name="Set FG"
 *                     elif 48 in params:
 */
        __Pyx_TraceLine(698,0,__PYX_ERR(0, 698, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_int_38, __pyx_v_params, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 698, __pyx_L1_error)
        __pyx_t_11 = (__pyx_t_12 != 0);
        if (__pyx_t_11) {

          /* "ttygif/tty/viewer.pyx":699
 *                 if command=='m':
 *                     if 38 in params:
 *                         name="Set FG"             # <<<<<<<<<<<<<<
 *                     elif 48 in params:
 *                         name="Set BG"
 */
          __Pyx_TraceLine(699,0,__PYX_ERR(0, 699, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Set_FG);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_FG);

          /* "ttygif/tty/viewer.pyx":698
 * 
 *                 if command=='m':
 *                     if 38 in params:             # <<<<<<<<<<<<<<
 *                         name="Set FG"
 *                     elif 48 in params:
 */
          goto __pyx_L17;
        }

        /* "ttygif/tty/viewer.pyx":700
 *                     if 38 in params:
 *                         name="Set FG"
 *                     elif 48 in params:             # <<<<<<<<<<<<<<
 *                         name="Set BG"
 *                     else:
 */
        __Pyx_TraceLine(700,0,__PYX_ERR(0, 700, __pyx_L1_error))
        __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_int_48, __pyx_v_params, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 700, __pyx_L1_error)
        __pyx_t_12 = (__pyx_t_11 != 0);
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":701
 *                         name="Set FG"
 *                     elif 48 in params:
 *                         name="Set BG"             # <<<<<<<<<<<<<<
 *                     else:
 *                         for cmd in params:
 */
          __Pyx_TraceLine(701,0,__PYX_ERR(0, 701, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Set_BG);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_BG);

          /* "ttygif/tty/viewer.pyx":700
 *                     if 38 in params:
 *                         name="Set FG"
 *                     elif 48 in params:             # <<<<<<<<<<<<<<
 *                         name="Set BG"
 *                     else:
 */
          goto __pyx_L17;
        }

        /* "ttygif/tty/viewer.pyx":703
 *                         name="Set BG"
 *                     else:
 *                         for cmd in params:             # <<<<<<<<<<<<<<
 *                             if cmd==0:
 *                                 name="RESET All"
 */
        __Pyx_TraceLine(703,0,__PYX_ERR(0, 703, __pyx_L1_error))
        /*else*/ {
          if (likely(PyList_CheckExact(__pyx_v_params)) || PyTuple_CheckExact(__pyx_v_params)) {
            __pyx_t_6 = __pyx_v_params; __Pyx_INCREF(__pyx_t_6); __pyx_t_13 = 0;
            __pyx_t_14 = NULL;
          } else {
            __pyx_t_13 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_v_params); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 703, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_14 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 703, __pyx_L1_error)
          }
          for (;;) {
            if (likely(!__pyx_t_14)) {
              if (likely(PyList_CheckExact(__pyx_t_6))) {
                if (__pyx_t_13 >= PyList_GET_SIZE(__pyx_t_6)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_13); __Pyx_INCREF(__pyx_t_10); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 703, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_6, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 703, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              } else {
                if (__pyx_t_13 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_13); __Pyx_INCREF(__pyx_t_10); __pyx_t_13++; if (unlikely(0 < 0)) __PYX_ERR(0, 703, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_6, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 703, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              }
            } else {
              __pyx_t_10 = __pyx_t_14(__pyx_t_6);
              if (unlikely(!__pyx_t_10)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 703, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_10);
            }
            __Pyx_XDECREF_SET(__pyx_v_cmd, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "ttygif/tty/viewer.pyx":704
 *                     else:
 *                         for cmd in params:
 *                             if cmd==0:             # <<<<<<<<<<<<<<
 *                                 name="RESET All"
 *                                 reverse_video=None
 */
            __Pyx_TraceLine(704,0,__PYX_ERR(0, 704, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 704, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 704, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":705
 *                         for cmd in params:
 *                             if cmd==0:
 *                                 name="RESET All"             # <<<<<<<<<<<<<<
 *                                 reverse_video=None
 *                             elif cmd==1:
 */
              __Pyx_TraceLine(705,0,__PYX_ERR(0, 705, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_RESET_All);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_RESET_All);

              /* "ttygif/tty/viewer.pyx":706
 *                             if cmd==0:
 *                                 name="RESET All"
 *                                 reverse_video=None             # <<<<<<<<<<<<<<
 *                             elif cmd==1:
 *                                 name="Set BOLD"
 */
              __Pyx_TraceLine(706,0,__PYX_ERR(0, 706, __pyx_L1_error))
              __Pyx_INCREF(Py_None);
              __Pyx_XDECREF_SET(__pyx_v_reverse_video, Py_None);

              /* "ttygif/tty/viewer.pyx":704
 *                     else:
 *                         for cmd in params:
 *                             if cmd==0:             # <<<<<<<<<<<<<<
 *                                 name="RESET All"
 *                                 reverse_video=None
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":707
 *                                 name="RESET All"
 *                                 reverse_video=None
 *                             elif cmd==1:             # <<<<<<<<<<<<<<
 *                                 name="Set BOLD"
 *                             elif cmd==7:
 */
            __Pyx_TraceLine(707,0,__PYX_ERR(0, 707, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 707, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 707, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":708
 *                                 reverse_video=None
 *                             elif cmd==1:
 *                                 name="Set BOLD"             # <<<<<<<<<<<<<<
 *                             elif cmd==7:
 *                                 name="Reverse Video On"
 */
              __Pyx_TraceLine(708,0,__PYX_ERR(0, 708, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Set_BOLD);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_BOLD);

              /* "ttygif/tty/viewer.pyx":707
 *                                 name="RESET All"
 *                                 reverse_video=None
 *                             elif cmd==1:             # <<<<<<<<<<<<<<
 *                                 name="Set BOLD"
 *                             elif cmd==7:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":709
 *                             elif cmd==1:
 *                                 name="Set BOLD"
 *                             elif cmd==7:             # <<<<<<<<<<<<<<
 *                                 name="Reverse Video On"
 *                             elif cmd==27:
 */
            __Pyx_TraceLine(709,0,__PYX_ERR(0, 709, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_7, 7, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 709, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 709, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":710
 *                                 name="Set BOLD"
 *                             elif cmd==7:
 *                                 name="Reverse Video On"             # <<<<<<<<<<<<<<
 *                             elif cmd==27:
 *                                 name="Reverse Video Off"
 */
              __Pyx_TraceLine(710,0,__PYX_ERR(0, 710, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Reverse_Video_On);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Reverse_Video_On);

              /* "ttygif/tty/viewer.pyx":709
 *                             elif cmd==1:
 *                                 name="Set BOLD"
 *                             elif cmd==7:             # <<<<<<<<<<<<<<
 *                                 name="Reverse Video On"
 *                             elif cmd==27:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":711
 *                             elif cmd==7:
 *                                 name="Reverse Video On"
 *                             elif cmd==27:             # <<<<<<<<<<<<<<
 *                                 name="Reverse Video Off"
 *                             elif cmd>=30 and cmd<=37:
 */
            __Pyx_TraceLine(711,0,__PYX_ERR(0, 711, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_27, 27, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 711, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 711, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":712
 *                                 name="Reverse Video On"
 *                             elif cmd==27:
 *                                 name="Reverse Video Off"             # <<<<<<<<<<<<<<
 *                             elif cmd>=30 and cmd<=37:
 *                                 name="Set FG"
 */
              __Pyx_TraceLine(712,0,__PYX_ERR(0, 712, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Reverse_Video_Off);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Reverse_Video_Off);

              /* "ttygif/tty/viewer.pyx":711
 *                             elif cmd==7:
 *                                 name="Reverse Video On"
 *                             elif cmd==27:             # <<<<<<<<<<<<<<
 *                                 name="Reverse Video Off"
 *                             elif cmd>=30 and cmd<=37:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":713
 *                             elif cmd==27:
 *                                 name="Reverse Video Off"
 *                             elif cmd>=30 and cmd<=37:             # <<<<<<<<<<<<<<
 *                                 name="Set FG"
 *                             elif cmd==39:
 */
            __Pyx_TraceLine(713,0,__PYX_ERR(0, 713, __pyx_L1_error))
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_30, Py_GE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 713, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 713, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_11) {
            } else {
              __pyx_t_12 = __pyx_t_11;
              goto __pyx_L21_bool_binop_done;
            }
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_37, Py_LE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 713, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 713, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_12 = __pyx_t_11;
            __pyx_L21_bool_binop_done:;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":714
 *                                 name="Reverse Video Off"
 *                             elif cmd>=30 and cmd<=37:
 *                                 name="Set FG"             # <<<<<<<<<<<<<<
 *                             elif cmd==39:
 *                                 name="Set Default FG"
 */
              __Pyx_TraceLine(714,0,__PYX_ERR(0, 714, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Set_FG);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_FG);

              /* "ttygif/tty/viewer.pyx":713
 *                             elif cmd==27:
 *                                 name="Reverse Video Off"
 *                             elif cmd>=30 and cmd<=37:             # <<<<<<<<<<<<<<
 *                                 name="Set FG"
 *                             elif cmd==39:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":715
 *                             elif cmd>=30 and cmd<=37:
 *                                 name="Set FG"
 *                             elif cmd==39:             # <<<<<<<<<<<<<<
 *                                 name="Set Default FG"
 *                             elif cmd>=40 and cmd<=47:
 */
            __Pyx_TraceLine(715,0,__PYX_ERR(0, 715, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_39, 39, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 715, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 715, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":716
 *                                 name="Set FG"
 *                             elif cmd==39:
 *                                 name="Set Default FG"             # <<<<<<<<<<<<<<
 *                             elif cmd>=40 and cmd<=47:
 *                                 name="Set BG"
 */
              __Pyx_TraceLine(716,0,__PYX_ERR(0, 716, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Set_Default_FG);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_Default_FG);

              /* "ttygif/tty/viewer.pyx":715
 *                             elif cmd>=30 and cmd<=37:
 *                                 name="Set FG"
 *                             elif cmd==39:             # <<<<<<<<<<<<<<
 *                                 name="Set Default FG"
 *                             elif cmd>=40 and cmd<=47:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":717
 *                             elif cmd==39:
 *                                 name="Set Default FG"
 *                             elif cmd>=40 and cmd<=47:             # <<<<<<<<<<<<<<
 *                                 name="Set BG"
 *                             elif cmd==49:
 */
            __Pyx_TraceLine(717,0,__PYX_ERR(0, 717, __pyx_L1_error))
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_40, Py_GE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 717, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 717, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_11) {
            } else {
              __pyx_t_12 = __pyx_t_11;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_47, Py_LE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 717, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 717, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_12 = __pyx_t_11;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":718
 *                                 name="Set Default FG"
 *                             elif cmd>=40 and cmd<=47:
 *                                 name="Set BG"             # <<<<<<<<<<<<<<
 *                             elif cmd==49:
 *                                 name="Set Default BG"
 */
              __Pyx_TraceLine(718,0,__PYX_ERR(0, 718, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Set_BG);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_BG);

              /* "ttygif/tty/viewer.pyx":717
 *                             elif cmd==39:
 *                                 name="Set Default FG"
 *                             elif cmd>=40 and cmd<=47:             # <<<<<<<<<<<<<<
 *                                 name="Set BG"
 *                             elif cmd==49:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":719
 *                             elif cmd>=40 and cmd<=47:
 *                                 name="Set BG"
 *                             elif cmd==49:             # <<<<<<<<<<<<<<
 *                                 name="Set Default BG"
 *                             elif cmd>=90 and cmd<=97:
 */
            __Pyx_TraceLine(719,0,__PYX_ERR(0, 719, __pyx_L1_error))
            __pyx_t_10 = __Pyx_PyInt_EqObjC(__pyx_v_cmd, __pyx_int_49, 49, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 719, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 719, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":720
 *                                 name="Set BG"
 *                             elif cmd==49:
 *                                 name="Set Default BG"             # <<<<<<<<<<<<<<
 *                             elif cmd>=90 and cmd<=97:
 *                                 name="Set High INTENSITY FG"
 */
              __Pyx_TraceLine(720,0,__PYX_ERR(0, 720, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Set_Default_BG);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_Default_BG);

              /* "ttygif/tty/viewer.pyx":719
 *                             elif cmd>=40 and cmd<=47:
 *                                 name="Set BG"
 *                             elif cmd==49:             # <<<<<<<<<<<<<<
 *                                 name="Set Default BG"
 *                             elif cmd>=90 and cmd<=97:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":721
 *                             elif cmd==49:
 *                                 name="Set Default BG"
 *                             elif cmd>=90 and cmd<=97:             # <<<<<<<<<<<<<<
 *                                 name="Set High INTENSITY FG"
 *                             elif cmd>=100 and cmd<=107:
 */
            __Pyx_TraceLine(721,0,__PYX_ERR(0, 721, __pyx_L1_error))
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_90, Py_GE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 721, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 721, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_11) {
            } else {
              __pyx_t_12 = __pyx_t_11;
              goto __pyx_L25_bool_binop_done;
            }
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_97, Py_LE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 721, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 721, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_12 = __pyx_t_11;
            __pyx_L25_bool_binop_done:;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":722
 *                                 name="Set Default BG"
 *                             elif cmd>=90 and cmd<=97:
 *                                 name="Set High INTENSITY FG"             # <<<<<<<<<<<<<<
 *                             elif cmd>=100 and cmd<=107:
 *                                 name="Set High INTENSITY BG"
 */
              __Pyx_TraceLine(722,0,__PYX_ERR(0, 722, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Set_High_INTENSITY_FG);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_High_INTENSITY_FG);

              /* "ttygif/tty/viewer.pyx":721
 *                             elif cmd==49:
 *                                 name="Set Default BG"
 *                             elif cmd>=90 and cmd<=97:             # <<<<<<<<<<<<<<
 *                                 name="Set High INTENSITY FG"
 *                             elif cmd>=100 and cmd<=107:
 */
              goto __pyx_L20;
            }

            /* "ttygif/tty/viewer.pyx":723
 *                             elif cmd>=90 and cmd<=97:
 *                                 name="Set High INTENSITY FG"
 *                             elif cmd>=100 and cmd<=107:             # <<<<<<<<<<<<<<
 *                                 name="Set High INTENSITY BG"
 *                             #self.add_command_sequence(esc_type,command,cmd,groups,name,timestamp)
 */
            __Pyx_TraceLine(723,0,__PYX_ERR(0, 723, __pyx_L1_error))
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_100, Py_GE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 723, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 723, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_11) {
            } else {
              __pyx_t_12 = __pyx_t_11;
              goto __pyx_L27_bool_binop_done;
            }
            __pyx_t_10 = PyObject_RichCompare(__pyx_v_cmd, __pyx_int_107, Py_LE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 723, __pyx_L1_error)
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 723, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_12 = __pyx_t_11;
            __pyx_L27_bool_binop_done:;
            if (__pyx_t_12) {

              /* "ttygif/tty/viewer.pyx":724
 *                                 name="Set High INTENSITY FG"
 *                             elif cmd>=100 and cmd<=107:
 *                                 name="Set High INTENSITY BG"             # <<<<<<<<<<<<<<
 *                             #self.add_command_sequence(esc_type,command,cmd,groups,name,timestamp)
 *                         #continue
 */
              __Pyx_TraceLine(724,0,__PYX_ERR(0, 724, __pyx_L1_error))
              __Pyx_INCREF(__pyx_kp_s_Set_High_INTENSITY_BG);
              __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Set_High_INTENSITY_BG);

              /* "ttygif/tty/viewer.pyx":723
 *                             elif cmd>=90 and cmd<=97:
 *                                 name="Set High INTENSITY FG"
 *                             elif cmd>=100 and cmd<=107:             # <<<<<<<<<<<<<<
 *                                 name="Set High INTENSITY BG"
 *                             #self.add_command_sequence(esc_type,command,cmd,groups,name,timestamp)
 */
            }
            __pyx_L20:;

            /* "ttygif/tty/viewer.pyx":703
 *                         name="Set BG"
 *                     else:
 *                         for cmd in params:             # <<<<<<<<<<<<<<
 *                             if cmd==0:
 *                                 name="RESET All"
 */
            __Pyx_TraceLine(703,0,__PYX_ERR(0, 703, __pyx_L1_error))
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_L17:;

        /* "ttygif/tty/viewer.pyx":697
 *                             params = (1,)
 * 
 *                 if command=='m':             # <<<<<<<<<<<<<<
 *                     if 38 in params:
 *                         name="Set FG"
 */
        goto __pyx_L16;
      }

      /* "ttygif/tty/viewer.pyx":729
 * 
 *                 else:
 *                     if command=='A': # move cursor up             # <<<<<<<<<<<<<<
 *                         name="Cursor Up"
 *                     elif command=='B': # move cursor down
 */
      __Pyx_TraceLine(729,0,__PYX_ERR(0, 729, __pyx_L1_error))
      /*else*/ {
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_A, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 729, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":730
 *                 else:
 *                     if command=='A': # move cursor up
 *                         name="Cursor Up"             # <<<<<<<<<<<<<<
 *                     elif command=='B': # move cursor down
 *                         name="Cursor Down"
 */
          __Pyx_TraceLine(730,0,__PYX_ERR(0, 730, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_Up);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_Up);

          /* "ttygif/tty/viewer.pyx":729
 * 
 *                 else:
 *                     if command=='A': # move cursor up             # <<<<<<<<<<<<<<
 *                         name="Cursor Up"
 *                     elif command=='B': # move cursor down
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":731
 *                     if command=='A': # move cursor up
 *                         name="Cursor Up"
 *                     elif command=='B': # move cursor down             # <<<<<<<<<<<<<<
 *                         name="Cursor Down"
 *                     elif command=='C': # move cursor back
 */
        __Pyx_TraceLine(731,0,__PYX_ERR(0, 731, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_B, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 731, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":732
 *                         name="Cursor Up"
 *                     elif command=='B': # move cursor down
 *                         name="Cursor Down"             # <<<<<<<<<<<<<<
 *                     elif command=='C': # move cursor back
 *                         name="Cursor Right"
 */
          __Pyx_TraceLine(732,0,__PYX_ERR(0, 732, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_Down);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_Down);

          /* "ttygif/tty/viewer.pyx":731
 *                     if command=='A': # move cursor up
 *                         name="Cursor Up"
 *                     elif command=='B': # move cursor down             # <<<<<<<<<<<<<<
 *                         name="Cursor Down"
 *                     elif command=='C': # move cursor back
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":733
 *                     elif command=='B': # move cursor down
 *                         name="Cursor Down"
 *                     elif command=='C': # move cursor back             # <<<<<<<<<<<<<<
 *                         name="Cursor Right"
 *                     elif command=='D': # move cursor right
 */
        __Pyx_TraceLine(733,0,__PYX_ERR(0, 733, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_C, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 733, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":734
 *                         name="Cursor Down"
 *                     elif command=='C': # move cursor back
 *                         name="Cursor Right"             # <<<<<<<<<<<<<<
 *                     elif command=='D': # move cursor right
 *                         name="Cursor Left"
 */
          __Pyx_TraceLine(734,0,__PYX_ERR(0, 734, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_Right);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_Right);

          /* "ttygif/tty/viewer.pyx":733
 *                     elif command=='B': # move cursor down
 *                         name="Cursor Down"
 *                     elif command=='C': # move cursor back             # <<<<<<<<<<<<<<
 *                         name="Cursor Right"
 *                     elif command=='D': # move cursor right
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":735
 *                     elif command=='C': # move cursor back
 *                         name="Cursor Right"
 *                     elif command=='D': # move cursor right             # <<<<<<<<<<<<<<
 *                         name="Cursor Left"
 *                     elif command=='E': # move cursor next line
 */
        __Pyx_TraceLine(735,0,__PYX_ERR(0, 735, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_D, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 735, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":736
 *                         name="Cursor Right"
 *                     elif command=='D': # move cursor right
 *                         name="Cursor Left"             # <<<<<<<<<<<<<<
 *                     elif command=='E': # move cursor next line
 *                         name="Cursor Next Line"
 */
          __Pyx_TraceLine(736,0,__PYX_ERR(0, 736, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_Left);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_Left);

          /* "ttygif/tty/viewer.pyx":735
 *                     elif command=='C': # move cursor back
 *                         name="Cursor Right"
 *                     elif command=='D': # move cursor right             # <<<<<<<<<<<<<<
 *                         name="Cursor Left"
 *                     elif command=='E': # move cursor next line
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":737
 *                     elif command=='D': # move cursor right
 *                         name="Cursor Left"
 *                     elif command=='E': # move cursor next line             # <<<<<<<<<<<<<<
 *                         name="Cursor Next Line"
 *                     elif command=='F': # move cursor previous  line
 */
        __Pyx_TraceLine(737,0,__PYX_ERR(0, 737, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_E, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 737, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":738
 *                         name="Cursor Left"
 *                     elif command=='E': # move cursor next line
 *                         name="Cursor Next Line"             # <<<<<<<<<<<<<<
 *                     elif command=='F': # move cursor previous  line
 *                         name="Cursor Previous Line"
 */
          __Pyx_TraceLine(738,0,__PYX_ERR(0, 738, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_Next_Line);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_Next_Line);

          /* "ttygif/tty/viewer.pyx":737
 *                     elif command=='D': # move cursor right
 *                         name="Cursor Left"
 *                     elif command=='E': # move cursor next line             # <<<<<<<<<<<<<<
 *                         name="Cursor Next Line"
 *                     elif command=='F': # move cursor previous  line
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":739
 *                     elif command=='E': # move cursor next line
 *                         name="Cursor Next Line"
 *                     elif command=='F': # move cursor previous  line             # <<<<<<<<<<<<<<
 *                         name="Cursor Previous Line"
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 */
        __Pyx_TraceLine(739,0,__PYX_ERR(0, 739, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_F, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 739, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":740
 *                         name="Cursor Next Line"
 *                     elif command=='F': # move cursor previous  line
 *                         name="Cursor Previous Line"             # <<<<<<<<<<<<<<
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         name="Cursor X"
 */
          __Pyx_TraceLine(740,0,__PYX_ERR(0, 740, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_Previous_Line);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_Previous_Line);

          /* "ttygif/tty/viewer.pyx":739
 *                     elif command=='E': # move cursor next line
 *                         name="Cursor Next Line"
 *                     elif command=='F': # move cursor previous  line             # <<<<<<<<<<<<<<
 *                         name="Cursor Previous Line"
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":741
 *                     elif command=='F': # move cursor previous  line
 *                         name="Cursor Previous Line"
 *                     elif command=='G': # move cursor to HORIZONTAL pos X             # <<<<<<<<<<<<<<
 *                         name="Cursor X"
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 */
        __Pyx_TraceLine(741,0,__PYX_ERR(0, 741, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_G, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 741, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":742
 *                         name="Cursor Previous Line"
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         name="Cursor X"             # <<<<<<<<<<<<<<
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 *                         name="Cursor Pos"
 */
          __Pyx_TraceLine(742,0,__PYX_ERR(0, 742, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_X);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_X);

          /* "ttygif/tty/viewer.pyx":741
 *                     elif command=='F': # move cursor previous  line
 *                         name="Cursor Previous Line"
 *                     elif command=='G': # move cursor to HORIZONTAL pos X             # <<<<<<<<<<<<<<
 *                         name="Cursor X"
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":743
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         name="Cursor X"
 *                     elif command=='H' or command=='f': # move cursor to x,y pos             # <<<<<<<<<<<<<<
 *                         name="Cursor Pos"
 *                     elif command=='J': # erase display
 */
        __Pyx_TraceLine(743,0,__PYX_ERR(0, 743, __pyx_L1_error))
        __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_H, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 743, __pyx_L1_error)
        if (!__pyx_t_11) {
        } else {
          __pyx_t_12 = __pyx_t_11;
          goto __pyx_L30_bool_binop_done;
        }
        __pyx_t_11 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_f, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 743, __pyx_L1_error)
        __pyx_t_12 = __pyx_t_11;
        __pyx_L30_bool_binop_done:;
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":744
 *                         name="Cursor X"
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 *                         name="Cursor Pos"             # <<<<<<<<<<<<<<
 *                     elif command=='J': # erase display
 *                         name="Erase Display"
 */
          __Pyx_TraceLine(744,0,__PYX_ERR(0, 744, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Cursor_Pos);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Cursor_Pos);

          /* "ttygif/tty/viewer.pyx":743
 *                     elif command=='G': # move cursor to HORIZONTAL pos X
 *                         name="Cursor X"
 *                     elif command=='H' or command=='f': # move cursor to x,y pos             # <<<<<<<<<<<<<<
 *                         name="Cursor Pos"
 *                     elif command=='J': # erase display
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":745
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 *                         name="Cursor Pos"
 *                     elif command=='J': # erase display             # <<<<<<<<<<<<<<
 *                         name="Erase Display"
 *                     elif command=='K': # erase line
 */
        __Pyx_TraceLine(745,0,__PYX_ERR(0, 745, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_J, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 745, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":746
 *                         name="Cursor Pos"
 *                     elif command=='J': # erase display
 *                         name="Erase Display"             # <<<<<<<<<<<<<<
 *                     elif command=='K': # erase line
 *                         name="Erase Line"
 */
          __Pyx_TraceLine(746,0,__PYX_ERR(0, 746, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Erase_Display);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Erase_Display);

          /* "ttygif/tty/viewer.pyx":745
 *                     elif command=='H' or command=='f': # move cursor to x,y pos
 *                         name="Cursor Pos"
 *                     elif command=='J': # erase display             # <<<<<<<<<<<<<<
 *                         name="Erase Display"
 *                     elif command=='K': # erase line
 */
          goto __pyx_L29;
        }

        /* "ttygif/tty/viewer.pyx":747
 *                     elif command=='J': # erase display
 *                         name="Erase Display"
 *                     elif command=='K': # erase line             # <<<<<<<<<<<<<<
 *                         name="Erase Line"
 *                 self.add_command_sequence(esc_type,command,params,groups,name,timestamp,delay)
 */
        __Pyx_TraceLine(747,0,__PYX_ERR(0, 747, __pyx_L1_error))
        __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_v_command, __pyx_n_s_K, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 747, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ttygif/tty/viewer.pyx":748
 *                         name="Erase Display"
 *                     elif command=='K': # erase line
 *                         name="Erase Line"             # <<<<<<<<<<<<<<
 *                 self.add_command_sequence(esc_type,command,params,groups,name,timestamp,delay)
 * 
 */
          __Pyx_TraceLine(748,0,__PYX_ERR(0, 748, __pyx_L1_error))
          __Pyx_INCREF(__pyx_kp_s_Erase_Line);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_kp_s_Erase_Line);

          /* "ttygif/tty/viewer.pyx":747
 *                     elif command=='J': # erase display
 *                         name="Erase Display"
 *                     elif command=='K': # erase line             # <<<<<<<<<<<<<<
 *                         name="Erase Line"
 *                 self.add_command_sequence(esc_type,command,params,groups,name,timestamp,delay)
 */
        }
        __pyx_L29:;
      }
      __pyx_L16:;

      /* "ttygif/tty/viewer.pyx":749
 *                     elif command=='K': # erase line
 *                         name="Erase Line"
 *                 self.add_command_sequence(esc_type,command,params,groups,name,timestamp,delay)             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_TraceLine(749,0,__PYX_ERR(0, 749, __pyx_L1_error))
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_add_command_sequence); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_1 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[8] = {__pyx_t_1, __pyx_v_esc_type, __pyx_v_command, __pyx_v_params, __pyx_v_groups, __pyx_v_name, __pyx_v_timestamp, __pyx_v_delay};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_9, 7+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 749, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[8] = {__pyx_t_1, __pyx_v_esc_type, __pyx_v_command, __pyx_v_params, __pyx_v_groups, __pyx_v_name, __pyx_v_timestamp, __pyx_v_delay};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_9, 7+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 749, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(7+__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(__pyx_v_esc_type);
        __Pyx_GIVEREF(__pyx_v_esc_type);
        PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_9, __pyx_v_esc_type);
        __Pyx_INCREF(__pyx_v_command);
        __Pyx_GIVEREF(__pyx_v_command);
        PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_9, __pyx_v_command);
        __Pyx_INCREF(__pyx_v_params);
        __Pyx_GIVEREF(__pyx_v_params);
        PyTuple_SET_ITEM(__pyx_t_2, 2+__pyx_t_9, __pyx_v_params);
        __Pyx_INCREF(__pyx_v_groups);
        __Pyx_GIVEREF(__pyx_v_groups);
        PyTuple_SET_ITEM(__pyx_t_2, 3+__pyx_t_9, __pyx_v_groups);
        __Pyx_INCREF(__pyx_v_name);
        __Pyx_GIVEREF(__pyx_v_name);
        PyTuple_SET_ITEM(__pyx_t_2, 4+__pyx_t_9, __pyx_v_name);
        __Pyx_INCREF(__pyx_v_timestamp);
        __Pyx_GIVEREF(__pyx_v_timestamp);
        PyTuple_SET_ITEM(__pyx_t_2, 5+__pyx_t_9, __pyx_v_timestamp);
        __Pyx_INCREF(__pyx_v_delay);
        __Pyx_GIVEREF(__pyx_v_delay);
        PyTuple_SET_ITEM(__pyx_t_2, 6+__pyx_t_9, __pyx_v_delay);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "ttygif/tty/viewer.pyx":677
 *                 params=[groups[11]]
 * 
 *             elif groups[8]:             # <<<<<<<<<<<<<<
 *                 esc_type='CSI'
 *                 paramstring=groups[9]
 */
    }
    __pyx_L7:;

    /* "ttygif/tty/viewer.pyx":651
 *         ANSI=re.compile(ANSI_REGEX)
 *         cursor=0
 *         for match in ANSI.finditer(text):             # <<<<<<<<<<<<<<
 *             name=""
 *             start, end = match.span()
 */
    __Pyx_TraceLine(651,0,__PYX_ERR(0, 651, __pyx_L1_error))
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "ttygif/tty/viewer.pyx":752
 * 
 * 
 *         if self.has_escape(text[cursor:]):             # <<<<<<<<<<<<<<
 *             #print ("EXTRA")
 *             #print text[cursor:]
 */
  __Pyx_TraceLine(752,0,__PYX_ERR(0, 752, __pyx_L1_error))
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_has_escape); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_10 = __Pyx_PyObject_GetSlice(__pyx_v_text, 0, 0, &__pyx_v_cursor, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_2, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_10);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_12) {

    /* "ttygif/tty/viewer.pyx":755
 *             #print ("EXTRA")
 *             #print text[cursor:]
 *             self.extra_text=text[cursor:]             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_TraceLine(755,0,__PYX_ERR(0, 755, __pyx_L1_error))
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_text, 0, 0, &__pyx_v_cursor, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->extra_text);
    __Pyx_DECREF(__pyx_v_self->extra_text);
    __pyx_v_self->extra_text = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "ttygif/tty/viewer.pyx":752
 * 
 * 
 *         if self.has_escape(text[cursor:]):             # <<<<<<<<<<<<<<
 *             #print ("EXTRA")
 *             #print text[cursor:]
 */
    goto __pyx_L32;
  }

  /* "ttygif/tty/viewer.pyx":760
 *             #print ("NO EXTRA")
 *             #print text[cursor:]
 *             self.extra_text=""             # <<<<<<<<<<<<<<
 *             #print("->",text[cursor:])
 *             self.add_text_sequence(text[cursor:],timestamp,0)
 */
  __Pyx_TraceLine(760,0,__PYX_ERR(0, 760, __pyx_L1_error))
  /*else*/ {
    __Pyx_INCREF(__pyx_kp_s_);
    __Pyx_GIVEREF(__pyx_kp_s_);
    __Pyx_GOTREF(__pyx_v_self->extra_text);
    __Pyx_DECREF(__pyx_v_self->extra_text);
    __pyx_v_self->extra_text = __pyx_kp_s_;

    /* "ttygif/tty/viewer.pyx":762
 *             self.extra_text=""
 *             #print("->",text[cursor:])
 *             self.add_text_sequence(text[cursor:],timestamp,0)             # <<<<<<<<<<<<<<
 * 
 *     def last_frame(self):
 */
    __Pyx_TraceLine(762,0,__PYX_ERR(0, 762, __pyx_L1_error))
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_add_text_sequence); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 762, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = __Pyx_PyObject_GetSlice(__pyx_v_text, 0, 0, &__pyx_v_cursor, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 762, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_9 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_t_10, __pyx_v_timestamp, __pyx_int_0};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 762, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_t_10, __pyx_v_timestamp, __pyx_int_0};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 762, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__pyx_t_2) {
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2); __pyx_t_2 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_9, __pyx_t_10);
      __Pyx_INCREF(__pyx_v_timestamp);
      __Pyx_GIVEREF(__pyx_v_timestamp);
      PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_9, __pyx_v_timestamp);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_9, __pyx_int_0);
      __pyx_t_10 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L32:;

  /* "ttygif/tty/viewer.pyx":631
 * 
 * 
 *     cdef stream_2_sequence(self,text,timestamp,delay):             # <<<<<<<<<<<<<<
 * 
 *         # patterns for filtering out commands from the stream
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.stream_2_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ANSI_SINGLE);
  __Pyx_XDECREF(__pyx_v_ANSI_CHAR_SET);
  __Pyx_XDECREF(__pyx_v_ANSI_G0);
  __Pyx_XDECREF(__pyx_v_ANSI_G1);
  __Pyx_XDECREF(__pyx_v_ANSI_CSI_RE);
  __Pyx_XDECREF(__pyx_v_ANSI_OSC);
  __Pyx_XDECREF(__pyx_v_ESC_SEQUENCES);
  __Pyx_XDECREF(__pyx_v_ANSI_REGEX);
  __Pyx_XDECREF(__pyx_v_ANSI);
  __Pyx_XDECREF(__pyx_v_cursor);
  __Pyx_XDECREF(__pyx_v_match);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_end);
  __Pyx_XDECREF(__pyx_v_command);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_esc_type);
  __Pyx_XDECREF(__pyx_v_groups);
  __Pyx_XDECREF(__pyx_v_cmd);
  __Pyx_XDECREF(__pyx_v_reverse_video);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":764
 *             self.add_text_sequence(text[cursor:],timestamp,0)
 * 
 *     def last_frame(self):             # <<<<<<<<<<<<<<
 *         self.add_text_sequence(self.extra_text,self.last_timestamp,0)
 *         self.extra_text=""
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_15last_frame(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_15last_frame(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("last_frame (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_frame(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_frame(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("last_frame", 0);
  __Pyx_TraceCall("last_frame", __pyx_f[0], 764, 0, __PYX_ERR(0, 764, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":765
 * 
 *     def last_frame(self):
 *         self.add_text_sequence(self.extra_text,self.last_timestamp,0)             # <<<<<<<<<<<<<<
 *         self.extra_text=""
 * 
 */
  __Pyx_TraceLine(765,0,__PYX_ERR(0, 765, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_add_text_sequence); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_self->extra_text, __pyx_v_self->last_timestamp, __pyx_int_0};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_self->extra_text, __pyx_v_self->last_timestamp, __pyx_int_0};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(3+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_self->extra_text);
    __Pyx_GIVEREF(__pyx_v_self->extra_text);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_self->extra_text);
    __Pyx_INCREF(__pyx_v_self->last_timestamp);
    __Pyx_GIVEREF(__pyx_v_self->last_timestamp);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_self->last_timestamp);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, __pyx_int_0);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":766
 *     def last_frame(self):
 *         self.add_text_sequence(self.extra_text,self.last_timestamp,0)
 *         self.extra_text=""             # <<<<<<<<<<<<<<
 * 
 *     def has_escape(self,text):
 */
  __Pyx_TraceLine(766,0,__PYX_ERR(0, 766, __pyx_L1_error))
  __Pyx_INCREF(__pyx_kp_s_);
  __Pyx_GIVEREF(__pyx_kp_s_);
  __Pyx_GOTREF(__pyx_v_self->extra_text);
  __Pyx_DECREF(__pyx_v_self->extra_text);
  __pyx_v_self->extra_text = __pyx_kp_s_;

  /* "ttygif/tty/viewer.pyx":764
 *             self.add_text_sequence(text[cursor:],timestamp,0)
 * 
 *     def last_frame(self):             # <<<<<<<<<<<<<<
 *         self.add_text_sequence(self.extra_text,self.last_timestamp,0)
 *         self.extra_text=""
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.last_frame", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":768
 *         self.extra_text=""
 * 
 *     def has_escape(self,text):             # <<<<<<<<<<<<<<
 *         for i in text:
 *             if ord(i)==0x1B:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_17has_escape(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_17has_escape(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("has_escape (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_16has_escape(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_16has_escape(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  long __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("has_escape", 0);
  __Pyx_TraceCall("has_escape", __pyx_f[0], 768, 0, __PYX_ERR(0, 768, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":769
 * 
 *     def has_escape(self,text):
 *         for i in text:             # <<<<<<<<<<<<<<
 *             if ord(i)==0x1B:
 *                 return True
 */
  __Pyx_TraceLine(769,0,__PYX_ERR(0, 769, __pyx_L1_error))
  if (likely(PyList_CheckExact(__pyx_v_text)) || PyTuple_CheckExact(__pyx_v_text)) {
    __pyx_t_1 = __pyx_v_text; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 769, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 769, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 769, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 769, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 769, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 769, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "ttygif/tty/viewer.pyx":770
 *     def has_escape(self,text):
 *         for i in text:
 *             if ord(i)==0x1B:             # <<<<<<<<<<<<<<
 *                 return True
 *         return None
 */
    __Pyx_TraceLine(770,0,__PYX_ERR(0, 770, __pyx_L1_error))
    __pyx_t_5 = __Pyx_PyObject_Ord(__pyx_v_i); if (unlikely(__pyx_t_5 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 770, __pyx_L1_error)
    __pyx_t_6 = ((__pyx_t_5 == 0x1B) != 0);
    if (__pyx_t_6) {

      /* "ttygif/tty/viewer.pyx":771
 *         for i in text:
 *             if ord(i)==0x1B:
 *                 return True             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
      __Pyx_TraceLine(771,0,__PYX_ERR(0, 771, __pyx_L1_error))
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "ttygif/tty/viewer.pyx":770
 *     def has_escape(self,text):
 *         for i in text:
 *             if ord(i)==0x1B:             # <<<<<<<<<<<<<<
 *                 return True
 *         return None
 */
    }

    /* "ttygif/tty/viewer.pyx":769
 * 
 *     def has_escape(self,text):
 *         for i in text:             # <<<<<<<<<<<<<<
 *             if ord(i)==0x1B:
 *                 return True
 */
    __Pyx_TraceLine(769,0,__PYX_ERR(0, 769, __pyx_L1_error))
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":772
 *             if ord(i)==0x1B:
 *                 return True
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def clear_sequence(self):
 */
  __Pyx_TraceLine(772,0,__PYX_ERR(0, 772, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":768
 *         self.extra_text=""
 * 
 *     def has_escape(self,text):             # <<<<<<<<<<<<<<
 *         for i in text:
 *             if ord(i)==0x1B:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.has_escape", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":774
 *         return None
 * 
 *     def clear_sequence(self):             # <<<<<<<<<<<<<<
 *         self.sequence=[]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_19clear_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_19clear_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_18clear_sequence(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_18clear_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("clear_sequence", 0);
  __Pyx_TraceCall("clear_sequence", __pyx_f[0], 774, 0, __PYX_ERR(0, 774, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":775
 * 
 *     def clear_sequence(self):
 *         self.sequence=[]             # <<<<<<<<<<<<<<
 * 
 *     cdef remap_character(self,character):
 */
  __Pyx_TraceLine(775,0,__PYX_ERR(0, 775, __pyx_L1_error))
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":774
 *         return None
 * 
 *     def clear_sequence(self):             # <<<<<<<<<<<<<<
 *         self.sequence=[]
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.clear_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":777
 *         self.sequence=[]
 * 
 *     cdef remap_character(self,character):             # <<<<<<<<<<<<<<
 *       #print character
 *         #print character
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_remap_character(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_character) {
  int __pyx_v_c;
  int __pyx_v_replacment_char;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("remap_character", 0);
  __Pyx_TraceCall("remap_character", __pyx_f[0], 777, 0, __PYX_ERR(0, 777, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":780
 *       #print character
 *         #print character
 *         cdef int c=ord(character)             # <<<<<<<<<<<<<<
 *         cdef int replacment_char=ord('*')
 *         if c>255:
 */
  __Pyx_TraceLine(780,0,__PYX_ERR(0, 780, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyObject_Ord(__pyx_v_character); if (unlikely(__pyx_t_1 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 780, __pyx_L1_error)
  __pyx_v_c = __pyx_t_1;

  /* "ttygif/tty/viewer.pyx":781
 *         #print character
 *         cdef int c=ord(character)
 *         cdef int replacment_char=ord('*')             # <<<<<<<<<<<<<<
 *         if c>255:
 *             if c==8216:
 */
  __Pyx_TraceLine(781,0,__PYX_ERR(0, 781, __pyx_L1_error))
  __pyx_v_replacment_char = 42;

  /* "ttygif/tty/viewer.pyx":782
 *         cdef int c=ord(character)
 *         cdef int replacment_char=ord('*')
 *         if c>255:             # <<<<<<<<<<<<<<
 *             if c==8216:
 *                 c=39
 */
  __Pyx_TraceLine(782,0,__PYX_ERR(0, 782, __pyx_L1_error))
  __pyx_t_2 = ((__pyx_v_c > 0xFF) != 0);
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":783
 *         cdef int replacment_char=ord('*')
 *         if c>255:
 *             if c==8216:             # <<<<<<<<<<<<<<
 *                 c=39
 *             elif c==8217:
 */
    __Pyx_TraceLine(783,0,__PYX_ERR(0, 783, __pyx_L1_error))
    switch (__pyx_v_c) {
      case 0x2018:

      /* "ttygif/tty/viewer.pyx":784
 *         if c>255:
 *             if c==8216:
 *                 c=39             # <<<<<<<<<<<<<<
 *             elif c==8217:
 *                 c=39
 */
      __Pyx_TraceLine(784,0,__PYX_ERR(0, 784, __pyx_L1_error))
      __pyx_v_c = 39;

      /* "ttygif/tty/viewer.pyx":783
 *         cdef int replacment_char=ord('*')
 *         if c>255:
 *             if c==8216:             # <<<<<<<<<<<<<<
 *                 c=39
 *             elif c==8217:
 */
      break;
      case 0x2019:

      /* "ttygif/tty/viewer.pyx":786
 *                 c=39
 *             elif c==8217:
 *                 c=39             # <<<<<<<<<<<<<<
 *             elif c==9472:
 *                 c=196
 */
      __Pyx_TraceLine(786,0,__PYX_ERR(0, 786, __pyx_L1_error))
      __pyx_v_c = 39;

      /* "ttygif/tty/viewer.pyx":785
 *             if c==8216:
 *                 c=39
 *             elif c==8217:             # <<<<<<<<<<<<<<
 *                 c=39
 *             elif c==9472:
 */
      break;
      case 0x2500:

      /* "ttygif/tty/viewer.pyx":788
 *                 c=39
 *             elif c==9472:
 *                 c=196             # <<<<<<<<<<<<<<
 *             elif c==9474:
 *                 c=179
 */
      __Pyx_TraceLine(788,0,__PYX_ERR(0, 788, __pyx_L1_error))
      __pyx_v_c = 0xC4;

      /* "ttygif/tty/viewer.pyx":787
 *             elif c==8217:
 *                 c=39
 *             elif c==9472:             # <<<<<<<<<<<<<<
 *                 c=196
 *             elif c==9474:
 */
      break;
      case 0x2502:

      /* "ttygif/tty/viewer.pyx":790
 *                 c=196
 *             elif c==9474:
 *                 c=179             # <<<<<<<<<<<<<<
 *             elif c==9484:
 *                 c=218
 */
      __Pyx_TraceLine(790,0,__PYX_ERR(0, 790, __pyx_L1_error))
      __pyx_v_c = 0xB3;

      /* "ttygif/tty/viewer.pyx":789
 *             elif c==9472:
 *                 c=196
 *             elif c==9474:             # <<<<<<<<<<<<<<
 *                 c=179
 *             elif c==9484:
 */
      break;
      case 0x250C:

      /* "ttygif/tty/viewer.pyx":792
 *                 c=179
 *             elif c==9484:
 *                 c=218             # <<<<<<<<<<<<<<
 *             elif c==9488:
 *                 c=191
 */
      __Pyx_TraceLine(792,0,__PYX_ERR(0, 792, __pyx_L1_error))
      __pyx_v_c = 0xDA;

      /* "ttygif/tty/viewer.pyx":791
 *             elif c==9474:
 *                 c=179
 *             elif c==9484:             # <<<<<<<<<<<<<<
 *                 c=218
 *             elif c==9488:
 */
      break;
      case 0x2510:

      /* "ttygif/tty/viewer.pyx":794
 *                 c=218
 *             elif c==9488:
 *                 c=191             # <<<<<<<<<<<<<<
 *             elif c==9492:
 *                 c=192
 */
      __Pyx_TraceLine(794,0,__PYX_ERR(0, 794, __pyx_L1_error))
      __pyx_v_c = 0xBF;

      /* "ttygif/tty/viewer.pyx":793
 *             elif c==9484:
 *                 c=218
 *             elif c==9488:             # <<<<<<<<<<<<<<
 *                 c=191
 *             elif c==9492:
 */
      break;
      case 0x2514:

      /* "ttygif/tty/viewer.pyx":796
 *                 c=191
 *             elif c==9492:
 *                 c=192             # <<<<<<<<<<<<<<
 *             elif c==9496:
 *                 c=217
 */
      __Pyx_TraceLine(796,0,__PYX_ERR(0, 796, __pyx_L1_error))
      __pyx_v_c = 0xC0;

      /* "ttygif/tty/viewer.pyx":795
 *             elif c==9488:
 *                 c=191
 *             elif c==9492:             # <<<<<<<<<<<<<<
 *                 c=192
 *             elif c==9496:
 */
      break;
      case 0x2518:

      /* "ttygif/tty/viewer.pyx":798
 *                 c=192
 *             elif c==9496:
 *                 c=217             # <<<<<<<<<<<<<<
 *             elif c==9600:
 *                 c=223
 */
      __Pyx_TraceLine(798,0,__PYX_ERR(0, 798, __pyx_L1_error))
      __pyx_v_c = 0xD9;

      /* "ttygif/tty/viewer.pyx":797
 *             elif c==9492:
 *                 c=192
 *             elif c==9496:             # <<<<<<<<<<<<<<
 *                 c=217
 *             elif c==9600:
 */
      break;
      case 0x2580:

      /* "ttygif/tty/viewer.pyx":800
 *                 c=217
 *             elif c==9600:
 *                 c=223             # <<<<<<<<<<<<<<
 *             elif c==9604:
 *                 c=220
 */
      __Pyx_TraceLine(800,0,__PYX_ERR(0, 800, __pyx_L1_error))
      __pyx_v_c = 0xDF;

      /* "ttygif/tty/viewer.pyx":799
 *             elif c==9496:
 *                 c=217
 *             elif c==9600:             # <<<<<<<<<<<<<<
 *                 c=223
 *             elif c==9604:
 */
      break;
      case 0x2584:

      /* "ttygif/tty/viewer.pyx":802
 *                 c=223
 *             elif c==9604:
 *                 c=220             # <<<<<<<<<<<<<<
 *             elif c==9608:
 *                 c=219
 */
      __Pyx_TraceLine(802,0,__PYX_ERR(0, 802, __pyx_L1_error))
      __pyx_v_c = 0xDC;

      /* "ttygif/tty/viewer.pyx":801
 *             elif c==9600:
 *                 c=223
 *             elif c==9604:             # <<<<<<<<<<<<<<
 *                 c=220
 *             elif c==9608:
 */
      break;
      case 0x2588:

      /* "ttygif/tty/viewer.pyx":804
 *                 c=220
 *             elif c==9608:
 *                 c=219             # <<<<<<<<<<<<<<
 *             elif c==9612:
 *                 c=221
 */
      __Pyx_TraceLine(804,0,__PYX_ERR(0, 804, __pyx_L1_error))
      __pyx_v_c = 0xDB;

      /* "ttygif/tty/viewer.pyx":803
 *             elif c==9604:
 *                 c=220
 *             elif c==9608:             # <<<<<<<<<<<<<<
 *                 c=219
 *             elif c==9612:
 */
      break;
      case 0x258C:

      /* "ttygif/tty/viewer.pyx":806
 *                 c=219
 *             elif c==9612:
 *                 c=221             # <<<<<<<<<<<<<<
 *             elif c==9616:
 *                 c=222
 */
      __Pyx_TraceLine(806,0,__PYX_ERR(0, 806, __pyx_L1_error))
      __pyx_v_c = 0xDD;

      /* "ttygif/tty/viewer.pyx":805
 *             elif c==9608:
 *                 c=219
 *             elif c==9612:             # <<<<<<<<<<<<<<
 *                 c=221
 *             elif c==9616:
 */
      break;
      case 0x2590:

      /* "ttygif/tty/viewer.pyx":808
 *                 c=221
 *             elif c==9616:
 *                 c=222             # <<<<<<<<<<<<<<
 *             elif c==9617:
 *                 c=176
 */
      __Pyx_TraceLine(808,0,__PYX_ERR(0, 808, __pyx_L1_error))
      __pyx_v_c = 0xDE;

      /* "ttygif/tty/viewer.pyx":807
 *             elif c==9612:
 *                 c=221
 *             elif c==9616:             # <<<<<<<<<<<<<<
 *                 c=222
 *             elif c==9617:
 */
      break;
      case 0x2591:

      /* "ttygif/tty/viewer.pyx":810
 *                 c=222
 *             elif c==9617:
 *                 c=176             # <<<<<<<<<<<<<<
 *             elif c==9618:
 *                 c=177
 */
      __Pyx_TraceLine(810,0,__PYX_ERR(0, 810, __pyx_L1_error))
      __pyx_v_c = 0xB0;

      /* "ttygif/tty/viewer.pyx":809
 *             elif c==9616:
 *                 c=222
 *             elif c==9617:             # <<<<<<<<<<<<<<
 *                 c=176
 *             elif c==9618:
 */
      break;
      case 0x2592:

      /* "ttygif/tty/viewer.pyx":812
 *                 c=176
 *             elif c==9618:
 *                 c=177             # <<<<<<<<<<<<<<
 *             elif c==10140:
 *                 c=26
 */
      __Pyx_TraceLine(812,0,__PYX_ERR(0, 812, __pyx_L1_error))
      __pyx_v_c = 0xB1;

      /* "ttygif/tty/viewer.pyx":811
 *             elif c==9617:
 *                 c=176
 *             elif c==9618:             # <<<<<<<<<<<<<<
 *                 c=177
 *             elif c==10140:
 */
      break;
      case 0x279C:

      /* "ttygif/tty/viewer.pyx":814
 *                 c=177
 *             elif c==10140:
 *                 c=26             # <<<<<<<<<<<<<<
 *             else:
 *                 print ("Missing character: {0}".format(c))
 */
      __Pyx_TraceLine(814,0,__PYX_ERR(0, 814, __pyx_L1_error))
      __pyx_v_c = 26;

      /* "ttygif/tty/viewer.pyx":813
 *             elif c==9618:
 *                 c=177
 *             elif c==10140:             # <<<<<<<<<<<<<<
 *                 c=26
 *             else:
 */
      break;
      default:

      /* "ttygif/tty/viewer.pyx":816
 *                 c=26
 *             else:
 *                 print ("Missing character: {0}".format(c))             # <<<<<<<<<<<<<<
 *                 return unichr(replacment_char)
 *         else:
 */
      __Pyx_TraceLine(816,0,__PYX_ERR(0, 816, __pyx_L1_error))
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Missing_character_0, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_c); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PrintOne(0, __pyx_t_3) < 0) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "ttygif/tty/viewer.pyx":817
 *             else:
 *                 print ("Missing character: {0}".format(c))
 *                 return unichr(replacment_char)             # <<<<<<<<<<<<<<
 *         else:
 *             return character
 */
      __Pyx_TraceLine(817,0,__PYX_ERR(0, 817, __pyx_L1_error))
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_replacment_char); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_unichr, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;
      break;
    }

    /* "ttygif/tty/viewer.pyx":782
 *         cdef int c=ord(character)
 *         cdef int replacment_char=ord('*')
 *         if c>255:             # <<<<<<<<<<<<<<
 *             if c==8216:
 *                 c=39
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":819
 *                 return unichr(replacment_char)
 *         else:
 *             return character             # <<<<<<<<<<<<<<
 *         return unichr(c)
 * 
 */
  __Pyx_TraceLine(819,0,__PYX_ERR(0, 819, __pyx_L1_error))
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_character);
    __pyx_r = __pyx_v_character;
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "ttygif/tty/viewer.pyx":820
 *         else:
 *             return character
 *         return unichr(c)             # <<<<<<<<<<<<<<
 * 
 *     def add_text_sequence(self,text,timestamp,delay):
 */
  __Pyx_TraceLine(820,0,__PYX_ERR(0, 820, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_c); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_unichr, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":777
 *         self.sequence=[]
 * 
 *     cdef remap_character(self,character):             # <<<<<<<<<<<<<<
 *       #print character
 *         #print character
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.remap_character", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":822
 *         return unichr(c)
 * 
 *     def add_text_sequence(self,text,timestamp,delay):             # <<<<<<<<<<<<<<
 *         if len(text)==0:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_21add_text_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_21add_text_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_timestamp = 0;
  PyObject *__pyx_v_delay = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_text_sequence (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_text,&__pyx_n_s_timestamp,&__pyx_n_s_delay,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_text)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_timestamp)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_text_sequence", 1, 3, 3, 1); __PYX_ERR(0, 822, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_delay)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_text_sequence", 1, 3, 3, 2); __PYX_ERR(0, 822, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "add_text_sequence") < 0)) __PYX_ERR(0, 822, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_text = values[0];
    __pyx_v_timestamp = values[1];
    __pyx_v_delay = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_text_sequence", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 822, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.add_text_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_20add_text_sequence(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), __pyx_v_text, __pyx_v_timestamp, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_20add_text_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_timestamp, PyObject *__pyx_v_delay) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("add_text_sequence", 0);
  __Pyx_TraceCall("add_text_sequence", __pyx_f[0], 822, 0, __PYX_ERR(0, 822, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_text);

  /* "ttygif/tty/viewer.pyx":823
 * 
 *     def add_text_sequence(self,text,timestamp,delay):
 *         if len(text)==0:             # <<<<<<<<<<<<<<
 *             return
 *         #print "1",text
 */
  __Pyx_TraceLine(823,0,__PYX_ERR(0, 823, __pyx_L1_error))
  __pyx_t_1 = PyObject_Length(__pyx_v_text); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 823, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 == 0) != 0);
  if (__pyx_t_2) {

    /* "ttygif/tty/viewer.pyx":824
 *     def add_text_sequence(self,text,timestamp,delay):
 *         if len(text)==0:
 *             return             # <<<<<<<<<<<<<<
 *         #print "1",text
 *         #remapped=[u' ']*len(text)
 */
    __Pyx_TraceLine(824,0,__PYX_ERR(0, 824, __pyx_L1_error))
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "ttygif/tty/viewer.pyx":823
 * 
 *     def add_text_sequence(self,text,timestamp,delay):
 *         if len(text)==0:             # <<<<<<<<<<<<<<
 *             return
 *         #print "1",text
 */
  }

  /* "ttygif/tty/viewer.pyx":832
 *         #    remapped[i]=r
 *         #text="".join(remapped)
 *         text=[self.remap_character(i) for i in text]             # <<<<<<<<<<<<<<
 *         #if self.debug_mode:
 *         #    self.info ("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(text),len(text),timestamp))
 */
  __Pyx_TraceLine(832,0,__PYX_ERR(0, 832, __pyx_L1_error))
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_v_text)) || PyTuple_CheckExact(__pyx_v_text)) {
    __pyx_t_4 = __pyx_v_text; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 832, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 832, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 832, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 832, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 832, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_5(__pyx_t_4);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 832, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->remap_character(__pyx_v_self, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 832, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "ttygif/tty/viewer.pyx":835
 *         #if self.debug_mode:
 *         #    self.info ("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(text),len(text),timestamp))
 *         self.sequence.append({'type':'text','data':text,'timestamp':timestamp,'delay':delay})             # <<<<<<<<<<<<<<
 * 
 *     def add_command_sequence(self,esc_type,command,params,groups,name,timestamp,delay):
 */
  __Pyx_TraceLine(835,0,__PYX_ERR(0, 835, __pyx_L1_error))
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_type, __pyx_n_s_text) < 0) __PYX_ERR(0, 835, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_data, __pyx_v_text) < 0) __PYX_ERR(0, 835, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_timestamp, __pyx_v_timestamp) < 0) __PYX_ERR(0, 835, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_delay, __pyx_v_delay) < 0) __PYX_ERR(0, 835, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Append(__pyx_v_self->sequence, __pyx_t_3); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "ttygif/tty/viewer.pyx":822
 *         return unichr(c)
 * 
 *     def add_text_sequence(self,text,timestamp,delay):             # <<<<<<<<<<<<<<
 *         if len(text)==0:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.add_text_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":837
 *         self.sequence.append({'type':'text','data':text,'timestamp':timestamp,'delay':delay})
 * 
 *     def add_command_sequence(self,esc_type,command,params,groups,name,timestamp,delay):             # <<<<<<<<<<<<<<
 *         #if self.debug_mode:
 *         #    self.info("CMD:  '{0}', Name:'{3}', Command:{1}, Params:{2}  Timestamp:{4}".format(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_23add_command_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_23add_command_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_esc_type = 0;
  PyObject *__pyx_v_command = 0;
  PyObject *__pyx_v_params = 0;
  PyObject *__pyx_v_groups = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_timestamp = 0;
  PyObject *__pyx_v_delay = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_command_sequence (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_esc_type,&__pyx_n_s_command,&__pyx_n_s_params,&__pyx_n_s_groups,&__pyx_n_s_name,&__pyx_n_s_timestamp,&__pyx_n_s_delay,0};
    PyObject* values[7] = {0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_esc_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_command)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_command_sequence", 1, 7, 7, 1); __PYX_ERR(0, 837, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_params)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_command_sequence", 1, 7, 7, 2); __PYX_ERR(0, 837, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_groups)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_command_sequence", 1, 7, 7, 3); __PYX_ERR(0, 837, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_command_sequence", 1, 7, 7, 4); __PYX_ERR(0, 837, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_timestamp)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_command_sequence", 1, 7, 7, 5); __PYX_ERR(0, 837, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_delay)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_command_sequence", 1, 7, 7, 6); __PYX_ERR(0, 837, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "add_command_sequence") < 0)) __PYX_ERR(0, 837, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 7) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
    }
    __pyx_v_esc_type = values[0];
    __pyx_v_command = values[1];
    __pyx_v_params = values[2];
    __pyx_v_groups = values[3];
    __pyx_v_name = values[4];
    __pyx_v_timestamp = values[5];
    __pyx_v_delay = values[6];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_command_sequence", 1, 7, 7, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 837, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.add_command_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_22add_command_sequence(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), __pyx_v_esc_type, __pyx_v_command, __pyx_v_params, __pyx_v_groups, __pyx_v_name, __pyx_v_timestamp, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_22add_command_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_esc_type, PyObject *__pyx_v_command, PyObject *__pyx_v_params, PyObject *__pyx_v_groups, PyObject *__pyx_v_name, PyObject *__pyx_v_timestamp, PyObject *__pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("add_command_sequence", 0);
  __Pyx_TraceCall("add_command_sequence", __pyx_f[0], 837, 0, __PYX_ERR(0, 837, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":845
 *         #                                        name,
 *         #                                        timestamp))
 *         self.sequence.append({'type':'command','esc_type':esc_type,'command':command,'params':params,'groups':groups,'name':name,'timestamp':timestamp,'delay':delay})             # <<<<<<<<<<<<<<
 * 
 *     def debug_sequence(self):
 */
  __Pyx_TraceLine(845,0,__PYX_ERR(0, 845, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_command) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_esc_type, __pyx_v_esc_type) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_command, __pyx_v_command) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_groups, __pyx_v_groups) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_name, __pyx_v_name) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_timestamp, __pyx_v_timestamp) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_delay, __pyx_v_delay) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_self->sequence, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 845, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":837
 *         self.sequence.append({'type':'text','data':text,'timestamp':timestamp,'delay':delay})
 * 
 *     def add_command_sequence(self,esc_type,command,params,groups,name,timestamp,delay):             # <<<<<<<<<<<<<<
 *         #if self.debug_mode:
 *         #    self.info("CMD:  '{0}', Name:'{3}', Command:{1}, Params:{2}  Timestamp:{4}".format(
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.add_command_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":847
 *         self.sequence.append({'type':'command','esc_type':esc_type,'command':command,'params':params,'groups':groups,'name':name,'timestamp':timestamp,'delay':delay})
 * 
 *     def debug_sequence(self):             # <<<<<<<<<<<<<<
 *         print ("============")
 *         print ("Sequence List")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_25debug_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_25debug_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("debug_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_24debug_sequence(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_24debug_sequence(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  __Pyx_RefNannySetupContext("debug_sequence", 0);
  __Pyx_TraceCall("debug_sequence", __pyx_f[0], 847, 0, __PYX_ERR(0, 847, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":848
 * 
 *     def debug_sequence(self):
 *         print ("============")             # <<<<<<<<<<<<<<
 *         print ("Sequence List")
 *         print ("Count:{0}".format(len(self.sequence)))
 */
  __Pyx_TraceLine(848,0,__PYX_ERR(0, 848, __pyx_L1_error))
  if (__Pyx_PrintOne(0, __pyx_kp_s__16) < 0) __PYX_ERR(0, 848, __pyx_L1_error)

  /* "ttygif/tty/viewer.pyx":849
 *     def debug_sequence(self):
 *         print ("============")
 *         print ("Sequence List")             # <<<<<<<<<<<<<<
 *         print ("Count:{0}".format(len(self.sequence)))
 *         for item in self.sequence:
 */
  __Pyx_TraceLine(849,0,__PYX_ERR(0, 849, __pyx_L1_error))
  if (__Pyx_PrintOne(0, __pyx_kp_s_Sequence_List) < 0) __PYX_ERR(0, 849, __pyx_L1_error)

  /* "ttygif/tty/viewer.pyx":850
 *         print ("============")
 *         print ("Sequence List")
 *         print ("Count:{0}".format(len(self.sequence)))             # <<<<<<<<<<<<<<
 *         for item in self.sequence:
 *             if item['type']=='text':
 */
  __Pyx_TraceLine(850,0,__PYX_ERR(0, 850, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Count_0, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_v_self->sequence;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":851
 *         print ("Sequence List")
 *         print ("Count:{0}".format(len(self.sequence)))
 *         for item in self.sequence:             # <<<<<<<<<<<<<<
 *             if item['type']=='text':
 *                 print("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(item['data']),len(item['data']),item['timestamp']))
 */
  __Pyx_TraceLine(851,0,__PYX_ERR(0, 851, __pyx_L1_error))
  if (likely(PyList_CheckExact(__pyx_v_self->sequence)) || PyTuple_CheckExact(__pyx_v_self->sequence)) {
    __pyx_t_1 = __pyx_v_self->sequence; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_self->sequence); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 851, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 851, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 851, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 851, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 851, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 851, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ttygif/tty/viewer.pyx":852
 *         print ("Count:{0}".format(len(self.sequence)))
 *         for item in self.sequence:
 *             if item['type']=='text':             # <<<<<<<<<<<<<<
 *                 print("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(item['data']),len(item['data']),item['timestamp']))
 *             else:
 */
    __Pyx_TraceLine(852,0,__PYX_ERR(0, 852, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_n_s_text, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 852, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_7) {

      /* "ttygif/tty/viewer.pyx":853
 *         for item in self.sequence:
 *             if item['type']=='text':
 *                 print("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(item['data']),len(item['data']),item['timestamp']))             # <<<<<<<<<<<<<<
 *             else:
 *                 print("CMD:  '{0}', Name:'{3}', Command:{1}, Params:{2}  Timestamp:{4}".format(item['esc_type'],
 */
      __Pyx_TraceLine(853,0,__PYX_ERR(0, 853, __pyx_L1_error))
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Text_0_Length_1_Timestamp_2, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->ascii_safe(__pyx_v_self, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_timestamp); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_t_8, __pyx_t_5, __pyx_t_10};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 853, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_t_8, __pyx_t_5, __pyx_t_10};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 853, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 853, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_12, __pyx_t_10);
        __pyx_t_8 = 0;
        __pyx_t_5 = 0;
        __pyx_t_10 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 853, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 853, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ttygif/tty/viewer.pyx":852
 *         print ("Count:{0}".format(len(self.sequence)))
 *         for item in self.sequence:
 *             if item['type']=='text':             # <<<<<<<<<<<<<<
 *                 print("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(item['data']),len(item['data']),item['timestamp']))
 *             else:
 */
      goto __pyx_L5;
    }

    /* "ttygif/tty/viewer.pyx":855
 *                 print("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(item['data']),len(item['data']),item['timestamp']))
 *             else:
 *                 print("CMD:  '{0}', Name:'{3}', Command:{1}, Params:{2}  Timestamp:{4}".format(item['esc_type'],             # <<<<<<<<<<<<<<
 *                                                     item['command'],
 *                                                     item['params'],
 */
    __Pyx_TraceLine(855,0,__PYX_ERR(0, 855, __pyx_L1_error))
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_CMD_0_Name_3_Command_1_Params_2, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 855, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_13 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_esc_type); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 855, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);

      /* "ttygif/tty/viewer.pyx":856
 *             else:
 *                 print("CMD:  '{0}', Name:'{3}', Command:{1}, Params:{2}  Timestamp:{4}".format(item['esc_type'],
 *                                                     item['command'],             # <<<<<<<<<<<<<<
 *                                                     item['params'],
 *                                                     item['name'],
 */
      __Pyx_TraceLine(856,0,__PYX_ERR(0, 856, __pyx_L1_error))
      __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_command); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);

      /* "ttygif/tty/viewer.pyx":857
 *                 print("CMD:  '{0}', Name:'{3}', Command:{1}, Params:{2}  Timestamp:{4}".format(item['esc_type'],
 *                                                     item['command'],
 *                                                     item['params'],             # <<<<<<<<<<<<<<
 *                                                     item['name'],
 *                                                     item['timestamp']))
 */
      __Pyx_TraceLine(857,0,__PYX_ERR(0, 857, __pyx_L1_error))
      __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_params); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "ttygif/tty/viewer.pyx":858
 *                                                     item['command'],
 *                                                     item['params'],
 *                                                     item['name'],             # <<<<<<<<<<<<<<
 *                                                     item['timestamp']))
 * 
 */
      __Pyx_TraceLine(858,0,__PYX_ERR(0, 858, __pyx_L1_error))
      __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 858, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);

      /* "ttygif/tty/viewer.pyx":859
 *                                                     item['params'],
 *                                                     item['name'],
 *                                                     item['timestamp']))             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_TraceLine(859,0,__PYX_ERR(0, 859, __pyx_L1_error))
      __pyx_t_11 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_timestamp); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_14 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[6] = {__pyx_t_14, __pyx_t_13, __pyx_t_10, __pyx_t_5, __pyx_t_8, __pyx_t_11};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_12, 5+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 855, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[6] = {__pyx_t_14, __pyx_t_13, __pyx_t_10, __pyx_t_5, __pyx_t_8, __pyx_t_11};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_12, 5+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 855, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      {
        __pyx_t_15 = PyTuple_New(5+__pyx_t_12); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 855, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (__pyx_t_14) {
          __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_12, __pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_12, __pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_15, 2+__pyx_t_12, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_15, 3+__pyx_t_12, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_15, 4+__pyx_t_12, __pyx_t_11);
        __pyx_t_13 = 0;
        __pyx_t_10 = 0;
        __pyx_t_5 = 0;
        __pyx_t_8 = 0;
        __pyx_t_11 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 855, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 855, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L5:;

    /* "ttygif/tty/viewer.pyx":851
 *         print ("Sequence List")
 *         print ("Count:{0}".format(len(self.sequence)))
 *         for item in self.sequence:             # <<<<<<<<<<<<<<
 *             if item['type']=='text':
 *                 print("Text: '{0}' Length:{1} Timestamp:{2}".format(self.ascii_safe(item['data']),len(item['data']),item['timestamp']))
 */
    __Pyx_TraceLine(851,0,__PYX_ERR(0, 851, __pyx_L1_error))
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":847
 *         self.sequence.append({'type':'command','esc_type':esc_type,'command':command,'params':params,'groups':groups,'name':name,'timestamp':timestamp,'delay':delay})
 * 
 *     def debug_sequence(self):             # <<<<<<<<<<<<<<
 *         print ("============")
 *         print ("Sequence List")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.debug_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":862
 * 
 * 
 *     def get(self):             # <<<<<<<<<<<<<<
 *         return {'width':self.viewport_px_width,'height':self.viewport_px_height,'data':array.copy(self.video),'color_table':self.color_table}
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_27get(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_27get(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_26get(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_26get(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("get", 0);
  __Pyx_TraceCall("get", __pyx_f[0], 862, 0, __PYX_ERR(0, 862, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":863
 * 
 *     def get(self):
 *         return {'width':self.viewport_px_width,'height':self.viewport_px_height,'data':array.copy(self.video),'color_table':self.color_table}             # <<<<<<<<<<<<<<
 * 
 *     def add_event(self,event):
 */
  __Pyx_TraceLine(863,0,__PYX_ERR(0, 863, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_width); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_width, __pyx_t_2) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_height); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_height, __pyx_t_2) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_v_self->video);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_7cpython_5array_copy(((arrayobject *)__pyx_t_2))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_data, __pyx_t_3) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_color_table, __pyx_v_self->color_table) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "ttygif/tty/viewer.pyx":862
 * 
 * 
 *     def get(self):             # <<<<<<<<<<<<<<
 *         return {'width':self.viewport_px_width,'height':self.viewport_px_height,'data':array.copy(self.video),'color_table':self.color_table}
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":865
 *         return {'width':self.viewport_px_width,'height':self.viewport_px_height,'data':array.copy(self.video),'color_table':self.color_table}
 * 
 *     def add_event(self,event):             # <<<<<<<<<<<<<<
 *         timestamp=round(float(event[0]),3)
 *         event_type=event[1]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_29add_event(PyObject *__pyx_v_self, PyObject *__pyx_v_event); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_29add_event(PyObject *__pyx_v_self, PyObject *__pyx_v_event) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_event (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_28add_event(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_event));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_28add_event(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_event) {
  PyObject *__pyx_v_timestamp = NULL;
  PyObject *__pyx_v_event_type = NULL;
  PyObject *__pyx_v_event_io = NULL;
  CYTHON_UNUSED long __pyx_v_delay;
  Py_ssize_t __pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  __Pyx_RefNannySetupContext("add_event", 0);
  __Pyx_TraceCall("add_event", __pyx_f[0], 865, 0, __PYX_ERR(0, 865, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":866
 * 
 *     def add_event(self,event):
 *         timestamp=round(float(event[0]),3)             # <<<<<<<<<<<<<<
 *         event_type=event[1]
 *         event_io=event[2]
 */
  __Pyx_TraceLine(866,0,__PYX_ERR(0, 866, __pyx_L1_error))
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_event, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyNumber_Float(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_3);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_round, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_timestamp = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "ttygif/tty/viewer.pyx":867
 *     def add_event(self,event):
 *         timestamp=round(float(event[0]),3)
 *         event_type=event[1]             # <<<<<<<<<<<<<<
 *         event_io=event[2]
 *         if self.last_timestamp==0:
 */
  __Pyx_TraceLine(867,0,__PYX_ERR(0, 867, __pyx_L1_error))
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_event, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_event_type = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "ttygif/tty/viewer.pyx":868
 *         timestamp=round(float(event[0]),3)
 *         event_type=event[1]
 *         event_io=event[2]             # <<<<<<<<<<<<<<
 *         if self.last_timestamp==0:
 *             delay=0
 */
  __Pyx_TraceLine(868,0,__PYX_ERR(0, 868, __pyx_L1_error))
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_event, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_event_io = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "ttygif/tty/viewer.pyx":869
 *         event_type=event[1]
 *         event_io=event[2]
 *         if self.last_timestamp==0:             # <<<<<<<<<<<<<<
 *             delay=0
 *         else:
 */
  __Pyx_TraceLine(869,0,__PYX_ERR(0, 869, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_v_self->last_timestamp, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "ttygif/tty/viewer.pyx":870
 *         event_io=event[2]
 *         if self.last_timestamp==0:
 *             delay=0             # <<<<<<<<<<<<<<
 *         else:
 *             length=len(self.sequence)-1
 */
    __Pyx_TraceLine(870,0,__PYX_ERR(0, 870, __pyx_L1_error))
    __pyx_v_delay = 0;

    /* "ttygif/tty/viewer.pyx":869
 *         event_type=event[1]
 *         event_io=event[2]
 *         if self.last_timestamp==0:             # <<<<<<<<<<<<<<
 *             delay=0
 *         else:
 */
    goto __pyx_L3;
  }

  /* "ttygif/tty/viewer.pyx":872
 *             delay=0
 *         else:
 *             length=len(self.sequence)-1             # <<<<<<<<<<<<<<
 *             if length>0:
 *                 self.sequence[length]['delay']=timestamp-self.last_timestamp
 */
  __Pyx_TraceLine(872,0,__PYX_ERR(0, 872, __pyx_L1_error))
  /*else*/ {
    __pyx_t_2 = __pyx_v_self->sequence;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 872, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_length = (__pyx_t_4 - 1);

    /* "ttygif/tty/viewer.pyx":873
 *         else:
 *             length=len(self.sequence)-1
 *             if length>0:             # <<<<<<<<<<<<<<
 *                 self.sequence[length]['delay']=timestamp-self.last_timestamp
 *             else:
 */
    __Pyx_TraceLine(873,0,__PYX_ERR(0, 873, __pyx_L1_error))
    __pyx_t_3 = ((__pyx_v_length > 0) != 0);
    if (__pyx_t_3) {

      /* "ttygif/tty/viewer.pyx":874
 *             length=len(self.sequence)-1
 *             if length>0:
 *                 self.sequence[length]['delay']=timestamp-self.last_timestamp             # <<<<<<<<<<<<<<
 *             else:
 *                 delay=0
 */
      __Pyx_TraceLine(874,0,__PYX_ERR(0, 874, __pyx_L1_error))
      __pyx_t_2 = PyNumber_Subtract(__pyx_v_timestamp, __pyx_v_self->last_timestamp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 874, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_self->sequence, __pyx_v_length, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 874, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(PyObject_SetItem(__pyx_t_1, __pyx_n_s_delay, __pyx_t_2) < 0)) __PYX_ERR(0, 874, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ttygif/tty/viewer.pyx":873
 *         else:
 *             length=len(self.sequence)-1
 *             if length>0:             # <<<<<<<<<<<<<<
 *                 self.sequence[length]['delay']=timestamp-self.last_timestamp
 *             else:
 */
      goto __pyx_L4;
    }

    /* "ttygif/tty/viewer.pyx":876
 *                 self.sequence[length]['delay']=timestamp-self.last_timestamp
 *             else:
 *                 delay=0             # <<<<<<<<<<<<<<
 *         if event_type=='o':
 *             self.stream_2_sequence(self.extra_text+event_io,timestamp,0)
 */
    __Pyx_TraceLine(876,0,__PYX_ERR(0, 876, __pyx_L1_error))
    /*else*/ {
      __pyx_v_delay = 0;
    }
    __pyx_L4:;
  }
  __pyx_L3:;

  /* "ttygif/tty/viewer.pyx":877
 *             else:
 *                 delay=0
 *         if event_type=='o':             # <<<<<<<<<<<<<<
 *             self.stream_2_sequence(self.extra_text+event_io,timestamp,0)
 *             self.last_timestamp=timestamp
 */
  __Pyx_TraceLine(877,0,__PYX_ERR(0, 877, __pyx_L1_error))
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_event_type, __pyx_n_s_o, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 877, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "ttygif/tty/viewer.pyx":878
 *                 delay=0
 *         if event_type=='o':
 *             self.stream_2_sequence(self.extra_text+event_io,timestamp,0)             # <<<<<<<<<<<<<<
 *             self.last_timestamp=timestamp
 * 
 */
    __Pyx_TraceLine(878,0,__PYX_ERR(0, 878, __pyx_L1_error))
    __pyx_t_2 = PyNumber_Add(__pyx_v_self->extra_text, __pyx_v_event_io); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 878, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = ((struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer *)__pyx_v_self->__pyx_vtab)->stream_2_sequence(__pyx_v_self, __pyx_t_2, __pyx_v_timestamp, __pyx_int_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 878, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ttygif/tty/viewer.pyx":879
 *         if event_type=='o':
 *             self.stream_2_sequence(self.extra_text+event_io,timestamp,0)
 *             self.last_timestamp=timestamp             # <<<<<<<<<<<<<<
 * 
 *     cdef save_screen(self):
 */
    __Pyx_TraceLine(879,0,__PYX_ERR(0, 879, __pyx_L1_error))
    __Pyx_INCREF(__pyx_v_timestamp);
    __Pyx_GIVEREF(__pyx_v_timestamp);
    __Pyx_GOTREF(__pyx_v_self->last_timestamp);
    __Pyx_DECREF(__pyx_v_self->last_timestamp);
    __pyx_v_self->last_timestamp = __pyx_v_timestamp;

    /* "ttygif/tty/viewer.pyx":877
 *             else:
 *                 delay=0
 *         if event_type=='o':             # <<<<<<<<<<<<<<
 *             self.stream_2_sequence(self.extra_text+event_io,timestamp,0)
 *             self.last_timestamp=timestamp
 */
  }

  /* "ttygif/tty/viewer.pyx":865
 *         return {'width':self.viewport_px_width,'height':self.viewport_px_height,'data':array.copy(self.video),'color_table':self.color_table}
 * 
 *     def add_event(self,event):             # <<<<<<<<<<<<<<
 *         timestamp=round(float(event[0]),3)
 *         event_type=event[1]
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.add_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_timestamp);
  __Pyx_XDECREF(__pyx_v_event_type);
  __Pyx_XDECREF(__pyx_v_event_io);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":881
 *             self.last_timestamp=timestamp
 * 
 *     cdef save_screen(self):             # <<<<<<<<<<<<<<
 *         # todo save as gif..
 *         # pre test with canvas extension
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer_6viewer_save_screen(CYTHON_UNUSED struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  CYTHON_UNUSED long __pyx_v_x;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("save_screen", 0);
  __Pyx_TraceCall("save_screen", __pyx_f[0], 881, 0, __PYX_ERR(0, 881, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":884
 *         # todo save as gif..
 *         # pre test with canvas extension
 *         x=1             # <<<<<<<<<<<<<<
 */
  __Pyx_TraceLine(884,0,__PYX_ERR(0, 884, __pyx_L1_error))
  __pyx_v_x = 1;

  /* "ttygif/tty/viewer.pyx":881
 *             self.last_timestamp=timestamp
 * 
 *     cdef save_screen(self):             # <<<<<<<<<<<<<<
 *         # todo save as gif..
 *         # pre test with canvas extension
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.save_screen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":18
 * 
 * cdef class viewer:
 *     cdef public object          last_timestamp             # <<<<<<<<<<<<<<
 *     cdef public int             viewport_px_width
 *     cdef public int             viewport_px_height
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 18, 0, __PYX_ERR(0, 18, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->last_timestamp);
  __pyx_r = __pyx_v_self->last_timestamp;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.last_timestamp.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 18, 0, __PYX_ERR(0, 18, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->last_timestamp);
  __Pyx_DECREF(__pyx_v_self->last_timestamp);
  __pyx_v_self->last_timestamp = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.last_timestamp.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_14last_timestamp_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 18, 0, __PYX_ERR(0, 18, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->last_timestamp);
  __Pyx_DECREF(__pyx_v_self->last_timestamp);
  __pyx_v_self->last_timestamp = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.last_timestamp.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":19
 * cdef class viewer:
 *     cdef public object          last_timestamp
 *     cdef public int             viewport_px_width             # <<<<<<<<<<<<<<
 *     cdef public int             viewport_px_height
 *     cdef public int             viewport_char_height
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_17viewport_px_width___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_17viewport_px_width___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 19, 0, __PYX_ERR(0, 19, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_width); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_px_width.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 19, 0, __PYX_ERR(0, 19, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 19, __pyx_L1_error)
  __pyx_v_self->viewport_px_width = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_px_width.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":20
 *     cdef public object          last_timestamp
 *     cdef public int             viewport_px_width
 *     cdef public int             viewport_px_height             # <<<<<<<<<<<<<<
 *     cdef public int             viewport_char_height
 *     cdef public int             viewport_char_width
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_18viewport_px_height___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_18viewport_px_height___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 20, 0, __PYX_ERR(0, 20, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_height); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_px_height.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 20, 0, __PYX_ERR(0, 20, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 20, __pyx_L1_error)
  __pyx_v_self->viewport_px_height = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_px_height.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":21
 *     cdef public int             viewport_px_width
 *     cdef public int             viewport_px_height
 *     cdef public int             viewport_char_height             # <<<<<<<<<<<<<<
 *     cdef public int             viewport_char_width
 *     cdef public int             viewport_char_stride
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_height___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_height___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 21, 0, __PYX_ERR(0, 21, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_height); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_char_height.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 21, 0, __PYX_ERR(0, 21, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 21, __pyx_L1_error)
  __pyx_v_self->viewport_char_height = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_char_height.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":22
 *     cdef public int             viewport_px_height
 *     cdef public int             viewport_char_height
 *     cdef public int             viewport_char_width             # <<<<<<<<<<<<<<
 *     cdef public int             viewport_char_stride
 *     cdef public int             background_color
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_19viewport_char_width___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_19viewport_char_width___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 22, 0, __PYX_ERR(0, 22, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_char_width.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 22, 0, __PYX_ERR(0, 22, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 22, __pyx_L1_error)
  __pyx_v_self->viewport_char_width = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_char_width.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":23
 *     cdef public int             viewport_char_height
 *     cdef public int             viewport_char_width
 *     cdef public int             viewport_char_stride             # <<<<<<<<<<<<<<
 *     cdef public int             background_color
 *     cdef public int             foreground_color
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 23, 0, __PYX_ERR(0, 23, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_stride); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_char_stride.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 23, 0, __PYX_ERR(0, 23, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 23, __pyx_L1_error)
  __pyx_v_self->viewport_char_stride = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.viewport_char_stride.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":24
 *     cdef public int             viewport_char_width
 *     cdef public int             viewport_char_stride
 *     cdef public int             background_color             # <<<<<<<<<<<<<<
 *     cdef public int             foreground_color
 *     cdef public object          window_style
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_16background_color_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_16background_color_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_16background_color___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_16background_color___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 24, 0, __PYX_ERR(0, 24, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->background_color); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.background_color.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_16background_color_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_16background_color_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_16background_color_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_16background_color_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 24, 0, __PYX_ERR(0, 24, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 24, __pyx_L1_error)
  __pyx_v_self->background_color = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.background_color.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":25
 *     cdef public int             viewport_char_stride
 *     cdef public int             background_color
 *     cdef public int             foreground_color             # <<<<<<<<<<<<<<
 *     cdef public object          window_style
 *     cdef public object          stream
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_16foreground_color_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_16foreground_color_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_16foreground_color___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_16foreground_color___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 25, 0, __PYX_ERR(0, 25, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->foreground_color); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.foreground_color.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_16foreground_color_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_16foreground_color_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_16foreground_color_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_16foreground_color_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 25, 0, __PYX_ERR(0, 25, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 25, __pyx_L1_error)
  __pyx_v_self->foreground_color = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.foreground_color.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":26
 *     cdef public int             background_color
 *     cdef public int             foreground_color
 *     cdef public object          window_style             # <<<<<<<<<<<<<<
 *     cdef public object          stream
 *     cdef public int             video_length
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 26, 0, __PYX_ERR(0, 26, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->window_style);
  __pyx_r = __pyx_v_self->window_style;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.window_style.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 26, 0, __PYX_ERR(0, 26, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->window_style);
  __Pyx_DECREF(__pyx_v_self->window_style);
  __pyx_v_self->window_style = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.window_style.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12window_style_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 26, 0, __PYX_ERR(0, 26, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->window_style);
  __Pyx_DECREF(__pyx_v_self->window_style);
  __pyx_v_self->window_style = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.window_style.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":27
 *     cdef public int             foreground_color
 *     cdef public object          window_style
 *     cdef public object          stream             # <<<<<<<<<<<<<<
 *     cdef public int             video_length
 *     cdef        array.array     video
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 27, 0, __PYX_ERR(0, 27, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->stream);
  __pyx_r = __pyx_v_self->stream;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.stream.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 27, 0, __PYX_ERR(0, 27, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->stream);
  __Pyx_DECREF(__pyx_v_self->stream);
  __pyx_v_self->stream = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.stream.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6stream_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 27, 0, __PYX_ERR(0, 27, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->stream);
  __Pyx_DECREF(__pyx_v_self->stream);
  __pyx_v_self->stream = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.stream.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":28
 *     cdef public object          window_style
 *     cdef public object          stream
 *     cdef public int             video_length             # <<<<<<<<<<<<<<
 *     cdef        array.array     video
 *     cdef        object          color_table
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_12video_length_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_12video_length_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12video_length___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12video_length___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 28, 0, __PYX_ERR(0, 28, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->video_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.video_length.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12video_length_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12video_length_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12video_length_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12video_length_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 28, 0, __PYX_ERR(0, 28, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 28, __pyx_L1_error)
  __pyx_v_self->video_length = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.video_length.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":32
 *     cdef        object          color_table
 *     cdef        array.array     buffer
 *     cdef public int             buffer_rows             # <<<<<<<<<<<<<<
 *     cdef        object          debug_mode
 *     cdef public object          sequence
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_11buffer_rows_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_11buffer_rows_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_11buffer_rows___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_11buffer_rows___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 32, 0, __PYX_ERR(0, 32, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->buffer_rows); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.buffer_rows.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_11buffer_rows_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_11buffer_rows_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_11buffer_rows_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_11buffer_rows_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 32, 0, __PYX_ERR(0, 32, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 32, __pyx_L1_error)
  __pyx_v_self->buffer_rows = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.buffer_rows.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":34
 *     cdef public int             buffer_rows
 *     cdef        object          debug_mode
 *     cdef public object          sequence             # <<<<<<<<<<<<<<
 *     cdef public object          sequence_pos
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 34, 0, __PYX_ERR(0, 34, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __pyx_r = __pyx_v_self->sequence;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.sequence.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 34, 0, __PYX_ERR(0, 34, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.sequence.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_8sequence_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 34, 0, __PYX_ERR(0, 34, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.sequence.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":35
 *     cdef        object          debug_mode
 *     cdef public object          sequence
 *     cdef public object          sequence_pos             # <<<<<<<<<<<<<<
 * 
 *     cdef public int             x
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 35, 0, __PYX_ERR(0, 35, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence_pos);
  __pyx_r = __pyx_v_self->sequence_pos;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.sequence_pos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 35, 0, __PYX_ERR(0, 35, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->sequence_pos);
  __Pyx_DECREF(__pyx_v_self->sequence_pos);
  __pyx_v_self->sequence_pos = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.sequence_pos.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_12sequence_pos_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 35, 0, __PYX_ERR(0, 35, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sequence_pos);
  __Pyx_DECREF(__pyx_v_self->sequence_pos);
  __pyx_v_self->sequence_pos = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.sequence_pos.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":37
 *     cdef public object          sequence_pos
 * 
 *     cdef public int             x             # <<<<<<<<<<<<<<
 *     cdef public int             y
 *     cdef public int             def_fg
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_1x_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_1x_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_1x___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_1x___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 37, 0, __PYX_ERR(0, 37, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->x); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.x.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_1x_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_1x_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_1x_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_1x_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 37, 0, __PYX_ERR(0, 37, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 37, __pyx_L1_error)
  __pyx_v_self->x = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.x.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":38
 * 
 *     cdef public int             x
 *     cdef public int             y             # <<<<<<<<<<<<<<
 *     cdef public int             def_fg
 *     cdef public int             def_bg
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_1y_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_1y_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_1y___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_1y___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 38, 0, __PYX_ERR(0, 38, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->y); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.y.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_1y_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_1y_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_1y_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_1y_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 38, 0, __PYX_ERR(0, 38, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 38, __pyx_L1_error)
  __pyx_v_self->y = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.y.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":39
 *     cdef public int             x
 *     cdef public int             y
 *     cdef public int             def_fg             # <<<<<<<<<<<<<<
 *     cdef public int             def_bg
 *     cdef public int             fg
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_fg_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_fg_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_fg___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_fg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 39, 0, __PYX_ERR(0, 39, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->def_fg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.def_fg.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_fg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_fg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_fg_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_fg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 39, 0, __PYX_ERR(0, 39, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 39, __pyx_L1_error)
  __pyx_v_self->def_fg = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.def_fg.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":40
 *     cdef public int             y
 *     cdef public int             def_fg
 *     cdef public int             def_bg             # <<<<<<<<<<<<<<
 *     cdef public int             fg
 *     cdef public int             bg
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_bg_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_bg_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_bg___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_bg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 40, 0, __PYX_ERR(0, 40, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->def_bg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.def_bg.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_bg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_bg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_bg_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_6def_bg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 40, 0, __PYX_ERR(0, 40, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 40, __pyx_L1_error)
  __pyx_v_self->def_bg = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.def_bg.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":41
 *     cdef public int             def_fg
 *     cdef public int             def_bg
 *     cdef public int             fg             # <<<<<<<<<<<<<<
 *     cdef public int             bg
 *     cdef public object          reverse_video
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_2fg_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_2fg_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_2fg___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_2fg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 41, 0, __PYX_ERR(0, 41, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.fg.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_2fg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_2fg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_2fg_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_2fg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 41, 0, __PYX_ERR(0, 41, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 41, __pyx_L1_error)
  __pyx_v_self->fg = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.fg.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":42
 *     cdef public int             def_bg
 *     cdef public int             fg
 *     cdef public int             bg             # <<<<<<<<<<<<<<
 *     cdef public object          reverse_video
 *     cdef public object          bold
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_2bg_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_2bg_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_2bg___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_2bg___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 42, 0, __PYX_ERR(0, 42, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.bg.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_2bg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_2bg_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_2bg_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_2bg_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 42, 0, __PYX_ERR(0, 42, __pyx_L1_error));
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 42, __pyx_L1_error)
  __pyx_v_self->bg = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.bg.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":43
 *     cdef public int             fg
 *     cdef public int             bg
 *     cdef public object          reverse_video             # <<<<<<<<<<<<<<
 *     cdef public object          bold
 *     cdef public object          extra_text
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 43, 0, __PYX_ERR(0, 43, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->reverse_video);
  __pyx_r = __pyx_v_self->reverse_video;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.reverse_video.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 43, 0, __PYX_ERR(0, 43, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->reverse_video);
  __Pyx_DECREF(__pyx_v_self->reverse_video);
  __pyx_v_self->reverse_video = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.reverse_video.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_13reverse_video_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 43, 0, __PYX_ERR(0, 43, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->reverse_video);
  __Pyx_DECREF(__pyx_v_self->reverse_video);
  __pyx_v_self->reverse_video = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.reverse_video.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":44
 *     cdef public int             bg
 *     cdef public object          reverse_video
 *     cdef public object          bold             # <<<<<<<<<<<<<<
 *     cdef public object          extra_text
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 44, 0, __PYX_ERR(0, 44, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->bold);
  __pyx_r = __pyx_v_self->bold;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.bold.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 44, 0, __PYX_ERR(0, 44, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->bold);
  __Pyx_DECREF(__pyx_v_self->bold);
  __pyx_v_self->bold = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.bold.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_4bold_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 44, 0, __PYX_ERR(0, 44, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->bold);
  __Pyx_DECREF(__pyx_v_self->bold);
  __pyx_v_self->bold = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.bold.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/tty/viewer.pyx":45
 *     cdef public object          reverse_video
 *     cdef public object          bold
 *     cdef public object          extra_text             # <<<<<<<<<<<<<<
 * 
 *     cdef ascii_safe(self,text):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text___get__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text___get__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_TraceCall("__get__", __pyx_f[0], 45, 0, __PYX_ERR(0, 45, __pyx_L1_error));
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->extra_text);
  __pyx_r = __pyx_v_self->extra_text;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.extra_text.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text_2__set__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text_2__set__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_TraceCall("__set__", __pyx_f[0], 45, 0, __PYX_ERR(0, 45, __pyx_L1_error));
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->extra_text);
  __Pyx_DECREF(__pyx_v_self->extra_text);
  __pyx_v_self->extra_text = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.extra_text.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text_4__del__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ttygif_3tty_6viewer_6viewer_10extra_text_4__del__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_TraceCall("__del__", __pyx_f[0], 45, 0, __PYX_ERR(0, 45, __pyx_L1_error));
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->extra_text);
  __Pyx_DECREF(__pyx_v_self->extra_text);
  __pyx_v_self->extra_text = Py_None;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.extra_text.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_31__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_31__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_30__reduce_cython__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_30__reduce_cython__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);
  __Pyx_TraceCall("__reduce_cython__", __pyx_f[1], 1, 0, __PYX_ERR(1, 1, __pyx_L1_error));

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.background_color, self.bg, self.bold, self.buffer, self.buffer_rows, self.color_table, self.debug_mode, self.def_bg, self.def_fg, self.extra_text, self.fg, self.foreground_color, self.last_timestamp, self.reverse_video, self.sequence, self.sequence_pos, self.stream, self.video, self.video_length, self.viewport_char_height, self.viewport_char_stride, self.viewport_char_width, self.viewport_px_height, self.viewport_px_width, self.window_style, self.x, self.y)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_TraceLine(5,0,__PYX_ERR(1, 5, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->background_color); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->bg); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->buffer_rows); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->def_bg); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->def_fg); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->fg); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->foreground_color); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->video_length); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_height); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_stride); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_11 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_char_width); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_height); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_v_self->viewport_px_width); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_14 = __Pyx_PyInt_From_int(__pyx_v_self->x); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_15 = __Pyx_PyInt_From_int(__pyx_v_self->y); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_16 = PyTuple_New(27); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->bold);
  __Pyx_GIVEREF(__pyx_v_self->bold);
  PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_v_self->bold);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->buffer));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->buffer));
  PyTuple_SET_ITEM(__pyx_t_16, 3, ((PyObject *)__pyx_v_self->buffer));
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_16, 4, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->color_table);
  __Pyx_GIVEREF(__pyx_v_self->color_table);
  PyTuple_SET_ITEM(__pyx_t_16, 5, __pyx_v_self->color_table);
  __Pyx_INCREF(__pyx_v_self->debug_mode);
  __Pyx_GIVEREF(__pyx_v_self->debug_mode);
  PyTuple_SET_ITEM(__pyx_t_16, 6, __pyx_v_self->debug_mode);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_16, 7, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_16, 8, __pyx_t_5);
  __Pyx_INCREF(__pyx_v_self->extra_text);
  __Pyx_GIVEREF(__pyx_v_self->extra_text);
  PyTuple_SET_ITEM(__pyx_t_16, 9, __pyx_v_self->extra_text);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_16, 10, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_16, 11, __pyx_t_7);
  __Pyx_INCREF(__pyx_v_self->last_timestamp);
  __Pyx_GIVEREF(__pyx_v_self->last_timestamp);
  PyTuple_SET_ITEM(__pyx_t_16, 12, __pyx_v_self->last_timestamp);
  __Pyx_INCREF(__pyx_v_self->reverse_video);
  __Pyx_GIVEREF(__pyx_v_self->reverse_video);
  PyTuple_SET_ITEM(__pyx_t_16, 13, __pyx_v_self->reverse_video);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __Pyx_GIVEREF(__pyx_v_self->sequence);
  PyTuple_SET_ITEM(__pyx_t_16, 14, __pyx_v_self->sequence);
  __Pyx_INCREF(__pyx_v_self->sequence_pos);
  __Pyx_GIVEREF(__pyx_v_self->sequence_pos);
  PyTuple_SET_ITEM(__pyx_t_16, 15, __pyx_v_self->sequence_pos);
  __Pyx_INCREF(__pyx_v_self->stream);
  __Pyx_GIVEREF(__pyx_v_self->stream);
  PyTuple_SET_ITEM(__pyx_t_16, 16, __pyx_v_self->stream);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->video));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->video));
  PyTuple_SET_ITEM(__pyx_t_16, 17, ((PyObject *)__pyx_v_self->video));
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_16, 18, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_16, 19, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_10);
  PyTuple_SET_ITEM(__pyx_t_16, 20, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_11);
  PyTuple_SET_ITEM(__pyx_t_16, 21, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_12);
  PyTuple_SET_ITEM(__pyx_t_16, 22, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_16, 23, __pyx_t_13);
  __Pyx_INCREF(__pyx_v_self->window_style);
  __Pyx_GIVEREF(__pyx_v_self->window_style);
  PyTuple_SET_ITEM(__pyx_t_16, 24, __pyx_v_self->window_style);
  __Pyx_GIVEREF(__pyx_t_14);
  PyTuple_SET_ITEM(__pyx_t_16, 25, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_15);
  PyTuple_SET_ITEM(__pyx_t_16, 26, __pyx_t_15);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_t_11 = 0;
  __pyx_t_12 = 0;
  __pyx_t_13 = 0;
  __pyx_t_14 = 0;
  __pyx_t_15 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_16);
  __pyx_t_16 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.background_color, self.bg, self.bold, self.buffer, self.buffer_rows, self.color_table, self.debug_mode, self.def_bg, self.def_fg, self.extra_text, self.fg, self.foreground_color, self.last_timestamp, self.reverse_video, self.sequence, self.sequence_pos, self.stream, self.video, self.video_length, self.viewport_char_height, self.viewport_char_stride, self.viewport_char_width, self.viewport_px_height, self.viewport_px_width, self.window_style, self.x, self.y)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __Pyx_TraceLine(6,0,__PYX_ERR(1, 6, __pyx_L1_error))
  __pyx_t_16 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_v__dict = __pyx_t_16;
  __pyx_t_16 = 0;

  /* "(tree fragment)":7
 *     state = (self.background_color, self.bg, self.bold, self.buffer, self.buffer_rows, self.color_table, self.debug_mode, self.def_bg, self.def_fg, self.extra_text, self.fg, self.foreground_color, self.last_timestamp, self.reverse_video, self.sequence, self.sequence_pos, self.stream, self.video, self.video_length, self.viewport_char_height, self.viewport_char_stride, self.viewport_char_width, self.viewport_px_height, self.viewport_px_width, self.window_style, self.x, self.y)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __Pyx_TraceLine(7,0,__PYX_ERR(1, 7, __pyx_L1_error))
  __pyx_t_17 = (__pyx_v__dict != Py_None);
  __pyx_t_18 = (__pyx_t_17 != 0);
  if (__pyx_t_18) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __Pyx_TraceLine(8,0,__PYX_ERR(1, 8, __pyx_L1_error))
    __pyx_t_16 = PyTuple_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_v__dict);
    __pyx_t_15 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_15));
    __pyx_t_15 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.bold is not None or self.buffer is not None or self.color_table is not None or self.debug_mode is not None or self.extra_text is not None or self.last_timestamp is not None or self.reverse_video is not None or self.sequence is not None or self.sequence_pos is not None or self.stream is not None or self.video is not None or self.window_style is not None
 */
    __Pyx_TraceLine(9,0,__PYX_ERR(1, 9, __pyx_L1_error))
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.background_color, self.bg, self.bold, self.buffer, self.buffer_rows, self.color_table, self.debug_mode, self.def_bg, self.def_fg, self.extra_text, self.fg, self.foreground_color, self.last_timestamp, self.reverse_video, self.sequence, self.sequence_pos, self.stream, self.video, self.video_length, self.viewport_char_height, self.viewport_char_stride, self.viewport_char_width, self.viewport_px_height, self.viewport_px_width, self.window_style, self.x, self.y)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.bold is not None or self.buffer is not None or self.color_table is not None or self.debug_mode is not None or self.extra_text is not None or self.last_timestamp is not None or self.reverse_video is not None or self.sequence is not None or self.sequence_pos is not None or self.stream is not None or self.video is not None or self.window_style is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, None), state
 */
  __Pyx_TraceLine(11,0,__PYX_ERR(1, 11, __pyx_L1_error))
  /*else*/ {
    __pyx_t_17 = (__pyx_v_self->bold != Py_None);
    __pyx_t_19 = (__pyx_t_17 != 0);
    if (!__pyx_t_19) {
    } else {
      __pyx_t_18 = __pyx_t_19;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_19 = (((PyObject *)__pyx_v_self->buffer) != Py_None);
    __pyx_t_17 = (__pyx_t_19 != 0);
    if (!__pyx_t_17) {
    } else {
      __pyx_t_18 = __pyx_t_17;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_17 = (__pyx_v_self->color_table != Py_None);
    __pyx_t_19 = (__pyx_t_17 != 0);
    if (!__pyx_t_19) {
    } else {
      __pyx_t_18 = __pyx_t_19;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_19 = (__pyx_v_self->debug_mode != Py_None);
    __pyx_t_17 = (__pyx_t_19 != 0);
    if (!__pyx_t_17) {
    } else {
      __pyx_t_18 = __pyx_t_17;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_17 = (__pyx_v_self->extra_text != Py_None);
    __pyx_t_19 = (__pyx_t_17 != 0);
    if (!__pyx_t_19) {
    } else {
      __pyx_t_18 = __pyx_t_19;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_19 = (__pyx_v_self->last_timestamp != Py_None);
    __pyx_t_17 = (__pyx_t_19 != 0);
    if (!__pyx_t_17) {
    } else {
      __pyx_t_18 = __pyx_t_17;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_17 = (__pyx_v_self->reverse_video != Py_None);
    __pyx_t_19 = (__pyx_t_17 != 0);
    if (!__pyx_t_19) {
    } else {
      __pyx_t_18 = __pyx_t_19;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_19 = (__pyx_v_self->sequence != Py_None);
    __pyx_t_17 = (__pyx_t_19 != 0);
    if (!__pyx_t_17) {
    } else {
      __pyx_t_18 = __pyx_t_17;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_17 = (__pyx_v_self->sequence_pos != Py_None);
    __pyx_t_19 = (__pyx_t_17 != 0);
    if (!__pyx_t_19) {
    } else {
      __pyx_t_18 = __pyx_t_19;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_19 = (__pyx_v_self->stream != Py_None);
    __pyx_t_17 = (__pyx_t_19 != 0);
    if (!__pyx_t_17) {
    } else {
      __pyx_t_18 = __pyx_t_17;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_17 = (((PyObject *)__pyx_v_self->video) != Py_None);
    __pyx_t_19 = (__pyx_t_17 != 0);
    if (!__pyx_t_19) {
    } else {
      __pyx_t_18 = __pyx_t_19;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_19 = (__pyx_v_self->window_style != Py_None);
    __pyx_t_17 = (__pyx_t_19 != 0);
    __pyx_t_18 = __pyx_t_17;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_18;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bold is not None or self.buffer is not None or self.color_table is not None or self.debug_mode is not None or self.extra_text is not None or self.last_timestamp is not None or self.reverse_video is not None or self.sequence is not None or self.sequence_pos is not None or self.stream is not None or self.video is not None or self.window_style is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, None), state
 *     else:
 */
  __Pyx_TraceLine(12,0,__PYX_ERR(1, 12, __pyx_L1_error))
  __pyx_t_18 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_18) {

    /* "(tree fragment)":13
 *         use_setstate = self.bold is not None or self.buffer is not None or self.color_table is not None or self.debug_mode is not None or self.extra_text is not None or self.last_timestamp is not None or self.reverse_video is not None or self.sequence is not None or self.sequence_pos is not None or self.stream is not None or self.video is not None or self.window_style is not None
 *     if use_setstate:
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, state)
 */
    __Pyx_TraceLine(13,0,__PYX_ERR(1, 13, __pyx_L1_error))
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_pyx_unpickle_viewer); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_16 = PyTuple_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_16, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_63536012);
    __Pyx_GIVEREF(__pyx_int_63536012);
    PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_int_63536012);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_16, 2, Py_None);
    __pyx_t_14 = PyTuple_New(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_16);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_16);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_v_state);
    __pyx_t_15 = 0;
    __pyx_t_16 = 0;
    __pyx_r = __pyx_t_14;
    __pyx_t_14 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bold is not None or self.buffer is not None or self.color_table is not None or self.debug_mode is not None or self.extra_text is not None or self.last_timestamp is not None or self.reverse_video is not None or self.sequence is not None or self.sequence_pos is not None or self.stream is not None or self.video is not None or self.window_style is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, None), state
 *     else:
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_viewer__set_state(self, __pyx_state)
 */
  __Pyx_TraceLine(15,0,__PYX_ERR(1, 15, __pyx_L1_error))
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pyx_unpickle_viewer); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_16 = PyTuple_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_16, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_63536012);
    __Pyx_GIVEREF(__pyx_int_63536012);
    PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_int_63536012);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_v_state);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_16);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_16);
    __pyx_t_14 = 0;
    __pyx_t_16 = 0;
    __pyx_r = __pyx_t_15;
    __pyx_t_15 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_viewer__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_33__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_6viewer_33__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer_6viewer_32__setstate_cython__(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer_6viewer_32__setstate_cython__(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);
  __Pyx_TraceCall("__setstate_cython__", __pyx_f[1], 16, 0, __PYX_ERR(1, 16, __pyx_L1_error));

  /* "(tree fragment)":17
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_viewer__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  __Pyx_TraceLine(17,0,__PYX_ERR(1, 17, __pyx_L1_error))
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6ttygif_3tty_6viewer___pyx_unpickle_viewer__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_viewer, (type(self), 0x3c97b8c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_viewer__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.tty.viewer.viewer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_viewer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_1__pyx_unpickle_viewer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3tty_6viewer_1__pyx_unpickle_viewer = {"__pyx_unpickle_viewer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3tty_6viewer_1__pyx_unpickle_viewer, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6ttygif_3tty_6viewer_1__pyx_unpickle_viewer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_viewer (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_viewer", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_viewer", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_viewer") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_viewer", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.tty.viewer.__pyx_unpickle_viewer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3tty_6viewer___pyx_unpickle_viewer(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3tty_6viewer___pyx_unpickle_viewer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_TraceFrameInit(__pyx_codeobj__17)
  __Pyx_RefNannySetupContext("__pyx_unpickle_viewer", 0);
  __Pyx_TraceCall("__pyx_unpickle_viewer", __pyx_f[1], 1, 0, __PYX_ERR(1, 1, __pyx_L1_error));

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x3c97b8c:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))" % __pyx_checksum)
 */
  __Pyx_TraceLine(4,0,__PYX_ERR(1, 4, __pyx_L1_error))
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x3c97b8c) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x3c97b8c:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))" % __pyx_checksum)
 *     __pyx_result = viewer.__new__(__pyx_type)
 */
    __Pyx_TraceLine(5,0,__PYX_ERR(1, 5, __pyx_L1_error))
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x3c97b8c:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = viewer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __Pyx_TraceLine(6,0,__PYX_ERR(1, 6, __pyx_L1_error))
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x3c, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x3c97b8c:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))" % __pyx_checksum)
 *     __pyx_result = viewer.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)
 */
  __Pyx_TraceLine(7,0,__PYX_ERR(1, 7, __pyx_L1_error))
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6ttygif_3tty_6viewer_viewer), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))" % __pyx_checksum)
 *     __pyx_result = viewer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __Pyx_TraceLine(8,0,__PYX_ERR(1, 8, __pyx_L1_error))
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = viewer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):
 */
    __Pyx_TraceLine(9,0,__PYX_ERR(1, 9, __pyx_L1_error))
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_6ttygif_3tty_6viewer___pyx_unpickle_viewer__set_state(((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x3c97b8c = (background_color, bg, bold, buffer, buffer_rows, color_table, debug_mode, def_bg, def_fg, extra_text, fg, foreground_color, last_timestamp, reverse_video, sequence, sequence_pos, stream, video, video_length, viewport_char_height, viewport_char_stride, viewport_char_width, viewport_px_height, viewport_px_width, window_style, x, y))" % __pyx_checksum)
 *     __pyx_result = viewer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]
 */
  __Pyx_TraceLine(10,0,__PYX_ERR(1, 10, __pyx_L1_error))
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_viewer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ttygif.tty.viewer.__pyx_unpickle_viewer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]
 *     if len(__pyx_state) > 27 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_6ttygif_3tty_6viewer___pyx_unpickle_viewer__set_state(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("__pyx_unpickle_viewer__set_state", 0);
  __Pyx_TraceCall("__pyx_unpickle_viewer__set_state", __pyx_f[1], 11, 0, __PYX_ERR(1, 11, __pyx_L1_error));

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 27 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[27])
 */
  __Pyx_TraceLine(12,0,__PYX_ERR(1, 12, __pyx_L1_error))
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->background_color = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->bg = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->bold);
  __Pyx_DECREF(__pyx_v___pyx_result->bold);
  __pyx_v___pyx_result->bold = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->buffer);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->buffer));
  __pyx_v___pyx_result->buffer = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->buffer_rows = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->color_table);
  __Pyx_DECREF(__pyx_v___pyx_result->color_table);
  __pyx_v___pyx_result->color_table = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->debug_mode);
  __Pyx_DECREF(__pyx_v___pyx_result->debug_mode);
  __pyx_v___pyx_result->debug_mode = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->def_bg = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->def_fg = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->extra_text);
  __Pyx_DECREF(__pyx_v___pyx_result->extra_text);
  __pyx_v___pyx_result->extra_text = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->fg = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 11, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->foreground_color = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 12, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->last_timestamp);
  __Pyx_DECREF(__pyx_v___pyx_result->last_timestamp);
  __pyx_v___pyx_result->last_timestamp = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 13, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->reverse_video);
  __Pyx_DECREF(__pyx_v___pyx_result->reverse_video);
  __pyx_v___pyx_result->reverse_video = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 14, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->sequence);
  __Pyx_DECREF(__pyx_v___pyx_result->sequence);
  __pyx_v___pyx_result->sequence = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 15, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->sequence_pos);
  __Pyx_DECREF(__pyx_v___pyx_result->sequence_pos);
  __pyx_v___pyx_result->sequence_pos = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 16, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->stream);
  __Pyx_DECREF(__pyx_v___pyx_result->stream);
  __pyx_v___pyx_result->stream = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 17, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_5array_array))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->video);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->video));
  __pyx_v___pyx_result->video = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 18, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->video_length = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 19, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->viewport_char_height = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 20, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->viewport_char_stride = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 21, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->viewport_char_width = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 22, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->viewport_px_height = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 23, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->viewport_px_width = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 24, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->window_style);
  __Pyx_DECREF(__pyx_v___pyx_result->window_style);
  __pyx_v___pyx_result->window_style = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 25, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->x = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 26, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->y = __pyx_t_2;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]
 *     if len(__pyx_state) > 27 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[27])
 */
  __Pyx_TraceLine(13,0,__PYX_ERR(1, 13, __pyx_L1_error))
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 27) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]
 *     if len(__pyx_state) > 27 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[27])             # <<<<<<<<<<<<<<
 */
    __Pyx_TraceLine(14,0,__PYX_ERR(1, 14, __pyx_L1_error))
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 27, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]
 *     if len(__pyx_state) > 27 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[27])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]
 *     if len(__pyx_state) > 27 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("ttygif.tty.viewer.__pyx_unpickle_viewer__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":93
 *             __data_union data
 * 
 *         def __getbuffer__(self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cpython_5array_5array___getbuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags) {
  PyObject *__pyx_v_item_count = NULL;
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  char __pyx_t_7;
  if (__pyx_v_info == NULL) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);
  __Pyx_TraceCall("__getbuffer__", __pyx_f[2], 93, 0, __PYX_ERR(2, 93, __pyx_L1_error));

  /* "array.pxd":98
 *             # In particular strided access is always provided regardless
 *             # of flags
 *             item_count = Py_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *             info.suboffsets = NULL
 */
  __Pyx_TraceLine(98,0,__PYX_ERR(2, 98, __pyx_L1_error))
  __pyx_t_1 = PyInt_FromSsize_t(Py_SIZE(((PyObject *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_item_count = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "array.pxd":100
 *             item_count = Py_SIZE(self)
 * 
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
 */
  __Pyx_TraceLine(100,0,__PYX_ERR(2, 100, __pyx_L1_error))
  __pyx_v_info->suboffsets = NULL;

  /* "array.pxd":101
 * 
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars             # <<<<<<<<<<<<<<
 *             info.readonly = 0
 *             info.ndim = 1
 */
  __Pyx_TraceLine(101,0,__PYX_ERR(2, 101, __pyx_L1_error))
  __pyx_t_2 = __pyx_v_self->data.as_chars;
  __pyx_v_info->buf = __pyx_t_2;

  /* "array.pxd":102
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars
 *             info.readonly = 0             # <<<<<<<<<<<<<<
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 */
  __Pyx_TraceLine(102,0,__PYX_ERR(2, 102, __pyx_L1_error))
  __pyx_v_info->readonly = 0;

  /* "array.pxd":103
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
 *             info.ndim = 1             # <<<<<<<<<<<<<<
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 *             info.len = info.itemsize * item_count
 */
  __Pyx_TraceLine(103,0,__PYX_ERR(2, 103, __pyx_L1_error))
  __pyx_v_info->ndim = 1;

  /* "array.pxd":104
 *             info.readonly = 0
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)             # <<<<<<<<<<<<<<
 *             info.len = info.itemsize * item_count
 * 
 */
  __Pyx_TraceLine(104,0,__PYX_ERR(2, 104, __pyx_L1_error))
  __pyx_t_3 = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_info->itemsize = __pyx_t_3;

  /* "array.pxd":105
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 *             info.len = info.itemsize * item_count             # <<<<<<<<<<<<<<
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 */
  __Pyx_TraceLine(105,0,__PYX_ERR(2, 105, __pyx_L1_error))
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_info->itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_1, __pyx_v_item_count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_4); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 105, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_info->len = __pyx_t_5;

  /* "array.pxd":107
 *             info.len = info.itemsize * item_count
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)             # <<<<<<<<<<<<<<
 *             if not info.shape:
 *                 raise MemoryError()
 */
  __Pyx_TraceLine(107,0,__PYX_ERR(2, 107, __pyx_L1_error))
  __pyx_v_info->shape = ((Py_ssize_t *)PyObject_Malloc(((sizeof(Py_ssize_t)) + 2)));

  /* "array.pxd":108
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
 */
  __Pyx_TraceLine(108,0,__PYX_ERR(2, 108, __pyx_L1_error))
  __pyx_t_6 = ((!(__pyx_v_info->shape != 0)) != 0);
  if (unlikely(__pyx_t_6)) {

    /* "array.pxd":109
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:
 *                 raise MemoryError()             # <<<<<<<<<<<<<<
 *             info.shape[0] = item_count      # constant regardless of resizing
 *             info.strides = &info.itemsize
 */
    __Pyx_TraceLine(109,0,__PYX_ERR(2, 109, __pyx_L1_error))
    PyErr_NoMemory(); __PYX_ERR(2, 109, __pyx_L1_error)

    /* "array.pxd":108
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
 */
  }

  /* "array.pxd":110
 *             if not info.shape:
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing             # <<<<<<<<<<<<<<
 *             info.strides = &info.itemsize
 * 
 */
  __Pyx_TraceLine(110,0,__PYX_ERR(2, 110, __pyx_L1_error))
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_v_item_count); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 110, __pyx_L1_error)
  (__pyx_v_info->shape[0]) = __pyx_t_5;

  /* "array.pxd":111
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
 *             info.strides = &info.itemsize             # <<<<<<<<<<<<<<
 * 
 *             info.format = <char*> (info.shape + 1)
 */
  __Pyx_TraceLine(111,0,__PYX_ERR(2, 111, __pyx_L1_error))
  __pyx_v_info->strides = (&__pyx_v_info->itemsize);

  /* "array.pxd":113
 *             info.strides = &info.itemsize
 * 
 *             info.format = <char*> (info.shape + 1)             # <<<<<<<<<<<<<<
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
 */
  __Pyx_TraceLine(113,0,__PYX_ERR(2, 113, __pyx_L1_error))
  __pyx_v_info->format = ((char *)(__pyx_v_info->shape + 1));

  /* "array.pxd":114
 * 
 *             info.format = <char*> (info.shape + 1)
 *             info.format[0] = self.ob_descr.typecode             # <<<<<<<<<<<<<<
 *             info.format[1] = 0
 *             info.obj = self
 */
  __Pyx_TraceLine(114,0,__PYX_ERR(2, 114, __pyx_L1_error))
  __pyx_t_7 = __pyx_v_self->ob_descr->typecode;
  (__pyx_v_info->format[0]) = __pyx_t_7;

  /* "array.pxd":115
 *             info.format = <char*> (info.shape + 1)
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0             # <<<<<<<<<<<<<<
 *             info.obj = self
 * 
 */
  __Pyx_TraceLine(115,0,__PYX_ERR(2, 115, __pyx_L1_error))
  (__pyx_v_info->format[1]) = 0;

  /* "array.pxd":116
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
 *             info.obj = self             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(self, Py_buffer* info):
 */
  __Pyx_TraceLine(116,0,__PYX_ERR(2, 116, __pyx_L1_error))
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "array.pxd":93
 *             __data_union data
 * 
 *         def __getbuffer__(self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cpython.array.array.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_item_count);
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":118
 *             info.obj = self
 * 
 *         def __releasebuffer__(self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             PyObject_Free(info.shape)
 * 
 */

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_7cpython_5array_5array_2__releasebuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);
  __Pyx_TraceCall("__releasebuffer__", __pyx_f[2], 118, 0, __PYX_ERR(2, 118, __pyx_L1_error));

  /* "array.pxd":119
 * 
 *         def __releasebuffer__(self, Py_buffer* info):
 *             PyObject_Free(info.shape)             # <<<<<<<<<<<<<<
 * 
 *     array newarrayobject(PyTypeObject* type, Py_ssize_t size, arraydescr *descr)
 */
  __Pyx_TraceLine(119,0,__PYX_ERR(2, 119, __pyx_L1_error))
  PyObject_Free(__pyx_v_info->shape);

  /* "array.pxd":118
 *             info.obj = self
 * 
 *         def __releasebuffer__(self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             PyObject_Free(info.shape)
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cpython.array.array.__releasebuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
}

/* "array.pxd":130
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
 */

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_clone(arrayobject *__pyx_v_template, Py_ssize_t __pyx_v_length, int __pyx_v_zero) {
  arrayobject *__pyx_v_op = NULL;
  arrayobject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("clone", 0);
  __Pyx_TraceCall("clone", __pyx_f[2], 130, 0, __PYX_ERR(2, 130, __pyx_L1_error));

  /* "array.pxd":134
 *     type will be same as template.
 *     if zero is true, new array will be initialized with zeroes."""
 *     op = newarrayobject(Py_TYPE(template), length, template.ob_descr)             # <<<<<<<<<<<<<<
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 */
  __Pyx_TraceLine(134,0,__PYX_ERR(2, 134, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_template)), __pyx_v_length, __pyx_v_template->ob_descr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "array.pxd":135
 *     if zero is true, new array will be initialized with zeroes."""
 *     op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:             # <<<<<<<<<<<<<<
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op
 */
  __Pyx_TraceLine(135,0,__PYX_ERR(2, 135, __pyx_L1_error))
  __pyx_t_3 = (__pyx_v_zero != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (((PyObject *)__pyx_v_op) != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "array.pxd":136
 *     op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
 */
    __Pyx_TraceLine(136,0,__PYX_ERR(2, 136, __pyx_L1_error))
    (void)(memset(__pyx_v_op->data.as_chars, 0, (__pyx_v_length * __pyx_v_op->ob_descr->itemsize)));

    /* "array.pxd":135
 *     if zero is true, new array will be initialized with zeroes."""
 *     op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:             # <<<<<<<<<<<<<<
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op
 */
  }

  /* "array.pxd":137
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline array copy(array self):
 */
  __Pyx_TraceLine(137,0,__PYX_ERR(2, 137, __pyx_L1_error))
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_op));
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  /* "array.pxd":130
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.clone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":139
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 */

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_copy(arrayobject *__pyx_v_self) {
  arrayobject *__pyx_v_op = NULL;
  arrayobject *__pyx_r = NULL;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("copy", 0);
  __Pyx_TraceCall("copy", __pyx_f[2], 139, 0, __PYX_ERR(2, 139, __pyx_L1_error));

  /* "array.pxd":141
 * cdef inline array copy(array self):
 *     """ make a copy of an array. """
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)             # <<<<<<<<<<<<<<
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op
 */
  __Pyx_TraceLine(141,0,__PYX_ERR(2, 141, __pyx_L1_error))
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_self)), Py_SIZE(((PyObject *)__pyx_v_self)), __pyx_v_self->ob_descr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "array.pxd":142
 *     """ make a copy of an array. """
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
 */
  __Pyx_TraceLine(142,0,__PYX_ERR(2, 142, __pyx_L1_error))
  (void)(memcpy(__pyx_v_op->data.as_chars, __pyx_v_self->data.as_chars, (Py_SIZE(((PyObject *)__pyx_v_op)) * __pyx_v_op->ob_descr->itemsize)));

  /* "array.pxd":143
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:
 */
  __Pyx_TraceLine(143,0,__PYX_ERR(2, 143, __pyx_L1_error))
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_op));
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  /* "array.pxd":139
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_TraceReturn(__pyx_r, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":145
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:             # <<<<<<<<<<<<<<
 *     """ efficient appending of new stuff of same type
 *     (e.g. of same array type)
 */

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *__pyx_v_self, char *__pyx_v_stuff, Py_ssize_t __pyx_v_n) {
  Py_ssize_t __pyx_v_itemsize;
  Py_ssize_t __pyx_v_origsize;
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("extend_buffer", 0);
  __Pyx_TraceCall("extend_buffer", __pyx_f[2], 145, 0, __PYX_ERR(2, 145, __pyx_L1_error));

  /* "array.pxd":149
 *     (e.g. of same array type)
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)
 */
  __Pyx_TraceLine(149,0,__PYX_ERR(2, 149, __pyx_L1_error))
  __pyx_t_1 = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "array.pxd":150
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t origsize = Py_SIZE(self)             # <<<<<<<<<<<<<<
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 */
  __Pyx_TraceLine(150,0,__PYX_ERR(2, 150, __pyx_L1_error))
  __pyx_v_origsize = Py_SIZE(((PyObject *)__pyx_v_self));

  /* "array.pxd":151
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)             # <<<<<<<<<<<<<<
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 *     return 0
 */
  __Pyx_TraceLine(151,0,__PYX_ERR(2, 151, __pyx_L1_error))
  __pyx_t_1 = resize_smart(__pyx_v_self, (__pyx_v_origsize + __pyx_v_n)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 151, __pyx_L1_error)

  /* "array.pxd":152
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
  __Pyx_TraceLine(152,0,__PYX_ERR(2, 152, __pyx_L1_error))
  (void)(memcpy((__pyx_v_self->data.as_chars + (__pyx_v_origsize * __pyx_v_itemsize)), __pyx_v_stuff, (__pyx_v_n * __pyx_v_itemsize)));

  /* "array.pxd":153
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend(array self, array other) except -1:
 */
  __Pyx_TraceLine(153,0,__PYX_ERR(2, 153, __pyx_L1_error))
  __pyx_r = 0;
  goto __pyx_L0;

  /* "array.pxd":145
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:             # <<<<<<<<<<<<<<
 *     """ efficient appending of new stuff of same type
 *     (e.g. of same array type)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cpython.array.extend_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":155
 *     return 0
 * 
 * cdef inline int extend(array self, array other) except -1:             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 */

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend(arrayobject *__pyx_v_self, arrayobject *__pyx_v_other) {
  int __pyx_r;
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("extend", 0);
  __Pyx_TraceCall("extend", __pyx_f[2], 155, 0, __PYX_ERR(2, 155, __pyx_L1_error));

  /* "array.pxd":157
 * cdef inline int extend(array self, array other) except -1:
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:             # <<<<<<<<<<<<<<
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 */
  __Pyx_TraceLine(157,0,__PYX_ERR(2, 157, __pyx_L1_error))
  __pyx_t_1 = ((__pyx_v_self->ob_descr->typecode != __pyx_v_other->ob_descr->typecode) != 0);
  if (__pyx_t_1) {

    /* "array.pxd":158
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 *         PyErr_BadArgument()             # <<<<<<<<<<<<<<
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 */
    __Pyx_TraceLine(158,0,__PYX_ERR(2, 158, __pyx_L1_error))
    __pyx_t_2 = PyErr_BadArgument(); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(2, 158, __pyx_L1_error)

    /* "array.pxd":157
 * cdef inline int extend(array self, array other) except -1:
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:             # <<<<<<<<<<<<<<
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 */
  }

  /* "array.pxd":159
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))             # <<<<<<<<<<<<<<
 * 
 * cdef inline void zero(array self):
 */
  __Pyx_TraceLine(159,0,__PYX_ERR(2, 159, __pyx_L1_error))
  __pyx_t_2 = __pyx_f_7cpython_5array_extend_buffer(__pyx_v_self, __pyx_v_other->data.as_chars, Py_SIZE(((PyObject *)__pyx_v_other))); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 159, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "array.pxd":155
 *     return 0
 * 
 * cdef inline int extend(array self, array other) except -1:             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cpython.array.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":161
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self):             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
 */

static CYTHON_INLINE void __pyx_f_7cpython_5array_zero(arrayobject *__pyx_v_self) {
  __Pyx_TraceDeclarations
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("zero", 0);
  __Pyx_TraceCall("zero", __pyx_f[2], 161, 0, __PYX_ERR(2, 161, __pyx_L1_error));

  /* "array.pxd":163
 * cdef inline void zero(array self):
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 */
  __Pyx_TraceLine(163,0,__PYX_ERR(2, 163, __pyx_L1_error))
  (void)(memset(__pyx_v_self->data.as_chars, 0, (Py_SIZE(((PyObject *)__pyx_v_self)) * __pyx_v_self->ob_descr->itemsize)));

  /* "array.pxd":161
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self):             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cpython.array.zero", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_TraceReturn(Py_None, 0);
  __Pyx_RefNannyFinishContext();
}
static struct __pyx_vtabstruct_6ttygif_3tty_6viewer_viewer __pyx_vtable_6ttygif_3tty_6viewer_viewer;

static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer_viewer(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6ttygif_3tty_6viewer_viewer *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)o);
  p->__pyx_vtab = __pyx_vtabptr_6ttygif_3tty_6viewer_viewer;
  p->last_timestamp = Py_None; Py_INCREF(Py_None);
  p->window_style = Py_None; Py_INCREF(Py_None);
  p->stream = Py_None; Py_INCREF(Py_None);
  p->video = ((arrayobject *)Py_None); Py_INCREF(Py_None);
  p->color_table = Py_None; Py_INCREF(Py_None);
  p->buffer = ((arrayobject *)Py_None); Py_INCREF(Py_None);
  p->debug_mode = Py_None; Py_INCREF(Py_None);
  p->sequence = Py_None; Py_INCREF(Py_None);
  p->sequence_pos = Py_None; Py_INCREF(Py_None);
  p->reverse_video = Py_None; Py_INCREF(Py_None);
  p->bold = Py_None; Py_INCREF(Py_None);
  p->extra_text = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6ttygif_3tty_6viewer_viewer(PyObject *o) {
  struct __pyx_obj_6ttygif_3tty_6viewer_viewer *p = (struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->last_timestamp);
  Py_CLEAR(p->window_style);
  Py_CLEAR(p->stream);
  Py_CLEAR(p->video);
  Py_CLEAR(p->color_table);
  Py_CLEAR(p->buffer);
  Py_CLEAR(p->debug_mode);
  Py_CLEAR(p->sequence);
  Py_CLEAR(p->sequence_pos);
  Py_CLEAR(p->reverse_video);
  Py_CLEAR(p->bold);
  Py_CLEAR(p->extra_text);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6ttygif_3tty_6viewer_viewer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6ttygif_3tty_6viewer_viewer *p = (struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)o;
  if (p->last_timestamp) {
    e = (*v)(p->last_timestamp, a); if (e) return e;
  }
  if (p->window_style) {
    e = (*v)(p->window_style, a); if (e) return e;
  }
  if (p->stream) {
    e = (*v)(p->stream, a); if (e) return e;
  }
  if (p->video) {
    e = (*v)(((PyObject *)p->video), a); if (e) return e;
  }
  if (p->color_table) {
    e = (*v)(p->color_table, a); if (e) return e;
  }
  if (p->buffer) {
    e = (*v)(((PyObject *)p->buffer), a); if (e) return e;
  }
  if (p->debug_mode) {
    e = (*v)(p->debug_mode, a); if (e) return e;
  }
  if (p->sequence) {
    e = (*v)(p->sequence, a); if (e) return e;
  }
  if (p->sequence_pos) {
    e = (*v)(p->sequence_pos, a); if (e) return e;
  }
  if (p->reverse_video) {
    e = (*v)(p->reverse_video, a); if (e) return e;
  }
  if (p->bold) {
    e = (*v)(p->bold, a); if (e) return e;
  }
  if (p->extra_text) {
    e = (*v)(p->extra_text, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6ttygif_3tty_6viewer_viewer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6ttygif_3tty_6viewer_viewer *p = (struct __pyx_obj_6ttygif_3tty_6viewer_viewer *)o;
  tmp = ((PyObject*)p->last_timestamp);
  p->last_timestamp = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->window_style);
  p->window_style = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->stream);
  p->stream = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->video);
  p->video = ((arrayobject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->color_table);
  p->color_table = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->buffer);
  p->buffer = ((arrayobject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->debug_mode);
  p->debug_mode = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sequence);
  p->sequence = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sequence_pos);
  p->sequence_pos = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->reverse_video);
  p->reverse_video = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->bold);
  p->bold = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->extra_text);
  p->extra_text = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_last_timestamp(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_last_timestamp(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_14last_timestamp_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_px_width(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_px_width(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_17viewport_px_width_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_px_height(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_px_height(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_18viewport_px_height_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_char_height(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_char_height(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_height_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_char_width(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_char_width(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_19viewport_char_width_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_char_stride(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_char_stride(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_20viewport_char_stride_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_background_color(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_16background_color_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_background_color(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_16background_color_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_foreground_color(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_16foreground_color_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_foreground_color(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_16foreground_color_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_window_style(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_window_style(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12window_style_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_stream(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_stream(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_6stream_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_video_length(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12video_length_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_video_length(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12video_length_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_buffer_rows(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_11buffer_rows_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_buffer_rows(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_11buffer_rows_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_sequence(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_sequence(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_8sequence_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_sequence_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_sequence_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_12sequence_pos_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_x(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_1x_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_x(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_1x_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_y(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_1y_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_y(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_1y_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_def_fg(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_fg_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_def_fg(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_fg_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_def_bg(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_bg_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_def_bg(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_6def_bg_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_fg(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_2fg_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_fg(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_2fg_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_bg(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_2bg_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_bg(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_2bg_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_reverse_video(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_reverse_video(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_13reverse_video_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_bold(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_bold(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_4bold_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ttygif_3tty_6viewer_6viewer_extra_text(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_1__get__(o);
}

static int __pyx_setprop_6ttygif_3tty_6viewer_6viewer_extra_text(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ttygif_3tty_6viewer_6viewer_10extra_text_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6ttygif_3tty_6viewer_viewer[] = {
  {"draw_string", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3tty_6viewer_6viewer_3draw_string, METH_VARARGS|METH_KEYWORDS, 0},
  {"render", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_5render, METH_NOARGS, 0},
  {"get_text", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_7get_text, METH_NOARGS, 0},
  {"set_mode", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_9set_mode, METH_O, 0},
  {"reset_mode", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_11reset_mode, METH_O, 0},
  {"rgb_to_palette", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3tty_6viewer_6viewer_13rgb_to_palette, METH_VARARGS|METH_KEYWORDS, 0},
  {"last_frame", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_15last_frame, METH_NOARGS, 0},
  {"has_escape", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_17has_escape, METH_O, 0},
  {"clear_sequence", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_19clear_sequence, METH_NOARGS, 0},
  {"add_text_sequence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3tty_6viewer_6viewer_21add_text_sequence, METH_VARARGS|METH_KEYWORDS, 0},
  {"add_command_sequence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3tty_6viewer_6viewer_23add_command_sequence, METH_VARARGS|METH_KEYWORDS, 0},
  {"debug_sequence", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_25debug_sequence, METH_NOARGS, 0},
  {"get", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_27get, METH_NOARGS, 0},
  {"add_event", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_29add_event, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_31__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6ttygif_3tty_6viewer_6viewer_33__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6ttygif_3tty_6viewer_viewer[] = {
  {(char *)"last_timestamp", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_last_timestamp, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_last_timestamp, (char *)0, 0},
  {(char *)"viewport_px_width", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_px_width, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_px_width, (char *)0, 0},
  {(char *)"viewport_px_height", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_px_height, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_px_height, (char *)0, 0},
  {(char *)"viewport_char_height", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_char_height, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_char_height, (char *)0, 0},
  {(char *)"viewport_char_width", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_char_width, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_char_width, (char *)0, 0},
  {(char *)"viewport_char_stride", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_viewport_char_stride, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_viewport_char_stride, (char *)0, 0},
  {(char *)"background_color", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_background_color, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_background_color, (char *)0, 0},
  {(char *)"foreground_color", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_foreground_color, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_foreground_color, (char *)0, 0},
  {(char *)"window_style", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_window_style, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_window_style, (char *)0, 0},
  {(char *)"stream", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_stream, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_stream, (char *)0, 0},
  {(char *)"video_length", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_video_length, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_video_length, (char *)0, 0},
  {(char *)"buffer_rows", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_buffer_rows, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_buffer_rows, (char *)0, 0},
  {(char *)"sequence", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_sequence, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_sequence, (char *)0, 0},
  {(char *)"sequence_pos", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_sequence_pos, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_sequence_pos, (char *)0, 0},
  {(char *)"x", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_x, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_x, (char *)0, 0},
  {(char *)"y", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_y, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_y, (char *)0, 0},
  {(char *)"def_fg", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_def_fg, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_def_fg, (char *)0, 0},
  {(char *)"def_bg", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_def_bg, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_def_bg, (char *)0, 0},
  {(char *)"fg", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_fg, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_fg, (char *)0, 0},
  {(char *)"bg", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_bg, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_bg, (char *)0, 0},
  {(char *)"reverse_video", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_reverse_video, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_reverse_video, (char *)0, 0},
  {(char *)"bold", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_bold, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_bold, (char *)0, 0},
  {(char *)"extra_text", __pyx_getprop_6ttygif_3tty_6viewer_6viewer_extra_text, __pyx_setprop_6ttygif_3tty_6viewer_6viewer_extra_text, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6ttygif_3tty_6viewer_viewer = {
  PyVarObject_HEAD_INIT(0, 0)
  "ttygif.tty.viewer.viewer", /*tp_name*/
  sizeof(struct __pyx_obj_6ttygif_3tty_6viewer_viewer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6ttygif_3tty_6viewer_viewer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6ttygif_3tty_6viewer_viewer, /*tp_traverse*/
  __pyx_tp_clear_6ttygif_3tty_6viewer_viewer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6ttygif_3tty_6viewer_viewer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6ttygif_3tty_6viewer_viewer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_6ttygif_3tty_6viewer_6viewer_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6ttygif_3tty_6viewer_viewer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *__pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence[8];
static int __pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence = 0;

static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence)))) {
    o = (PyObject*)__pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence[--__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence];
    memset(o, 0, sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence(PyObject *o) {
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *p = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_paramstring);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence)))) {
    __pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence[__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence++] = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *p = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *)o;
  if (p->__pyx_v_paramstring) {
    e = (*v)(p->__pyx_v_paramstring, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *p = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence *)o;
  tmp = ((PyObject*)p->__pyx_v_paramstring);
  p->__pyx_v_paramstring = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence = {
  PyVarObject_HEAD_INIT(0, 0)
  "ttygif.tty.viewer.__pyx_scope_struct__stream_2_sequence", /*tp_name*/
  sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence, /*tp_traverse*/
  __pyx_tp_clear_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *__pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr[8];
static int __pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr = 0;

static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr[--__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr(PyObject *o) {
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_p);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr)))) {
    __pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr[__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr++] = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_p) {
    e = (*v)(p->__pyx_v_p, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "ttygif.tty.viewer.__pyx_scope_struct_1_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *__pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr[8];
static int __pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr = 0;

static PyObject *__pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr[--__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr(PyObject *o) {
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_p);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr)))) {
    __pyx_freelist_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr[__pyx_freecount_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr++] = ((struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_p) {
    e = (*v)(p->__pyx_v_p, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "ttygif.tty.viewer.__pyx_scope_struct_2_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_viewer(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_viewer},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "viewer",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 1, 0},
  {&__pyx_n_s_A, __pyx_k_A, sizeof(__pyx_k_A), 0, 0, 1, 1},
  {&__pyx_n_s_ABCD, __pyx_k_ABCD, sizeof(__pyx_k_ABCD), 0, 0, 1, 1},
  {&__pyx_n_s_B, __pyx_k_B, sizeof(__pyx_k_B), 0, 0, 1, 1},
  {&__pyx_n_s_BOTTOM, __pyx_k_BOTTOM, sizeof(__pyx_k_BOTTOM), 0, 0, 1, 1},
  {&__pyx_kp_s_Buffer, __pyx_k_Buffer, sizeof(__pyx_k_Buffer), 0, 0, 1, 0},
  {&__pyx_n_s_C, __pyx_k_C, sizeof(__pyx_k_C), 0, 0, 1, 1},
  {&__pyx_n_s_CHAR_SET, __pyx_k_CHAR_SET, sizeof(__pyx_k_CHAR_SET), 0, 0, 1, 1},
  {&__pyx_kp_s_CMD_0_Name_3_Command_1_Params_2, __pyx_k_CMD_0_Name_3_Command_1_Params_2, sizeof(__pyx_k_CMD_0_Name_3_Command_1_Params_2), 0, 0, 1, 0},
  {&__pyx_n_s_CSI, __pyx_k_CSI, sizeof(__pyx_k_CSI), 0, 0, 1, 1},
  {&__pyx_kp_s_Charactrer_out_of_range_0, __pyx_k_Charactrer_out_of_range_0, sizeof(__pyx_k_Charactrer_out_of_range_0), 0, 0, 1, 0},
  {&__pyx_kp_s_Count_0, __pyx_k_Count_0, sizeof(__pyx_k_Count_0), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Down, __pyx_k_Cursor_Down, sizeof(__pyx_k_Cursor_Down), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Down_0_x_1_2_y_2_2, __pyx_k_Cursor_Down_0_x_1_2_y_2_2, sizeof(__pyx_k_Cursor_Down_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Left, __pyx_k_Cursor_Left, sizeof(__pyx_k_Cursor_Left), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Left_0_x_1_2_y_2_2, __pyx_k_Cursor_Left_0_x_1_2_y_2_2, sizeof(__pyx_k_Cursor_Left_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Next_Line, __pyx_k_Cursor_Next_Line, sizeof(__pyx_k_Cursor_Next_Line), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Next_Line_0_x_1_2_y_2_2, __pyx_k_Cursor_Next_Line_0_x_1_2_y_2_2, sizeof(__pyx_k_Cursor_Next_Line_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Pos, __pyx_k_Cursor_Pos, sizeof(__pyx_k_Cursor_Pos), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Pos_0_1, __pyx_k_Cursor_Pos_0_1, sizeof(__pyx_k_Cursor_Pos_0_1), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Previous_Line, __pyx_k_Cursor_Previous_Line, sizeof(__pyx_k_Cursor_Previous_Line), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Previous_Line_0_x_1_2_y_2, __pyx_k_Cursor_Previous_Line_0_x_1_2_y_2, sizeof(__pyx_k_Cursor_Previous_Line_0_x_1_2_y_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Right, __pyx_k_Cursor_Right, sizeof(__pyx_k_Cursor_Right), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Right_0_x_1_2_y_2_2, __pyx_k_Cursor_Right_0_x_1_2_y_2_2, sizeof(__pyx_k_Cursor_Right_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Up, __pyx_k_Cursor_Up, sizeof(__pyx_k_Cursor_Up), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_Up_0_x_1_2_y_2_2, __pyx_k_Cursor_Up_0_x_1_2_y_2_2, sizeof(__pyx_k_Cursor_Up_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_X, __pyx_k_Cursor_X, sizeof(__pyx_k_Cursor_X), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_X_0_x_1_2_y_2_2, __pyx_k_Cursor_X_0_x_1_2_y_2_2, sizeof(__pyx_k_Cursor_X_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_X_0_x_1_2_y_2_2_2, __pyx_k_Cursor_X_0_x_1_2_y_2_2_2, sizeof(__pyx_k_Cursor_X_0_x_1_2_y_2_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Cursor_d_Y_0_x_1_2_y_2_2, __pyx_k_Cursor_d_Y_0_x_1_2_y_2_2, sizeof(__pyx_k_Cursor_d_Y_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_n_s_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 0, 1, 1},
  {&__pyx_kp_s_Delete_number_of_charchters_on_l, __pyx_k_Delete_number_of_charchters_on_l, sizeof(__pyx_k_Delete_number_of_charchters_on_l), 0, 0, 1, 0},
  {&__pyx_n_s_E, __pyx_k_E, sizeof(__pyx_k_E), 0, 0, 1, 1},
  {&__pyx_kp_s_Erase_Display, __pyx_k_Erase_Display, sizeof(__pyx_k_Erase_Display), 0, 0, 1, 0},
  {&__pyx_kp_s_Erase_Display_and_buffer, __pyx_k_Erase_Display_and_buffer, sizeof(__pyx_k_Erase_Display_and_buffer), 0, 0, 1, 0},
  {&__pyx_kp_s_Erase_Display_cursor_to_end, __pyx_k_Erase_Display_cursor_to_end, sizeof(__pyx_k_Erase_Display_cursor_to_end), 0, 0, 1, 0},
  {&__pyx_kp_s_Erase_Display_top_til_cursor, __pyx_k_Erase_Display_top_til_cursor, sizeof(__pyx_k_Erase_Display_top_til_cursor), 0, 0, 1, 0},
  {&__pyx_kp_s_Erase_Line, __pyx_k_Erase_Line, sizeof(__pyx_k_Erase_Line), 0, 0, 1, 0},
  {&__pyx_kp_s_Erase_Line_0, __pyx_k_Erase_Line_0, sizeof(__pyx_k_Erase_Line_0), 0, 0, 1, 0},
  {&__pyx_kp_s_Erase_number_of_charchters_on_li, __pyx_k_Erase_number_of_charchters_on_li, sizeof(__pyx_k_Erase_number_of_charchters_on_li), 0, 0, 1, 0},
  {&__pyx_n_s_F, __pyx_k_F, sizeof(__pyx_k_F), 0, 0, 1, 1},
  {&__pyx_n_s_G, __pyx_k_G, sizeof(__pyx_k_G), 0, 0, 1, 1},
  {&__pyx_n_s_G0, __pyx_k_G0, sizeof(__pyx_k_G0), 0, 0, 1, 1},
  {&__pyx_n_s_G1, __pyx_k_G1, sizeof(__pyx_k_G1), 0, 0, 1, 1},
  {&__pyx_n_s_H, __pyx_k_H, sizeof(__pyx_k_H), 0, 0, 1, 1},
  {&__pyx_n_s_Hf, __pyx_k_Hf, sizeof(__pyx_k_Hf), 0, 0, 1, 1},
  {&__pyx_kp_s_Impliment_pos_x_2_Y_3_0_1, __pyx_k_Impliment_pos_x_2_Y_3_0_1, sizeof(__pyx_k_Impliment_pos_x_2_Y_3_0_1), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x3c, __pyx_k_Incompatible_checksums_s_vs_0x3c, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x3c), 0, 0, 1, 0},
  {&__pyx_n_s_J, __pyx_k_J, sizeof(__pyx_k_J), 0, 0, 1, 1},
  {&__pyx_n_s_JKm, __pyx_k_JKm, sizeof(__pyx_k_JKm), 0, 0, 1, 1},
  {&__pyx_n_s_K, __pyx_k_K, sizeof(__pyx_k_K), 0, 0, 1, 1},
  {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
  {&__pyx_kp_s_Missing_character_0, __pyx_k_Missing_character_0, sizeof(__pyx_k_Missing_character_0), 0, 0, 1, 0},
  {&__pyx_kp_s_Msg_0_X_1_Y_2_C_3_FG_4_BG_5_Buff, __pyx_k_Msg_0_X_1_Y_2_C_3_FG_4_BG_5_Buff, sizeof(__pyx_k_Msg_0_X_1_Y_2_C_3_FG_4_BG_5_Buff), 0, 0, 1, 0},
  {&__pyx_n_s_OSC, __pyx_k_OSC, sizeof(__pyx_k_OSC), 0, 0, 1, 1},
  {&__pyx_n_s_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 0, 1, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_kp_s_RESET_All, __pyx_k_RESET_All, sizeof(__pyx_k_RESET_All), 0, 0, 1, 0},
  {&__pyx_kp_s_Reverse_Video_Off, __pyx_k_Reverse_Video_Off, sizeof(__pyx_k_Reverse_Video_Off), 0, 0, 1, 0},
  {&__pyx_kp_s_Reverse_Video_On, __pyx_k_Reverse_Video_On, sizeof(__pyx_k_Reverse_Video_On), 0, 0, 1, 0},
  {&__pyx_n_s_SINGLE, __pyx_k_SINGLE, sizeof(__pyx_k_SINGLE), 0, 0, 1, 1},
  {&__pyx_kp_s_Sequence_List, __pyx_k_Sequence_List, sizeof(__pyx_k_Sequence_List), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_BG, __pyx_k_Set_BG, sizeof(__pyx_k_Set_BG), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_BOLD, __pyx_k_Set_BOLD, sizeof(__pyx_k_Set_BOLD), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_Default_BG, __pyx_k_Set_Default_BG, sizeof(__pyx_k_Set_Default_BG), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_Default_FG, __pyx_k_Set_Default_FG, sizeof(__pyx_k_Set_Default_FG), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_FG, __pyx_k_Set_FG, sizeof(__pyx_k_Set_FG), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_High_INTENSITY_BG, __pyx_k_Set_High_INTENSITY_BG, sizeof(__pyx_k_Set_High_INTENSITY_BG), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_High_INTENSITY_FG, __pyx_k_Set_High_INTENSITY_FG, sizeof(__pyx_k_Set_High_INTENSITY_FG), 0, 0, 1, 0},
  {&__pyx_kp_s_Set_mode_0_x_1_2_y_2_2, __pyx_k_Set_mode_0_x_1_2_y_2_2, sizeof(__pyx_k_Set_mode_0_x_1_2_y_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Text_0_Length_1_Timestamp_2, __pyx_k_Text_0_Length_1_Timestamp_2, sizeof(__pyx_k_Text_0_Length_1_Timestamp_2), 0, 0, 1, 0},
  {&__pyx_kp_s_VIEWPORT, __pyx_k_VIEWPORT, sizeof(__pyx_k_VIEWPORT), 0, 0, 1, 0},
  {&__pyx_n_s_X, __pyx_k_X, sizeof(__pyx_k_X), 0, 0, 1, 1},
  {&__pyx_kp_u_X_0_2_1_2_FG_2_2_BG_3_Text_4, __pyx_k_X_0_2_1_2_FG_2_2_BG_3_Text_4, sizeof(__pyx_k_X_0_2_1_2_FG_2_2_BG_3_Text_4), 0, 1, 0, 0},
  {&__pyx_kp_s__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 0, 1, 0},
  {&__pyx_kp_s__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 0, 1, 0},
  {&__pyx_kp_s__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 0, 1, 0},
  {&__pyx_kp_s__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 0, 1, 0},
  {&__pyx_kp_s__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 0, 1, 0},
  {&__pyx_kp_s__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
  {&__pyx_kp_s__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 0, 1, 0},
  {&__pyx_kp_s__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 0, 1, 0},
  #if PY_MAJOR_VERSION >= 3
  {&__pyx_kp_s__8, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  #else
  {&__pyx_kp_s__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 0, 1, 0},
  #endif
  {&__pyx_kp_s__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 0, 1, 0},
  {&__pyx_n_s_add_command_sequence, __pyx_k_add_command_sequence, sizeof(__pyx_k_add_command_sequence), 0, 0, 1, 1},
  {&__pyx_n_s_add_text_sequence, __pyx_k_add_text_sequence, sizeof(__pyx_k_add_text_sequence), 0, 0, 1, 1},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
  {&__pyx_n_s_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 0, 1, 1},
  {&__pyx_kp_s_b_B0UK, __pyx_k_b_B0UK, sizeof(__pyx_k_b_B0UK), 0, 0, 1, 0},
  {&__pyx_kp_s_b_B0UK_2, __pyx_k_b_B0UK_2, sizeof(__pyx_k_b_B0UK_2), 0, 0, 1, 0},
  {&__pyx_kp_s_b_G, __pyx_k_b_G, sizeof(__pyx_k_b_G), 0, 0, 1, 0},
  {&__pyx_kp_s_b_cDEHMZ78, __pyx_k_b_cDEHMZ78, sizeof(__pyx_k_b_cDEHMZ78), 0, 0, 1, 0},
  {&__pyx_kp_s_b_d_a_zA_Z, __pyx_k_b_d_a_zA_Z, sizeof(__pyx_k_b_d_a_zA_Z), 0, 0, 1, 0},
  {&__pyx_kp_s_buffer_char_height_0, __pyx_k_buffer_char_height_0, sizeof(__pyx_k_buffer_char_height_0), 0, 0, 1, 0},
  {&__pyx_kp_s_char_buffer_size_0, __pyx_k_char_buffer_size_0, sizeof(__pyx_k_char_buffer_size_0), 0, 0, 1, 0},
  {&__pyx_n_s_char_height, __pyx_k_char_height, sizeof(__pyx_k_char_height), 0, 0, 1, 1},
  {&__pyx_kp_s_char_height_0, __pyx_k_char_height_0, sizeof(__pyx_k_char_height_0), 0, 0, 1, 0},
  {&__pyx_kp_s_char_stride_0, __pyx_k_char_stride_0, sizeof(__pyx_k_char_stride_0), 0, 0, 1, 0},
  {&__pyx_n_s_char_width, __pyx_k_char_width, sizeof(__pyx_k_char_width), 0, 0, 1, 1},
  {&__pyx_kp_s_char_width_0, __pyx_k_char_width_0, sizeof(__pyx_k_char_width_0), 0, 0, 1, 0},
  {&__pyx_n_s_clear_sequence, __pyx_k_clear_sequence, sizeof(__pyx_k_clear_sequence), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_color_table, __pyx_k_color_table, sizeof(__pyx_k_color_table), 0, 0, 1, 1},
  {&__pyx_n_s_command, __pyx_k_command, sizeof(__pyx_k_command), 0, 0, 1, 1},
  {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
  {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_s_delay, __pyx_k_delay, sizeof(__pyx_k_delay), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
  {&__pyx_n_s_esc_type, __pyx_k_esc_type, sizeof(__pyx_k_esc_type), 0, 0, 1, 1},
  {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
  {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
  {&__pyx_n_s_finditer, __pyx_k_finditer, sizeof(__pyx_k_finditer), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_g, __pyx_k_g, sizeof(__pyx_k_g), 0, 0, 1, 1},
  {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_groups, __pyx_k_groups, sizeof(__pyx_k_groups), 0, 0, 1, 1},
  {&__pyx_n_s_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 0, 1, 1},
  {&__pyx_n_s_has_escape, __pyx_k_has_escape, sizeof(__pyx_k_has_escape), 0, 0, 1, 1},
  {&__pyx_n_s_height, __pyx_k_height, sizeof(__pyx_k_height), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
  {&__pyx_n_s_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 0, 1, 1},
  {&__pyx_n_s_params, __pyx_k_params, sizeof(__pyx_k_params), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_kp_s_px_height_0, __pyx_k_px_height_0, sizeof(__pyx_k_px_height_0), 0, 0, 1, 0},
  {&__pyx_kp_s_px_width_0, __pyx_k_px_width_0, sizeof(__pyx_k_px_width_0), 0, 0, 1, 0},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_viewer, __pyx_k_pyx_unpickle_viewer, sizeof(__pyx_k_pyx_unpickle_viewer), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_reset_mode, __pyx_k_reset_mode, sizeof(__pyx_k_reset_mode), 0, 0, 1, 1},
  {&__pyx_n_s_rgb_to_palette, __pyx_k_rgb_to_palette, sizeof(__pyx_k_rgb_to_palette), 0, 0, 1, 1},
  {&__pyx_n_s_round, __pyx_k_round, sizeof(__pyx_k_round), 0, 0, 1, 1},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_set_mode, __pyx_k_set_mode, sizeof(__pyx_k_set_mode), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_span, __pyx_k_span, sizeof(__pyx_k_span), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_timestamp, __pyx_k_timestamp, sizeof(__pyx_k_timestamp), 0, 0, 1, 1},
  {&__pyx_n_s_ttygif_tty_viewer, __pyx_k_ttygif_tty_viewer, sizeof(__pyx_k_ttygif_tty_viewer), 0, 0, 1, 1},
  {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
  {&__pyx_n_s_unichr, __pyx_k_unichr, sizeof(__pyx_k_unichr), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_kp_s_video_buffer_size_0, __pyx_k_video_buffer_size_0, sizeof(__pyx_k_video_buffer_size_0), 0, 0, 1, 0},
  {&__pyx_n_s_viewer, __pyx_k_viewer, sizeof(__pyx_k_viewer), 0, 0, 1, 1},
  {&__pyx_n_s_viewer_stream_2_sequence_locals, __pyx_k_viewer_stream_2_sequence_locals, sizeof(__pyx_k_viewer_stream_2_sequence_locals), 0, 0, 1, 1},
  {&__pyx_n_s_width, __pyx_k_width, sizeof(__pyx_k_width), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {&__pyx_n_s_y, __pyx_k_y, sizeof(__pyx_k_y), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 255, __pyx_L1_error)
  __pyx_builtin_unichr = __Pyx_GetBuiltinName(__pyx_n_s_unichr); if (!__pyx_builtin_unichr) __PYX_ERR(0, 273, __pyx_L1_error)
  __pyx_builtin_round = __Pyx_GetBuiltinName(__pyx_n_s_round); if (!__pyx_builtin_round) __PYX_ERR(0, 866, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(2, 109, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "ttygif/tty/viewer.pyx":55
 * 
 *     cdef new_char_buffer(self):
 *         cdef array.array buffer=array.array('B')             # <<<<<<<<<<<<<<
 *         array.resize(buffer,self.viewport_char_stride*self.viewport_char_height)
 *         memset(buffer.data.as_voidptr, self.background_color, len(buffer) * sizeof(char))
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_n_s_B); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "ttygif/tty/viewer.pyx":684
 *                     params = tuple(int(p) if len(p) != 0 else 1 for p in paramstring.split(';'))
 *                     while len(params) < 2:
 *                         params = params + (1,)             # <<<<<<<<<<<<<<
 *                 #        DEC Private Mode (DECSET/DECRST) sequences
 *                 elif paramstring and len(paramstring)>0 and paramstring[0]=='?':
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "ttygif/tty/viewer.pyx":687
 *                 #        DEC Private Mode (DECSET/DECRST) sequences
 *                 elif paramstring and len(paramstring)>0 and paramstring[0]=='?':
 *                     params=['?',paramstring[1:-1],paramstring[-1]]             # <<<<<<<<<<<<<<
 *                 else:
 * 
 */
  __pyx_slice__14 = PySlice_New(__pyx_int_1, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__14)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__14);
  __Pyx_GIVEREF(__pyx_slice__14);

  /* "ttygif/tty/viewer.pyx":693
 *                     if len(params) == 0:
 *                         if command in 'JKm':
 *                             params = (0,)             # <<<<<<<<<<<<<<
 *                         elif command in 'ABCD':
 *                             params = (1,)
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_int_0); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "(tree fragment)":1
 * def __pyx_unpickle_viewer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__18 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);
  __pyx_codeobj__17 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_viewer, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__17)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_18 = PyInt_FromLong(18); if (unlikely(!__pyx_int_18)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_27 = PyInt_FromLong(27); if (unlikely(!__pyx_int_27)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_28 = PyInt_FromLong(28); if (unlikely(!__pyx_int_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_30 = PyInt_FromLong(30); if (unlikely(!__pyx_int_30)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_32 = PyInt_FromLong(32); if (unlikely(!__pyx_int_32)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_37 = PyInt_FromLong(37); if (unlikely(!__pyx_int_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_38 = PyInt_FromLong(38); if (unlikely(!__pyx_int_38)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_39 = PyInt_FromLong(39); if (unlikely(!__pyx_int_39)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_40 = PyInt_FromLong(40); if (unlikely(!__pyx_int_40)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_47 = PyInt_FromLong(47); if (unlikely(!__pyx_int_47)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_48 = PyInt_FromLong(48); if (unlikely(!__pyx_int_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_49 = PyInt_FromLong(49); if (unlikely(!__pyx_int_49)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_58 = PyInt_FromLong(58); if (unlikely(!__pyx_int_58)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_68 = PyInt_FromLong(68); if (unlikely(!__pyx_int_68)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_78 = PyInt_FromLong(78); if (unlikely(!__pyx_int_78)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_88 = PyInt_FromLong(88); if (unlikely(!__pyx_int_88)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_90 = PyInt_FromLong(90); if (unlikely(!__pyx_int_90)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_95 = PyInt_FromLong(95); if (unlikely(!__pyx_int_95)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_97 = PyInt_FromLong(97); if (unlikely(!__pyx_int_97)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_98 = PyInt_FromLong(98); if (unlikely(!__pyx_int_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_100 = PyInt_FromLong(100); if (unlikely(!__pyx_int_100)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_107 = PyInt_FromLong(107); if (unlikely(!__pyx_int_107)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_108 = PyInt_FromLong(108); if (unlikely(!__pyx_int_108)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_118 = PyInt_FromLong(118); if (unlikely(!__pyx_int_118)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_135 = PyInt_FromLong(135); if (unlikely(!__pyx_int_135)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_138 = PyInt_FromLong(138); if (unlikely(!__pyx_int_138)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_148 = PyInt_FromLong(148); if (unlikely(!__pyx_int_148)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_158 = PyInt_FromLong(158); if (unlikely(!__pyx_int_158)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_168 = PyInt_FromLong(168); if (unlikely(!__pyx_int_168)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_175 = PyInt_FromLong(175); if (unlikely(!__pyx_int_175)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_178 = PyInt_FromLong(178); if (unlikely(!__pyx_int_178)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_188 = PyInt_FromLong(188); if (unlikely(!__pyx_int_188)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_192 = PyInt_FromLong(192); if (unlikely(!__pyx_int_192)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_198 = PyInt_FromLong(198); if (unlikely(!__pyx_int_198)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_208 = PyInt_FromLong(208); if (unlikely(!__pyx_int_208)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_215 = PyInt_FromLong(215); if (unlikely(!__pyx_int_215)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_218 = PyInt_FromLong(218); if (unlikely(!__pyx_int_218)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_228 = PyInt_FromLong(228); if (unlikely(!__pyx_int_228)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_238 = PyInt_FromLong(238); if (unlikely(!__pyx_int_238)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_255 = PyInt_FromLong(255); if (unlikely(!__pyx_int_255)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_480 = PyInt_FromLong(480); if (unlikely(!__pyx_int_480)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_640 = PyInt_FromLong(640); if (unlikely(!__pyx_int_640)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_63536012 = PyInt_FromLong(63536012L); if (unlikely(!__pyx_int_63536012)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_6ttygif_3tty_6viewer_viewer = &__pyx_vtable_6ttygif_3tty_6viewer_viewer;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.ascii_safe = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *))__pyx_f_6ttygif_3tty_6viewer_6viewer_ascii_safe;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.info = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *))__pyx_f_6ttygif_3tty_6viewer_6viewer_info;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.new_char_buffer = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *))__pyx_f_6ttygif_3tty_6viewer_6viewer_new_char_buffer;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.new_video_buffer = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *))__pyx_f_6ttygif_3tty_6viewer_6viewer_new_video_buffer;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.draw_character3 = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, int, int, int, int, int, int))__pyx_f_6ttygif_3tty_6viewer_6viewer_draw_character3;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.get_buffer_height = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *))__pyx_f_6ttygif_3tty_6viewer_6viewer_get_buffer_height;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.debug = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *))__pyx_f_6ttygif_3tty_6viewer_6viewer_debug;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.shift_buffer = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, arrayobject *))__pyx_f_6ttygif_3tty_6viewer_6viewer_shift_buffer;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.write_buffer = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, int, int, int, arrayobject *))__pyx_f_6ttygif_3tty_6viewer_6viewer_write_buffer;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.sequence_to_buffer = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *))__pyx_f_6ttygif_3tty_6viewer_6viewer_sequence_to_buffer;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.stream_2_sequence = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *, PyObject *, PyObject *))__pyx_f_6ttygif_3tty_6viewer_6viewer_stream_2_sequence;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.remap_character = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *, PyObject *))__pyx_f_6ttygif_3tty_6viewer_6viewer_remap_character;
  __pyx_vtable_6ttygif_3tty_6viewer_viewer.save_screen = (PyObject *(*)(struct __pyx_obj_6ttygif_3tty_6viewer_viewer *))__pyx_f_6ttygif_3tty_6viewer_6viewer_save_screen;
  if (PyType_Ready(&__pyx_type_6ttygif_3tty_6viewer_viewer) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __pyx_type_6ttygif_3tty_6viewer_viewer.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6ttygif_3tty_6viewer_viewer.tp_dictoffset && __pyx_type_6ttygif_3tty_6viewer_viewer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6ttygif_3tty_6viewer_viewer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6ttygif_3tty_6viewer_viewer.tp_dict, __pyx_vtabptr_6ttygif_3tty_6viewer_viewer) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_viewer, (PyObject *)&__pyx_type_6ttygif_3tty_6viewer_viewer) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6ttygif_3tty_6viewer_viewer) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __pyx_ptype_6ttygif_3tty_6viewer_viewer = &__pyx_type_6ttygif_3tty_6viewer_viewer;
  if (PyType_Ready(&__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence) < 0) __PYX_ERR(0, 631, __pyx_L1_error)
  __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence.tp_dictoffset && __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence = &__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct__stream_2_sequence;
  if (PyType_Ready(&__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr) < 0) __PYX_ERR(0, 682, __pyx_L1_error)
  __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr.tp_dictoffset && __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr = &__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_1_genexpr;
  if (PyType_Ready(&__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 690, __pyx_L1_error)
  __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr.tp_dictoffset && __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr = &__pyx_type_6ttygif_3tty_6viewer___pyx_scope_struct_2_genexpr;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "bool", sizeof(PyBoolObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4bool_bool) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "complex", sizeof(PyComplexObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_7complex_complex) __PYX_ERR(5, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("array"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_5array_array = __Pyx_ImportType(__pyx_t_1, "array", "array", sizeof(arrayobject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_5array_array) __PYX_ERR(2, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ttygif.tty.font"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6ttygif_3tty_4font_font_map = __Pyx_ImportType(__pyx_t_1, "ttygif.tty.font", "font_map", sizeof(struct __pyx_obj_6ttygif_3tty_4font_font_map), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ttygif_3tty_4font_font_map) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __pyx_t_1 = PyImport_ImportModule("ttygif.tty.fonts"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "font", (void **)&__pyx_vp_6ttygif_3tty_5fonts_font, "struct __pyx_obj_6ttygif_3tty_4font_font_map *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION < 3
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC void
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#else
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initviewer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initviewer(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_viewer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_viewer(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_viewer(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  __Pyx_TraceDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'viewer' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_viewer(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("viewer", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_ttygif__tty__viewer) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "ttygif.tty.viewer")) {
      if (unlikely(PyDict_SetItemString(modules, "ttygif.tty.viewer", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() != 0)) goto __pyx_L1_error;
  if (unlikely(__Pyx_modinit_type_import_code() != 0)) goto __pyx_L1_error;
  if (unlikely(__Pyx_modinit_variable_import_code() != 0)) goto __pyx_L1_error;
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __Pyx_TraceCall("__Pyx_PyMODINIT_FUNC PyInit_viewer(void)", __pyx_f[0], 1, 0, __PYX_ERR(0, 1, __pyx_L1_error));

  /* "ttygif/tty/viewer.pyx":4
 * 
 * from cpython cimport array
 * import array             # <<<<<<<<<<<<<<
 * import re
 * from libc.string cimport memset
 */
  __Pyx_TraceLine(4,0,__PYX_ERR(0, 4, __pyx_L1_error))
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_array, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_array, __pyx_t_1) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":5
 * from cpython cimport array
 * import array
 * import re             # <<<<<<<<<<<<<<
 * from libc.string cimport memset
 * 
 */
  __Pyx_TraceLine(5,0,__PYX_ERR(0, 5, __pyx_L1_error))
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_re, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_1) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/tty/viewer.pyx":47
 *     cdef public object          extra_text
 * 
 *     cdef ascii_safe(self,text):             # <<<<<<<<<<<<<<
 *         return ''.join([i if ord(i) < 128 else '*' for i in text])
 * 
 */
  __Pyx_TraceLine(47,0,__PYX_ERR(0, 47, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":50
 *         return ''.join([i if ord(i) < 128 else '*' for i in text])
 * 
 *     cdef info(self,text):             # <<<<<<<<<<<<<<
 *         if self.debug_mode:
 *             print(self.ascii_safe(text))
 */
  __Pyx_TraceLine(50,0,__PYX_ERR(0, 50, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":54
 *             print(self.ascii_safe(text))
 * 
 *     cdef new_char_buffer(self):             # <<<<<<<<<<<<<<
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_char_stride*self.viewport_char_height)
 */
  __Pyx_TraceLine(54,0,__PYX_ERR(0, 54, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":61
 *         return buffer
 * 
 *     cdef new_video_buffer(self):             # <<<<<<<<<<<<<<
 *         cdef array.array buffer=array.array('B')
 *         array.resize(buffer,self.viewport_px_width*self.viewport_px_height)
 */
  __Pyx_TraceLine(61,0,__PYX_ERR(0, 61, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":158
 *             x+=1
 * 
 *     cdef draw_character3(self,int character,int x,int y,int offset,int foreground_color,int background_color):             # <<<<<<<<<<<<<<
 *         cdef int fs            = font.width
 *         cdef int fw            = font.font_width
 */
  __Pyx_TraceLine(158,0,__PYX_ERR(0, 158, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":202
 * 
 * 
 *     cdef get_buffer_height(self):             # <<<<<<<<<<<<<<
 *         #print self.buffer_rows,"ROWS"
 *         height=self.buffer_rows*font.font_height
 */
  __Pyx_TraceLine(202,0,__PYX_ERR(0, 202, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":237
 * 
 *     # convert the text stream to a text formated grid
 *     cdef debug(self):             # <<<<<<<<<<<<<<
 *         print("VIEWPORT:")
 *         print("  px height:          {0}".format(self.viewport_px_height))
 */
  __Pyx_TraceLine(237,0,__PYX_ERR(0, 237, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":252
 * 
 * 
 *     cdef shift_buffer(self,array.array buffer):             # <<<<<<<<<<<<<<
 *         cdef int buffer_length=len(buffer)
 *         cdef int index=self.viewport_char_width
 */
  __Pyx_TraceLine(252,0,__PYX_ERR(0, 252, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":290
 * 
 * 
 *     cdef write_buffer(self,int x,int y,int c,array.array buffer):             # <<<<<<<<<<<<<<
 *         if c>255:
 *             err_msg="Charactrer out of range -{0}".format(c)
 */
  __Pyx_TraceLine(290,0,__PYX_ERR(0, 290, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":396
 * 
 *     # commands pre parsed on add_event
 *     cdef sequence_to_buffer(self):             # <<<<<<<<<<<<<<
 * 
 *         cdef int pos=0
 */
  __Pyx_TraceLine(396,0,__PYX_ERR(0, 396, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":631
 * 
 * 
 *     cdef stream_2_sequence(self,text,timestamp,delay):             # <<<<<<<<<<<<<<
 * 
 *         # patterns for filtering out commands from the stream
 */
  __Pyx_TraceLine(631,0,__PYX_ERR(0, 631, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":777
 *         self.sequence=[]
 * 
 *     cdef remap_character(self,character):             # <<<<<<<<<<<<<<
 *       #print character
 *         #print character
 */
  __Pyx_TraceLine(777,0,__PYX_ERR(0, 777, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":881
 *             self.last_timestamp=timestamp
 * 
 *     cdef save_screen(self):             # <<<<<<<<<<<<<<
 *         # todo save as gif..
 *         # pre test with canvas extension
 */
  __Pyx_TraceLine(881,0,__PYX_ERR(0, 881, __pyx_L1_error))


  /* "(tree fragment)":1
 * def __pyx_unpickle_viewer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __Pyx_TraceLine(1,0,__PYX_ERR(1, 1, __pyx_L1_error))
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_6ttygif_3tty_6viewer_1__pyx_unpickle_viewer, NULL, __pyx_n_s_ttygif_tty_viewer); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_viewer, __pyx_t_1) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_viewer__set_state(<viewer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_viewer__set_state(viewer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.background_color = __pyx_state[0]; __pyx_result.bg = __pyx_state[1]; __pyx_result.bold = __pyx_state[2]; __pyx_result.buffer = __pyx_state[3]; __pyx_result.buffer_rows = __pyx_state[4]; __pyx_result.color_table = __pyx_state[5]; __pyx_result.debug_mode = __pyx_state[6]; __pyx_result.def_bg = __pyx_state[7]; __pyx_result.def_fg = __pyx_state[8]; __pyx_result.extra_text = __pyx_state[9]; __pyx_result.fg = __pyx_state[10]; __pyx_result.foreground_color = __pyx_state[11]; __pyx_result.last_timestamp = __pyx_state[12]; __pyx_result.reverse_video = __pyx_state[13]; __pyx_result.sequence = __pyx_state[14]; __pyx_result.sequence_pos = __pyx_state[15]; __pyx_result.stream = __pyx_state[16]; __pyx_result.video = __pyx_state[17]; __pyx_result.video_length = __pyx_state[18]; __pyx_result.viewport_char_height = __pyx_state[19]; __pyx_result.viewport_char_stride = __pyx_state[20]; __pyx_result.viewport_char_width = __pyx_state[21]; __pyx_result.viewport_px_height = __pyx_state[22]; __pyx_result.viewport_px_width = __pyx_state[23]; __pyx_result.window_style = __pyx_state[24]; __pyx_result.x = __pyx_state[25]; __pyx_result.y = __pyx_state[26]
 *     if len(__pyx_state) > 27 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_TraceLine(11,0,__PYX_ERR(1, 11, __pyx_L1_error))


  /* "ttygif/tty/viewer.pyx":1
 * # cython: linetrace=True             # <<<<<<<<<<<<<<
 * 
 * from cpython cimport array
 */
  __Pyx_TraceLine(1,0,__PYX_ERR(0, 1, __pyx_L1_error))
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "array.pxd":130
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
 */
  __Pyx_TraceLine(130,0,__PYX_ERR(2, 130, __pyx_L1_error))


  /* "array.pxd":139
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 */
  __Pyx_TraceLine(139,0,__PYX_ERR(2, 139, __pyx_L1_error))


  /* "array.pxd":145
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:             # <<<<<<<<<<<<<<
 *     """ efficient appending of new stuff of same type
 *     (e.g. of same array type)
 */
  __Pyx_TraceLine(145,0,__PYX_ERR(2, 145, __pyx_L1_error))


  /* "array.pxd":155
 *     return 0
 * 
 * cdef inline int extend(array self, array other) except -1:             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 */
  __Pyx_TraceLine(155,0,__PYX_ERR(2, 155, __pyx_L1_error))


  /* "array.pxd":161
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self):             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
 */
  __Pyx_TraceLine(161,0,__PYX_ERR(2, 161, __pyx_L1_error))

  __Pyx_TraceReturn(Py_None, 0);

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init ttygif.tty.viewer", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init ttygif.tty.viewer");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* Profile */
#if CYTHON_PROFILE
static int __Pyx_TraceSetupAndCall(PyCodeObject** code,
                                   PyFrameObject** frame,
                                   PyThreadState* tstate,
                                   const char *funcname,
                                   const char *srcfile,
                                   int firstlineno) {
    PyObject *type, *value, *traceback;
    int retval;
    if (*frame == NULL || !CYTHON_PROFILE_REUSE_FRAME) {
        if (*code == NULL) {
            *code = __Pyx_createFrameCodeObject(funcname, srcfile, firstlineno);
            if (*code == NULL) return 0;
        }
        *frame = PyFrame_New(
            tstate,                          /*PyThreadState *tstate*/
            *code,                           /*PyCodeObject *code*/
            __pyx_d,                  /*PyObject *globals*/
            0                                /*PyObject *locals*/
        );
        if (*frame == NULL) return 0;
        if (CYTHON_TRACE && (*frame)->f_trace == NULL) {
            Py_INCREF(Py_None);
            (*frame)->f_trace = Py_None;
        }
#if PY_VERSION_HEX < 0x030400B1
    } else {
        (*frame)->f_tstate = tstate;
#endif
    }
      __Pyx_PyFrame_SetLineNumber(*frame, firstlineno);
    retval = 1;
    tstate->tracing++;
    tstate->use_tracing = 0;
    __Pyx_ErrFetchInState(tstate, &type, &value, &traceback);
    #if CYTHON_TRACE
    if (tstate->c_tracefunc)
        retval = tstate->c_tracefunc(tstate->c_traceobj, *frame, PyTrace_CALL, NULL) == 0;
    if (retval && tstate->c_profilefunc)
    #endif
        retval = tstate->c_profilefunc(tstate->c_profileobj, *frame, PyTrace_CALL, NULL) == 0;
    tstate->use_tracing = (tstate->c_profilefunc ||
                           (CYTHON_TRACE && tstate->c_tracefunc));
    tstate->tracing--;
    if (retval) {
        __Pyx_ErrRestoreInState(tstate, type, value, traceback);
        return tstate->use_tracing && retval;
    } else {
        Py_XDECREF(type);
        Py_XDECREF(value);
        Py_XDECREF(traceback);
        return -1;
    }
}
static PyCodeObject *__Pyx_createFrameCodeObject(const char *funcname, const char *srcfile, int firstlineno) {
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    PyCodeObject *py_code = 0;
    #if PY_MAJOR_VERSION < 3
    py_funcname = PyString_FromString(funcname);
    py_srcfile = PyString_FromString(srcfile);
    #else
    py_funcname = PyUnicode_FromString(funcname);
    py_srcfile = PyUnicode_FromString(srcfile);
    #endif
    if (!py_funcname | !py_srcfile) goto bad;
    py_code = PyCode_New(
        0,
        #if PY_MAJOR_VERSION >= 3
        0,
        #endif
        0,
        0,
        CO_OPTIMIZED | CO_NEWLOCALS,
        __pyx_empty_bytes,     /*PyObject *code,*/
        __pyx_empty_tuple,     /*PyObject *consts,*/
        __pyx_empty_tuple,     /*PyObject *names,*/
        __pyx_empty_tuple,     /*PyObject *varnames,*/
        __pyx_empty_tuple,     /*PyObject *freevars,*/
        __pyx_empty_tuple,     /*PyObject *cellvars,*/
        py_srcfile,       /*PyObject *filename,*/
        py_funcname,      /*PyObject *name,*/
        firstlineno,
        __pyx_empty_bytes      /*PyObject *lnotab*/
    );
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return py_code;
}
#endif

/* StringJoin */
#if !CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    return PyObject_CallMethodObjArgs(sep, __pyx_n_s_join, values, NULL);
}
#endif

/* UnicodeAsUCS4 */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject* x) {
   Py_ssize_t length;
   #if CYTHON_PEP393_ENABLED
   length = PyUnicode_GET_LENGTH(x);
   if (likely(length == 1)) {
       return PyUnicode_READ_CHAR(x, 0);
   }
   #else
   length = PyUnicode_GET_SIZE(x);
   if (likely(length == 1)) {
       return PyUnicode_AS_UNICODE(x)[0];
   }
   #if Py_UNICODE_SIZE == 2
   else if (PyUnicode_GET_SIZE(x) == 2) {
       Py_UCS4 high_val = PyUnicode_AS_UNICODE(x)[0];
       if (high_val >= 0xD800 && high_val <= 0xDBFF) {
           Py_UCS4 low_val = PyUnicode_AS_UNICODE(x)[1];
           if (low_val >= 0xDC00 && low_val <= 0xDFFF) {
               return 0x10000 + (((high_val & ((1<<10)-1)) << 10) | (low_val & ((1<<10)-1)));
           }
       }
   }
   #endif
   #endif
   PyErr_Format(PyExc_ValueError,
                "only single character unicode strings can be converted to Py_UCS4, "
                "got length %" CYTHON_FORMAT_SSIZE_T "d", length);
   return (Py_UCS4)-1;
}

/* object_ord */
static long __Pyx__PyObject_Ord(PyObject* c) {
    Py_ssize_t size;
    if (PyBytes_Check(c)) {
        size = PyBytes_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyBytes_AS_STRING(c)[0];
        }
#if PY_MAJOR_VERSION < 3
    } else if (PyUnicode_Check(c)) {
        return (long)__Pyx_PyUnicode_AsPy_UCS4(c);
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    } else if (PyByteArray_Check(c)) {
        size = PyByteArray_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyByteArray_AS_STRING(c)[0];
        }
#endif
    } else {
        PyErr_Format(PyExc_TypeError,
            "ord() expected string of length 1, but %.200s found", c->ob_type->tp_name);
        return (long)(Py_UCS4)-1;
    }
    PyErr_Format(PyExc_TypeError,
        "ord() expected a character, but string of length %zd found", size);
    return (long)(Py_UCS4)-1;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* None */
static CYTHON_INLINE int __Pyx_div_int(int a, int b) {
    int q = a / b;
    int r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* None */
static CYTHON_INLINE int __Pyx_mod_int(int a, int b) {
    int r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* pop_index */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix) {
    PyObject *r;
    if (unlikely(!py_ix)) return NULL;
    r = __Pyx__PyObject_PopIndex(L, py_ix);
    Py_DECREF(py_ix);
    return r;
}
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix) {
    return __Pyx_PyObject_CallMethod1(L, __pyx_n_s_pop, py_ix);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix) {
    Py_ssize_t size = PyList_GET_SIZE(L);
    if (likely(size > (((PyListObject*)L)->allocated >> 1))) {
        Py_ssize_t cix = ix;
        if (cix < 0) {
            cix += size;
        }
        if (likely(__Pyx_is_valid_index(cix, size))) {
            PyObject* v = PyList_GET_ITEM(L, cix);
            Py_SIZE(L) -= 1;
            size -= 1;
            memmove(&PyList_GET_ITEM(L, cix), &PyList_GET_ITEM(L, cix+1), (size_t)(size-cix)*sizeof(PyObject*));
            return v;
        }
    }
    if (py_ix == Py_None) {
        return __Pyx__PyObject_PopNewIndex(L, PyInt_FromSsize_t(ix));
    } else {
        return __Pyx__PyObject_PopIndex(L, py_ix);
    }
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_FALSE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* None */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_cython); if (unlikely(!reduce_cython)) goto BAD;
            ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto BAD;
            ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto BAD;
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate_cython); if (unlikely(!setstate_cython)) goto BAD;
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto BAD;
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto GOOD;
BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* Print */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static PyObject *__Pyx_GetStdout(void) {
    PyObject *f = PySys_GetObject((char *)"stdout");
    if (!f) {
        PyErr_SetString(PyExc_RuntimeError, "lost sys.stdout");
    }
    return f;
}
static int __Pyx_Print(PyObject* f, PyObject *arg_tuple, int newline) {
    int i;
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    for (i=0; i < PyTuple_GET_SIZE(arg_tuple); i++) {
        PyObject* v;
        if (PyFile_SoftSpace(f, 1)) {
            if (PyFile_WriteString(" ", f) < 0)
                goto error;
        }
        v = PyTuple_GET_ITEM(arg_tuple, i);
        if (PyFile_WriteObject(v, f, Py_PRINT_RAW) < 0)
            goto error;
        if (PyString_Check(v)) {
            char *s = PyString_AsString(v);
            Py_ssize_t len = PyString_Size(v);
            if (len > 0) {
                switch (s[len-1]) {
                    case ' ': break;
                    case '\f': case '\r': case '\n': case '\t': case '\v':
                        PyFile_SoftSpace(f, 0);
                        break;
                    default:  break;
                }
            }
        }
    }
    if (newline) {
        if (PyFile_WriteString("\n", f) < 0)
            goto error;
        PyFile_SoftSpace(f, 0);
    }
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
}
#else
static int __Pyx_Print(PyObject* stream, PyObject *arg_tuple, int newline) {
    PyObject* kwargs = 0;
    PyObject* result = 0;
    PyObject* end_string;
    if (unlikely(!__pyx_print)) {
        __pyx_print = PyObject_GetAttr(__pyx_b, __pyx_n_s_print);
        if (!__pyx_print)
            return -1;
    }
    if (stream) {
        kwargs = PyDict_New();
        if (unlikely(!kwargs))
            return -1;
        if (unlikely(PyDict_SetItem(kwargs, __pyx_n_s_file, stream) < 0))
            goto bad;
        if (!newline) {
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                goto bad;
            if (PyDict_SetItem(kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                goto bad;
            }
            Py_DECREF(end_string);
        }
    } else if (!newline) {
        if (unlikely(!__pyx_print_kwargs)) {
            __pyx_print_kwargs = PyDict_New();
            if (unlikely(!__pyx_print_kwargs))
                return -1;
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                return -1;
            if (PyDict_SetItem(__pyx_print_kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                return -1;
            }
            Py_DECREF(end_string);
        }
        kwargs = __pyx_print_kwargs;
    }
    result = PyObject_Call(__pyx_print, arg_tuple, kwargs);
    if (unlikely(kwargs) && (kwargs != __pyx_print_kwargs))
        Py_DECREF(kwargs);
    if (!result)
        return -1;
    Py_DECREF(result);
    return 0;
bad:
    if (kwargs != __pyx_print_kwargs)
        Py_XDECREF(kwargs);
    return -1;
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* PrintOne */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static int __Pyx_PrintOne(PyObject* f, PyObject *o) {
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    if (PyFile_SoftSpace(f, 0)) {
        if (PyFile_WriteString(" ", f) < 0)
            goto error;
    }
    if (PyFile_WriteObject(o, f, Py_PRINT_RAW) < 0)
        goto error;
    if (PyFile_WriteString("\n", f) < 0)
        goto error;
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
    /* the line below is just to avoid C compiler
     * warnings about unused functions */
    return __Pyx_Print(f, NULL, 0);
}
#else
static int __Pyx_PrintOne(PyObject* stream, PyObject *o) {
    int res;
    PyObject* arg_tuple = PyTuple_Pack(1, o);
    if (unlikely(!arg_tuple))
        return -1;
    res = __Pyx_Print(stream, arg_tuple, 1);
    Py_DECREF(arg_tuple);
    return res;
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* CoroutineBase */
#include <structmember.h>
#include <frameobject.h>
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_type) {
        #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
        #else
        if (exc_state->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_state->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *exc_tb = exc_state->exc_traceback;
    if (likely(exc_tb)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, CYTHON_UNUSED PyObject *arg) {
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    self->ob_refcnt = 1;
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        self->ob_refcnt = refcnt;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr
#define __PYX_HAVE_RT_ImportVoidPtr
static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, name);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C variable %.200s",
                PyModule_GetName(module), name);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C variable %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C variable %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), name, sig, desc);
        goto bad;
    }
    *p = PyCObject_AsVoidPtr(cobj);}
#endif
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
