/* Generated by Cython 0.29.7 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_TRACE", 
                "1"
            ]
        ], 
        "name": "ttygif.gif.color_table", 
        "sources": [
            "./ttygif/gif/color_table.py"
        ]
    }, 
    "module_name": "ttygif.gif.color_table"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_7"
#define CYTHON_HEX_VERSION 0x001D07F0
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
  #define PyObject_Unicode             PyObject_Str
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : (Py_INCREF(func), func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__ttygif__gif__color_table
#define __PYX_HAVE_API__ttygif__gif__color_table
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "ttygif/gif/color_table.py",
};

/*--- Type declarations ---*/

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunction.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code)\
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* Print.proto */
static int __Pyx_Print(PyObject*, PyObject *, int);
#if CYTHON_COMPILING_IN_PYPY || PY_MAJOR_VERSION >= 3
static PyObject* __pyx_print = 0;
static PyObject* __pyx_print_kwargs = 0;
#endif

/* PrintOne.proto */
static int __Pyx_PrintOne(PyObject* stream, PyObject *o);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'ttygif.gif.color_table' */
#define __Pyx_MODULE_NAME "ttygif.gif.color_table"
extern int __pyx_module_is_main_ttygif__gif__color_table;
int __pyx_module_is_main_ttygif__gif__color_table = 0;

/* Implementation of 'ttygif.gif.color_table' */
static PyObject *__pyx_builtin_range;
static const char __pyx_k_i[] = "i";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_new[] = "new";
static const char __pyx_k_pos[] = "pos";
static const char __pyx_k_red[] = "red";
static const char __pyx_k_blue[] = "blue";
static const char __pyx_k_byte[] = "byte";
static const char __pyx_k_file[] = "file";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_color[] = "color";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_green[] = "green";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_colors[] = "colors";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_stream[] = "stream";
static const char __pyx_k_entries[] = "entries";
static const char __pyx_k_palette[] = "palette";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_colors_len[] = "colors_len";
static const char __pyx_k_write_byte[] = "write_byte";
static const char __pyx_k_color_table[] = "color_table";
static const char __pyx_k_Offset_0_02X[] = "  Offset: {0:02X}";
static const char __pyx_k_get_byte_size[] = "get_byte_size";
static const char __pyx_k_gif_color_table[] = "gif_color_table";
static const char __pyx_k_Color_Table_Block[] = "Color Table Block";
static const char __pyx_k_internal_position[] = "internal_position";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_gif_color_table_new[] = "gif_color_table.new";
static const char __pyx_k_gif_color_table_read[] = "gif_color_table.read";
static const char __pyx_k_gif_color_table_debug[] = "gif_color_table.debug";
static const char __pyx_k_gif_color_table_write[] = "gif_color_table.write";
static const char __pyx_k_gif_color_table___init[] = "gif_color_table.__init__";
static const char __pyx_k_ttygif_gif_color_table[] = "ttygif.gif.color_table";
static const char __pyx_k_ttygif_gif_color_table_py[] = "ttygif/gif/color_table.py";
static const char __pyx_k_gif_color_table_get_byte_size[] = "gif_color_table.get_byte_size";
static const char __pyx_k_Index_3_3_R_0x_0_02X_G_0x_1_02X[] = "  Index:{3:3}, R:0x{0:02X}, G:0x{1:02X}, B:0x{2:02X}";
static PyObject *__pyx_kp_s_Color_Table_Block;
static PyObject *__pyx_kp_s_Index_3_3_R_0x_0_02X_G_0x_1_02X;
static PyObject *__pyx_kp_s_Offset_0_02X;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_blue;
static PyObject *__pyx_n_s_byte;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_color;
static PyObject *__pyx_n_s_color_table;
static PyObject *__pyx_n_s_colors;
static PyObject *__pyx_n_s_colors_len;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_end;
static PyObject *__pyx_n_s_entries;
static PyObject *__pyx_n_s_file;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_get_byte_size;
static PyObject *__pyx_n_s_gif_color_table;
static PyObject *__pyx_n_s_gif_color_table___init;
static PyObject *__pyx_n_s_gif_color_table_debug;
static PyObject *__pyx_n_s_gif_color_table_get_byte_size;
static PyObject *__pyx_n_s_gif_color_table_new;
static PyObject *__pyx_n_s_gif_color_table_read;
static PyObject *__pyx_n_s_gif_color_table_write;
static PyObject *__pyx_n_s_green;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_internal_position;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_palette;
static PyObject *__pyx_n_s_pos;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_read;
static PyObject *__pyx_n_s_red;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_size;
static PyObject *__pyx_n_s_stream;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_ttygif_gif_color_table;
static PyObject *__pyx_kp_s_ttygif_gif_color_table_py;
static PyObject *__pyx_n_s_write;
static PyObject *__pyx_n_s_write_byte;
static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_stream); /* proto */
static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_2get_byte_size(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_4read(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_entries); /* proto */
static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_6write(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_8new(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_palette); /* proto */
static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_10debug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_18;
static PyObject *__pyx_int_28;
static PyObject *__pyx_int_38;
static PyObject *__pyx_int_48;
static PyObject *__pyx_int_58;
static PyObject *__pyx_int_68;
static PyObject *__pyx_int_78;
static PyObject *__pyx_int_88;
static PyObject *__pyx_int_95;
static PyObject *__pyx_int_98;
static PyObject *__pyx_int_108;
static PyObject *__pyx_int_118;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_135;
static PyObject *__pyx_int_138;
static PyObject *__pyx_int_148;
static PyObject *__pyx_int_158;
static PyObject *__pyx_int_168;
static PyObject *__pyx_int_175;
static PyObject *__pyx_int_178;
static PyObject *__pyx_int_188;
static PyObject *__pyx_int_192;
static PyObject *__pyx_int_198;
static PyObject *__pyx_int_208;
static PyObject *__pyx_int_215;
static PyObject *__pyx_int_218;
static PyObject *__pyx_int_228;
static PyObject *__pyx_int_238;
static PyObject *__pyx_int_255;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_codeobj__2;
static PyObject *__pyx_codeobj__4;
static PyObject *__pyx_codeobj__6;
static PyObject *__pyx_codeobj__8;
static PyObject *__pyx_codeobj__10;
static PyObject *__pyx_codeobj__13;
/* Late includes */

/* "ttygif/gif/color_table.py":5
 * # ColorTableSize = 3L * (1L << (SizeOfGlobalColorTable + 1));
 * class gif_color_table:
 *     def __init__(self,stream):             # <<<<<<<<<<<<<<
 *         self.stream=stream
 *         self.internal_position=self.stream.pos
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_1__init__ = {"__init__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_stream = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_stream,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_stream)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 5, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 5, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_stream = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3gif_11color_table_15gif_color_table___init__(__pyx_self, __pyx_v_self, __pyx_v_stream);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_stream) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "ttygif/gif/color_table.py":6
 * class gif_color_table:
 *     def __init__(self,stream):
 *         self.stream=stream             # <<<<<<<<<<<<<<
 *         self.internal_position=self.stream.pos
 *         self.colors=[]
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_stream, __pyx_v_stream) < 0) __PYX_ERR(0, 6, __pyx_L1_error)

  /* "ttygif/gif/color_table.py":7
 *     def __init__(self,stream):
 *         self.stream=stream
 *         self.internal_position=self.stream.pos             # <<<<<<<<<<<<<<
 *         self.colors=[]
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_internal_position, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":8
 *         self.stream=stream
 *         self.internal_position=self.stream.pos
 *         self.colors=[]             # <<<<<<<<<<<<<<
 * 
 *     def get_byte_size(self):
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_colors, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":5
 * # ColorTableSize = 3L * (1L << (SizeOfGlobalColorTable + 1));
 * class gif_color_table:
 *     def __init__(self,stream):             # <<<<<<<<<<<<<<
 *         self.stream=stream
 *         self.internal_position=self.stream.pos
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/gif/color_table.py":10
 *         self.colors=[]
 * 
 *     def get_byte_size(self):             # <<<<<<<<<<<<<<
 *         colors_len=len(self.colors)
 *         size=0
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_3get_byte_size(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_3get_byte_size = {"get_byte_size", (PyCFunction)__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_3get_byte_size, METH_O, 0};
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_3get_byte_size(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_byte_size (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_2get_byte_size(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_2get_byte_size(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_v_colors_len;
  long __pyx_v_size;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("get_byte_size", 0);

  /* "ttygif/gif/color_table.py":11
 * 
 *     def get_byte_size(self):
 *         colors_len=len(self.colors)             # <<<<<<<<<<<<<<
 *         size=0
 *         if   colors_len>128: size=7
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_colors); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_colors_len = __pyx_t_2;

  /* "ttygif/gif/color_table.py":12
 *     def get_byte_size(self):
 *         colors_len=len(self.colors)
 *         size=0             # <<<<<<<<<<<<<<
 *         if   colors_len>128: size=7
 *         elif colors_len>64 : size=6
 */
  __pyx_v_size = 0;

  /* "ttygif/gif/color_table.py":13
 *         colors_len=len(self.colors)
 *         size=0
 *         if   colors_len>128: size=7             # <<<<<<<<<<<<<<
 *         elif colors_len>64 : size=6
 *         elif colors_len>32 : size=5
 */
  __pyx_t_3 = ((__pyx_v_colors_len > 0x80) != 0);
  if (__pyx_t_3) {
    __pyx_v_size = 7;
    goto __pyx_L3;
  }

  /* "ttygif/gif/color_table.py":14
 *         size=0
 *         if   colors_len>128: size=7
 *         elif colors_len>64 : size=6             # <<<<<<<<<<<<<<
 *         elif colors_len>32 : size=5
 *         elif colors_len>16 : size=4
 */
  __pyx_t_3 = ((__pyx_v_colors_len > 64) != 0);
  if (__pyx_t_3) {
    __pyx_v_size = 6;
    goto __pyx_L3;
  }

  /* "ttygif/gif/color_table.py":15
 *         if   colors_len>128: size=7
 *         elif colors_len>64 : size=6
 *         elif colors_len>32 : size=5             # <<<<<<<<<<<<<<
 *         elif colors_len>16 : size=4
 *         elif colors_len>8  : size=3
 */
  __pyx_t_3 = ((__pyx_v_colors_len > 32) != 0);
  if (__pyx_t_3) {
    __pyx_v_size = 5;
    goto __pyx_L3;
  }

  /* "ttygif/gif/color_table.py":16
 *         elif colors_len>64 : size=6
 *         elif colors_len>32 : size=5
 *         elif colors_len>16 : size=4             # <<<<<<<<<<<<<<
 *         elif colors_len>8  : size=3
 *         elif colors_len>4  : size=2
 */
  __pyx_t_3 = ((__pyx_v_colors_len > 16) != 0);
  if (__pyx_t_3) {
    __pyx_v_size = 4;
    goto __pyx_L3;
  }

  /* "ttygif/gif/color_table.py":17
 *         elif colors_len>32 : size=5
 *         elif colors_len>16 : size=4
 *         elif colors_len>8  : size=3             # <<<<<<<<<<<<<<
 *         elif colors_len>4  : size=2
 *         elif colors_len>0  : size=1
 */
  __pyx_t_3 = ((__pyx_v_colors_len > 8) != 0);
  if (__pyx_t_3) {
    __pyx_v_size = 3;
    goto __pyx_L3;
  }

  /* "ttygif/gif/color_table.py":18
 *         elif colors_len>16 : size=4
 *         elif colors_len>8  : size=3
 *         elif colors_len>4  : size=2             # <<<<<<<<<<<<<<
 *         elif colors_len>0  : size=1
 *         return size
 */
  __pyx_t_3 = ((__pyx_v_colors_len > 4) != 0);
  if (__pyx_t_3) {
    __pyx_v_size = 2;
    goto __pyx_L3;
  }

  /* "ttygif/gif/color_table.py":19
 *         elif colors_len>8  : size=3
 *         elif colors_len>4  : size=2
 *         elif colors_len>0  : size=1             # <<<<<<<<<<<<<<
 *         return size
 * 
 */
  __pyx_t_3 = ((__pyx_v_colors_len > 0) != 0);
  if (__pyx_t_3) {
    __pyx_v_size = 1;
  }
  __pyx_L3:;

  /* "ttygif/gif/color_table.py":20
 *         elif colors_len>4  : size=2
 *         elif colors_len>0  : size=1
 *         return size             # <<<<<<<<<<<<<<
 * 
 *     def read(self,entries):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "ttygif/gif/color_table.py":10
 *         self.colors=[]
 * 
 *     def get_byte_size(self):             # <<<<<<<<<<<<<<
 *         colors_len=len(self.colors)
 *         size=0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.get_byte_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/gif/color_table.py":22
 *         return size
 * 
 *     def read(self,entries):             # <<<<<<<<<<<<<<
 *         self.internal_position=self.stream.pos
 *         self.colors=[]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_5read(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_5read = {"read", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_5read, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_5read(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_entries = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_entries,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_entries)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("read", 1, 2, 2, 1); __PYX_ERR(0, 22, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "read") < 0)) __PYX_ERR(0, 22, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_entries = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("read", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 22, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_4read(__pyx_self, __pyx_v_self, __pyx_v_entries);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_4read(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_entries) {
  CYTHON_UNUSED PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_red = NULL;
  PyObject *__pyx_v_green = NULL;
  PyObject *__pyx_v_blue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("read", 0);

  /* "ttygif/gif/color_table.py":23
 * 
 *     def read(self,entries):
 *         self.internal_position=self.stream.pos             # <<<<<<<<<<<<<<
 *         self.colors=[]
 *         for i in range(0,entries):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_internal_position, __pyx_t_2) < 0) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":24
 *     def read(self,entries):
 *         self.internal_position=self.stream.pos
 *         self.colors=[]             # <<<<<<<<<<<<<<
 *         for i in range(0,entries):
 *             red  = self.stream.byte()                           # Red Color Element
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_colors, __pyx_t_2) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":25
 *         self.internal_position=self.stream.pos
 *         self.colors=[]
 *         for i in range(0,entries):             # <<<<<<<<<<<<<<
 *             red  = self.stream.byte()                           # Red Color Element
 *             green= self.stream.byte()                          # Green Color Element
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_v_entries);
  __Pyx_GIVEREF(__pyx_v_entries);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_entries);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 25, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 25, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 25, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 25, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":26
 *         self.colors=[]
 *         for i in range(0,entries):
 *             red  = self.stream.byte()                           # Red Color Element             # <<<<<<<<<<<<<<
 *             green= self.stream.byte()                          # Green Color Element
 *             blue = self.stream.byte()                          # Blue Color Element
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 26, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_byte); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 26, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 26, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_red, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":27
 *         for i in range(0,entries):
 *             red  = self.stream.byte()                           # Red Color Element
 *             green= self.stream.byte()                          # Green Color Element             # <<<<<<<<<<<<<<
 *             blue = self.stream.byte()                          # Blue Color Element
 *             self.colors.append([red,green,blue])
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 27, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_byte); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 27, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 27, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_green, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":28
 *             red  = self.stream.byte()                           # Red Color Element
 *             green= self.stream.byte()                          # Green Color Element
 *             blue = self.stream.byte()                          # Blue Color Element             # <<<<<<<<<<<<<<
 *             self.colors.append([red,green,blue])
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 28, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_byte); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 28, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 28, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_blue, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":29
 *             green= self.stream.byte()                          # Green Color Element
 *             blue = self.stream.byte()                          # Blue Color Element
 *             self.colors.append([red,green,blue])             # <<<<<<<<<<<<<<
 * 
 *     def write(self):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_colors); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_red);
    __Pyx_GIVEREF(__pyx_v_red);
    PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_red);
    __Pyx_INCREF(__pyx_v_green);
    __Pyx_GIVEREF(__pyx_v_green);
    PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_green);
    __Pyx_INCREF(__pyx_v_blue);
    __Pyx_GIVEREF(__pyx_v_blue);
    PyList_SET_ITEM(__pyx_t_6, 2, __pyx_v_blue);
    __pyx_t_7 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_6); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 29, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "ttygif/gif/color_table.py":25
 *         self.internal_position=self.stream.pos
 *         self.colors=[]
 *         for i in range(0,entries):             # <<<<<<<<<<<<<<
 *             red  = self.stream.byte()                           # Red Color Element
 *             green= self.stream.byte()                          # Green Color Element
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":22
 *         return size
 * 
 *     def read(self,entries):             # <<<<<<<<<<<<<<
 *         self.internal_position=self.stream.pos
 *         self.colors=[]
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_red);
  __Pyx_XDECREF(__pyx_v_green);
  __Pyx_XDECREF(__pyx_v_blue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/gif/color_table.py":31
 *             self.colors.append([red,green,blue])
 * 
 *     def write(self):             # <<<<<<<<<<<<<<
 *         for color in self.colors:
 *             self.stream.write_byte(color[0])
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_7write(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_7write = {"write", (PyCFunction)__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_7write, METH_O, 0};
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_7write(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_6write(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_6write(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_color = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("write", 0);

  /* "ttygif/gif/color_table.py":32
 * 
 *     def write(self):
 *         for color in self.colors:             # <<<<<<<<<<<<<<
 *             self.stream.write_byte(color[0])
 *             self.stream.write_byte(color[1])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_colors); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 32, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 32, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 32, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 32, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_color, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":33
 *     def write(self):
 *         for color in self.colors:
 *             self.stream.write_byte(color[0])             # <<<<<<<<<<<<<<
 *             self.stream.write_byte(color[1])
 *             self.stream.write_byte(color[2])
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_write_byte); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_color, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":34
 *         for color in self.colors:
 *             self.stream.write_byte(color[0])
 *             self.stream.write_byte(color[1])             # <<<<<<<<<<<<<<
 *             self.stream.write_byte(color[2])
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_write_byte); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_color, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":35
 *             self.stream.write_byte(color[0])
 *             self.stream.write_byte(color[1])
 *             self.stream.write_byte(color[2])             # <<<<<<<<<<<<<<
 * 
 *     def new(self,palette=None):
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stream); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_write_byte); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_color, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":32
 * 
 *     def write(self):
 *         for color in self.colors:             # <<<<<<<<<<<<<<
 *             self.stream.write_byte(color[0])
 *             self.stream.write_byte(color[1])
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":31
 *             self.colors.append([red,green,blue])
 * 
 *     def write(self):             # <<<<<<<<<<<<<<
 *         for color in self.colors:
 *             self.stream.write_byte(color[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_color);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/gif/color_table.py":37
 *             self.stream.write_byte(color[2])
 * 
 *     def new(self,palette=None):             # <<<<<<<<<<<<<<
 *         self.colors=[]
 *         if palette:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_9new(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_9new = {"new", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_9new, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_9new(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_palette = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_palette,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_palette);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "new") < 0)) __PYX_ERR(0, 37, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_palette = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("new", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 37, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_8new(__pyx_self, __pyx_v_self, __pyx_v_palette);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_8new(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_palette) {
  PyObject *__pyx_v_color_table = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  PyObject *__pyx_t_32 = NULL;
  PyObject *__pyx_t_33 = NULL;
  PyObject *__pyx_t_34 = NULL;
  PyObject *__pyx_t_35 = NULL;
  PyObject *__pyx_t_36 = NULL;
  PyObject *__pyx_t_37 = NULL;
  PyObject *__pyx_t_38 = NULL;
  PyObject *__pyx_t_39 = NULL;
  PyObject *__pyx_t_40 = NULL;
  PyObject *__pyx_t_41 = NULL;
  PyObject *__pyx_t_42 = NULL;
  PyObject *__pyx_t_43 = NULL;
  PyObject *__pyx_t_44 = NULL;
  PyObject *__pyx_t_45 = NULL;
  PyObject *__pyx_t_46 = NULL;
  PyObject *__pyx_t_47 = NULL;
  PyObject *__pyx_t_48 = NULL;
  PyObject *__pyx_t_49 = NULL;
  PyObject *__pyx_t_50 = NULL;
  PyObject *__pyx_t_51 = NULL;
  PyObject *__pyx_t_52 = NULL;
  PyObject *__pyx_t_53 = NULL;
  PyObject *__pyx_t_54 = NULL;
  PyObject *__pyx_t_55 = NULL;
  PyObject *__pyx_t_56 = NULL;
  PyObject *__pyx_t_57 = NULL;
  PyObject *__pyx_t_58 = NULL;
  PyObject *__pyx_t_59 = NULL;
  PyObject *__pyx_t_60 = NULL;
  PyObject *__pyx_t_61 = NULL;
  PyObject *__pyx_t_62 = NULL;
  PyObject *__pyx_t_63 = NULL;
  PyObject *__pyx_t_64 = NULL;
  PyObject *__pyx_t_65 = NULL;
  PyObject *__pyx_t_66 = NULL;
  PyObject *__pyx_t_67 = NULL;
  PyObject *__pyx_t_68 = NULL;
  PyObject *__pyx_t_69 = NULL;
  PyObject *__pyx_t_70 = NULL;
  PyObject *__pyx_t_71 = NULL;
  PyObject *__pyx_t_72 = NULL;
  PyObject *__pyx_t_73 = NULL;
  PyObject *__pyx_t_74 = NULL;
  PyObject *__pyx_t_75 = NULL;
  PyObject *__pyx_t_76 = NULL;
  PyObject *__pyx_t_77 = NULL;
  PyObject *__pyx_t_78 = NULL;
  PyObject *__pyx_t_79 = NULL;
  PyObject *__pyx_t_80 = NULL;
  PyObject *__pyx_t_81 = NULL;
  PyObject *__pyx_t_82 = NULL;
  PyObject *__pyx_t_83 = NULL;
  PyObject *__pyx_t_84 = NULL;
  PyObject *__pyx_t_85 = NULL;
  PyObject *__pyx_t_86 = NULL;
  PyObject *__pyx_t_87 = NULL;
  PyObject *__pyx_t_88 = NULL;
  PyObject *__pyx_t_89 = NULL;
  PyObject *__pyx_t_90 = NULL;
  PyObject *__pyx_t_91 = NULL;
  PyObject *__pyx_t_92 = NULL;
  PyObject *__pyx_t_93 = NULL;
  PyObject *__pyx_t_94 = NULL;
  PyObject *__pyx_t_95 = NULL;
  PyObject *__pyx_t_96 = NULL;
  PyObject *__pyx_t_97 = NULL;
  PyObject *__pyx_t_98 = NULL;
  PyObject *__pyx_t_99 = NULL;
  PyObject *__pyx_t_100 = NULL;
  PyObject *__pyx_t_101 = NULL;
  PyObject *__pyx_t_102 = NULL;
  PyObject *__pyx_t_103 = NULL;
  PyObject *__pyx_t_104 = NULL;
  PyObject *__pyx_t_105 = NULL;
  PyObject *__pyx_t_106 = NULL;
  PyObject *__pyx_t_107 = NULL;
  PyObject *__pyx_t_108 = NULL;
  PyObject *__pyx_t_109 = NULL;
  PyObject *__pyx_t_110 = NULL;
  PyObject *__pyx_t_111 = NULL;
  PyObject *__pyx_t_112 = NULL;
  PyObject *__pyx_t_113 = NULL;
  PyObject *__pyx_t_114 = NULL;
  PyObject *__pyx_t_115 = NULL;
  PyObject *__pyx_t_116 = NULL;
  PyObject *__pyx_t_117 = NULL;
  PyObject *__pyx_t_118 = NULL;
  PyObject *__pyx_t_119 = NULL;
  PyObject *__pyx_t_120 = NULL;
  PyObject *__pyx_t_121 = NULL;
  PyObject *__pyx_t_122 = NULL;
  PyObject *__pyx_t_123 = NULL;
  PyObject *__pyx_t_124 = NULL;
  PyObject *__pyx_t_125 = NULL;
  PyObject *__pyx_t_126 = NULL;
  PyObject *__pyx_t_127 = NULL;
  PyObject *__pyx_t_128 = NULL;
  PyObject *__pyx_t_129 = NULL;
  PyObject *__pyx_t_130 = NULL;
  PyObject *__pyx_t_131 = NULL;
  PyObject *__pyx_t_132 = NULL;
  PyObject *__pyx_t_133 = NULL;
  PyObject *__pyx_t_134 = NULL;
  PyObject *__pyx_t_135 = NULL;
  PyObject *__pyx_t_136 = NULL;
  PyObject *__pyx_t_137 = NULL;
  PyObject *__pyx_t_138 = NULL;
  PyObject *__pyx_t_139 = NULL;
  PyObject *__pyx_t_140 = NULL;
  PyObject *__pyx_t_141 = NULL;
  PyObject *__pyx_t_142 = NULL;
  PyObject *__pyx_t_143 = NULL;
  PyObject *__pyx_t_144 = NULL;
  PyObject *__pyx_t_145 = NULL;
  PyObject *__pyx_t_146 = NULL;
  PyObject *__pyx_t_147 = NULL;
  PyObject *__pyx_t_148 = NULL;
  PyObject *__pyx_t_149 = NULL;
  PyObject *__pyx_t_150 = NULL;
  PyObject *__pyx_t_151 = NULL;
  PyObject *__pyx_t_152 = NULL;
  PyObject *__pyx_t_153 = NULL;
  PyObject *__pyx_t_154 = NULL;
  PyObject *__pyx_t_155 = NULL;
  PyObject *__pyx_t_156 = NULL;
  PyObject *__pyx_t_157 = NULL;
  PyObject *__pyx_t_158 = NULL;
  PyObject *__pyx_t_159 = NULL;
  PyObject *__pyx_t_160 = NULL;
  PyObject *__pyx_t_161 = NULL;
  PyObject *__pyx_t_162 = NULL;
  PyObject *__pyx_t_163 = NULL;
  PyObject *__pyx_t_164 = NULL;
  PyObject *__pyx_t_165 = NULL;
  PyObject *__pyx_t_166 = NULL;
  PyObject *__pyx_t_167 = NULL;
  PyObject *__pyx_t_168 = NULL;
  PyObject *__pyx_t_169 = NULL;
  PyObject *__pyx_t_170 = NULL;
  PyObject *__pyx_t_171 = NULL;
  PyObject *__pyx_t_172 = NULL;
  PyObject *__pyx_t_173 = NULL;
  PyObject *__pyx_t_174 = NULL;
  PyObject *__pyx_t_175 = NULL;
  PyObject *__pyx_t_176 = NULL;
  PyObject *__pyx_t_177 = NULL;
  PyObject *__pyx_t_178 = NULL;
  PyObject *__pyx_t_179 = NULL;
  PyObject *__pyx_t_180 = NULL;
  PyObject *__pyx_t_181 = NULL;
  PyObject *__pyx_t_182 = NULL;
  PyObject *__pyx_t_183 = NULL;
  PyObject *__pyx_t_184 = NULL;
  PyObject *__pyx_t_185 = NULL;
  PyObject *__pyx_t_186 = NULL;
  PyObject *__pyx_t_187 = NULL;
  PyObject *__pyx_t_188 = NULL;
  PyObject *__pyx_t_189 = NULL;
  PyObject *__pyx_t_190 = NULL;
  PyObject *__pyx_t_191 = NULL;
  PyObject *__pyx_t_192 = NULL;
  PyObject *__pyx_t_193 = NULL;
  PyObject *__pyx_t_194 = NULL;
  PyObject *__pyx_t_195 = NULL;
  PyObject *__pyx_t_196 = NULL;
  PyObject *__pyx_t_197 = NULL;
  PyObject *__pyx_t_198 = NULL;
  PyObject *__pyx_t_199 = NULL;
  PyObject *__pyx_t_200 = NULL;
  PyObject *__pyx_t_201 = NULL;
  PyObject *__pyx_t_202 = NULL;
  PyObject *__pyx_t_203 = NULL;
  PyObject *__pyx_t_204 = NULL;
  PyObject *__pyx_t_205 = NULL;
  PyObject *__pyx_t_206 = NULL;
  PyObject *__pyx_t_207 = NULL;
  PyObject *__pyx_t_208 = NULL;
  PyObject *__pyx_t_209 = NULL;
  PyObject *__pyx_t_210 = NULL;
  PyObject *__pyx_t_211 = NULL;
  PyObject *__pyx_t_212 = NULL;
  PyObject *__pyx_t_213 = NULL;
  PyObject *__pyx_t_214 = NULL;
  PyObject *__pyx_t_215 = NULL;
  PyObject *__pyx_t_216 = NULL;
  PyObject *__pyx_t_217 = NULL;
  PyObject *__pyx_t_218 = NULL;
  PyObject *__pyx_t_219 = NULL;
  PyObject *__pyx_t_220 = NULL;
  PyObject *__pyx_t_221 = NULL;
  PyObject *__pyx_t_222 = NULL;
  PyObject *__pyx_t_223 = NULL;
  PyObject *__pyx_t_224 = NULL;
  PyObject *__pyx_t_225 = NULL;
  PyObject *__pyx_t_226 = NULL;
  PyObject *__pyx_t_227 = NULL;
  PyObject *__pyx_t_228 = NULL;
  PyObject *__pyx_t_229 = NULL;
  PyObject *__pyx_t_230 = NULL;
  PyObject *__pyx_t_231 = NULL;
  PyObject *__pyx_t_232 = NULL;
  PyObject *__pyx_t_233 = NULL;
  PyObject *__pyx_t_234 = NULL;
  PyObject *__pyx_t_235 = NULL;
  PyObject *__pyx_t_236 = NULL;
  PyObject *__pyx_t_237 = NULL;
  PyObject *__pyx_t_238 = NULL;
  PyObject *__pyx_t_239 = NULL;
  PyObject *__pyx_t_240 = NULL;
  PyObject *__pyx_t_241 = NULL;
  PyObject *__pyx_t_242 = NULL;
  PyObject *__pyx_t_243 = NULL;
  PyObject *__pyx_t_244 = NULL;
  PyObject *__pyx_t_245 = NULL;
  PyObject *__pyx_t_246 = NULL;
  PyObject *__pyx_t_247 = NULL;
  PyObject *__pyx_t_248 = NULL;
  PyObject *__pyx_t_249 = NULL;
  PyObject *__pyx_t_250 = NULL;
  PyObject *__pyx_t_251 = NULL;
  PyObject *__pyx_t_252 = NULL;
  PyObject *__pyx_t_253 = NULL;
  PyObject *__pyx_t_254 = NULL;
  PyObject *__pyx_t_255 = NULL;
  PyObject *__pyx_t_256 = NULL;
  PyObject *__pyx_t_257 = NULL;
  PyObject *__pyx_t_258 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "ttygif/gif/color_table.py":38
 * 
 *     def new(self,palette=None):
 *         self.colors=[]             # <<<<<<<<<<<<<<
 *         if palette:
 *             self.colors=palette
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_colors, __pyx_t_1) < 0) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/gif/color_table.py":39
 *     def new(self,palette=None):
 *         self.colors=[]
 *         if palette:             # <<<<<<<<<<<<<<
 *             self.colors=palette
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_palette); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 39, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "ttygif/gif/color_table.py":40
 *         self.colors=[]
 *         if palette:
 *             self.colors=palette             # <<<<<<<<<<<<<<
 *         else:
 *             color_table=[  # 16 System Colors
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_colors, __pyx_v_palette) < 0) __PYX_ERR(0, 40, __pyx_L1_error)

    /* "ttygif/gif/color_table.py":39
 *     def new(self,palette=None):
 *         self.colors=[]
 *         if palette:             # <<<<<<<<<<<<<<
 *             self.colors=palette
 *         else:
 */
    goto __pyx_L3;
  }

  /* "ttygif/gif/color_table.py":42
 *             self.colors=palette
 *         else:
 *             color_table=[  # 16 System Colors             # <<<<<<<<<<<<<<
 *                 [0,0,0],[128,0,0],[0,128,0],[128,128,0],
 *                 [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 */
  /*else*/ {

    /* "ttygif/gif/color_table.py":43
 *         else:
 *             color_table=[  # 16 System Colors
 *                 [0,0,0],[128,0,0],[0,128,0],[128,128,0],             # <<<<<<<<<<<<<<
 *                 [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 *                 [128,128,128],[255,0,0],[0,255,0],[255,255,0],
 */
    __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_1, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_1, 2, __pyx_int_0);
    __pyx_t_3 = PyList_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_3, 2, __pyx_int_0);
    __pyx_t_4 = PyList_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_4, 1, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_4, 2, __pyx_int_0);
    __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_5, 1, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_5, 2, __pyx_int_0);

    /* "ttygif/gif/color_table.py":44
 *             color_table=[  # 16 System Colors
 *                 [0,0,0],[128,0,0],[0,128,0],[128,128,0],
 *                 [0,0,128],[128,0,128],[0,128,128],[192,192,192],             # <<<<<<<<<<<<<<
 *                 [128,128,128],[255,0,0],[0,255,0],[255,255,0],
 *                 [0,0,255],[255,0,255],[0,255,255],[255,255,255],
 */
    __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_6, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_6, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_6, 2, __pyx_int_128);
    __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_7, 0, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_7, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_7, 2, __pyx_int_128);
    __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_8, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_8, 1, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_8, 2, __pyx_int_128);
    __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_int_192);
    __Pyx_GIVEREF(__pyx_int_192);
    PyList_SET_ITEM(__pyx_t_9, 0, __pyx_int_192);
    __Pyx_INCREF(__pyx_int_192);
    __Pyx_GIVEREF(__pyx_int_192);
    PyList_SET_ITEM(__pyx_t_9, 1, __pyx_int_192);
    __Pyx_INCREF(__pyx_int_192);
    __Pyx_GIVEREF(__pyx_int_192);
    PyList_SET_ITEM(__pyx_t_9, 2, __pyx_int_192);

    /* "ttygif/gif/color_table.py":45
 *                 [0,0,0],[128,0,0],[0,128,0],[128,128,0],
 *                 [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 *                 [128,128,128],[255,0,0],[0,255,0],[255,255,0],             # <<<<<<<<<<<<<<
 *                 [0,0,255],[255,0,255],[0,255,255],[255,255,255],
 *                 # xterm palette
 */
    __pyx_t_10 = PyList_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_10, 0, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_10, 1, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_10, 2, __pyx_int_128);
    __pyx_t_11 = PyList_New(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_11, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_11, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_11, 2, __pyx_int_0);
    __pyx_t_12 = PyList_New(3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_12, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_12, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_12, 2, __pyx_int_0);
    __pyx_t_13 = PyList_New(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_13, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_13, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_13, 2, __pyx_int_0);

    /* "ttygif/gif/color_table.py":46
 *                 [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 *                 [128,128,128],[255,0,0],[0,255,0],[255,255,0],
 *                 [0,0,255],[255,0,255],[0,255,255],[255,255,255],             # <<<<<<<<<<<<<<
 *                 # xterm palette
 *                 [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],
 */
    __pyx_t_14 = PyList_New(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_14, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_14, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_14, 2, __pyx_int_255);
    __pyx_t_15 = PyList_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_15, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_15, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_15, 2, __pyx_int_255);
    __pyx_t_16 = PyList_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_16, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_16, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_16, 2, __pyx_int_255);
    __pyx_t_17 = PyList_New(3); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_17, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_17, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_17, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":48
 *                 [0,0,255],[255,0,255],[0,255,255],[255,255,255],
 *                 # xterm palette
 *                 [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],             # <<<<<<<<<<<<<<
 *                 [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],
 *                 [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 */
    __pyx_t_18 = PyList_New(3); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_18);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_18, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_18, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_18, 2, __pyx_int_0);
    __pyx_t_19 = PyList_New(3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_19, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_19, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_19, 2, __pyx_int_95);
    __pyx_t_20 = PyList_New(3); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_20);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_20, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_20, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_20, 2, __pyx_int_135);
    __pyx_t_21 = PyList_New(3); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_21, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_21, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_21, 2, __pyx_int_175);
    __pyx_t_22 = PyList_New(3); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_22);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_22, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_22, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_22, 2, __pyx_int_215);
    __pyx_t_23 = PyList_New(3); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_23);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_23, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_23, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_23, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":49
 *                 # xterm palette
 *                 [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],
 *                 [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],             # <<<<<<<<<<<<<<
 *                 [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 *                 [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 */
    __pyx_t_24 = PyList_New(3); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_24);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_24, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_24, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_24, 2, __pyx_int_0);
    __pyx_t_25 = PyList_New(3); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_25);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_25, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_25, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_25, 2, __pyx_int_95);
    __pyx_t_26 = PyList_New(3); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_26);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_26, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_26, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_26, 2, __pyx_int_135);
    __pyx_t_27 = PyList_New(3); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_27);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_27, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_27, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_27, 2, __pyx_int_175);
    __pyx_t_28 = PyList_New(3); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_28);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_28, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_28, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_28, 2, __pyx_int_215);
    __pyx_t_29 = PyList_New(3); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_29);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_29, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_29, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_29, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":50
 *                 [0,0,0],[0,0,95],[0,0,135],[0,0,175],[0,0,215],[0,0,255],
 *                 [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],
 *                 [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],             # <<<<<<<<<<<<<<
 *                 [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 *                 [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 */
    __pyx_t_30 = PyList_New(3); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_30);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_30, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_30, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_30, 2, __pyx_int_0);
    __pyx_t_31 = PyList_New(3); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_31);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_31, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_31, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_31, 2, __pyx_int_95);
    __pyx_t_32 = PyList_New(3); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_32);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_32, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_32, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_32, 2, __pyx_int_135);
    __pyx_t_33 = PyList_New(3); if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_33);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_33, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_33, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_33, 2, __pyx_int_175);
    __pyx_t_34 = PyList_New(3); if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_34);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_34, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_34, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_34, 2, __pyx_int_215);
    __pyx_t_35 = PyList_New(3); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_35);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_35, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_35, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_35, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":51
 *                 [0,95,0],[0,95,95],[0,95,135],[0,95,175],[0,95,215],[0,95,255],
 *                 [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 *                 [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],             # <<<<<<<<<<<<<<
 *                 [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 *                 [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 */
    __pyx_t_36 = PyList_New(3); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_36);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_36, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_36, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_36, 2, __pyx_int_0);
    __pyx_t_37 = PyList_New(3); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_37);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_37, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_37, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_37, 2, __pyx_int_95);
    __pyx_t_38 = PyList_New(3); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_38);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_38, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_38, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_38, 2, __pyx_int_135);
    __pyx_t_39 = PyList_New(3); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_39);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_39, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_39, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_39, 2, __pyx_int_175);
    __pyx_t_40 = PyList_New(3); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_40);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_40, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_40, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_40, 2, __pyx_int_215);
    __pyx_t_41 = PyList_New(3); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_41);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_41, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_41, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_41, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":52
 *                 [0,135,0],[0,135,95],[0,135,135],[0,135,175],[0,135,215],[0,135,255],
 *                 [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 *                 [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],             # <<<<<<<<<<<<<<
 *                 [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 *                 [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 */
    __pyx_t_42 = PyList_New(3); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_42);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_42, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_42, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_42, 2, __pyx_int_0);
    __pyx_t_43 = PyList_New(3); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_43);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_43, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_43, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_43, 2, __pyx_int_95);
    __pyx_t_44 = PyList_New(3); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_44);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_44, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_44, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_44, 2, __pyx_int_135);
    __pyx_t_45 = PyList_New(3); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_45);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_45, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_45, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_45, 2, __pyx_int_175);
    __pyx_t_46 = PyList_New(3); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_46);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_46, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_46, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_46, 2, __pyx_int_215);
    __pyx_t_47 = PyList_New(3); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_47);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_47, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_47, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_47, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":53
 *                 [0,175,0],[0,175,95],[0,175,135],[0,175,175],[0,175,215],[0,175,255],
 *                 [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 *                 [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],             # <<<<<<<<<<<<<<
 *                 [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 *                 [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 */
    __pyx_t_48 = PyList_New(3); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_48);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_48, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_48, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_48, 2, __pyx_int_0);
    __pyx_t_49 = PyList_New(3); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_49);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_49, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_49, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_49, 2, __pyx_int_95);
    __pyx_t_50 = PyList_New(3); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_50);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_50, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_50, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_50, 2, __pyx_int_135);
    __pyx_t_51 = PyList_New(3); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_51);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_51, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_51, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_51, 2, __pyx_int_175);
    __pyx_t_52 = PyList_New(3); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_52);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_52, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_52, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_52, 2, __pyx_int_215);
    __pyx_t_53 = PyList_New(3); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_53);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_53, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_53, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_53, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":54
 *                 [0,215,0],[0,215,95],[0,215,135],[0,215,175],[0,215,215],[0,215,255],
 *                 [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 *                 [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],             # <<<<<<<<<<<<<<
 *                 [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 *                 [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 */
    __pyx_t_54 = PyList_New(3); if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_54);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_54, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_54, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_54, 2, __pyx_int_0);
    __pyx_t_55 = PyList_New(3); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_55);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_55, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_55, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_55, 2, __pyx_int_95);
    __pyx_t_56 = PyList_New(3); if (unlikely(!__pyx_t_56)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_56);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_56, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_56, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_56, 2, __pyx_int_135);
    __pyx_t_57 = PyList_New(3); if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_57);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_57, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_57, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_57, 2, __pyx_int_175);
    __pyx_t_58 = PyList_New(3); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_58);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_58, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_58, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_58, 2, __pyx_int_215);
    __pyx_t_59 = PyList_New(3); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_59);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_59, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_59, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_59, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":55
 *                 [0,255,0],[0,255,95],[0,255,135],[0,255,175],[0,255,215],[0,255,255],
 *                 [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 *                 [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],             # <<<<<<<<<<<<<<
 *                 [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 *                 [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 */
    __pyx_t_60 = PyList_New(3); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_60);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_60, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_60, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_60, 2, __pyx_int_0);
    __pyx_t_61 = PyList_New(3); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_61);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_61, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_61, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_61, 2, __pyx_int_95);
    __pyx_t_62 = PyList_New(3); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_62);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_62, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_62, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_62, 2, __pyx_int_135);
    __pyx_t_63 = PyList_New(3); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_63);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_63, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_63, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_63, 2, __pyx_int_175);
    __pyx_t_64 = PyList_New(3); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_64);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_64, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_64, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_64, 2, __pyx_int_215);
    __pyx_t_65 = PyList_New(3); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_65);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_65, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_65, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_65, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":56
 *                 [95,0,0],[95,0,95],[95,0,135],[95,0,175],[95,0,215],[95,0,255],
 *                 [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 *                 [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],             # <<<<<<<<<<<<<<
 *                 [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 *                 [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 */
    __pyx_t_66 = PyList_New(3); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_66);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_66, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_66, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_66, 2, __pyx_int_0);
    __pyx_t_67 = PyList_New(3); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_67);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_67, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_67, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_67, 2, __pyx_int_95);
    __pyx_t_68 = PyList_New(3); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_68);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_68, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_68, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_68, 2, __pyx_int_135);
    __pyx_t_69 = PyList_New(3); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_69);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_69, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_69, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_69, 2, __pyx_int_175);
    __pyx_t_70 = PyList_New(3); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_70);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_70, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_70, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_70, 2, __pyx_int_215);
    __pyx_t_71 = PyList_New(3); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_71);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_71, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_71, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_71, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":57
 *                 [95,95,0],[95,95,95],[95,95,135],[95,95,175],[95,95,215],[95,95,255],
 *                 [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 *                 [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],             # <<<<<<<<<<<<<<
 *                 [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 *                 [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 */
    __pyx_t_72 = PyList_New(3); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_72);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_72, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_72, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_72, 2, __pyx_int_0);
    __pyx_t_73 = PyList_New(3); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_73);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_73, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_73, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_73, 2, __pyx_int_95);
    __pyx_t_74 = PyList_New(3); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_74);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_74, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_74, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_74, 2, __pyx_int_135);
    __pyx_t_75 = PyList_New(3); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_75);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_75, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_75, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_75, 2, __pyx_int_175);
    __pyx_t_76 = PyList_New(3); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_76);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_76, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_76, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_76, 2, __pyx_int_215);
    __pyx_t_77 = PyList_New(3); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_77);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_77, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_77, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_77, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":58
 *                 [95,135,0],[95,135,95],[95,135,135],[95,135,175],[95,135,215],[95,135,255],
 *                 [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 *                 [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],             # <<<<<<<<<<<<<<
 *                 [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 *                 [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 */
    __pyx_t_78 = PyList_New(3); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_78);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_78, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_78, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_78, 2, __pyx_int_0);
    __pyx_t_79 = PyList_New(3); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_79);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_79, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_79, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_79, 2, __pyx_int_95);
    __pyx_t_80 = PyList_New(3); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_80);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_80, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_80, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_80, 2, __pyx_int_135);
    __pyx_t_81 = PyList_New(3); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_81);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_81, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_81, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_81, 2, __pyx_int_175);
    __pyx_t_82 = PyList_New(3); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_82);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_82, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_82, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_82, 2, __pyx_int_215);
    __pyx_t_83 = PyList_New(3); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_83);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_83, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_83, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_83, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":59
 *                 [95,175,0],[95,175,95],[95,175,135],[95,175,175],[95,175,215],[95,175,255],
 *                 [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 *                 [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],             # <<<<<<<<<<<<<<
 *                 [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 *                 [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 */
    __pyx_t_84 = PyList_New(3); if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_84);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_84, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_84, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_84, 2, __pyx_int_0);
    __pyx_t_85 = PyList_New(3); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_85);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_85, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_85, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_85, 2, __pyx_int_95);
    __pyx_t_86 = PyList_New(3); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_86);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_86, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_86, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_86, 2, __pyx_int_135);
    __pyx_t_87 = PyList_New(3); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_87);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_87, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_87, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_87, 2, __pyx_int_175);
    __pyx_t_88 = PyList_New(3); if (unlikely(!__pyx_t_88)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_88);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_88, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_88, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_88, 2, __pyx_int_215);
    __pyx_t_89 = PyList_New(3); if (unlikely(!__pyx_t_89)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_89);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_89, 0, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_89, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_89, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":60
 *                 [95,215,0],[95,215,95],[95,215,135],[95,215,175],[95,215,215],[95,215,255],
 *                 [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 *                 [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],             # <<<<<<<<<<<<<<
 *                 [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 *                 [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 */
    __pyx_t_90 = PyList_New(3); if (unlikely(!__pyx_t_90)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_90);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_90, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_90, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_90, 2, __pyx_int_0);
    __pyx_t_91 = PyList_New(3); if (unlikely(!__pyx_t_91)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_91);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_91, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_91, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_91, 2, __pyx_int_95);
    __pyx_t_92 = PyList_New(3); if (unlikely(!__pyx_t_92)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_92);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_92, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_92, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_92, 2, __pyx_int_135);
    __pyx_t_93 = PyList_New(3); if (unlikely(!__pyx_t_93)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_93);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_93, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_93, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_93, 2, __pyx_int_175);
    __pyx_t_94 = PyList_New(3); if (unlikely(!__pyx_t_94)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_94);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_94, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_94, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_94, 2, __pyx_int_215);
    __pyx_t_95 = PyList_New(3); if (unlikely(!__pyx_t_95)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_95, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_95, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_95, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":61
 *                 [95,255,0],[95,255,95],[95,255,135],[95,255,175],[95,255,215],[95,255,255],
 *                 [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 *                 [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],             # <<<<<<<<<<<<<<
 *                 [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 *                 [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 */
    __pyx_t_96 = PyList_New(3); if (unlikely(!__pyx_t_96)) __PYX_ERR(0, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_96, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_96, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_96, 2, __pyx_int_0);
    __pyx_t_97 = PyList_New(3); if (unlikely(!__pyx_t_97)) __PYX_ERR(0, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_97);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_97, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_97, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_97, 2, __pyx_int_95);
    __pyx_t_98 = PyList_New(3); if (unlikely(!__pyx_t_98)) __PYX_ERR(0, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_98);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_98, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_98, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_98, 2, __pyx_int_135);
    __pyx_t_99 = PyList_New(3); if (unlikely(!__pyx_t_99)) __PYX_ERR(0, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_99);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_99, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_99, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_99, 2, __pyx_int_175);
    __pyx_t_100 = PyList_New(3); if (unlikely(!__pyx_t_100)) __PYX_ERR(0, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_100);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_100, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_100, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_100, 2, __pyx_int_215);
    __pyx_t_101 = PyList_New(3); if (unlikely(!__pyx_t_101)) __PYX_ERR(0, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_101);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_101, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_101, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_101, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":62
 *                 [135,0,0],[135,0,95],[135,0,135],[135,0,175],[135,0,215],[135,0,255],
 *                 [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 *                 [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],             # <<<<<<<<<<<<<<
 *                 [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 *                 [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 */
    __pyx_t_102 = PyList_New(3); if (unlikely(!__pyx_t_102)) __PYX_ERR(0, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_102);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_102, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_102, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_102, 2, __pyx_int_0);
    __pyx_t_103 = PyList_New(3); if (unlikely(!__pyx_t_103)) __PYX_ERR(0, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_103);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_103, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_103, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_103, 2, __pyx_int_95);
    __pyx_t_104 = PyList_New(3); if (unlikely(!__pyx_t_104)) __PYX_ERR(0, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_104);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_104, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_104, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_104, 2, __pyx_int_135);
    __pyx_t_105 = PyList_New(3); if (unlikely(!__pyx_t_105)) __PYX_ERR(0, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_105);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_105, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_105, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_105, 2, __pyx_int_175);
    __pyx_t_106 = PyList_New(3); if (unlikely(!__pyx_t_106)) __PYX_ERR(0, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_106);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_106, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_106, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_106, 2, __pyx_int_215);
    __pyx_t_107 = PyList_New(3); if (unlikely(!__pyx_t_107)) __PYX_ERR(0, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_107);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_107, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_107, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_107, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":63
 *                 [135,95,0],[135,95,95],[135,95,135],[135,95,175],[135,95,215],[135,95,255],
 *                 [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 *                 [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],             # <<<<<<<<<<<<<<
 *                 [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 *                 [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 */
    __pyx_t_108 = PyList_New(3); if (unlikely(!__pyx_t_108)) __PYX_ERR(0, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_108);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_108, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_108, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_108, 2, __pyx_int_0);
    __pyx_t_109 = PyList_New(3); if (unlikely(!__pyx_t_109)) __PYX_ERR(0, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_109);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_109, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_109, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_109, 2, __pyx_int_95);
    __pyx_t_110 = PyList_New(3); if (unlikely(!__pyx_t_110)) __PYX_ERR(0, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_110);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_110, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_110, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_110, 2, __pyx_int_135);
    __pyx_t_111 = PyList_New(3); if (unlikely(!__pyx_t_111)) __PYX_ERR(0, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_111);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_111, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_111, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_111, 2, __pyx_int_175);
    __pyx_t_112 = PyList_New(3); if (unlikely(!__pyx_t_112)) __PYX_ERR(0, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_112);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_112, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_112, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_112, 2, __pyx_int_215);
    __pyx_t_113 = PyList_New(3); if (unlikely(!__pyx_t_113)) __PYX_ERR(0, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_113);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_113, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_113, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_113, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":64
 *                 [135,135,0],[135,135,95],[135,135,135],[135,135,175],[135,135,215],[135,135,255],
 *                 [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 *                 [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],             # <<<<<<<<<<<<<<
 *                 [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 *                 [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 */
    __pyx_t_114 = PyList_New(3); if (unlikely(!__pyx_t_114)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_114);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_114, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_114, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_114, 2, __pyx_int_0);
    __pyx_t_115 = PyList_New(3); if (unlikely(!__pyx_t_115)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_115);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_115, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_115, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_115, 2, __pyx_int_95);
    __pyx_t_116 = PyList_New(3); if (unlikely(!__pyx_t_116)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_116);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_116, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_116, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_116, 2, __pyx_int_135);
    __pyx_t_117 = PyList_New(3); if (unlikely(!__pyx_t_117)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_117);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_117, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_117, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_117, 2, __pyx_int_175);
    __pyx_t_118 = PyList_New(3); if (unlikely(!__pyx_t_118)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_118);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_118, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_118, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_118, 2, __pyx_int_215);
    __pyx_t_119 = PyList_New(3); if (unlikely(!__pyx_t_119)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_119);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_119, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_119, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_119, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":65
 *                 [135,175,0],[135,175,95],[135,175,135],[135,175,175],[135,175,215],[135,175,255],
 *                 [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 *                 [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],             # <<<<<<<<<<<<<<
 *                 [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 *                 [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 */
    __pyx_t_120 = PyList_New(3); if (unlikely(!__pyx_t_120)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_120);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_120, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_120, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_120, 2, __pyx_int_0);
    __pyx_t_121 = PyList_New(3); if (unlikely(!__pyx_t_121)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_121);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_121, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_121, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_121, 2, __pyx_int_95);
    __pyx_t_122 = PyList_New(3); if (unlikely(!__pyx_t_122)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_122);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_122, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_122, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_122, 2, __pyx_int_135);
    __pyx_t_123 = PyList_New(3); if (unlikely(!__pyx_t_123)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_123);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_123, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_123, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_123, 2, __pyx_int_175);
    __pyx_t_124 = PyList_New(3); if (unlikely(!__pyx_t_124)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_124);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_124, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_124, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_124, 2, __pyx_int_215);
    __pyx_t_125 = PyList_New(3); if (unlikely(!__pyx_t_125)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_125);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_125, 0, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_125, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_125, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":66
 *                 [135,215,0],[135,215,95],[135,215,135],[135,215,175],[135,215,215],[135,215,255],
 *                 [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 *                 [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],             # <<<<<<<<<<<<<<
 *                 [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 *                 [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 */
    __pyx_t_126 = PyList_New(3); if (unlikely(!__pyx_t_126)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_126);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_126, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_126, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_126, 2, __pyx_int_0);
    __pyx_t_127 = PyList_New(3); if (unlikely(!__pyx_t_127)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_127);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_127, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_127, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_127, 2, __pyx_int_95);
    __pyx_t_128 = PyList_New(3); if (unlikely(!__pyx_t_128)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_128);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_128, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_128, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_128, 2, __pyx_int_135);
    __pyx_t_129 = PyList_New(3); if (unlikely(!__pyx_t_129)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_129);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_129, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_129, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_129, 2, __pyx_int_175);
    __pyx_t_130 = PyList_New(3); if (unlikely(!__pyx_t_130)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_130);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_130, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_130, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_130, 2, __pyx_int_215);
    __pyx_t_131 = PyList_New(3); if (unlikely(!__pyx_t_131)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_131);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_131, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_131, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_131, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":67
 *                 [135,255,0],[135,255,95],[135,255,135],[135,255,175],[135,255,215],[135,255,255],
 *                 [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 *                 [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],             # <<<<<<<<<<<<<<
 *                 [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 *                 [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 */
    __pyx_t_132 = PyList_New(3); if (unlikely(!__pyx_t_132)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_132);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_132, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_132, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_132, 2, __pyx_int_0);
    __pyx_t_133 = PyList_New(3); if (unlikely(!__pyx_t_133)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_133);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_133, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_133, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_133, 2, __pyx_int_95);
    __pyx_t_134 = PyList_New(3); if (unlikely(!__pyx_t_134)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_134);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_134, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_134, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_134, 2, __pyx_int_135);
    __pyx_t_135 = PyList_New(3); if (unlikely(!__pyx_t_135)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_135, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_135, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_135, 2, __pyx_int_175);
    __pyx_t_136 = PyList_New(3); if (unlikely(!__pyx_t_136)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_136);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_136, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_136, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_136, 2, __pyx_int_215);
    __pyx_t_137 = PyList_New(3); if (unlikely(!__pyx_t_137)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_137);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_137, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_137, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_137, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":68
 *                 [175,0,0],[175,0,95],[175,0,135],[175,0,175],[175,0,215],[175,0,255],
 *                 [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 *                 [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],             # <<<<<<<<<<<<<<
 *                 [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 *                 [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 */
    __pyx_t_138 = PyList_New(3); if (unlikely(!__pyx_t_138)) __PYX_ERR(0, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_138);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_138, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_138, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_138, 2, __pyx_int_0);
    __pyx_t_139 = PyList_New(3); if (unlikely(!__pyx_t_139)) __PYX_ERR(0, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_139);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_139, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_139, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_139, 2, __pyx_int_95);
    __pyx_t_140 = PyList_New(3); if (unlikely(!__pyx_t_140)) __PYX_ERR(0, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_140);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_140, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_140, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_140, 2, __pyx_int_135);
    __pyx_t_141 = PyList_New(3); if (unlikely(!__pyx_t_141)) __PYX_ERR(0, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_141);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_141, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_141, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_141, 2, __pyx_int_175);
    __pyx_t_142 = PyList_New(3); if (unlikely(!__pyx_t_142)) __PYX_ERR(0, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_142);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_142, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_142, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_142, 2, __pyx_int_215);
    __pyx_t_143 = PyList_New(3); if (unlikely(!__pyx_t_143)) __PYX_ERR(0, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_143);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_143, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_143, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_143, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":69
 *                 [175,95,0],[175,95,95],[175,95,135],[175,95,175],[175,95,215],[175,95,255],
 *                 [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 *                 [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],             # <<<<<<<<<<<<<<
 *                 [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 *                 [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 */
    __pyx_t_144 = PyList_New(3); if (unlikely(!__pyx_t_144)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_144);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_144, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_144, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_144, 2, __pyx_int_0);
    __pyx_t_145 = PyList_New(3); if (unlikely(!__pyx_t_145)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_145);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_145, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_145, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_145, 2, __pyx_int_95);
    __pyx_t_146 = PyList_New(3); if (unlikely(!__pyx_t_146)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_146);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_146, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_146, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_146, 2, __pyx_int_135);
    __pyx_t_147 = PyList_New(3); if (unlikely(!__pyx_t_147)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_147);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_147, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_147, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_147, 2, __pyx_int_175);
    __pyx_t_148 = PyList_New(3); if (unlikely(!__pyx_t_148)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_148);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_148, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_148, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_148, 2, __pyx_int_215);
    __pyx_t_149 = PyList_New(3); if (unlikely(!__pyx_t_149)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_149);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_149, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_149, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_149, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":70
 *                 [175,135,0],[175,135,95],[175,135,135],[175,135,175],[175,135,215],[175,135,255],
 *                 [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 *                 [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],             # <<<<<<<<<<<<<<
 *                 [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 *                 [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 */
    __pyx_t_150 = PyList_New(3); if (unlikely(!__pyx_t_150)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_150);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_150, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_150, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_150, 2, __pyx_int_0);
    __pyx_t_151 = PyList_New(3); if (unlikely(!__pyx_t_151)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_151);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_151, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_151, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_151, 2, __pyx_int_95);
    __pyx_t_152 = PyList_New(3); if (unlikely(!__pyx_t_152)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_152);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_152, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_152, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_152, 2, __pyx_int_135);
    __pyx_t_153 = PyList_New(3); if (unlikely(!__pyx_t_153)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_153);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_153, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_153, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_153, 2, __pyx_int_175);
    __pyx_t_154 = PyList_New(3); if (unlikely(!__pyx_t_154)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_154);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_154, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_154, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_154, 2, __pyx_int_215);
    __pyx_t_155 = PyList_New(3); if (unlikely(!__pyx_t_155)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_155);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_155, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_155, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_155, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":71
 *                 [175,175,0],[175,175,95],[175,175,135],[175,175,175],[175,175,215],[175,175,255],
 *                 [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 *                 [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],             # <<<<<<<<<<<<<<
 *                 [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 *                 [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 */
    __pyx_t_156 = PyList_New(3); if (unlikely(!__pyx_t_156)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_156);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_156, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_156, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_156, 2, __pyx_int_0);
    __pyx_t_157 = PyList_New(3); if (unlikely(!__pyx_t_157)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_157);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_157, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_157, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_157, 2, __pyx_int_95);
    __pyx_t_158 = PyList_New(3); if (unlikely(!__pyx_t_158)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_158);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_158, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_158, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_158, 2, __pyx_int_135);
    __pyx_t_159 = PyList_New(3); if (unlikely(!__pyx_t_159)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_159);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_159, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_159, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_159, 2, __pyx_int_175);
    __pyx_t_160 = PyList_New(3); if (unlikely(!__pyx_t_160)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_160);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_160, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_160, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_160, 2, __pyx_int_215);
    __pyx_t_161 = PyList_New(3); if (unlikely(!__pyx_t_161)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_161);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_161, 0, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_161, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_161, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":72
 *                 [175,215,0],[175,215,95],[175,215,135],[175,215,175],[175,215,215],[175,215,255],
 *                 [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 *                 [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],             # <<<<<<<<<<<<<<
 *                 [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 *                 [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 */
    __pyx_t_162 = PyList_New(3); if (unlikely(!__pyx_t_162)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_162);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_162, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_162, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_162, 2, __pyx_int_0);
    __pyx_t_163 = PyList_New(3); if (unlikely(!__pyx_t_163)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_163);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_163, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_163, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_163, 2, __pyx_int_95);
    __pyx_t_164 = PyList_New(3); if (unlikely(!__pyx_t_164)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_164);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_164, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_164, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_164, 2, __pyx_int_135);
    __pyx_t_165 = PyList_New(3); if (unlikely(!__pyx_t_165)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_165);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_165, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_165, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_165, 2, __pyx_int_175);
    __pyx_t_166 = PyList_New(3); if (unlikely(!__pyx_t_166)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_166);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_166, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_166, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_166, 2, __pyx_int_215);
    __pyx_t_167 = PyList_New(3); if (unlikely(!__pyx_t_167)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_167);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_167, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_167, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_167, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":73
 *                 [175,255,0],[175,255,95],[175,255,135],[175,255,175],[175,255,215],[175,255,255],
 *                 [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 *                 [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],             # <<<<<<<<<<<<<<
 *                 [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 *                 [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 */
    __pyx_t_168 = PyList_New(3); if (unlikely(!__pyx_t_168)) __PYX_ERR(0, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_168);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_168, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_168, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_168, 2, __pyx_int_0);
    __pyx_t_169 = PyList_New(3); if (unlikely(!__pyx_t_169)) __PYX_ERR(0, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_169);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_169, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_169, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_169, 2, __pyx_int_95);
    __pyx_t_170 = PyList_New(3); if (unlikely(!__pyx_t_170)) __PYX_ERR(0, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_170);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_170, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_170, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_170, 2, __pyx_int_135);
    __pyx_t_171 = PyList_New(3); if (unlikely(!__pyx_t_171)) __PYX_ERR(0, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_171);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_171, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_171, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_171, 2, __pyx_int_175);
    __pyx_t_172 = PyList_New(3); if (unlikely(!__pyx_t_172)) __PYX_ERR(0, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_172);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_172, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_172, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_172, 2, __pyx_int_215);
    __pyx_t_173 = PyList_New(3); if (unlikely(!__pyx_t_173)) __PYX_ERR(0, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_173);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_173, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_173, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_173, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":74
 *                 [215,0,0],[215,0,95],[215,0,135],[215,0,175],[215,0,215],[215,0,255],
 *                 [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 *                 [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],             # <<<<<<<<<<<<<<
 *                 [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 *                 [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 */
    __pyx_t_174 = PyList_New(3); if (unlikely(!__pyx_t_174)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_174);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_174, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_174, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_174, 2, __pyx_int_0);
    __pyx_t_175 = PyList_New(3); if (unlikely(!__pyx_t_175)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_175, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_175, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_175, 2, __pyx_int_95);
    __pyx_t_176 = PyList_New(3); if (unlikely(!__pyx_t_176)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_176);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_176, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_176, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_176, 2, __pyx_int_135);
    __pyx_t_177 = PyList_New(3); if (unlikely(!__pyx_t_177)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_177);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_177, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_177, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_177, 2, __pyx_int_175);
    __pyx_t_178 = PyList_New(3); if (unlikely(!__pyx_t_178)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_178);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_178, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_178, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_178, 2, __pyx_int_215);
    __pyx_t_179 = PyList_New(3); if (unlikely(!__pyx_t_179)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_179);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_179, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_179, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_179, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":75
 *                 [215,95,0],[215,95,95],[215,95,135],[215,95,175],[215,95,215],[215,95,255],
 *                 [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 *                 [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],             # <<<<<<<<<<<<<<
 *                 [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 *                 [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 */
    __pyx_t_180 = PyList_New(3); if (unlikely(!__pyx_t_180)) __PYX_ERR(0, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_180);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_180, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_180, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_180, 2, __pyx_int_0);
    __pyx_t_181 = PyList_New(3); if (unlikely(!__pyx_t_181)) __PYX_ERR(0, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_181);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_181, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_181, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_181, 2, __pyx_int_95);
    __pyx_t_182 = PyList_New(3); if (unlikely(!__pyx_t_182)) __PYX_ERR(0, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_182);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_182, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_182, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_182, 2, __pyx_int_135);
    __pyx_t_183 = PyList_New(3); if (unlikely(!__pyx_t_183)) __PYX_ERR(0, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_183);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_183, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_183, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_183, 2, __pyx_int_175);
    __pyx_t_184 = PyList_New(3); if (unlikely(!__pyx_t_184)) __PYX_ERR(0, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_184);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_184, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_184, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_184, 2, __pyx_int_215);
    __pyx_t_185 = PyList_New(3); if (unlikely(!__pyx_t_185)) __PYX_ERR(0, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_185);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_185, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_185, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_185, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":76
 *                 [215,135,0],[215,135,95],[215,135,135],[215,135,175],[215,135,215],[215,135,255],
 *                 [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 *                 [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],             # <<<<<<<<<<<<<<
 *                 [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 *                 [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 */
    __pyx_t_186 = PyList_New(3); if (unlikely(!__pyx_t_186)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_186);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_186, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_186, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_186, 2, __pyx_int_0);
    __pyx_t_187 = PyList_New(3); if (unlikely(!__pyx_t_187)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_187);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_187, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_187, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_187, 2, __pyx_int_95);
    __pyx_t_188 = PyList_New(3); if (unlikely(!__pyx_t_188)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_188);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_188, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_188, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_188, 2, __pyx_int_135);
    __pyx_t_189 = PyList_New(3); if (unlikely(!__pyx_t_189)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_189);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_189, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_189, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_189, 2, __pyx_int_175);
    __pyx_t_190 = PyList_New(3); if (unlikely(!__pyx_t_190)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_190);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_190, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_190, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_190, 2, __pyx_int_215);
    __pyx_t_191 = PyList_New(3); if (unlikely(!__pyx_t_191)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_191);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_191, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_191, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_191, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":77
 *                 [215,175,0],[215,175,95],[215,175,135],[215,175,175],[215,175,215],[215,175,255],
 *                 [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 *                 [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],             # <<<<<<<<<<<<<<
 *                 [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 *                 [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 */
    __pyx_t_192 = PyList_New(3); if (unlikely(!__pyx_t_192)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_192);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_192, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_192, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_192, 2, __pyx_int_0);
    __pyx_t_193 = PyList_New(3); if (unlikely(!__pyx_t_193)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_193);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_193, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_193, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_193, 2, __pyx_int_95);
    __pyx_t_194 = PyList_New(3); if (unlikely(!__pyx_t_194)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_194);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_194, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_194, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_194, 2, __pyx_int_135);
    __pyx_t_195 = PyList_New(3); if (unlikely(!__pyx_t_195)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_195);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_195, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_195, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_195, 2, __pyx_int_175);
    __pyx_t_196 = PyList_New(3); if (unlikely(!__pyx_t_196)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_196);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_196, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_196, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_196, 2, __pyx_int_215);
    __pyx_t_197 = PyList_New(3); if (unlikely(!__pyx_t_197)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_197);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_197, 0, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_197, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_197, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":78
 *                 [215,215,0],[215,215,95],[215,215,135],[215,215,175],[215,215,215],[215,215,255],
 *                 [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 *                 [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],             # <<<<<<<<<<<<<<
 *                 [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 *                 [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 */
    __pyx_t_198 = PyList_New(3); if (unlikely(!__pyx_t_198)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_198);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_198, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_198, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_198, 2, __pyx_int_0);
    __pyx_t_199 = PyList_New(3); if (unlikely(!__pyx_t_199)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_199);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_199, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_199, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_199, 2, __pyx_int_95);
    __pyx_t_200 = PyList_New(3); if (unlikely(!__pyx_t_200)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_200);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_200, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_200, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_200, 2, __pyx_int_135);
    __pyx_t_201 = PyList_New(3); if (unlikely(!__pyx_t_201)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_201);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_201, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_201, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_201, 2, __pyx_int_175);
    __pyx_t_202 = PyList_New(3); if (unlikely(!__pyx_t_202)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_202);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_202, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_202, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_202, 2, __pyx_int_215);
    __pyx_t_203 = PyList_New(3); if (unlikely(!__pyx_t_203)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_203);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_203, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_203, 1, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_203, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":79
 *                 [215,255,0],[215,255,95],[215,255,135],[215,255,175],[215,255,215],[215,255,255],
 *                 [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 *                 [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],             # <<<<<<<<<<<<<<
 *                 [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 *                 [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 */
    __pyx_t_204 = PyList_New(3); if (unlikely(!__pyx_t_204)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_204);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_204, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_204, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_204, 2, __pyx_int_0);
    __pyx_t_205 = PyList_New(3); if (unlikely(!__pyx_t_205)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_205);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_205, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_205, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_205, 2, __pyx_int_95);
    __pyx_t_206 = PyList_New(3); if (unlikely(!__pyx_t_206)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_206);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_206, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_206, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_206, 2, __pyx_int_135);
    __pyx_t_207 = PyList_New(3); if (unlikely(!__pyx_t_207)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_207);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_207, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_207, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_207, 2, __pyx_int_175);
    __pyx_t_208 = PyList_New(3); if (unlikely(!__pyx_t_208)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_208);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_208, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_208, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_208, 2, __pyx_int_215);
    __pyx_t_209 = PyList_New(3); if (unlikely(!__pyx_t_209)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_209);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_209, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_209, 1, __pyx_int_95);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_209, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":80
 *                 [255,0,0],[255,0,95],[255,0,135],[255,0,175],[255,0,215],[255,0,255],
 *                 [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 *                 [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],             # <<<<<<<<<<<<<<
 *                 [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 *                 [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 */
    __pyx_t_210 = PyList_New(3); if (unlikely(!__pyx_t_210)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_210);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_210, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_210, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_210, 2, __pyx_int_0);
    __pyx_t_211 = PyList_New(3); if (unlikely(!__pyx_t_211)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_211);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_211, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_211, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_211, 2, __pyx_int_95);
    __pyx_t_212 = PyList_New(3); if (unlikely(!__pyx_t_212)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_212);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_212, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_212, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_212, 2, __pyx_int_135);
    __pyx_t_213 = PyList_New(3); if (unlikely(!__pyx_t_213)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_213);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_213, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_213, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_213, 2, __pyx_int_175);
    __pyx_t_214 = PyList_New(3); if (unlikely(!__pyx_t_214)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_214);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_214, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_214, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_214, 2, __pyx_int_215);
    __pyx_t_215 = PyList_New(3); if (unlikely(!__pyx_t_215)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_215, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_215, 1, __pyx_int_135);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_215, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":81
 *                 [255,95,0],[255,95,95],[255,95,135],[255,95,175],[255,95,215],[255,95,255],
 *                 [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 *                 [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],             # <<<<<<<<<<<<<<
 *                 [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 *                 [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 */
    __pyx_t_216 = PyList_New(3); if (unlikely(!__pyx_t_216)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_216);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_216, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_216, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_216, 2, __pyx_int_0);
    __pyx_t_217 = PyList_New(3); if (unlikely(!__pyx_t_217)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_217);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_217, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_217, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_217, 2, __pyx_int_95);
    __pyx_t_218 = PyList_New(3); if (unlikely(!__pyx_t_218)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_218);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_218, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_218, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_218, 2, __pyx_int_135);
    __pyx_t_219 = PyList_New(3); if (unlikely(!__pyx_t_219)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_219);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_219, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_219, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_219, 2, __pyx_int_175);
    __pyx_t_220 = PyList_New(3); if (unlikely(!__pyx_t_220)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_220);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_220, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_220, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_220, 2, __pyx_int_215);
    __pyx_t_221 = PyList_New(3); if (unlikely(!__pyx_t_221)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_221);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_221, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_221, 1, __pyx_int_175);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_221, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":82
 *                 [255,135,0],[255,135,95],[255,135,135],[255,135,175],[255,135,215],[255,135,255],
 *                 [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 *                 [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],             # <<<<<<<<<<<<<<
 *                 [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 *                 [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 */
    __pyx_t_222 = PyList_New(3); if (unlikely(!__pyx_t_222)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_222);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_222, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_222, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_222, 2, __pyx_int_0);
    __pyx_t_223 = PyList_New(3); if (unlikely(!__pyx_t_223)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_223);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_223, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_223, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_223, 2, __pyx_int_95);
    __pyx_t_224 = PyList_New(3); if (unlikely(!__pyx_t_224)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_224);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_224, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_224, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_224, 2, __pyx_int_135);
    __pyx_t_225 = PyList_New(3); if (unlikely(!__pyx_t_225)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_225);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_225, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_225, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_225, 2, __pyx_int_175);
    __pyx_t_226 = PyList_New(3); if (unlikely(!__pyx_t_226)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_226);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_226, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_226, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_226, 2, __pyx_int_215);
    __pyx_t_227 = PyList_New(3); if (unlikely(!__pyx_t_227)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_227);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_227, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_227, 1, __pyx_int_215);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_227, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":83
 *                 [255,175,0],[255,175,95],[255,175,135],[255,175,175],[255,175,215],[255,175,255],
 *                 [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 *                 [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],             # <<<<<<<<<<<<<<
 *                 [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 *                 [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 */
    __pyx_t_228 = PyList_New(3); if (unlikely(!__pyx_t_228)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_228);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_228, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_228, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_228, 2, __pyx_int_0);
    __pyx_t_229 = PyList_New(3); if (unlikely(!__pyx_t_229)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_229);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_229, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_229, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyList_SET_ITEM(__pyx_t_229, 2, __pyx_int_95);
    __pyx_t_230 = PyList_New(3); if (unlikely(!__pyx_t_230)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_230);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_230, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_230, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_135);
    __Pyx_GIVEREF(__pyx_int_135);
    PyList_SET_ITEM(__pyx_t_230, 2, __pyx_int_135);
    __pyx_t_231 = PyList_New(3); if (unlikely(!__pyx_t_231)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_231);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_231, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_231, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_175);
    __Pyx_GIVEREF(__pyx_int_175);
    PyList_SET_ITEM(__pyx_t_231, 2, __pyx_int_175);
    __pyx_t_232 = PyList_New(3); if (unlikely(!__pyx_t_232)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_232);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_232, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_232, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_215);
    __Pyx_GIVEREF(__pyx_int_215);
    PyList_SET_ITEM(__pyx_t_232, 2, __pyx_int_215);
    __pyx_t_233 = PyList_New(3); if (unlikely(!__pyx_t_233)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_233);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_233, 0, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_233, 1, __pyx_int_255);
    __Pyx_INCREF(__pyx_int_255);
    __Pyx_GIVEREF(__pyx_int_255);
    PyList_SET_ITEM(__pyx_t_233, 2, __pyx_int_255);

    /* "ttygif/gif/color_table.py":84
 *                 [255,215,0],[255,215,95],[255,215,135],[255,215,175],[255,215,215],[255,215,255],
 *                 [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 *                 [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],             # <<<<<<<<<<<<<<
 *                 [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 *                 [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],
 */
    __pyx_t_234 = PyList_New(3); if (unlikely(!__pyx_t_234)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_234);
    __Pyx_INCREF(__pyx_int_8);
    __Pyx_GIVEREF(__pyx_int_8);
    PyList_SET_ITEM(__pyx_t_234, 0, __pyx_int_8);
    __Pyx_INCREF(__pyx_int_8);
    __Pyx_GIVEREF(__pyx_int_8);
    PyList_SET_ITEM(__pyx_t_234, 1, __pyx_int_8);
    __Pyx_INCREF(__pyx_int_8);
    __Pyx_GIVEREF(__pyx_int_8);
    PyList_SET_ITEM(__pyx_t_234, 2, __pyx_int_8);
    __pyx_t_235 = PyList_New(3); if (unlikely(!__pyx_t_235)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_235);
    __Pyx_INCREF(__pyx_int_18);
    __Pyx_GIVEREF(__pyx_int_18);
    PyList_SET_ITEM(__pyx_t_235, 0, __pyx_int_18);
    __Pyx_INCREF(__pyx_int_18);
    __Pyx_GIVEREF(__pyx_int_18);
    PyList_SET_ITEM(__pyx_t_235, 1, __pyx_int_18);
    __Pyx_INCREF(__pyx_int_18);
    __Pyx_GIVEREF(__pyx_int_18);
    PyList_SET_ITEM(__pyx_t_235, 2, __pyx_int_18);
    __pyx_t_236 = PyList_New(3); if (unlikely(!__pyx_t_236)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_236);
    __Pyx_INCREF(__pyx_int_28);
    __Pyx_GIVEREF(__pyx_int_28);
    PyList_SET_ITEM(__pyx_t_236, 0, __pyx_int_28);
    __Pyx_INCREF(__pyx_int_28);
    __Pyx_GIVEREF(__pyx_int_28);
    PyList_SET_ITEM(__pyx_t_236, 1, __pyx_int_28);
    __Pyx_INCREF(__pyx_int_28);
    __Pyx_GIVEREF(__pyx_int_28);
    PyList_SET_ITEM(__pyx_t_236, 2, __pyx_int_28);
    __pyx_t_237 = PyList_New(3); if (unlikely(!__pyx_t_237)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_237);
    __Pyx_INCREF(__pyx_int_38);
    __Pyx_GIVEREF(__pyx_int_38);
    PyList_SET_ITEM(__pyx_t_237, 0, __pyx_int_38);
    __Pyx_INCREF(__pyx_int_38);
    __Pyx_GIVEREF(__pyx_int_38);
    PyList_SET_ITEM(__pyx_t_237, 1, __pyx_int_38);
    __Pyx_INCREF(__pyx_int_38);
    __Pyx_GIVEREF(__pyx_int_38);
    PyList_SET_ITEM(__pyx_t_237, 2, __pyx_int_38);
    __pyx_t_238 = PyList_New(3); if (unlikely(!__pyx_t_238)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_238);
    __Pyx_INCREF(__pyx_int_48);
    __Pyx_GIVEREF(__pyx_int_48);
    PyList_SET_ITEM(__pyx_t_238, 0, __pyx_int_48);
    __Pyx_INCREF(__pyx_int_48);
    __Pyx_GIVEREF(__pyx_int_48);
    PyList_SET_ITEM(__pyx_t_238, 1, __pyx_int_48);
    __Pyx_INCREF(__pyx_int_48);
    __Pyx_GIVEREF(__pyx_int_48);
    PyList_SET_ITEM(__pyx_t_238, 2, __pyx_int_48);
    __pyx_t_239 = PyList_New(3); if (unlikely(!__pyx_t_239)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_239);
    __Pyx_INCREF(__pyx_int_58);
    __Pyx_GIVEREF(__pyx_int_58);
    PyList_SET_ITEM(__pyx_t_239, 0, __pyx_int_58);
    __Pyx_INCREF(__pyx_int_58);
    __Pyx_GIVEREF(__pyx_int_58);
    PyList_SET_ITEM(__pyx_t_239, 1, __pyx_int_58);
    __Pyx_INCREF(__pyx_int_58);
    __Pyx_GIVEREF(__pyx_int_58);
    PyList_SET_ITEM(__pyx_t_239, 2, __pyx_int_58);
    __pyx_t_240 = PyList_New(3); if (unlikely(!__pyx_t_240)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_240);
    __Pyx_INCREF(__pyx_int_68);
    __Pyx_GIVEREF(__pyx_int_68);
    PyList_SET_ITEM(__pyx_t_240, 0, __pyx_int_68);
    __Pyx_INCREF(__pyx_int_68);
    __Pyx_GIVEREF(__pyx_int_68);
    PyList_SET_ITEM(__pyx_t_240, 1, __pyx_int_68);
    __Pyx_INCREF(__pyx_int_68);
    __Pyx_GIVEREF(__pyx_int_68);
    PyList_SET_ITEM(__pyx_t_240, 2, __pyx_int_68);

    /* "ttygif/gif/color_table.py":85
 *                 [255,255,0],[255,255,95],[255,255,135],[255,255,175],[255,255,215],[255,255,255],
 *                 [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 *                 [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],             # <<<<<<<<<<<<<<
 *                 [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],
 *                 [198,198,198],[208,208,208],[218,218,218],[228,228,228],[238,238,238] ]
 */
    __pyx_t_241 = PyList_New(3); if (unlikely(!__pyx_t_241)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_241);
    __Pyx_INCREF(__pyx_int_78);
    __Pyx_GIVEREF(__pyx_int_78);
    PyList_SET_ITEM(__pyx_t_241, 0, __pyx_int_78);
    __Pyx_INCREF(__pyx_int_78);
    __Pyx_GIVEREF(__pyx_int_78);
    PyList_SET_ITEM(__pyx_t_241, 1, __pyx_int_78);
    __Pyx_INCREF(__pyx_int_78);
    __Pyx_GIVEREF(__pyx_int_78);
    PyList_SET_ITEM(__pyx_t_241, 2, __pyx_int_78);
    __pyx_t_242 = PyList_New(3); if (unlikely(!__pyx_t_242)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_242);
    __Pyx_INCREF(__pyx_int_88);
    __Pyx_GIVEREF(__pyx_int_88);
    PyList_SET_ITEM(__pyx_t_242, 0, __pyx_int_88);
    __Pyx_INCREF(__pyx_int_88);
    __Pyx_GIVEREF(__pyx_int_88);
    PyList_SET_ITEM(__pyx_t_242, 1, __pyx_int_88);
    __Pyx_INCREF(__pyx_int_88);
    __Pyx_GIVEREF(__pyx_int_88);
    PyList_SET_ITEM(__pyx_t_242, 2, __pyx_int_88);
    __pyx_t_243 = PyList_New(3); if (unlikely(!__pyx_t_243)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_243);
    __Pyx_INCREF(__pyx_int_98);
    __Pyx_GIVEREF(__pyx_int_98);
    PyList_SET_ITEM(__pyx_t_243, 0, __pyx_int_98);
    __Pyx_INCREF(__pyx_int_98);
    __Pyx_GIVEREF(__pyx_int_98);
    PyList_SET_ITEM(__pyx_t_243, 1, __pyx_int_98);
    __Pyx_INCREF(__pyx_int_98);
    __Pyx_GIVEREF(__pyx_int_98);
    PyList_SET_ITEM(__pyx_t_243, 2, __pyx_int_98);
    __pyx_t_244 = PyList_New(3); if (unlikely(!__pyx_t_244)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_244);
    __Pyx_INCREF(__pyx_int_108);
    __Pyx_GIVEREF(__pyx_int_108);
    PyList_SET_ITEM(__pyx_t_244, 0, __pyx_int_108);
    __Pyx_INCREF(__pyx_int_108);
    __Pyx_GIVEREF(__pyx_int_108);
    PyList_SET_ITEM(__pyx_t_244, 1, __pyx_int_108);
    __Pyx_INCREF(__pyx_int_108);
    __Pyx_GIVEREF(__pyx_int_108);
    PyList_SET_ITEM(__pyx_t_244, 2, __pyx_int_108);
    __pyx_t_245 = PyList_New(3); if (unlikely(!__pyx_t_245)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_245);
    __Pyx_INCREF(__pyx_int_118);
    __Pyx_GIVEREF(__pyx_int_118);
    PyList_SET_ITEM(__pyx_t_245, 0, __pyx_int_118);
    __Pyx_INCREF(__pyx_int_118);
    __Pyx_GIVEREF(__pyx_int_118);
    PyList_SET_ITEM(__pyx_t_245, 1, __pyx_int_118);
    __Pyx_INCREF(__pyx_int_118);
    __Pyx_GIVEREF(__pyx_int_118);
    PyList_SET_ITEM(__pyx_t_245, 2, __pyx_int_118);
    __pyx_t_246 = PyList_New(3); if (unlikely(!__pyx_t_246)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_246);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_246, 0, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_246, 1, __pyx_int_128);
    __Pyx_INCREF(__pyx_int_128);
    __Pyx_GIVEREF(__pyx_int_128);
    PyList_SET_ITEM(__pyx_t_246, 2, __pyx_int_128);

    /* "ttygif/gif/color_table.py":86
 *                 [8,8,8],[18,18,18],[28,28,28],[38,38,38],[48,48,48],[58,58,58],[68,68,68],
 *                 [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 *                 [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],             # <<<<<<<<<<<<<<
 *                 [198,198,198],[208,208,208],[218,218,218],[228,228,228],[238,238,238] ]
 *             self.colors=color_table
 */
    __pyx_t_247 = PyList_New(3); if (unlikely(!__pyx_t_247)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_247);
    __Pyx_INCREF(__pyx_int_138);
    __Pyx_GIVEREF(__pyx_int_138);
    PyList_SET_ITEM(__pyx_t_247, 0, __pyx_int_138);
    __Pyx_INCREF(__pyx_int_138);
    __Pyx_GIVEREF(__pyx_int_138);
    PyList_SET_ITEM(__pyx_t_247, 1, __pyx_int_138);
    __Pyx_INCREF(__pyx_int_138);
    __Pyx_GIVEREF(__pyx_int_138);
    PyList_SET_ITEM(__pyx_t_247, 2, __pyx_int_138);
    __pyx_t_248 = PyList_New(3); if (unlikely(!__pyx_t_248)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_248);
    __Pyx_INCREF(__pyx_int_148);
    __Pyx_GIVEREF(__pyx_int_148);
    PyList_SET_ITEM(__pyx_t_248, 0, __pyx_int_148);
    __Pyx_INCREF(__pyx_int_148);
    __Pyx_GIVEREF(__pyx_int_148);
    PyList_SET_ITEM(__pyx_t_248, 1, __pyx_int_148);
    __Pyx_INCREF(__pyx_int_148);
    __Pyx_GIVEREF(__pyx_int_148);
    PyList_SET_ITEM(__pyx_t_248, 2, __pyx_int_148);
    __pyx_t_249 = PyList_New(3); if (unlikely(!__pyx_t_249)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_249);
    __Pyx_INCREF(__pyx_int_158);
    __Pyx_GIVEREF(__pyx_int_158);
    PyList_SET_ITEM(__pyx_t_249, 0, __pyx_int_158);
    __Pyx_INCREF(__pyx_int_158);
    __Pyx_GIVEREF(__pyx_int_158);
    PyList_SET_ITEM(__pyx_t_249, 1, __pyx_int_158);
    __Pyx_INCREF(__pyx_int_158);
    __Pyx_GIVEREF(__pyx_int_158);
    PyList_SET_ITEM(__pyx_t_249, 2, __pyx_int_158);
    __pyx_t_250 = PyList_New(3); if (unlikely(!__pyx_t_250)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_250);
    __Pyx_INCREF(__pyx_int_168);
    __Pyx_GIVEREF(__pyx_int_168);
    PyList_SET_ITEM(__pyx_t_250, 0, __pyx_int_168);
    __Pyx_INCREF(__pyx_int_168);
    __Pyx_GIVEREF(__pyx_int_168);
    PyList_SET_ITEM(__pyx_t_250, 1, __pyx_int_168);
    __Pyx_INCREF(__pyx_int_168);
    __Pyx_GIVEREF(__pyx_int_168);
    PyList_SET_ITEM(__pyx_t_250, 2, __pyx_int_168);
    __pyx_t_251 = PyList_New(3); if (unlikely(!__pyx_t_251)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_251);
    __Pyx_INCREF(__pyx_int_178);
    __Pyx_GIVEREF(__pyx_int_178);
    PyList_SET_ITEM(__pyx_t_251, 0, __pyx_int_178);
    __Pyx_INCREF(__pyx_int_178);
    __Pyx_GIVEREF(__pyx_int_178);
    PyList_SET_ITEM(__pyx_t_251, 1, __pyx_int_178);
    __Pyx_INCREF(__pyx_int_178);
    __Pyx_GIVEREF(__pyx_int_178);
    PyList_SET_ITEM(__pyx_t_251, 2, __pyx_int_178);
    __pyx_t_252 = PyList_New(3); if (unlikely(!__pyx_t_252)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_252);
    __Pyx_INCREF(__pyx_int_188);
    __Pyx_GIVEREF(__pyx_int_188);
    PyList_SET_ITEM(__pyx_t_252, 0, __pyx_int_188);
    __Pyx_INCREF(__pyx_int_188);
    __Pyx_GIVEREF(__pyx_int_188);
    PyList_SET_ITEM(__pyx_t_252, 1, __pyx_int_188);
    __Pyx_INCREF(__pyx_int_188);
    __Pyx_GIVEREF(__pyx_int_188);
    PyList_SET_ITEM(__pyx_t_252, 2, __pyx_int_188);

    /* "ttygif/gif/color_table.py":87
 *                 [78,78,78],[88,88,88],[98,98,98],[108,108,108],[118,118,118],[128,128,128],
 *                 [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],
 *                 [198,198,198],[208,208,208],[218,218,218],[228,228,228],[238,238,238] ]             # <<<<<<<<<<<<<<
 *             self.colors=color_table
 * 
 */
    __pyx_t_253 = PyList_New(3); if (unlikely(!__pyx_t_253)) __PYX_ERR(0, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_253);
    __Pyx_INCREF(__pyx_int_198);
    __Pyx_GIVEREF(__pyx_int_198);
    PyList_SET_ITEM(__pyx_t_253, 0, __pyx_int_198);
    __Pyx_INCREF(__pyx_int_198);
    __Pyx_GIVEREF(__pyx_int_198);
    PyList_SET_ITEM(__pyx_t_253, 1, __pyx_int_198);
    __Pyx_INCREF(__pyx_int_198);
    __Pyx_GIVEREF(__pyx_int_198);
    PyList_SET_ITEM(__pyx_t_253, 2, __pyx_int_198);
    __pyx_t_254 = PyList_New(3); if (unlikely(!__pyx_t_254)) __PYX_ERR(0, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_254);
    __Pyx_INCREF(__pyx_int_208);
    __Pyx_GIVEREF(__pyx_int_208);
    PyList_SET_ITEM(__pyx_t_254, 0, __pyx_int_208);
    __Pyx_INCREF(__pyx_int_208);
    __Pyx_GIVEREF(__pyx_int_208);
    PyList_SET_ITEM(__pyx_t_254, 1, __pyx_int_208);
    __Pyx_INCREF(__pyx_int_208);
    __Pyx_GIVEREF(__pyx_int_208);
    PyList_SET_ITEM(__pyx_t_254, 2, __pyx_int_208);
    __pyx_t_255 = PyList_New(3); if (unlikely(!__pyx_t_255)) __PYX_ERR(0, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_255);
    __Pyx_INCREF(__pyx_int_218);
    __Pyx_GIVEREF(__pyx_int_218);
    PyList_SET_ITEM(__pyx_t_255, 0, __pyx_int_218);
    __Pyx_INCREF(__pyx_int_218);
    __Pyx_GIVEREF(__pyx_int_218);
    PyList_SET_ITEM(__pyx_t_255, 1, __pyx_int_218);
    __Pyx_INCREF(__pyx_int_218);
    __Pyx_GIVEREF(__pyx_int_218);
    PyList_SET_ITEM(__pyx_t_255, 2, __pyx_int_218);
    __pyx_t_256 = PyList_New(3); if (unlikely(!__pyx_t_256)) __PYX_ERR(0, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_256);
    __Pyx_INCREF(__pyx_int_228);
    __Pyx_GIVEREF(__pyx_int_228);
    PyList_SET_ITEM(__pyx_t_256, 0, __pyx_int_228);
    __Pyx_INCREF(__pyx_int_228);
    __Pyx_GIVEREF(__pyx_int_228);
    PyList_SET_ITEM(__pyx_t_256, 1, __pyx_int_228);
    __Pyx_INCREF(__pyx_int_228);
    __Pyx_GIVEREF(__pyx_int_228);
    PyList_SET_ITEM(__pyx_t_256, 2, __pyx_int_228);
    __pyx_t_257 = PyList_New(3); if (unlikely(!__pyx_t_257)) __PYX_ERR(0, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_257);
    __Pyx_INCREF(__pyx_int_238);
    __Pyx_GIVEREF(__pyx_int_238);
    PyList_SET_ITEM(__pyx_t_257, 0, __pyx_int_238);
    __Pyx_INCREF(__pyx_int_238);
    __Pyx_GIVEREF(__pyx_int_238);
    PyList_SET_ITEM(__pyx_t_257, 1, __pyx_int_238);
    __Pyx_INCREF(__pyx_int_238);
    __Pyx_GIVEREF(__pyx_int_238);
    PyList_SET_ITEM(__pyx_t_257, 2, __pyx_int_238);

    /* "ttygif/gif/color_table.py":42
 *             self.colors=palette
 *         else:
 *             color_table=[  # 16 System Colors             # <<<<<<<<<<<<<<
 *                 [0,0,0],[128,0,0],[0,128,0],[128,128,0],
 *                 [0,0,128],[128,0,128],[0,128,128],[192,192,192],
 */
    __pyx_t_258 = PyList_New(256); if (unlikely(!__pyx_t_258)) __PYX_ERR(0, 42, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_258);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_258, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyList_SET_ITEM(__pyx_t_258, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyList_SET_ITEM(__pyx_t_258, 2, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyList_SET_ITEM(__pyx_t_258, 3, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyList_SET_ITEM(__pyx_t_258, 4, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyList_SET_ITEM(__pyx_t_258, 5, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_8);
    PyList_SET_ITEM(__pyx_t_258, 6, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_9);
    PyList_SET_ITEM(__pyx_t_258, 7, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_10);
    PyList_SET_ITEM(__pyx_t_258, 8, __pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_11);
    PyList_SET_ITEM(__pyx_t_258, 9, __pyx_t_11);
    __Pyx_GIVEREF(__pyx_t_12);
    PyList_SET_ITEM(__pyx_t_258, 10, __pyx_t_12);
    __Pyx_GIVEREF(__pyx_t_13);
    PyList_SET_ITEM(__pyx_t_258, 11, __pyx_t_13);
    __Pyx_GIVEREF(__pyx_t_14);
    PyList_SET_ITEM(__pyx_t_258, 12, __pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyList_SET_ITEM(__pyx_t_258, 13, __pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_16);
    PyList_SET_ITEM(__pyx_t_258, 14, __pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_17);
    PyList_SET_ITEM(__pyx_t_258, 15, __pyx_t_17);
    __Pyx_GIVEREF(__pyx_t_18);
    PyList_SET_ITEM(__pyx_t_258, 16, __pyx_t_18);
    __Pyx_GIVEREF(__pyx_t_19);
    PyList_SET_ITEM(__pyx_t_258, 17, __pyx_t_19);
    __Pyx_GIVEREF(__pyx_t_20);
    PyList_SET_ITEM(__pyx_t_258, 18, __pyx_t_20);
    __Pyx_GIVEREF(__pyx_t_21);
    PyList_SET_ITEM(__pyx_t_258, 19, __pyx_t_21);
    __Pyx_GIVEREF(__pyx_t_22);
    PyList_SET_ITEM(__pyx_t_258, 20, __pyx_t_22);
    __Pyx_GIVEREF(__pyx_t_23);
    PyList_SET_ITEM(__pyx_t_258, 21, __pyx_t_23);
    __Pyx_GIVEREF(__pyx_t_24);
    PyList_SET_ITEM(__pyx_t_258, 22, __pyx_t_24);
    __Pyx_GIVEREF(__pyx_t_25);
    PyList_SET_ITEM(__pyx_t_258, 23, __pyx_t_25);
    __Pyx_GIVEREF(__pyx_t_26);
    PyList_SET_ITEM(__pyx_t_258, 24, __pyx_t_26);
    __Pyx_GIVEREF(__pyx_t_27);
    PyList_SET_ITEM(__pyx_t_258, 25, __pyx_t_27);
    __Pyx_GIVEREF(__pyx_t_28);
    PyList_SET_ITEM(__pyx_t_258, 26, __pyx_t_28);
    __Pyx_GIVEREF(__pyx_t_29);
    PyList_SET_ITEM(__pyx_t_258, 27, __pyx_t_29);
    __Pyx_GIVEREF(__pyx_t_30);
    PyList_SET_ITEM(__pyx_t_258, 28, __pyx_t_30);
    __Pyx_GIVEREF(__pyx_t_31);
    PyList_SET_ITEM(__pyx_t_258, 29, __pyx_t_31);
    __Pyx_GIVEREF(__pyx_t_32);
    PyList_SET_ITEM(__pyx_t_258, 30, __pyx_t_32);
    __Pyx_GIVEREF(__pyx_t_33);
    PyList_SET_ITEM(__pyx_t_258, 31, __pyx_t_33);
    __Pyx_GIVEREF(__pyx_t_34);
    PyList_SET_ITEM(__pyx_t_258, 32, __pyx_t_34);
    __Pyx_GIVEREF(__pyx_t_35);
    PyList_SET_ITEM(__pyx_t_258, 33, __pyx_t_35);
    __Pyx_GIVEREF(__pyx_t_36);
    PyList_SET_ITEM(__pyx_t_258, 34, __pyx_t_36);
    __Pyx_GIVEREF(__pyx_t_37);
    PyList_SET_ITEM(__pyx_t_258, 35, __pyx_t_37);
    __Pyx_GIVEREF(__pyx_t_38);
    PyList_SET_ITEM(__pyx_t_258, 36, __pyx_t_38);
    __Pyx_GIVEREF(__pyx_t_39);
    PyList_SET_ITEM(__pyx_t_258, 37, __pyx_t_39);
    __Pyx_GIVEREF(__pyx_t_40);
    PyList_SET_ITEM(__pyx_t_258, 38, __pyx_t_40);
    __Pyx_GIVEREF(__pyx_t_41);
    PyList_SET_ITEM(__pyx_t_258, 39, __pyx_t_41);
    __Pyx_GIVEREF(__pyx_t_42);
    PyList_SET_ITEM(__pyx_t_258, 40, __pyx_t_42);
    __Pyx_GIVEREF(__pyx_t_43);
    PyList_SET_ITEM(__pyx_t_258, 41, __pyx_t_43);
    __Pyx_GIVEREF(__pyx_t_44);
    PyList_SET_ITEM(__pyx_t_258, 42, __pyx_t_44);
    __Pyx_GIVEREF(__pyx_t_45);
    PyList_SET_ITEM(__pyx_t_258, 43, __pyx_t_45);
    __Pyx_GIVEREF(__pyx_t_46);
    PyList_SET_ITEM(__pyx_t_258, 44, __pyx_t_46);
    __Pyx_GIVEREF(__pyx_t_47);
    PyList_SET_ITEM(__pyx_t_258, 45, __pyx_t_47);
    __Pyx_GIVEREF(__pyx_t_48);
    PyList_SET_ITEM(__pyx_t_258, 46, __pyx_t_48);
    __Pyx_GIVEREF(__pyx_t_49);
    PyList_SET_ITEM(__pyx_t_258, 47, __pyx_t_49);
    __Pyx_GIVEREF(__pyx_t_50);
    PyList_SET_ITEM(__pyx_t_258, 48, __pyx_t_50);
    __Pyx_GIVEREF(__pyx_t_51);
    PyList_SET_ITEM(__pyx_t_258, 49, __pyx_t_51);
    __Pyx_GIVEREF(__pyx_t_52);
    PyList_SET_ITEM(__pyx_t_258, 50, __pyx_t_52);
    __Pyx_GIVEREF(__pyx_t_53);
    PyList_SET_ITEM(__pyx_t_258, 51, __pyx_t_53);
    __Pyx_GIVEREF(__pyx_t_54);
    PyList_SET_ITEM(__pyx_t_258, 52, __pyx_t_54);
    __Pyx_GIVEREF(__pyx_t_55);
    PyList_SET_ITEM(__pyx_t_258, 53, __pyx_t_55);
    __Pyx_GIVEREF(__pyx_t_56);
    PyList_SET_ITEM(__pyx_t_258, 54, __pyx_t_56);
    __Pyx_GIVEREF(__pyx_t_57);
    PyList_SET_ITEM(__pyx_t_258, 55, __pyx_t_57);
    __Pyx_GIVEREF(__pyx_t_58);
    PyList_SET_ITEM(__pyx_t_258, 56, __pyx_t_58);
    __Pyx_GIVEREF(__pyx_t_59);
    PyList_SET_ITEM(__pyx_t_258, 57, __pyx_t_59);
    __Pyx_GIVEREF(__pyx_t_60);
    PyList_SET_ITEM(__pyx_t_258, 58, __pyx_t_60);
    __Pyx_GIVEREF(__pyx_t_61);
    PyList_SET_ITEM(__pyx_t_258, 59, __pyx_t_61);
    __Pyx_GIVEREF(__pyx_t_62);
    PyList_SET_ITEM(__pyx_t_258, 60, __pyx_t_62);
    __Pyx_GIVEREF(__pyx_t_63);
    PyList_SET_ITEM(__pyx_t_258, 61, __pyx_t_63);
    __Pyx_GIVEREF(__pyx_t_64);
    PyList_SET_ITEM(__pyx_t_258, 62, __pyx_t_64);
    __Pyx_GIVEREF(__pyx_t_65);
    PyList_SET_ITEM(__pyx_t_258, 63, __pyx_t_65);
    __Pyx_GIVEREF(__pyx_t_66);
    PyList_SET_ITEM(__pyx_t_258, 64, __pyx_t_66);
    __Pyx_GIVEREF(__pyx_t_67);
    PyList_SET_ITEM(__pyx_t_258, 65, __pyx_t_67);
    __Pyx_GIVEREF(__pyx_t_68);
    PyList_SET_ITEM(__pyx_t_258, 66, __pyx_t_68);
    __Pyx_GIVEREF(__pyx_t_69);
    PyList_SET_ITEM(__pyx_t_258, 67, __pyx_t_69);
    __Pyx_GIVEREF(__pyx_t_70);
    PyList_SET_ITEM(__pyx_t_258, 68, __pyx_t_70);
    __Pyx_GIVEREF(__pyx_t_71);
    PyList_SET_ITEM(__pyx_t_258, 69, __pyx_t_71);
    __Pyx_GIVEREF(__pyx_t_72);
    PyList_SET_ITEM(__pyx_t_258, 70, __pyx_t_72);
    __Pyx_GIVEREF(__pyx_t_73);
    PyList_SET_ITEM(__pyx_t_258, 71, __pyx_t_73);
    __Pyx_GIVEREF(__pyx_t_74);
    PyList_SET_ITEM(__pyx_t_258, 72, __pyx_t_74);
    __Pyx_GIVEREF(__pyx_t_75);
    PyList_SET_ITEM(__pyx_t_258, 73, __pyx_t_75);
    __Pyx_GIVEREF(__pyx_t_76);
    PyList_SET_ITEM(__pyx_t_258, 74, __pyx_t_76);
    __Pyx_GIVEREF(__pyx_t_77);
    PyList_SET_ITEM(__pyx_t_258, 75, __pyx_t_77);
    __Pyx_GIVEREF(__pyx_t_78);
    PyList_SET_ITEM(__pyx_t_258, 76, __pyx_t_78);
    __Pyx_GIVEREF(__pyx_t_79);
    PyList_SET_ITEM(__pyx_t_258, 77, __pyx_t_79);
    __Pyx_GIVEREF(__pyx_t_80);
    PyList_SET_ITEM(__pyx_t_258, 78, __pyx_t_80);
    __Pyx_GIVEREF(__pyx_t_81);
    PyList_SET_ITEM(__pyx_t_258, 79, __pyx_t_81);
    __Pyx_GIVEREF(__pyx_t_82);
    PyList_SET_ITEM(__pyx_t_258, 80, __pyx_t_82);
    __Pyx_GIVEREF(__pyx_t_83);
    PyList_SET_ITEM(__pyx_t_258, 81, __pyx_t_83);
    __Pyx_GIVEREF(__pyx_t_84);
    PyList_SET_ITEM(__pyx_t_258, 82, __pyx_t_84);
    __Pyx_GIVEREF(__pyx_t_85);
    PyList_SET_ITEM(__pyx_t_258, 83, __pyx_t_85);
    __Pyx_GIVEREF(__pyx_t_86);
    PyList_SET_ITEM(__pyx_t_258, 84, __pyx_t_86);
    __Pyx_GIVEREF(__pyx_t_87);
    PyList_SET_ITEM(__pyx_t_258, 85, __pyx_t_87);
    __Pyx_GIVEREF(__pyx_t_88);
    PyList_SET_ITEM(__pyx_t_258, 86, __pyx_t_88);
    __Pyx_GIVEREF(__pyx_t_89);
    PyList_SET_ITEM(__pyx_t_258, 87, __pyx_t_89);
    __Pyx_GIVEREF(__pyx_t_90);
    PyList_SET_ITEM(__pyx_t_258, 88, __pyx_t_90);
    __Pyx_GIVEREF(__pyx_t_91);
    PyList_SET_ITEM(__pyx_t_258, 89, __pyx_t_91);
    __Pyx_GIVEREF(__pyx_t_92);
    PyList_SET_ITEM(__pyx_t_258, 90, __pyx_t_92);
    __Pyx_GIVEREF(__pyx_t_93);
    PyList_SET_ITEM(__pyx_t_258, 91, __pyx_t_93);
    __Pyx_GIVEREF(__pyx_t_94);
    PyList_SET_ITEM(__pyx_t_258, 92, __pyx_t_94);
    __Pyx_GIVEREF(__pyx_t_95);
    PyList_SET_ITEM(__pyx_t_258, 93, __pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_96);
    PyList_SET_ITEM(__pyx_t_258, 94, __pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_97);
    PyList_SET_ITEM(__pyx_t_258, 95, __pyx_t_97);
    __Pyx_GIVEREF(__pyx_t_98);
    PyList_SET_ITEM(__pyx_t_258, 96, __pyx_t_98);
    __Pyx_GIVEREF(__pyx_t_99);
    PyList_SET_ITEM(__pyx_t_258, 97, __pyx_t_99);
    __Pyx_GIVEREF(__pyx_t_100);
    PyList_SET_ITEM(__pyx_t_258, 98, __pyx_t_100);
    __Pyx_GIVEREF(__pyx_t_101);
    PyList_SET_ITEM(__pyx_t_258, 99, __pyx_t_101);
    __Pyx_GIVEREF(__pyx_t_102);
    PyList_SET_ITEM(__pyx_t_258, 100, __pyx_t_102);
    __Pyx_GIVEREF(__pyx_t_103);
    PyList_SET_ITEM(__pyx_t_258, 101, __pyx_t_103);
    __Pyx_GIVEREF(__pyx_t_104);
    PyList_SET_ITEM(__pyx_t_258, 102, __pyx_t_104);
    __Pyx_GIVEREF(__pyx_t_105);
    PyList_SET_ITEM(__pyx_t_258, 103, __pyx_t_105);
    __Pyx_GIVEREF(__pyx_t_106);
    PyList_SET_ITEM(__pyx_t_258, 104, __pyx_t_106);
    __Pyx_GIVEREF(__pyx_t_107);
    PyList_SET_ITEM(__pyx_t_258, 105, __pyx_t_107);
    __Pyx_GIVEREF(__pyx_t_108);
    PyList_SET_ITEM(__pyx_t_258, 106, __pyx_t_108);
    __Pyx_GIVEREF(__pyx_t_109);
    PyList_SET_ITEM(__pyx_t_258, 107, __pyx_t_109);
    __Pyx_GIVEREF(__pyx_t_110);
    PyList_SET_ITEM(__pyx_t_258, 108, __pyx_t_110);
    __Pyx_GIVEREF(__pyx_t_111);
    PyList_SET_ITEM(__pyx_t_258, 109, __pyx_t_111);
    __Pyx_GIVEREF(__pyx_t_112);
    PyList_SET_ITEM(__pyx_t_258, 110, __pyx_t_112);
    __Pyx_GIVEREF(__pyx_t_113);
    PyList_SET_ITEM(__pyx_t_258, 111, __pyx_t_113);
    __Pyx_GIVEREF(__pyx_t_114);
    PyList_SET_ITEM(__pyx_t_258, 112, __pyx_t_114);
    __Pyx_GIVEREF(__pyx_t_115);
    PyList_SET_ITEM(__pyx_t_258, 113, __pyx_t_115);
    __Pyx_GIVEREF(__pyx_t_116);
    PyList_SET_ITEM(__pyx_t_258, 114, __pyx_t_116);
    __Pyx_GIVEREF(__pyx_t_117);
    PyList_SET_ITEM(__pyx_t_258, 115, __pyx_t_117);
    __Pyx_GIVEREF(__pyx_t_118);
    PyList_SET_ITEM(__pyx_t_258, 116, __pyx_t_118);
    __Pyx_GIVEREF(__pyx_t_119);
    PyList_SET_ITEM(__pyx_t_258, 117, __pyx_t_119);
    __Pyx_GIVEREF(__pyx_t_120);
    PyList_SET_ITEM(__pyx_t_258, 118, __pyx_t_120);
    __Pyx_GIVEREF(__pyx_t_121);
    PyList_SET_ITEM(__pyx_t_258, 119, __pyx_t_121);
    __Pyx_GIVEREF(__pyx_t_122);
    PyList_SET_ITEM(__pyx_t_258, 120, __pyx_t_122);
    __Pyx_GIVEREF(__pyx_t_123);
    PyList_SET_ITEM(__pyx_t_258, 121, __pyx_t_123);
    __Pyx_GIVEREF(__pyx_t_124);
    PyList_SET_ITEM(__pyx_t_258, 122, __pyx_t_124);
    __Pyx_GIVEREF(__pyx_t_125);
    PyList_SET_ITEM(__pyx_t_258, 123, __pyx_t_125);
    __Pyx_GIVEREF(__pyx_t_126);
    PyList_SET_ITEM(__pyx_t_258, 124, __pyx_t_126);
    __Pyx_GIVEREF(__pyx_t_127);
    PyList_SET_ITEM(__pyx_t_258, 125, __pyx_t_127);
    __Pyx_GIVEREF(__pyx_t_128);
    PyList_SET_ITEM(__pyx_t_258, 126, __pyx_t_128);
    __Pyx_GIVEREF(__pyx_t_129);
    PyList_SET_ITEM(__pyx_t_258, 127, __pyx_t_129);
    __Pyx_GIVEREF(__pyx_t_130);
    PyList_SET_ITEM(__pyx_t_258, 128, __pyx_t_130);
    __Pyx_GIVEREF(__pyx_t_131);
    PyList_SET_ITEM(__pyx_t_258, 129, __pyx_t_131);
    __Pyx_GIVEREF(__pyx_t_132);
    PyList_SET_ITEM(__pyx_t_258, 130, __pyx_t_132);
    __Pyx_GIVEREF(__pyx_t_133);
    PyList_SET_ITEM(__pyx_t_258, 131, __pyx_t_133);
    __Pyx_GIVEREF(__pyx_t_134);
    PyList_SET_ITEM(__pyx_t_258, 132, __pyx_t_134);
    __Pyx_GIVEREF(__pyx_t_135);
    PyList_SET_ITEM(__pyx_t_258, 133, __pyx_t_135);
    __Pyx_GIVEREF(__pyx_t_136);
    PyList_SET_ITEM(__pyx_t_258, 134, __pyx_t_136);
    __Pyx_GIVEREF(__pyx_t_137);
    PyList_SET_ITEM(__pyx_t_258, 135, __pyx_t_137);
    __Pyx_GIVEREF(__pyx_t_138);
    PyList_SET_ITEM(__pyx_t_258, 136, __pyx_t_138);
    __Pyx_GIVEREF(__pyx_t_139);
    PyList_SET_ITEM(__pyx_t_258, 137, __pyx_t_139);
    __Pyx_GIVEREF(__pyx_t_140);
    PyList_SET_ITEM(__pyx_t_258, 138, __pyx_t_140);
    __Pyx_GIVEREF(__pyx_t_141);
    PyList_SET_ITEM(__pyx_t_258, 139, __pyx_t_141);
    __Pyx_GIVEREF(__pyx_t_142);
    PyList_SET_ITEM(__pyx_t_258, 140, __pyx_t_142);
    __Pyx_GIVEREF(__pyx_t_143);
    PyList_SET_ITEM(__pyx_t_258, 141, __pyx_t_143);
    __Pyx_GIVEREF(__pyx_t_144);
    PyList_SET_ITEM(__pyx_t_258, 142, __pyx_t_144);
    __Pyx_GIVEREF(__pyx_t_145);
    PyList_SET_ITEM(__pyx_t_258, 143, __pyx_t_145);
    __Pyx_GIVEREF(__pyx_t_146);
    PyList_SET_ITEM(__pyx_t_258, 144, __pyx_t_146);
    __Pyx_GIVEREF(__pyx_t_147);
    PyList_SET_ITEM(__pyx_t_258, 145, __pyx_t_147);
    __Pyx_GIVEREF(__pyx_t_148);
    PyList_SET_ITEM(__pyx_t_258, 146, __pyx_t_148);
    __Pyx_GIVEREF(__pyx_t_149);
    PyList_SET_ITEM(__pyx_t_258, 147, __pyx_t_149);
    __Pyx_GIVEREF(__pyx_t_150);
    PyList_SET_ITEM(__pyx_t_258, 148, __pyx_t_150);
    __Pyx_GIVEREF(__pyx_t_151);
    PyList_SET_ITEM(__pyx_t_258, 149, __pyx_t_151);
    __Pyx_GIVEREF(__pyx_t_152);
    PyList_SET_ITEM(__pyx_t_258, 150, __pyx_t_152);
    __Pyx_GIVEREF(__pyx_t_153);
    PyList_SET_ITEM(__pyx_t_258, 151, __pyx_t_153);
    __Pyx_GIVEREF(__pyx_t_154);
    PyList_SET_ITEM(__pyx_t_258, 152, __pyx_t_154);
    __Pyx_GIVEREF(__pyx_t_155);
    PyList_SET_ITEM(__pyx_t_258, 153, __pyx_t_155);
    __Pyx_GIVEREF(__pyx_t_156);
    PyList_SET_ITEM(__pyx_t_258, 154, __pyx_t_156);
    __Pyx_GIVEREF(__pyx_t_157);
    PyList_SET_ITEM(__pyx_t_258, 155, __pyx_t_157);
    __Pyx_GIVEREF(__pyx_t_158);
    PyList_SET_ITEM(__pyx_t_258, 156, __pyx_t_158);
    __Pyx_GIVEREF(__pyx_t_159);
    PyList_SET_ITEM(__pyx_t_258, 157, __pyx_t_159);
    __Pyx_GIVEREF(__pyx_t_160);
    PyList_SET_ITEM(__pyx_t_258, 158, __pyx_t_160);
    __Pyx_GIVEREF(__pyx_t_161);
    PyList_SET_ITEM(__pyx_t_258, 159, __pyx_t_161);
    __Pyx_GIVEREF(__pyx_t_162);
    PyList_SET_ITEM(__pyx_t_258, 160, __pyx_t_162);
    __Pyx_GIVEREF(__pyx_t_163);
    PyList_SET_ITEM(__pyx_t_258, 161, __pyx_t_163);
    __Pyx_GIVEREF(__pyx_t_164);
    PyList_SET_ITEM(__pyx_t_258, 162, __pyx_t_164);
    __Pyx_GIVEREF(__pyx_t_165);
    PyList_SET_ITEM(__pyx_t_258, 163, __pyx_t_165);
    __Pyx_GIVEREF(__pyx_t_166);
    PyList_SET_ITEM(__pyx_t_258, 164, __pyx_t_166);
    __Pyx_GIVEREF(__pyx_t_167);
    PyList_SET_ITEM(__pyx_t_258, 165, __pyx_t_167);
    __Pyx_GIVEREF(__pyx_t_168);
    PyList_SET_ITEM(__pyx_t_258, 166, __pyx_t_168);
    __Pyx_GIVEREF(__pyx_t_169);
    PyList_SET_ITEM(__pyx_t_258, 167, __pyx_t_169);
    __Pyx_GIVEREF(__pyx_t_170);
    PyList_SET_ITEM(__pyx_t_258, 168, __pyx_t_170);
    __Pyx_GIVEREF(__pyx_t_171);
    PyList_SET_ITEM(__pyx_t_258, 169, __pyx_t_171);
    __Pyx_GIVEREF(__pyx_t_172);
    PyList_SET_ITEM(__pyx_t_258, 170, __pyx_t_172);
    __Pyx_GIVEREF(__pyx_t_173);
    PyList_SET_ITEM(__pyx_t_258, 171, __pyx_t_173);
    __Pyx_GIVEREF(__pyx_t_174);
    PyList_SET_ITEM(__pyx_t_258, 172, __pyx_t_174);
    __Pyx_GIVEREF(__pyx_t_175);
    PyList_SET_ITEM(__pyx_t_258, 173, __pyx_t_175);
    __Pyx_GIVEREF(__pyx_t_176);
    PyList_SET_ITEM(__pyx_t_258, 174, __pyx_t_176);
    __Pyx_GIVEREF(__pyx_t_177);
    PyList_SET_ITEM(__pyx_t_258, 175, __pyx_t_177);
    __Pyx_GIVEREF(__pyx_t_178);
    PyList_SET_ITEM(__pyx_t_258, 176, __pyx_t_178);
    __Pyx_GIVEREF(__pyx_t_179);
    PyList_SET_ITEM(__pyx_t_258, 177, __pyx_t_179);
    __Pyx_GIVEREF(__pyx_t_180);
    PyList_SET_ITEM(__pyx_t_258, 178, __pyx_t_180);
    __Pyx_GIVEREF(__pyx_t_181);
    PyList_SET_ITEM(__pyx_t_258, 179, __pyx_t_181);
    __Pyx_GIVEREF(__pyx_t_182);
    PyList_SET_ITEM(__pyx_t_258, 180, __pyx_t_182);
    __Pyx_GIVEREF(__pyx_t_183);
    PyList_SET_ITEM(__pyx_t_258, 181, __pyx_t_183);
    __Pyx_GIVEREF(__pyx_t_184);
    PyList_SET_ITEM(__pyx_t_258, 182, __pyx_t_184);
    __Pyx_GIVEREF(__pyx_t_185);
    PyList_SET_ITEM(__pyx_t_258, 183, __pyx_t_185);
    __Pyx_GIVEREF(__pyx_t_186);
    PyList_SET_ITEM(__pyx_t_258, 184, __pyx_t_186);
    __Pyx_GIVEREF(__pyx_t_187);
    PyList_SET_ITEM(__pyx_t_258, 185, __pyx_t_187);
    __Pyx_GIVEREF(__pyx_t_188);
    PyList_SET_ITEM(__pyx_t_258, 186, __pyx_t_188);
    __Pyx_GIVEREF(__pyx_t_189);
    PyList_SET_ITEM(__pyx_t_258, 187, __pyx_t_189);
    __Pyx_GIVEREF(__pyx_t_190);
    PyList_SET_ITEM(__pyx_t_258, 188, __pyx_t_190);
    __Pyx_GIVEREF(__pyx_t_191);
    PyList_SET_ITEM(__pyx_t_258, 189, __pyx_t_191);
    __Pyx_GIVEREF(__pyx_t_192);
    PyList_SET_ITEM(__pyx_t_258, 190, __pyx_t_192);
    __Pyx_GIVEREF(__pyx_t_193);
    PyList_SET_ITEM(__pyx_t_258, 191, __pyx_t_193);
    __Pyx_GIVEREF(__pyx_t_194);
    PyList_SET_ITEM(__pyx_t_258, 192, __pyx_t_194);
    __Pyx_GIVEREF(__pyx_t_195);
    PyList_SET_ITEM(__pyx_t_258, 193, __pyx_t_195);
    __Pyx_GIVEREF(__pyx_t_196);
    PyList_SET_ITEM(__pyx_t_258, 194, __pyx_t_196);
    __Pyx_GIVEREF(__pyx_t_197);
    PyList_SET_ITEM(__pyx_t_258, 195, __pyx_t_197);
    __Pyx_GIVEREF(__pyx_t_198);
    PyList_SET_ITEM(__pyx_t_258, 196, __pyx_t_198);
    __Pyx_GIVEREF(__pyx_t_199);
    PyList_SET_ITEM(__pyx_t_258, 197, __pyx_t_199);
    __Pyx_GIVEREF(__pyx_t_200);
    PyList_SET_ITEM(__pyx_t_258, 198, __pyx_t_200);
    __Pyx_GIVEREF(__pyx_t_201);
    PyList_SET_ITEM(__pyx_t_258, 199, __pyx_t_201);
    __Pyx_GIVEREF(__pyx_t_202);
    PyList_SET_ITEM(__pyx_t_258, 200, __pyx_t_202);
    __Pyx_GIVEREF(__pyx_t_203);
    PyList_SET_ITEM(__pyx_t_258, 201, __pyx_t_203);
    __Pyx_GIVEREF(__pyx_t_204);
    PyList_SET_ITEM(__pyx_t_258, 202, __pyx_t_204);
    __Pyx_GIVEREF(__pyx_t_205);
    PyList_SET_ITEM(__pyx_t_258, 203, __pyx_t_205);
    __Pyx_GIVEREF(__pyx_t_206);
    PyList_SET_ITEM(__pyx_t_258, 204, __pyx_t_206);
    __Pyx_GIVEREF(__pyx_t_207);
    PyList_SET_ITEM(__pyx_t_258, 205, __pyx_t_207);
    __Pyx_GIVEREF(__pyx_t_208);
    PyList_SET_ITEM(__pyx_t_258, 206, __pyx_t_208);
    __Pyx_GIVEREF(__pyx_t_209);
    PyList_SET_ITEM(__pyx_t_258, 207, __pyx_t_209);
    __Pyx_GIVEREF(__pyx_t_210);
    PyList_SET_ITEM(__pyx_t_258, 208, __pyx_t_210);
    __Pyx_GIVEREF(__pyx_t_211);
    PyList_SET_ITEM(__pyx_t_258, 209, __pyx_t_211);
    __Pyx_GIVEREF(__pyx_t_212);
    PyList_SET_ITEM(__pyx_t_258, 210, __pyx_t_212);
    __Pyx_GIVEREF(__pyx_t_213);
    PyList_SET_ITEM(__pyx_t_258, 211, __pyx_t_213);
    __Pyx_GIVEREF(__pyx_t_214);
    PyList_SET_ITEM(__pyx_t_258, 212, __pyx_t_214);
    __Pyx_GIVEREF(__pyx_t_215);
    PyList_SET_ITEM(__pyx_t_258, 213, __pyx_t_215);
    __Pyx_GIVEREF(__pyx_t_216);
    PyList_SET_ITEM(__pyx_t_258, 214, __pyx_t_216);
    __Pyx_GIVEREF(__pyx_t_217);
    PyList_SET_ITEM(__pyx_t_258, 215, __pyx_t_217);
    __Pyx_GIVEREF(__pyx_t_218);
    PyList_SET_ITEM(__pyx_t_258, 216, __pyx_t_218);
    __Pyx_GIVEREF(__pyx_t_219);
    PyList_SET_ITEM(__pyx_t_258, 217, __pyx_t_219);
    __Pyx_GIVEREF(__pyx_t_220);
    PyList_SET_ITEM(__pyx_t_258, 218, __pyx_t_220);
    __Pyx_GIVEREF(__pyx_t_221);
    PyList_SET_ITEM(__pyx_t_258, 219, __pyx_t_221);
    __Pyx_GIVEREF(__pyx_t_222);
    PyList_SET_ITEM(__pyx_t_258, 220, __pyx_t_222);
    __Pyx_GIVEREF(__pyx_t_223);
    PyList_SET_ITEM(__pyx_t_258, 221, __pyx_t_223);
    __Pyx_GIVEREF(__pyx_t_224);
    PyList_SET_ITEM(__pyx_t_258, 222, __pyx_t_224);
    __Pyx_GIVEREF(__pyx_t_225);
    PyList_SET_ITEM(__pyx_t_258, 223, __pyx_t_225);
    __Pyx_GIVEREF(__pyx_t_226);
    PyList_SET_ITEM(__pyx_t_258, 224, __pyx_t_226);
    __Pyx_GIVEREF(__pyx_t_227);
    PyList_SET_ITEM(__pyx_t_258, 225, __pyx_t_227);
    __Pyx_GIVEREF(__pyx_t_228);
    PyList_SET_ITEM(__pyx_t_258, 226, __pyx_t_228);
    __Pyx_GIVEREF(__pyx_t_229);
    PyList_SET_ITEM(__pyx_t_258, 227, __pyx_t_229);
    __Pyx_GIVEREF(__pyx_t_230);
    PyList_SET_ITEM(__pyx_t_258, 228, __pyx_t_230);
    __Pyx_GIVEREF(__pyx_t_231);
    PyList_SET_ITEM(__pyx_t_258, 229, __pyx_t_231);
    __Pyx_GIVEREF(__pyx_t_232);
    PyList_SET_ITEM(__pyx_t_258, 230, __pyx_t_232);
    __Pyx_GIVEREF(__pyx_t_233);
    PyList_SET_ITEM(__pyx_t_258, 231, __pyx_t_233);
    __Pyx_GIVEREF(__pyx_t_234);
    PyList_SET_ITEM(__pyx_t_258, 232, __pyx_t_234);
    __Pyx_GIVEREF(__pyx_t_235);
    PyList_SET_ITEM(__pyx_t_258, 233, __pyx_t_235);
    __Pyx_GIVEREF(__pyx_t_236);
    PyList_SET_ITEM(__pyx_t_258, 234, __pyx_t_236);
    __Pyx_GIVEREF(__pyx_t_237);
    PyList_SET_ITEM(__pyx_t_258, 235, __pyx_t_237);
    __Pyx_GIVEREF(__pyx_t_238);
    PyList_SET_ITEM(__pyx_t_258, 236, __pyx_t_238);
    __Pyx_GIVEREF(__pyx_t_239);
    PyList_SET_ITEM(__pyx_t_258, 237, __pyx_t_239);
    __Pyx_GIVEREF(__pyx_t_240);
    PyList_SET_ITEM(__pyx_t_258, 238, __pyx_t_240);
    __Pyx_GIVEREF(__pyx_t_241);
    PyList_SET_ITEM(__pyx_t_258, 239, __pyx_t_241);
    __Pyx_GIVEREF(__pyx_t_242);
    PyList_SET_ITEM(__pyx_t_258, 240, __pyx_t_242);
    __Pyx_GIVEREF(__pyx_t_243);
    PyList_SET_ITEM(__pyx_t_258, 241, __pyx_t_243);
    __Pyx_GIVEREF(__pyx_t_244);
    PyList_SET_ITEM(__pyx_t_258, 242, __pyx_t_244);
    __Pyx_GIVEREF(__pyx_t_245);
    PyList_SET_ITEM(__pyx_t_258, 243, __pyx_t_245);
    __Pyx_GIVEREF(__pyx_t_246);
    PyList_SET_ITEM(__pyx_t_258, 244, __pyx_t_246);
    __Pyx_GIVEREF(__pyx_t_247);
    PyList_SET_ITEM(__pyx_t_258, 245, __pyx_t_247);
    __Pyx_GIVEREF(__pyx_t_248);
    PyList_SET_ITEM(__pyx_t_258, 246, __pyx_t_248);
    __Pyx_GIVEREF(__pyx_t_249);
    PyList_SET_ITEM(__pyx_t_258, 247, __pyx_t_249);
    __Pyx_GIVEREF(__pyx_t_250);
    PyList_SET_ITEM(__pyx_t_258, 248, __pyx_t_250);
    __Pyx_GIVEREF(__pyx_t_251);
    PyList_SET_ITEM(__pyx_t_258, 249, __pyx_t_251);
    __Pyx_GIVEREF(__pyx_t_252);
    PyList_SET_ITEM(__pyx_t_258, 250, __pyx_t_252);
    __Pyx_GIVEREF(__pyx_t_253);
    PyList_SET_ITEM(__pyx_t_258, 251, __pyx_t_253);
    __Pyx_GIVEREF(__pyx_t_254);
    PyList_SET_ITEM(__pyx_t_258, 252, __pyx_t_254);
    __Pyx_GIVEREF(__pyx_t_255);
    PyList_SET_ITEM(__pyx_t_258, 253, __pyx_t_255);
    __Pyx_GIVEREF(__pyx_t_256);
    PyList_SET_ITEM(__pyx_t_258, 254, __pyx_t_256);
    __Pyx_GIVEREF(__pyx_t_257);
    PyList_SET_ITEM(__pyx_t_258, 255, __pyx_t_257);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_t_10 = 0;
    __pyx_t_11 = 0;
    __pyx_t_12 = 0;
    __pyx_t_13 = 0;
    __pyx_t_14 = 0;
    __pyx_t_15 = 0;
    __pyx_t_16 = 0;
    __pyx_t_17 = 0;
    __pyx_t_18 = 0;
    __pyx_t_19 = 0;
    __pyx_t_20 = 0;
    __pyx_t_21 = 0;
    __pyx_t_22 = 0;
    __pyx_t_23 = 0;
    __pyx_t_24 = 0;
    __pyx_t_25 = 0;
    __pyx_t_26 = 0;
    __pyx_t_27 = 0;
    __pyx_t_28 = 0;
    __pyx_t_29 = 0;
    __pyx_t_30 = 0;
    __pyx_t_31 = 0;
    __pyx_t_32 = 0;
    __pyx_t_33 = 0;
    __pyx_t_34 = 0;
    __pyx_t_35 = 0;
    __pyx_t_36 = 0;
    __pyx_t_37 = 0;
    __pyx_t_38 = 0;
    __pyx_t_39 = 0;
    __pyx_t_40 = 0;
    __pyx_t_41 = 0;
    __pyx_t_42 = 0;
    __pyx_t_43 = 0;
    __pyx_t_44 = 0;
    __pyx_t_45 = 0;
    __pyx_t_46 = 0;
    __pyx_t_47 = 0;
    __pyx_t_48 = 0;
    __pyx_t_49 = 0;
    __pyx_t_50 = 0;
    __pyx_t_51 = 0;
    __pyx_t_52 = 0;
    __pyx_t_53 = 0;
    __pyx_t_54 = 0;
    __pyx_t_55 = 0;
    __pyx_t_56 = 0;
    __pyx_t_57 = 0;
    __pyx_t_58 = 0;
    __pyx_t_59 = 0;
    __pyx_t_60 = 0;
    __pyx_t_61 = 0;
    __pyx_t_62 = 0;
    __pyx_t_63 = 0;
    __pyx_t_64 = 0;
    __pyx_t_65 = 0;
    __pyx_t_66 = 0;
    __pyx_t_67 = 0;
    __pyx_t_68 = 0;
    __pyx_t_69 = 0;
    __pyx_t_70 = 0;
    __pyx_t_71 = 0;
    __pyx_t_72 = 0;
    __pyx_t_73 = 0;
    __pyx_t_74 = 0;
    __pyx_t_75 = 0;
    __pyx_t_76 = 0;
    __pyx_t_77 = 0;
    __pyx_t_78 = 0;
    __pyx_t_79 = 0;
    __pyx_t_80 = 0;
    __pyx_t_81 = 0;
    __pyx_t_82 = 0;
    __pyx_t_83 = 0;
    __pyx_t_84 = 0;
    __pyx_t_85 = 0;
    __pyx_t_86 = 0;
    __pyx_t_87 = 0;
    __pyx_t_88 = 0;
    __pyx_t_89 = 0;
    __pyx_t_90 = 0;
    __pyx_t_91 = 0;
    __pyx_t_92 = 0;
    __pyx_t_93 = 0;
    __pyx_t_94 = 0;
    __pyx_t_95 = 0;
    __pyx_t_96 = 0;
    __pyx_t_97 = 0;
    __pyx_t_98 = 0;
    __pyx_t_99 = 0;
    __pyx_t_100 = 0;
    __pyx_t_101 = 0;
    __pyx_t_102 = 0;
    __pyx_t_103 = 0;
    __pyx_t_104 = 0;
    __pyx_t_105 = 0;
    __pyx_t_106 = 0;
    __pyx_t_107 = 0;
    __pyx_t_108 = 0;
    __pyx_t_109 = 0;
    __pyx_t_110 = 0;
    __pyx_t_111 = 0;
    __pyx_t_112 = 0;
    __pyx_t_113 = 0;
    __pyx_t_114 = 0;
    __pyx_t_115 = 0;
    __pyx_t_116 = 0;
    __pyx_t_117 = 0;
    __pyx_t_118 = 0;
    __pyx_t_119 = 0;
    __pyx_t_120 = 0;
    __pyx_t_121 = 0;
    __pyx_t_122 = 0;
    __pyx_t_123 = 0;
    __pyx_t_124 = 0;
    __pyx_t_125 = 0;
    __pyx_t_126 = 0;
    __pyx_t_127 = 0;
    __pyx_t_128 = 0;
    __pyx_t_129 = 0;
    __pyx_t_130 = 0;
    __pyx_t_131 = 0;
    __pyx_t_132 = 0;
    __pyx_t_133 = 0;
    __pyx_t_134 = 0;
    __pyx_t_135 = 0;
    __pyx_t_136 = 0;
    __pyx_t_137 = 0;
    __pyx_t_138 = 0;
    __pyx_t_139 = 0;
    __pyx_t_140 = 0;
    __pyx_t_141 = 0;
    __pyx_t_142 = 0;
    __pyx_t_143 = 0;
    __pyx_t_144 = 0;
    __pyx_t_145 = 0;
    __pyx_t_146 = 0;
    __pyx_t_147 = 0;
    __pyx_t_148 = 0;
    __pyx_t_149 = 0;
    __pyx_t_150 = 0;
    __pyx_t_151 = 0;
    __pyx_t_152 = 0;
    __pyx_t_153 = 0;
    __pyx_t_154 = 0;
    __pyx_t_155 = 0;
    __pyx_t_156 = 0;
    __pyx_t_157 = 0;
    __pyx_t_158 = 0;
    __pyx_t_159 = 0;
    __pyx_t_160 = 0;
    __pyx_t_161 = 0;
    __pyx_t_162 = 0;
    __pyx_t_163 = 0;
    __pyx_t_164 = 0;
    __pyx_t_165 = 0;
    __pyx_t_166 = 0;
    __pyx_t_167 = 0;
    __pyx_t_168 = 0;
    __pyx_t_169 = 0;
    __pyx_t_170 = 0;
    __pyx_t_171 = 0;
    __pyx_t_172 = 0;
    __pyx_t_173 = 0;
    __pyx_t_174 = 0;
    __pyx_t_175 = 0;
    __pyx_t_176 = 0;
    __pyx_t_177 = 0;
    __pyx_t_178 = 0;
    __pyx_t_179 = 0;
    __pyx_t_180 = 0;
    __pyx_t_181 = 0;
    __pyx_t_182 = 0;
    __pyx_t_183 = 0;
    __pyx_t_184 = 0;
    __pyx_t_185 = 0;
    __pyx_t_186 = 0;
    __pyx_t_187 = 0;
    __pyx_t_188 = 0;
    __pyx_t_189 = 0;
    __pyx_t_190 = 0;
    __pyx_t_191 = 0;
    __pyx_t_192 = 0;
    __pyx_t_193 = 0;
    __pyx_t_194 = 0;
    __pyx_t_195 = 0;
    __pyx_t_196 = 0;
    __pyx_t_197 = 0;
    __pyx_t_198 = 0;
    __pyx_t_199 = 0;
    __pyx_t_200 = 0;
    __pyx_t_201 = 0;
    __pyx_t_202 = 0;
    __pyx_t_203 = 0;
    __pyx_t_204 = 0;
    __pyx_t_205 = 0;
    __pyx_t_206 = 0;
    __pyx_t_207 = 0;
    __pyx_t_208 = 0;
    __pyx_t_209 = 0;
    __pyx_t_210 = 0;
    __pyx_t_211 = 0;
    __pyx_t_212 = 0;
    __pyx_t_213 = 0;
    __pyx_t_214 = 0;
    __pyx_t_215 = 0;
    __pyx_t_216 = 0;
    __pyx_t_217 = 0;
    __pyx_t_218 = 0;
    __pyx_t_219 = 0;
    __pyx_t_220 = 0;
    __pyx_t_221 = 0;
    __pyx_t_222 = 0;
    __pyx_t_223 = 0;
    __pyx_t_224 = 0;
    __pyx_t_225 = 0;
    __pyx_t_226 = 0;
    __pyx_t_227 = 0;
    __pyx_t_228 = 0;
    __pyx_t_229 = 0;
    __pyx_t_230 = 0;
    __pyx_t_231 = 0;
    __pyx_t_232 = 0;
    __pyx_t_233 = 0;
    __pyx_t_234 = 0;
    __pyx_t_235 = 0;
    __pyx_t_236 = 0;
    __pyx_t_237 = 0;
    __pyx_t_238 = 0;
    __pyx_t_239 = 0;
    __pyx_t_240 = 0;
    __pyx_t_241 = 0;
    __pyx_t_242 = 0;
    __pyx_t_243 = 0;
    __pyx_t_244 = 0;
    __pyx_t_245 = 0;
    __pyx_t_246 = 0;
    __pyx_t_247 = 0;
    __pyx_t_248 = 0;
    __pyx_t_249 = 0;
    __pyx_t_250 = 0;
    __pyx_t_251 = 0;
    __pyx_t_252 = 0;
    __pyx_t_253 = 0;
    __pyx_t_254 = 0;
    __pyx_t_255 = 0;
    __pyx_t_256 = 0;
    __pyx_t_257 = 0;
    __pyx_v_color_table = ((PyObject*)__pyx_t_258);
    __pyx_t_258 = 0;

    /* "ttygif/gif/color_table.py":88
 *                 [138,138,138],[148,148,148],[158,158,158],[168,168,168],[178,178,178],[188,188,188],
 *                 [198,198,198],[208,208,208],[218,218,218],[228,228,228],[238,238,238] ]
 *             self.colors=color_table             # <<<<<<<<<<<<<<
 * 
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_colors, __pyx_v_color_table) < 0) __PYX_ERR(0, 88, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "ttygif/gif/color_table.py":37
 *             self.stream.write_byte(color[2])
 * 
 *     def new(self,palette=None):             # <<<<<<<<<<<<<<
 *         self.colors=[]
 *         if palette:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_XDECREF(__pyx_t_30);
  __Pyx_XDECREF(__pyx_t_31);
  __Pyx_XDECREF(__pyx_t_32);
  __Pyx_XDECREF(__pyx_t_33);
  __Pyx_XDECREF(__pyx_t_34);
  __Pyx_XDECREF(__pyx_t_35);
  __Pyx_XDECREF(__pyx_t_36);
  __Pyx_XDECREF(__pyx_t_37);
  __Pyx_XDECREF(__pyx_t_38);
  __Pyx_XDECREF(__pyx_t_39);
  __Pyx_XDECREF(__pyx_t_40);
  __Pyx_XDECREF(__pyx_t_41);
  __Pyx_XDECREF(__pyx_t_42);
  __Pyx_XDECREF(__pyx_t_43);
  __Pyx_XDECREF(__pyx_t_44);
  __Pyx_XDECREF(__pyx_t_45);
  __Pyx_XDECREF(__pyx_t_46);
  __Pyx_XDECREF(__pyx_t_47);
  __Pyx_XDECREF(__pyx_t_48);
  __Pyx_XDECREF(__pyx_t_49);
  __Pyx_XDECREF(__pyx_t_50);
  __Pyx_XDECREF(__pyx_t_51);
  __Pyx_XDECREF(__pyx_t_52);
  __Pyx_XDECREF(__pyx_t_53);
  __Pyx_XDECREF(__pyx_t_54);
  __Pyx_XDECREF(__pyx_t_55);
  __Pyx_XDECREF(__pyx_t_56);
  __Pyx_XDECREF(__pyx_t_57);
  __Pyx_XDECREF(__pyx_t_58);
  __Pyx_XDECREF(__pyx_t_59);
  __Pyx_XDECREF(__pyx_t_60);
  __Pyx_XDECREF(__pyx_t_61);
  __Pyx_XDECREF(__pyx_t_62);
  __Pyx_XDECREF(__pyx_t_63);
  __Pyx_XDECREF(__pyx_t_64);
  __Pyx_XDECREF(__pyx_t_65);
  __Pyx_XDECREF(__pyx_t_66);
  __Pyx_XDECREF(__pyx_t_67);
  __Pyx_XDECREF(__pyx_t_68);
  __Pyx_XDECREF(__pyx_t_69);
  __Pyx_XDECREF(__pyx_t_70);
  __Pyx_XDECREF(__pyx_t_71);
  __Pyx_XDECREF(__pyx_t_72);
  __Pyx_XDECREF(__pyx_t_73);
  __Pyx_XDECREF(__pyx_t_74);
  __Pyx_XDECREF(__pyx_t_75);
  __Pyx_XDECREF(__pyx_t_76);
  __Pyx_XDECREF(__pyx_t_77);
  __Pyx_XDECREF(__pyx_t_78);
  __Pyx_XDECREF(__pyx_t_79);
  __Pyx_XDECREF(__pyx_t_80);
  __Pyx_XDECREF(__pyx_t_81);
  __Pyx_XDECREF(__pyx_t_82);
  __Pyx_XDECREF(__pyx_t_83);
  __Pyx_XDECREF(__pyx_t_84);
  __Pyx_XDECREF(__pyx_t_85);
  __Pyx_XDECREF(__pyx_t_86);
  __Pyx_XDECREF(__pyx_t_87);
  __Pyx_XDECREF(__pyx_t_88);
  __Pyx_XDECREF(__pyx_t_89);
  __Pyx_XDECREF(__pyx_t_90);
  __Pyx_XDECREF(__pyx_t_91);
  __Pyx_XDECREF(__pyx_t_92);
  __Pyx_XDECREF(__pyx_t_93);
  __Pyx_XDECREF(__pyx_t_94);
  __Pyx_XDECREF(__pyx_t_95);
  __Pyx_XDECREF(__pyx_t_96);
  __Pyx_XDECREF(__pyx_t_97);
  __Pyx_XDECREF(__pyx_t_98);
  __Pyx_XDECREF(__pyx_t_99);
  __Pyx_XDECREF(__pyx_t_100);
  __Pyx_XDECREF(__pyx_t_101);
  __Pyx_XDECREF(__pyx_t_102);
  __Pyx_XDECREF(__pyx_t_103);
  __Pyx_XDECREF(__pyx_t_104);
  __Pyx_XDECREF(__pyx_t_105);
  __Pyx_XDECREF(__pyx_t_106);
  __Pyx_XDECREF(__pyx_t_107);
  __Pyx_XDECREF(__pyx_t_108);
  __Pyx_XDECREF(__pyx_t_109);
  __Pyx_XDECREF(__pyx_t_110);
  __Pyx_XDECREF(__pyx_t_111);
  __Pyx_XDECREF(__pyx_t_112);
  __Pyx_XDECREF(__pyx_t_113);
  __Pyx_XDECREF(__pyx_t_114);
  __Pyx_XDECREF(__pyx_t_115);
  __Pyx_XDECREF(__pyx_t_116);
  __Pyx_XDECREF(__pyx_t_117);
  __Pyx_XDECREF(__pyx_t_118);
  __Pyx_XDECREF(__pyx_t_119);
  __Pyx_XDECREF(__pyx_t_120);
  __Pyx_XDECREF(__pyx_t_121);
  __Pyx_XDECREF(__pyx_t_122);
  __Pyx_XDECREF(__pyx_t_123);
  __Pyx_XDECREF(__pyx_t_124);
  __Pyx_XDECREF(__pyx_t_125);
  __Pyx_XDECREF(__pyx_t_126);
  __Pyx_XDECREF(__pyx_t_127);
  __Pyx_XDECREF(__pyx_t_128);
  __Pyx_XDECREF(__pyx_t_129);
  __Pyx_XDECREF(__pyx_t_130);
  __Pyx_XDECREF(__pyx_t_131);
  __Pyx_XDECREF(__pyx_t_132);
  __Pyx_XDECREF(__pyx_t_133);
  __Pyx_XDECREF(__pyx_t_134);
  __Pyx_XDECREF(__pyx_t_135);
  __Pyx_XDECREF(__pyx_t_136);
  __Pyx_XDECREF(__pyx_t_137);
  __Pyx_XDECREF(__pyx_t_138);
  __Pyx_XDECREF(__pyx_t_139);
  __Pyx_XDECREF(__pyx_t_140);
  __Pyx_XDECREF(__pyx_t_141);
  __Pyx_XDECREF(__pyx_t_142);
  __Pyx_XDECREF(__pyx_t_143);
  __Pyx_XDECREF(__pyx_t_144);
  __Pyx_XDECREF(__pyx_t_145);
  __Pyx_XDECREF(__pyx_t_146);
  __Pyx_XDECREF(__pyx_t_147);
  __Pyx_XDECREF(__pyx_t_148);
  __Pyx_XDECREF(__pyx_t_149);
  __Pyx_XDECREF(__pyx_t_150);
  __Pyx_XDECREF(__pyx_t_151);
  __Pyx_XDECREF(__pyx_t_152);
  __Pyx_XDECREF(__pyx_t_153);
  __Pyx_XDECREF(__pyx_t_154);
  __Pyx_XDECREF(__pyx_t_155);
  __Pyx_XDECREF(__pyx_t_156);
  __Pyx_XDECREF(__pyx_t_157);
  __Pyx_XDECREF(__pyx_t_158);
  __Pyx_XDECREF(__pyx_t_159);
  __Pyx_XDECREF(__pyx_t_160);
  __Pyx_XDECREF(__pyx_t_161);
  __Pyx_XDECREF(__pyx_t_162);
  __Pyx_XDECREF(__pyx_t_163);
  __Pyx_XDECREF(__pyx_t_164);
  __Pyx_XDECREF(__pyx_t_165);
  __Pyx_XDECREF(__pyx_t_166);
  __Pyx_XDECREF(__pyx_t_167);
  __Pyx_XDECREF(__pyx_t_168);
  __Pyx_XDECREF(__pyx_t_169);
  __Pyx_XDECREF(__pyx_t_170);
  __Pyx_XDECREF(__pyx_t_171);
  __Pyx_XDECREF(__pyx_t_172);
  __Pyx_XDECREF(__pyx_t_173);
  __Pyx_XDECREF(__pyx_t_174);
  __Pyx_XDECREF(__pyx_t_175);
  __Pyx_XDECREF(__pyx_t_176);
  __Pyx_XDECREF(__pyx_t_177);
  __Pyx_XDECREF(__pyx_t_178);
  __Pyx_XDECREF(__pyx_t_179);
  __Pyx_XDECREF(__pyx_t_180);
  __Pyx_XDECREF(__pyx_t_181);
  __Pyx_XDECREF(__pyx_t_182);
  __Pyx_XDECREF(__pyx_t_183);
  __Pyx_XDECREF(__pyx_t_184);
  __Pyx_XDECREF(__pyx_t_185);
  __Pyx_XDECREF(__pyx_t_186);
  __Pyx_XDECREF(__pyx_t_187);
  __Pyx_XDECREF(__pyx_t_188);
  __Pyx_XDECREF(__pyx_t_189);
  __Pyx_XDECREF(__pyx_t_190);
  __Pyx_XDECREF(__pyx_t_191);
  __Pyx_XDECREF(__pyx_t_192);
  __Pyx_XDECREF(__pyx_t_193);
  __Pyx_XDECREF(__pyx_t_194);
  __Pyx_XDECREF(__pyx_t_195);
  __Pyx_XDECREF(__pyx_t_196);
  __Pyx_XDECREF(__pyx_t_197);
  __Pyx_XDECREF(__pyx_t_198);
  __Pyx_XDECREF(__pyx_t_199);
  __Pyx_XDECREF(__pyx_t_200);
  __Pyx_XDECREF(__pyx_t_201);
  __Pyx_XDECREF(__pyx_t_202);
  __Pyx_XDECREF(__pyx_t_203);
  __Pyx_XDECREF(__pyx_t_204);
  __Pyx_XDECREF(__pyx_t_205);
  __Pyx_XDECREF(__pyx_t_206);
  __Pyx_XDECREF(__pyx_t_207);
  __Pyx_XDECREF(__pyx_t_208);
  __Pyx_XDECREF(__pyx_t_209);
  __Pyx_XDECREF(__pyx_t_210);
  __Pyx_XDECREF(__pyx_t_211);
  __Pyx_XDECREF(__pyx_t_212);
  __Pyx_XDECREF(__pyx_t_213);
  __Pyx_XDECREF(__pyx_t_214);
  __Pyx_XDECREF(__pyx_t_215);
  __Pyx_XDECREF(__pyx_t_216);
  __Pyx_XDECREF(__pyx_t_217);
  __Pyx_XDECREF(__pyx_t_218);
  __Pyx_XDECREF(__pyx_t_219);
  __Pyx_XDECREF(__pyx_t_220);
  __Pyx_XDECREF(__pyx_t_221);
  __Pyx_XDECREF(__pyx_t_222);
  __Pyx_XDECREF(__pyx_t_223);
  __Pyx_XDECREF(__pyx_t_224);
  __Pyx_XDECREF(__pyx_t_225);
  __Pyx_XDECREF(__pyx_t_226);
  __Pyx_XDECREF(__pyx_t_227);
  __Pyx_XDECREF(__pyx_t_228);
  __Pyx_XDECREF(__pyx_t_229);
  __Pyx_XDECREF(__pyx_t_230);
  __Pyx_XDECREF(__pyx_t_231);
  __Pyx_XDECREF(__pyx_t_232);
  __Pyx_XDECREF(__pyx_t_233);
  __Pyx_XDECREF(__pyx_t_234);
  __Pyx_XDECREF(__pyx_t_235);
  __Pyx_XDECREF(__pyx_t_236);
  __Pyx_XDECREF(__pyx_t_237);
  __Pyx_XDECREF(__pyx_t_238);
  __Pyx_XDECREF(__pyx_t_239);
  __Pyx_XDECREF(__pyx_t_240);
  __Pyx_XDECREF(__pyx_t_241);
  __Pyx_XDECREF(__pyx_t_242);
  __Pyx_XDECREF(__pyx_t_243);
  __Pyx_XDECREF(__pyx_t_244);
  __Pyx_XDECREF(__pyx_t_245);
  __Pyx_XDECREF(__pyx_t_246);
  __Pyx_XDECREF(__pyx_t_247);
  __Pyx_XDECREF(__pyx_t_248);
  __Pyx_XDECREF(__pyx_t_249);
  __Pyx_XDECREF(__pyx_t_250);
  __Pyx_XDECREF(__pyx_t_251);
  __Pyx_XDECREF(__pyx_t_252);
  __Pyx_XDECREF(__pyx_t_253);
  __Pyx_XDECREF(__pyx_t_254);
  __Pyx_XDECREF(__pyx_t_255);
  __Pyx_XDECREF(__pyx_t_256);
  __Pyx_XDECREF(__pyx_t_257);
  __Pyx_XDECREF(__pyx_t_258);
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_color_table);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ttygif/gif/color_table.py":92
 * 
 * 
 *     def debug(self):             # <<<<<<<<<<<<<<
 *         index=0
 *         print("Color Table Block")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_11debug(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_11debug = {"debug", (PyCFunction)__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_11debug, METH_O, 0};
static PyObject *__pyx_pw_6ttygif_3gif_11color_table_15gif_color_table_11debug(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("debug (wrapper)", 0);
  __pyx_r = __pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_10debug(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ttygif_3gif_11color_table_15gif_color_table_10debug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("debug", 0);

  /* "ttygif/gif/color_table.py":93
 * 
 *     def debug(self):
 *         index=0             # <<<<<<<<<<<<<<
 *         print("Color Table Block")
 *         print("  Offset: {0:02X}".format(self.internal_position))
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_index = __pyx_int_0;

  /* "ttygif/gif/color_table.py":94
 *     def debug(self):
 *         index=0
 *         print("Color Table Block")             # <<<<<<<<<<<<<<
 *         print("  Offset: {0:02X}".format(self.internal_position))
 * 
 */
  if (__Pyx_PrintOne(0, __pyx_kp_s_Color_Table_Block) < 0) __PYX_ERR(0, 94, __pyx_L1_error)

  /* "ttygif/gif/color_table.py":95
 *         index=0
 *         print("Color Table Block")
 *         print("  Offset: {0:02X}".format(self.internal_position))             # <<<<<<<<<<<<<<
 * 
 *         for i in self.colors:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Offset_0_02X, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_internal_position); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/gif/color_table.py":97
 *         print("  Offset: {0:02X}".format(self.internal_position))
 * 
 *         for i in self.colors:             # <<<<<<<<<<<<<<
 *             print("  Index:{3:3}, R:0x{0:02X}, G:0x{1:02X}, B:0x{2:02X}".format(i[0],i[1],i[2],index))
 *             index+=1
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_colors); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 97, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 97, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 97, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_6(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 97, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":98
 * 
 *         for i in self.colors:
 *             print("  Index:{3:3}, R:0x{0:02X}, G:0x{1:02X}, B:0x{2:02X}".format(i[0],i[1],i[2],index))             # <<<<<<<<<<<<<<
 *             index+=1
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Index_3_3_R_0x_0_02X_G_0x_1_02X, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_i, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_i, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_i, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_10 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_t_4, __pyx_t_7, __pyx_t_8, __pyx_v_index};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_10, 4+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_t_4, __pyx_t_7, __pyx_t_8, __pyx_v_index};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_10, 4+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(4+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 98, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__pyx_t_9) {
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_11, 2+__pyx_t_10, __pyx_t_8);
      __Pyx_INCREF(__pyx_v_index);
      __Pyx_GIVEREF(__pyx_v_index);
      PyTuple_SET_ITEM(__pyx_t_11, 3+__pyx_t_10, __pyx_v_index);
      __pyx_t_4 = 0;
      __pyx_t_7 = 0;
      __pyx_t_8 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PrintOne(0, __pyx_t_1) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":99
 *         for i in self.colors:
 *             print("  Index:{3:3}, R:0x{0:02X}, G:0x{1:02X}, B:0x{2:02X}".format(i[0],i[1],i[2],index))
 *             index+=1             # <<<<<<<<<<<<<<
 */
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "ttygif/gif/color_table.py":97
 *         print("  Offset: {0:02X}".format(self.internal_position))
 * 
 *         for i in self.colors:             # <<<<<<<<<<<<<<
 *             print("  Index:{3:3}, R:0x{0:02X}, G:0x{1:02X}, B:0x{2:02X}".format(i[0],i[1],i[2],index))
 *             index+=1
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":92
 * 
 * 
 *     def debug(self):             # <<<<<<<<<<<<<<
 *         index=0
 *         print("Color Table Block")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("ttygif.gif.color_table.gif_color_table.debug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_color_table(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_color_table},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "color_table",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_Color_Table_Block, __pyx_k_Color_Table_Block, sizeof(__pyx_k_Color_Table_Block), 0, 0, 1, 0},
  {&__pyx_kp_s_Index_3_3_R_0x_0_02X_G_0x_1_02X, __pyx_k_Index_3_3_R_0x_0_02X_G_0x_1_02X, sizeof(__pyx_k_Index_3_3_R_0x_0_02X_G_0x_1_02X), 0, 0, 1, 0},
  {&__pyx_kp_s_Offset_0_02X, __pyx_k_Offset_0_02X, sizeof(__pyx_k_Offset_0_02X), 0, 0, 1, 0},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_blue, __pyx_k_blue, sizeof(__pyx_k_blue), 0, 0, 1, 1},
  {&__pyx_n_s_byte, __pyx_k_byte, sizeof(__pyx_k_byte), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_color, __pyx_k_color, sizeof(__pyx_k_color), 0, 0, 1, 1},
  {&__pyx_n_s_color_table, __pyx_k_color_table, sizeof(__pyx_k_color_table), 0, 0, 1, 1},
  {&__pyx_n_s_colors, __pyx_k_colors, sizeof(__pyx_k_colors), 0, 0, 1, 1},
  {&__pyx_n_s_colors_len, __pyx_k_colors_len, sizeof(__pyx_k_colors_len), 0, 0, 1, 1},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
  {&__pyx_n_s_entries, __pyx_k_entries, sizeof(__pyx_k_entries), 0, 0, 1, 1},
  {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_get_byte_size, __pyx_k_get_byte_size, sizeof(__pyx_k_get_byte_size), 0, 0, 1, 1},
  {&__pyx_n_s_gif_color_table, __pyx_k_gif_color_table, sizeof(__pyx_k_gif_color_table), 0, 0, 1, 1},
  {&__pyx_n_s_gif_color_table___init, __pyx_k_gif_color_table___init, sizeof(__pyx_k_gif_color_table___init), 0, 0, 1, 1},
  {&__pyx_n_s_gif_color_table_debug, __pyx_k_gif_color_table_debug, sizeof(__pyx_k_gif_color_table_debug), 0, 0, 1, 1},
  {&__pyx_n_s_gif_color_table_get_byte_size, __pyx_k_gif_color_table_get_byte_size, sizeof(__pyx_k_gif_color_table_get_byte_size), 0, 0, 1, 1},
  {&__pyx_n_s_gif_color_table_new, __pyx_k_gif_color_table_new, sizeof(__pyx_k_gif_color_table_new), 0, 0, 1, 1},
  {&__pyx_n_s_gif_color_table_read, __pyx_k_gif_color_table_read, sizeof(__pyx_k_gif_color_table_read), 0, 0, 1, 1},
  {&__pyx_n_s_gif_color_table_write, __pyx_k_gif_color_table_write, sizeof(__pyx_k_gif_color_table_write), 0, 0, 1, 1},
  {&__pyx_n_s_green, __pyx_k_green, sizeof(__pyx_k_green), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_internal_position, __pyx_k_internal_position, sizeof(__pyx_k_internal_position), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_palette, __pyx_k_palette, sizeof(__pyx_k_palette), 0, 0, 1, 1},
  {&__pyx_n_s_pos, __pyx_k_pos, sizeof(__pyx_k_pos), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
  {&__pyx_n_s_red, __pyx_k_red, sizeof(__pyx_k_red), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
  {&__pyx_n_s_stream, __pyx_k_stream, sizeof(__pyx_k_stream), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_ttygif_gif_color_table, __pyx_k_ttygif_gif_color_table, sizeof(__pyx_k_ttygif_gif_color_table), 0, 0, 1, 1},
  {&__pyx_kp_s_ttygif_gif_color_table_py, __pyx_k_ttygif_gif_color_table_py, sizeof(__pyx_k_ttygif_gif_color_table_py), 0, 0, 1, 0},
  {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {&__pyx_n_s_write_byte, __pyx_k_write_byte, sizeof(__pyx_k_write_byte), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 25, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "ttygif/gif/color_table.py":5
 * # ColorTableSize = 3L * (1L << (SizeOfGlobalColorTable + 1));
 * class gif_color_table:
 *     def __init__(self,stream):             # <<<<<<<<<<<<<<
 *         self.stream=stream
 *         self.internal_position=self.stream.pos
 */
  __pyx_tuple_ = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_stream); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);
  __pyx_codeobj__2 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple_, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_gif_color_table_py, __pyx_n_s_init, 5, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__2)) __PYX_ERR(0, 5, __pyx_L1_error)

  /* "ttygif/gif/color_table.py":10
 *         self.colors=[]
 * 
 *     def get_byte_size(self):             # <<<<<<<<<<<<<<
 *         colors_len=len(self.colors)
 *         size=0
 */
  __pyx_tuple__3 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_colors_len, __pyx_n_s_size); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);
  __pyx_codeobj__4 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__3, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_gif_color_table_py, __pyx_n_s_get_byte_size, 10, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__4)) __PYX_ERR(0, 10, __pyx_L1_error)

  /* "ttygif/gif/color_table.py":22
 *         return size
 * 
 *     def read(self,entries):             # <<<<<<<<<<<<<<
 *         self.internal_position=self.stream.pos
 *         self.colors=[]
 */
  __pyx_tuple__5 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_entries, __pyx_n_s_i, __pyx_n_s_red, __pyx_n_s_green, __pyx_n_s_blue); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);
  __pyx_codeobj__6 = (PyObject*)__Pyx_PyCode_New(2, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__5, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_gif_color_table_py, __pyx_n_s_read, 22, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__6)) __PYX_ERR(0, 22, __pyx_L1_error)

  /* "ttygif/gif/color_table.py":31
 *             self.colors.append([red,green,blue])
 * 
 *     def write(self):             # <<<<<<<<<<<<<<
 *         for color in self.colors:
 *             self.stream.write_byte(color[0])
 */
  __pyx_tuple__7 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_color); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);
  __pyx_codeobj__8 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__7, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_gif_color_table_py, __pyx_n_s_write, 31, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__8)) __PYX_ERR(0, 31, __pyx_L1_error)

  /* "ttygif/gif/color_table.py":37
 *             self.stream.write_byte(color[2])
 * 
 *     def new(self,palette=None):             # <<<<<<<<<<<<<<
 *         self.colors=[]
 *         if palette:
 */
  __pyx_tuple__9 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_palette, __pyx_n_s_color_table); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);
  __pyx_codeobj__10 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__9, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_gif_color_table_py, __pyx_n_s_new, 37, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__10)) __PYX_ERR(0, 37, __pyx_L1_error)
  __pyx_tuple__11 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "ttygif/gif/color_table.py":92
 * 
 * 
 *     def debug(self):             # <<<<<<<<<<<<<<
 *         index=0
 *         print("Color Table Block")
 */
  __pyx_tuple__12 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_index, __pyx_n_s_i); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);
  __pyx_codeobj__13 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__12, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ttygif_gif_color_table_py, __pyx_n_s_debug, 92, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__13)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 2, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_18 = PyInt_FromLong(18); if (unlikely(!__pyx_int_18)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_28 = PyInt_FromLong(28); if (unlikely(!__pyx_int_28)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_38 = PyInt_FromLong(38); if (unlikely(!__pyx_int_38)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_48 = PyInt_FromLong(48); if (unlikely(!__pyx_int_48)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_58 = PyInt_FromLong(58); if (unlikely(!__pyx_int_58)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_68 = PyInt_FromLong(68); if (unlikely(!__pyx_int_68)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_78 = PyInt_FromLong(78); if (unlikely(!__pyx_int_78)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_88 = PyInt_FromLong(88); if (unlikely(!__pyx_int_88)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_95 = PyInt_FromLong(95); if (unlikely(!__pyx_int_95)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_98 = PyInt_FromLong(98); if (unlikely(!__pyx_int_98)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_108 = PyInt_FromLong(108); if (unlikely(!__pyx_int_108)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_118 = PyInt_FromLong(118); if (unlikely(!__pyx_int_118)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_135 = PyInt_FromLong(135); if (unlikely(!__pyx_int_135)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_138 = PyInt_FromLong(138); if (unlikely(!__pyx_int_138)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_148 = PyInt_FromLong(148); if (unlikely(!__pyx_int_148)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_158 = PyInt_FromLong(158); if (unlikely(!__pyx_int_158)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_168 = PyInt_FromLong(168); if (unlikely(!__pyx_int_168)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_175 = PyInt_FromLong(175); if (unlikely(!__pyx_int_175)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_178 = PyInt_FromLong(178); if (unlikely(!__pyx_int_178)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_188 = PyInt_FromLong(188); if (unlikely(!__pyx_int_188)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_192 = PyInt_FromLong(192); if (unlikely(!__pyx_int_192)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_198 = PyInt_FromLong(198); if (unlikely(!__pyx_int_198)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_208 = PyInt_FromLong(208); if (unlikely(!__pyx_int_208)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_215 = PyInt_FromLong(215); if (unlikely(!__pyx_int_215)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_218 = PyInt_FromLong(218); if (unlikely(!__pyx_int_218)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_228 = PyInt_FromLong(228); if (unlikely(!__pyx_int_228)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_238 = PyInt_FromLong(238); if (unlikely(!__pyx_int_238)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_255 = PyInt_FromLong(255); if (unlikely(!__pyx_int_255)) __PYX_ERR(0, 2, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION < 3
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC void
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#else
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initcolor_table(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initcolor_table(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_color_table(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_color_table(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_color_table(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'color_table' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_color_table(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 2, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("color_table", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 2, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 2, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 2, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 2, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_ttygif__gif__color_table) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 2, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "ttygif.gif.color_table")) {
      if (unlikely(PyDict_SetItemString(modules, "ttygif.gif.color_table", __pyx_m) < 0)) __PYX_ERR(0, 2, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif

  /* "ttygif/gif/color_table.py":4
 * # array..
 * # ColorTableSize = 3L * (1L << (SizeOfGlobalColorTable + 1));
 * class gif_color_table:             # <<<<<<<<<<<<<<
 *     def __init__(self,stream):
 *         self.stream=stream
 */
  __pyx_t_1 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_gif_color_table, __pyx_n_s_gif_color_table, (PyObject *) NULL, __pyx_n_s_ttygif_gif_color_table, (PyObject *) NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "ttygif/gif/color_table.py":5
 * # ColorTableSize = 3L * (1L << (SizeOfGlobalColorTable + 1));
 * class gif_color_table:
 *     def __init__(self,stream):             # <<<<<<<<<<<<<<
 *         self.stream=stream
 *         self.internal_position=self.stream.pos
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_1__init__, 0, __pyx_n_s_gif_color_table___init, NULL, __pyx_n_s_ttygif_gif_color_table, __pyx_d, ((PyObject *)__pyx_codeobj__2)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":10
 *         self.colors=[]
 * 
 *     def get_byte_size(self):             # <<<<<<<<<<<<<<
 *         colors_len=len(self.colors)
 *         size=0
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_3get_byte_size, 0, __pyx_n_s_gif_color_table_get_byte_size, NULL, __pyx_n_s_ttygif_gif_color_table, __pyx_d, ((PyObject *)__pyx_codeobj__4)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_get_byte_size, __pyx_t_2) < 0) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":22
 *         return size
 * 
 *     def read(self,entries):             # <<<<<<<<<<<<<<
 *         self.internal_position=self.stream.pos
 *         self.colors=[]
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_5read, 0, __pyx_n_s_gif_color_table_read, NULL, __pyx_n_s_ttygif_gif_color_table, __pyx_d, ((PyObject *)__pyx_codeobj__6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_read, __pyx_t_2) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":31
 *             self.colors.append([red,green,blue])
 * 
 *     def write(self):             # <<<<<<<<<<<<<<
 *         for color in self.colors:
 *             self.stream.write_byte(color[0])
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_7write, 0, __pyx_n_s_gif_color_table_write, NULL, __pyx_n_s_ttygif_gif_color_table, __pyx_d, ((PyObject *)__pyx_codeobj__8)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_write, __pyx_t_2) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":37
 *             self.stream.write_byte(color[2])
 * 
 *     def new(self,palette=None):             # <<<<<<<<<<<<<<
 *         self.colors=[]
 *         if palette:
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_9new, 0, __pyx_n_s_gif_color_table_new, NULL, __pyx_n_s_ttygif_gif_color_table, __pyx_d, ((PyObject *)__pyx_codeobj__10)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__11);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_new, __pyx_t_2) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":92
 * 
 * 
 *     def debug(self):             # <<<<<<<<<<<<<<
 *         index=0
 *         print("Color Table Block")
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6ttygif_3gif_11color_table_15gif_color_table_11debug, 0, __pyx_n_s_gif_color_table_debug, NULL, __pyx_n_s_ttygif_gif_color_table, __pyx_d, ((PyObject *)__pyx_codeobj__13)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_debug, __pyx_t_2) < 0) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ttygif/gif/color_table.py":4
 * # array..
 * # ColorTableSize = 3L * (1L << (SizeOfGlobalColorTable + 1));
 * class gif_color_table:             # <<<<<<<<<<<<<<
 *     def __init__(self,stream):
 *         self.stream=stream
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(((PyObject*)&__Pyx_DefaultClassType), __pyx_n_s_gif_color_table, __pyx_empty_tuple, __pyx_t_1, NULL, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_gif_color_table, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ttygif/gif/color_table.py":2
 * 
 * # array..             # <<<<<<<<<<<<<<
 * # ColorTableSize = 3L * (1L << (SizeOfGlobalColorTable + 1));
 * class gif_color_table:
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init ttygif.gif.color_table", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init ttygif.gif.color_table");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunction */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* Print */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static PyObject *__Pyx_GetStdout(void) {
    PyObject *f = PySys_GetObject((char *)"stdout");
    if (!f) {
        PyErr_SetString(PyExc_RuntimeError, "lost sys.stdout");
    }
    return f;
}
static int __Pyx_Print(PyObject* f, PyObject *arg_tuple, int newline) {
    int i;
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    for (i=0; i < PyTuple_GET_SIZE(arg_tuple); i++) {
        PyObject* v;
        if (PyFile_SoftSpace(f, 1)) {
            if (PyFile_WriteString(" ", f) < 0)
                goto error;
        }
        v = PyTuple_GET_ITEM(arg_tuple, i);
        if (PyFile_WriteObject(v, f, Py_PRINT_RAW) < 0)
            goto error;
        if (PyString_Check(v)) {
            char *s = PyString_AsString(v);
            Py_ssize_t len = PyString_Size(v);
            if (len > 0) {
                switch (s[len-1]) {
                    case ' ': break;
                    case '\f': case '\r': case '\n': case '\t': case '\v':
                        PyFile_SoftSpace(f, 0);
                        break;
                    default:  break;
                }
            }
        }
    }
    if (newline) {
        if (PyFile_WriteString("\n", f) < 0)
            goto error;
        PyFile_SoftSpace(f, 0);
    }
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
}
#else
static int __Pyx_Print(PyObject* stream, PyObject *arg_tuple, int newline) {
    PyObject* kwargs = 0;
    PyObject* result = 0;
    PyObject* end_string;
    if (unlikely(!__pyx_print)) {
        __pyx_print = PyObject_GetAttr(__pyx_b, __pyx_n_s_print);
        if (!__pyx_print)
            return -1;
    }
    if (stream) {
        kwargs = PyDict_New();
        if (unlikely(!kwargs))
            return -1;
        if (unlikely(PyDict_SetItem(kwargs, __pyx_n_s_file, stream) < 0))
            goto bad;
        if (!newline) {
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                goto bad;
            if (PyDict_SetItem(kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                goto bad;
            }
            Py_DECREF(end_string);
        }
    } else if (!newline) {
        if (unlikely(!__pyx_print_kwargs)) {
            __pyx_print_kwargs = PyDict_New();
            if (unlikely(!__pyx_print_kwargs))
                return -1;
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                return -1;
            if (PyDict_SetItem(__pyx_print_kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                return -1;
            }
            Py_DECREF(end_string);
        }
        kwargs = __pyx_print_kwargs;
    }
    result = PyObject_Call(__pyx_print, arg_tuple, kwargs);
    if (unlikely(kwargs) && (kwargs != __pyx_print_kwargs))
        Py_DECREF(kwargs);
    if (!result)
        return -1;
    Py_DECREF(result);
    return 0;
bad:
    if (kwargs != __pyx_print_kwargs)
        Py_XDECREF(kwargs);
    return -1;
}
#endif

/* PrintOne */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static int __Pyx_PrintOne(PyObject* f, PyObject *o) {
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    if (PyFile_SoftSpace(f, 0)) {
        if (PyFile_WriteString(" ", f) < 0)
            goto error;
    }
    if (PyFile_WriteObject(o, f, Py_PRINT_RAW) < 0)
        goto error;
    if (PyFile_WriteString("\n", f) < 0)
        goto error;
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
    /* the line below is just to avoid C compiler
     * warnings about unused functions */
    return __Pyx_Print(f, NULL, 0);
}
#else
static int __Pyx_PrintOne(PyObject* stream, PyObject *o) {
    int res;
    PyObject* arg_tuple = PyTuple_Pack(1, o);
    if (unlikely(!arg_tuple))
        return -1;
    res = __Pyx_Print(stream, arg_tuple, 1);
    Py_DECREF(arg_tuple);
    return res;
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
